package main;

use 5.006002;

use strict;
use warnings;

use DateTime;
use DateTime::Fiction::JRRTolkien::Shire;
use Test::More 0.47;	# The best we can do with 5.6.2.
use Time::Local;

plan tests => 70128;

print <<'EOT';
# Created Wed Feb  8 05:16:06 2017 UT
# using Date::Tolkien::Shire 0.02_01
EOT

my ( $dts, $epoch );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 1999-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 1999-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-01 Gregorian' );
Monday 9 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63050832000, 'utc_rd_as_seconds() on 1999-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729755,
  0,
  0
]
, 'utc_rd_values() on 1999-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  2
]
, 'week() on 1999-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 1999-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 1999-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-02 Gregorian' );
Trewsday 10 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63050918400, 'utc_rd_as_seconds() on 1999-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729756,
  0,
  0
]
, 'utc_rd_values() on 1999-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  2
]
, 'week() on 1999-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 1999-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 1999-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-03 Gregorian' );
Hevensday 11 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051004800, 'utc_rd_as_seconds() on 1999-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729757,
  0,
  0
]
, 'utc_rd_values() on 1999-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  2
]
, 'week() on 1999-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 1999-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 1999-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-04 Gregorian' );
Mersday 12 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051091200, 'utc_rd_as_seconds() on 1999-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729758,
  0,
  0
]
, 'utc_rd_values() on 1999-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  2
]
, 'week() on 1999-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 1999-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 1999-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-05 Gregorian' );
Highday 13 Afteryule 7463

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051177600, 'utc_rd_as_seconds() on 1999-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729759,
  0,
  0
]
, 'utc_rd_values() on 1999-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  2
]
, 'week() on 1999-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 1999-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 1999-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-06 Gregorian' );
Sterday 14 Afteryule 7463

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051264000, 'utc_rd_as_seconds() on 1999-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729760,
  0,
  0
]
, 'utc_rd_values() on 1999-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 1999-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 1999-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-07 Gregorian' );
Sunday 15 Afteryule 7463

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051350400, 'utc_rd_as_seconds() on 1999-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729761,
  0,
  0
]
, 'utc_rd_values() on 1999-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 1999-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 1999-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-08 Gregorian' );
Monday 16 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051436800, 'utc_rd_as_seconds() on 1999-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729762,
  0,
  0
]
, 'utc_rd_values() on 1999-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 1999-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 1999-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-09 Gregorian' );
Trewsday 17 Afteryule 7463

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051523200, 'utc_rd_as_seconds() on 1999-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729763,
  0,
  0
]
, 'utc_rd_values() on 1999-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 1999-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 1999-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-10 Gregorian' );
Hevensday 18 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051609600, 'utc_rd_as_seconds() on 1999-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729764,
  0,
  0
]
, 'utc_rd_values() on 1999-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 1999-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 1999-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-11 Gregorian' );
Mersday 19 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051696000, 'utc_rd_as_seconds() on 1999-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729765,
  0,
  0
]
, 'utc_rd_values() on 1999-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 1999-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 1999-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-12 Gregorian' );
Highday 20 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051782400, 'utc_rd_as_seconds() on 1999-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729766,
  0,
  0
]
, 'utc_rd_values() on 1999-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  3
]
, 'week() on 1999-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 1999-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 1999-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 1999-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-13 Gregorian' );
Sterday 21 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051868800, 'utc_rd_as_seconds() on 1999-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729767,
  0,
  0
]
, 'utc_rd_values() on 1999-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 1999-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 1999-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-14 Gregorian' );
Sunday 22 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63051955200, 'utc_rd_as_seconds() on 1999-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729768,
  0,
  0
]
, 'utc_rd_values() on 1999-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 1999-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 1999-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-15 Gregorian' );
Monday 23 Afteryule 7463

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052041600, 'utc_rd_as_seconds() on 1999-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729769,
  0,
  0
]
, 'utc_rd_values() on 1999-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 1999-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 1999-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-16 Gregorian' );
Trewsday 24 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052128000, 'utc_rd_as_seconds() on 1999-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729770,
  0,
  0
]
, 'utc_rd_values() on 1999-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 1999-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 1999-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-17 Gregorian' );
Hevensday 25 Afteryule 7463

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052214400, 'utc_rd_as_seconds() on 1999-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729771,
  0,
  0
]
, 'utc_rd_values() on 1999-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 1999-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 1999-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-18 Gregorian' );
Mersday 26 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052300800, 'utc_rd_as_seconds() on 1999-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729772,
  0,
  0
]
, 'utc_rd_values() on 1999-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 1999-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 1999-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-19 Gregorian' );
Highday 27 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052387200, 'utc_rd_as_seconds() on 1999-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729773,
  0,
  0
]
, 'utc_rd_values() on 1999-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  4
]
, 'week() on 1999-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 1999-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 1999-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 1999-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-20 Gregorian' );
Sterday 28 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052473600, 'utc_rd_as_seconds() on 1999-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729774,
  0,
  0
]
, 'utc_rd_values() on 1999-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 1999-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 1999-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-21 Gregorian' );
Sunday 29 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052560000, 'utc_rd_as_seconds() on 1999-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729775,
  0,
  0
]
, 'utc_rd_values() on 1999-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 1999-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 1999-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-22 Gregorian' );
Monday 30 Afteryule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052646400, 'utc_rd_as_seconds() on 1999-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729776,
  0,
  0
]
, 'utc_rd_values() on 1999-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 1999-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 1999-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-23 Gregorian' );
Trewsday 1 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052732800, 'utc_rd_as_seconds() on 1999-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729777,
  0,
  0
]
, 'utc_rd_values() on 1999-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 1999-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 1999-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-24 Gregorian' );
Hevensday 2 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052819200, 'utc_rd_as_seconds() on 1999-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729778,
  0,
  0
]
, 'utc_rd_values() on 1999-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 1999-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 1999-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-25 Gregorian' );
Mersday 3 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052905600, 'utc_rd_as_seconds() on 1999-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729779,
  0,
  0
]
, 'utc_rd_values() on 1999-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 1999-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 1999-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-26 Gregorian' );
Highday 4 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63052992000, 'utc_rd_as_seconds() on 1999-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729780,
  0,
  0
]
, 'utc_rd_values() on 1999-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  5
]
, 'week() on 1999-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 1999-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 1999-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 1999-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-27 Gregorian' );
Sterday 5 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053078400, 'utc_rd_as_seconds() on 1999-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729781,
  0,
  0
]
, 'utc_rd_values() on 1999-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 1999-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 1999-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-28 Gregorian' );
Sunday 6 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053164800, 'utc_rd_as_seconds() on 1999-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729782,
  0,
  0
]
, 'utc_rd_values() on 1999-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 1999-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 1999-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-29 Gregorian' );
Monday 7 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053251200, 'utc_rd_as_seconds() on 1999-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729783,
  0,
  0
]
, 'utc_rd_values() on 1999-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 1999-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 1999-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-30 Gregorian' );
Trewsday 8 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053337600, 'utc_rd_as_seconds() on 1999-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729784,
  0,
  0
]
, 'utc_rd_values() on 1999-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 1999-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 1999-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-01-31 Gregorian' );
Hevensday 9 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053424000, 'utc_rd_as_seconds() on 1999-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729785,
  0,
  0
]
, 'utc_rd_values() on 1999-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 1999-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 1999-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-01 Gregorian' );
Mersday 10 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053510400, 'utc_rd_as_seconds() on 1999-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729786,
  0,
  0
]
, 'utc_rd_values() on 1999-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 1999-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 1999-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-02 Gregorian' );
Highday 11 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053596800, 'utc_rd_as_seconds() on 1999-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729787,
  0,
  0
]
, 'utc_rd_values() on 1999-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  6
]
, 'week() on 1999-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 1999-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 1999-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 1999-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-03 Gregorian' );
Sterday 12 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053683200, 'utc_rd_as_seconds() on 1999-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729788,
  0,
  0
]
, 'utc_rd_values() on 1999-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 1999-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 1999-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-04 Gregorian' );
Sunday 13 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053769600, 'utc_rd_as_seconds() on 1999-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729789,
  0,
  0
]
, 'utc_rd_values() on 1999-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 1999-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 1999-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-05 Gregorian' );
Monday 14 Solmath 7463

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053856000, 'utc_rd_as_seconds() on 1999-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729790,
  0,
  0
]
, 'utc_rd_values() on 1999-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 1999-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 1999-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-06 Gregorian' );
Trewsday 15 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63053942400, 'utc_rd_as_seconds() on 1999-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729791,
  0,
  0
]
, 'utc_rd_values() on 1999-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 1999-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 1999-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-07 Gregorian' );
Hevensday 16 Solmath 7463

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054028800, 'utc_rd_as_seconds() on 1999-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729792,
  0,
  0
]
, 'utc_rd_values() on 1999-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 1999-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 1999-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-08 Gregorian' );
Mersday 17 Solmath 7463

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054115200, 'utc_rd_as_seconds() on 1999-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729793,
  0,
  0
]
, 'utc_rd_values() on 1999-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 1999-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 1999-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-09 Gregorian' );
Highday 18 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054201600, 'utc_rd_as_seconds() on 1999-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729794,
  0,
  0
]
, 'utc_rd_values() on 1999-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  7
]
, 'week() on 1999-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 1999-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 1999-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 1999-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-10 Gregorian' );
Sterday 19 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054288000, 'utc_rd_as_seconds() on 1999-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729795,
  0,
  0
]
, 'utc_rd_values() on 1999-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 1999-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 1999-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-11 Gregorian' );
Sunday 20 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054374400, 'utc_rd_as_seconds() on 1999-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729796,
  0,
  0
]
, 'utc_rd_values() on 1999-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 1999-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 1999-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-12 Gregorian' );
Monday 21 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054460800, 'utc_rd_as_seconds() on 1999-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729797,
  0,
  0
]
, 'utc_rd_values() on 1999-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 1999-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 1999-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-13 Gregorian' );
Trewsday 22 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054547200, 'utc_rd_as_seconds() on 1999-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729798,
  0,
  0
]
, 'utc_rd_values() on 1999-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 1999-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 1999-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-14 Gregorian' );
Hevensday 23 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054633600, 'utc_rd_as_seconds() on 1999-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729799,
  0,
  0
]
, 'utc_rd_values() on 1999-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 1999-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 1999-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-15 Gregorian' );
Mersday 24 Solmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054720000, 'utc_rd_as_seconds() on 1999-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729800,
  0,
  0
]
, 'utc_rd_values() on 1999-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 1999-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 1999-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-16 Gregorian' );
Highday 25 Solmath 7463

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054806400, 'utc_rd_as_seconds() on 1999-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729801,
  0,
  0
]
, 'utc_rd_values() on 1999-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  8
]
, 'week() on 1999-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 1999-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 1999-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 1999-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-17 Gregorian' );
Sterday 26 Solmath 7463

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054892800, 'utc_rd_as_seconds() on 1999-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729802,
  0,
  0
]
, 'utc_rd_values() on 1999-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 1999-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 1999-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-18 Gregorian' );
Sunday 27 Solmath 7463

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63054979200, 'utc_rd_as_seconds() on 1999-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729803,
  0,
  0
]
, 'utc_rd_values() on 1999-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 1999-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 1999-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-19 Gregorian' );
Monday 28 Solmath 7463

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055065600, 'utc_rd_as_seconds() on 1999-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729804,
  0,
  0
]
, 'utc_rd_values() on 1999-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 1999-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 1999-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-20 Gregorian' );
Trewsday 29 Solmath 7463

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055152000, 'utc_rd_as_seconds() on 1999-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729805,
  0,
  0
]
, 'utc_rd_values() on 1999-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 1999-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 1999-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 1999-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 1999-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-21 Gregorian' );
Hevensday 30 Solmath 7463

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055238400, 'utc_rd_as_seconds() on 1999-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729806,
  0,
  0
]
, 'utc_rd_values() on 1999-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 1999-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 1999-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-22 Gregorian' );
Mersday 1 Rethe 7463

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055324800, 'utc_rd_as_seconds() on 1999-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729807,
  0,
  0
]
, 'utc_rd_values() on 1999-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 1999-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 1999-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-23 Gregorian' );
Highday 2 Rethe 7463

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055411200, 'utc_rd_as_seconds() on 1999-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729808,
  0,
  0
]
, 'utc_rd_values() on 1999-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  9
]
, 'week() on 1999-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 1999-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 1999-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 1999-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-24 Gregorian' );
Sterday 3 Rethe 7463

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055497600, 'utc_rd_as_seconds() on 1999-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729809,
  0,
  0
]
, 'utc_rd_values() on 1999-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 1999-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 1999-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-25 Gregorian' );
Sunday 4 Rethe 7463

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055584000, 'utc_rd_as_seconds() on 1999-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729810,
  0,
  0
]
, 'utc_rd_values() on 1999-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 1999-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 1999-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-26 Gregorian' );
Monday 5 Rethe 7463

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055670400, 'utc_rd_as_seconds() on 1999-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729811,
  0,
  0
]
, 'utc_rd_values() on 1999-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 1999-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 1999-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-27 Gregorian' );
Trewsday 6 Rethe 7463

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055756800, 'utc_rd_as_seconds() on 1999-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729812,
  0,
  0
]
, 'utc_rd_values() on 1999-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 1999-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 1999-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-02-28 Gregorian' );
Hevensday 7 Rethe 7463

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055843200, 'utc_rd_as_seconds() on 1999-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729813,
  0,
  0
]
, 'utc_rd_values() on 1999-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 1999-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 1999-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-01 Gregorian' );
Mersday 8 Rethe 7463

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63055929600, 'utc_rd_as_seconds() on 1999-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729814,
  0,
  0
]
, 'utc_rd_values() on 1999-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 1999-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 1999-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-02 Gregorian' );
Highday 9 Rethe 7463

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056016000, 'utc_rd_as_seconds() on 1999-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729815,
  0,
  0
]
, 'utc_rd_values() on 1999-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  10
]
, 'week() on 1999-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 1999-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 1999-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 1999-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-03 Gregorian' );
Sterday 10 Rethe 7463

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056102400, 'utc_rd_as_seconds() on 1999-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729816,
  0,
  0
]
, 'utc_rd_values() on 1999-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 1999-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 1999-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-04 Gregorian' );
Sunday 11 Rethe 7463

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056188800, 'utc_rd_as_seconds() on 1999-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729817,
  0,
  0
]
, 'utc_rd_values() on 1999-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 1999-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 1999-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-05 Gregorian' );
Monday 12 Rethe 7463

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056275200, 'utc_rd_as_seconds() on 1999-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729818,
  0,
  0
]
, 'utc_rd_values() on 1999-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 1999-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 1999-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-06 Gregorian' );
Trewsday 13 Rethe 7463

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056361600, 'utc_rd_as_seconds() on 1999-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729819,
  0,
  0
]
, 'utc_rd_values() on 1999-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 1999-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 1999-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-07 Gregorian' );
Hevensday 14 Rethe 7463

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056448000, 'utc_rd_as_seconds() on 1999-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729820,
  0,
  0
]
, 'utc_rd_values() on 1999-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 1999-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 1999-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-08 Gregorian' );
Mersday 15 Rethe 7463

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056534400, 'utc_rd_as_seconds() on 1999-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729821,
  0,
  0
]
, 'utc_rd_values() on 1999-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 1999-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 1999-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-09 Gregorian' );
Highday 16 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056620800, 'utc_rd_as_seconds() on 1999-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729822,
  0,
  0
]
, 'utc_rd_values() on 1999-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  11
]
, 'week() on 1999-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 1999-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 1999-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 1999-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-10 Gregorian' );
Sterday 17 Rethe 7463

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056707200, 'utc_rd_as_seconds() on 1999-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729823,
  0,
  0
]
, 'utc_rd_values() on 1999-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 1999-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 1999-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-11 Gregorian' );
Sunday 18 Rethe 7463

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056793600, 'utc_rd_as_seconds() on 1999-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729824,
  0,
  0
]
, 'utc_rd_values() on 1999-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 1999-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 1999-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-12 Gregorian' );
Monday 19 Rethe 7463

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056880000, 'utc_rd_as_seconds() on 1999-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729825,
  0,
  0
]
, 'utc_rd_values() on 1999-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 1999-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 1999-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-13 Gregorian' );
Trewsday 20 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63056966400, 'utc_rd_as_seconds() on 1999-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729826,
  0,
  0
]
, 'utc_rd_values() on 1999-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 1999-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 1999-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-14 Gregorian' );
Hevensday 21 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057052800, 'utc_rd_as_seconds() on 1999-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729827,
  0,
  0
]
, 'utc_rd_values() on 1999-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 1999-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 1999-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-15 Gregorian' );
Mersday 22 Rethe 7463

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057139200, 'utc_rd_as_seconds() on 1999-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729828,
  0,
  0
]
, 'utc_rd_values() on 1999-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 1999-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 1999-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-16 Gregorian' );
Highday 23 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057225600, 'utc_rd_as_seconds() on 1999-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729829,
  0,
  0
]
, 'utc_rd_values() on 1999-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  12
]
, 'week() on 1999-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 1999-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 1999-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 1999-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-17 Gregorian' );
Sterday 24 Rethe 7463

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057312000, 'utc_rd_as_seconds() on 1999-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729830,
  0,
  0
]
, 'utc_rd_values() on 1999-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 1999-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 1999-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-18 Gregorian' );
Sunday 25 Rethe 7463

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057398400, 'utc_rd_as_seconds() on 1999-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729831,
  0,
  0
]
, 'utc_rd_values() on 1999-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 1999-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 1999-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-19 Gregorian' );
Monday 26 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057484800, 'utc_rd_as_seconds() on 1999-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729832,
  0,
  0
]
, 'utc_rd_values() on 1999-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 1999-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 1999-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-20 Gregorian' );
Trewsday 27 Rethe 7463

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057571200, 'utc_rd_as_seconds() on 1999-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729833,
  0,
  0
]
, 'utc_rd_values() on 1999-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 1999-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 1999-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-21 Gregorian' );
Hevensday 28 Rethe 7463

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057657600, 'utc_rd_as_seconds() on 1999-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729834,
  0,
  0
]
, 'utc_rd_values() on 1999-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 1999-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 1999-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-22 Gregorian' );
Mersday 29 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057744000, 'utc_rd_as_seconds() on 1999-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729835,
  0,
  0
]
, 'utc_rd_values() on 1999-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 1999-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 1999-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 1999-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 1999-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-23 Gregorian' );
Highday 30 Rethe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057830400, 'utc_rd_as_seconds() on 1999-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729836,
  0,
  0
]
, 'utc_rd_values() on 1999-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  13
]
, 'week() on 1999-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 1999-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 1999-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 1999-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-24 Gregorian' );
Sterday 1 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63057916800, 'utc_rd_as_seconds() on 1999-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729837,
  0,
  0
]
, 'utc_rd_values() on 1999-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 1999-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 1999-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-25 Gregorian' );
Sunday 2 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058003200, 'utc_rd_as_seconds() on 1999-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729838,
  0,
  0
]
, 'utc_rd_values() on 1999-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 1999-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 1999-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-26 Gregorian' );
Monday 3 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058089600, 'utc_rd_as_seconds() on 1999-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729839,
  0,
  0
]
, 'utc_rd_values() on 1999-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 1999-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 1999-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-27 Gregorian' );
Trewsday 4 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058176000, 'utc_rd_as_seconds() on 1999-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729840,
  0,
  0
]
, 'utc_rd_values() on 1999-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 1999-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 1999-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-28 Gregorian' );
Hevensday 5 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058262400, 'utc_rd_as_seconds() on 1999-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729841,
  0,
  0
]
, 'utc_rd_values() on 1999-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 1999-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 1999-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-29 Gregorian' );
Mersday 6 Astron 7463

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058348800, 'utc_rd_as_seconds() on 1999-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729842,
  0,
  0
]
, 'utc_rd_values() on 1999-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 1999-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 1999-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-30 Gregorian' );
Highday 7 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058435200, 'utc_rd_as_seconds() on 1999-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729843,
  0,
  0
]
, 'utc_rd_values() on 1999-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  14
]
, 'week() on 1999-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 1999-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 1999-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 1999-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-03-31 Gregorian' );
Sterday 8 Astron 7463

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058521600, 'utc_rd_as_seconds() on 1999-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729844,
  0,
  0
]
, 'utc_rd_values() on 1999-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 1999-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 1999-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-01 Gregorian' );
Sunday 9 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058608000, 'utc_rd_as_seconds() on 1999-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729845,
  0,
  0
]
, 'utc_rd_values() on 1999-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 1999-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 1999-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-02 Gregorian' );
Monday 10 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058694400, 'utc_rd_as_seconds() on 1999-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729846,
  0,
  0
]
, 'utc_rd_values() on 1999-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 1999-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 1999-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-03 Gregorian' );
Trewsday 11 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058780800, 'utc_rd_as_seconds() on 1999-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729847,
  0,
  0
]
, 'utc_rd_values() on 1999-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 1999-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 1999-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-04 Gregorian' );
Hevensday 12 Astron 7463

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058867200, 'utc_rd_as_seconds() on 1999-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729848,
  0,
  0
]
, 'utc_rd_values() on 1999-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 1999-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 1999-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-05 Gregorian' );
Mersday 13 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63058953600, 'utc_rd_as_seconds() on 1999-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729849,
  0,
  0
]
, 'utc_rd_values() on 1999-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 1999-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 1999-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-06 Gregorian' );
Highday 14 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059040000, 'utc_rd_as_seconds() on 1999-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729850,
  0,
  0
]
, 'utc_rd_values() on 1999-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  15
]
, 'week() on 1999-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 1999-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 1999-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 1999-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-07 Gregorian' );
Sterday 15 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059126400, 'utc_rd_as_seconds() on 1999-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729851,
  0,
  0
]
, 'utc_rd_values() on 1999-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 1999-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 1999-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-08 Gregorian' );
Sunday 16 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059212800, 'utc_rd_as_seconds() on 1999-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729852,
  0,
  0
]
, 'utc_rd_values() on 1999-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 1999-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 1999-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-09 Gregorian' );
Monday 17 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059299200, 'utc_rd_as_seconds() on 1999-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729853,
  0,
  0
]
, 'utc_rd_values() on 1999-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 1999-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 1999-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-10 Gregorian' );
Trewsday 18 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059385600, 'utc_rd_as_seconds() on 1999-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729854,
  0,
  0
]
, 'utc_rd_values() on 1999-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 1999-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 1999-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-11 Gregorian' );
Hevensday 19 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059472000, 'utc_rd_as_seconds() on 1999-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729855,
  0,
  0
]
, 'utc_rd_values() on 1999-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 1999-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 1999-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-12 Gregorian' );
Mersday 20 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059558400, 'utc_rd_as_seconds() on 1999-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729856,
  0,
  0
]
, 'utc_rd_values() on 1999-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 1999-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 1999-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-13 Gregorian' );
Highday 21 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059644800, 'utc_rd_as_seconds() on 1999-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729857,
  0,
  0
]
, 'utc_rd_values() on 1999-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  16
]
, 'week() on 1999-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 1999-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 1999-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 1999-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-14 Gregorian' );
Sterday 22 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059731200, 'utc_rd_as_seconds() on 1999-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729858,
  0,
  0
]
, 'utc_rd_values() on 1999-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 1999-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 1999-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-15 Gregorian' );
Sunday 23 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059817600, 'utc_rd_as_seconds() on 1999-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729859,
  0,
  0
]
, 'utc_rd_values() on 1999-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 1999-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 1999-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-16 Gregorian' );
Monday 24 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059904000, 'utc_rd_as_seconds() on 1999-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729860,
  0,
  0
]
, 'utc_rd_values() on 1999-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 1999-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 1999-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-17 Gregorian' );
Trewsday 25 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63059990400, 'utc_rd_as_seconds() on 1999-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729861,
  0,
  0
]
, 'utc_rd_values() on 1999-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 1999-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 1999-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-18 Gregorian' );
Hevensday 26 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060076800, 'utc_rd_as_seconds() on 1999-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729862,
  0,
  0
]
, 'utc_rd_values() on 1999-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 1999-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 1999-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-19 Gregorian' );
Mersday 27 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060163200, 'utc_rd_as_seconds() on 1999-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729863,
  0,
  0
]
, 'utc_rd_values() on 1999-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 1999-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 1999-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-20 Gregorian' );
Highday 28 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060249600, 'utc_rd_as_seconds() on 1999-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729864,
  0,
  0
]
, 'utc_rd_values() on 1999-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  17
]
, 'week() on 1999-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 1999-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 1999-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 1999-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-21 Gregorian' );
Sterday 29 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060336000, 'utc_rd_as_seconds() on 1999-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729865,
  0,
  0
]
, 'utc_rd_values() on 1999-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 1999-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 1999-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 1999-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 1999-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-22 Gregorian' );
Sunday 30 Astron 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060422400, 'utc_rd_as_seconds() on 1999-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729866,
  0,
  0
]
, 'utc_rd_values() on 1999-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 1999-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 1999-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-23 Gregorian' );
Monday 1 Thrimidge 7463

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060508800, 'utc_rd_as_seconds() on 1999-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729867,
  0,
  0
]
, 'utc_rd_values() on 1999-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 1999-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 1999-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-24 Gregorian' );
Trewsday 2 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060595200, 'utc_rd_as_seconds() on 1999-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729868,
  0,
  0
]
, 'utc_rd_values() on 1999-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 1999-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 1999-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-25 Gregorian' );
Hevensday 3 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060681600, 'utc_rd_as_seconds() on 1999-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729869,
  0,
  0
]
, 'utc_rd_values() on 1999-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 1999-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 1999-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-26 Gregorian' );
Mersday 4 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060768000, 'utc_rd_as_seconds() on 1999-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729870,
  0,
  0
]
, 'utc_rd_values() on 1999-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 1999-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 1999-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-27 Gregorian' );
Highday 5 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060854400, 'utc_rd_as_seconds() on 1999-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729871,
  0,
  0
]
, 'utc_rd_values() on 1999-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  18
]
, 'week() on 1999-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 1999-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 1999-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 1999-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-28 Gregorian' );
Sterday 6 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63060940800, 'utc_rd_as_seconds() on 1999-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729872,
  0,
  0
]
, 'utc_rd_values() on 1999-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 1999-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 1999-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-29 Gregorian' );
Sunday 7 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061027200, 'utc_rd_as_seconds() on 1999-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729873,
  0,
  0
]
, 'utc_rd_values() on 1999-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 1999-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 1999-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-04-30 Gregorian' );
Monday 8 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061113600, 'utc_rd_as_seconds() on 1999-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729874,
  0,
  0
]
, 'utc_rd_values() on 1999-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 1999-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 1999-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-01 Gregorian' );
Trewsday 9 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061200000, 'utc_rd_as_seconds() on 1999-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729875,
  0,
  0
]
, 'utc_rd_values() on 1999-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 1999-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 1999-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-02 Gregorian' );
Hevensday 10 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061286400, 'utc_rd_as_seconds() on 1999-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729876,
  0,
  0
]
, 'utc_rd_values() on 1999-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 1999-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 1999-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-03 Gregorian' );
Mersday 11 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061372800, 'utc_rd_as_seconds() on 1999-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729877,
  0,
  0
]
, 'utc_rd_values() on 1999-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 1999-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 1999-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-04 Gregorian' );
Highday 12 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061459200, 'utc_rd_as_seconds() on 1999-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729878,
  0,
  0
]
, 'utc_rd_values() on 1999-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  19
]
, 'week() on 1999-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 1999-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 1999-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 1999-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-05 Gregorian' );
Sterday 13 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061545600, 'utc_rd_as_seconds() on 1999-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729879,
  0,
  0
]
, 'utc_rd_values() on 1999-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 1999-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 1999-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-06 Gregorian' );
Sunday 14 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061632000, 'utc_rd_as_seconds() on 1999-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729880,
  0,
  0
]
, 'utc_rd_values() on 1999-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 1999-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 1999-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-07 Gregorian' );
Monday 15 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061718400, 'utc_rd_as_seconds() on 1999-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729881,
  0,
  0
]
, 'utc_rd_values() on 1999-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 1999-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 1999-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-08 Gregorian' );
Trewsday 16 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061804800, 'utc_rd_as_seconds() on 1999-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729882,
  0,
  0
]
, 'utc_rd_values() on 1999-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 1999-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 1999-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-09 Gregorian' );
Hevensday 17 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061891200, 'utc_rd_as_seconds() on 1999-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729883,
  0,
  0
]
, 'utc_rd_values() on 1999-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 1999-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 1999-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-10 Gregorian' );
Mersday 18 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63061977600, 'utc_rd_as_seconds() on 1999-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729884,
  0,
  0
]
, 'utc_rd_values() on 1999-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 1999-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 1999-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-11 Gregorian' );
Highday 19 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062064000, 'utc_rd_as_seconds() on 1999-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729885,
  0,
  0
]
, 'utc_rd_values() on 1999-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  20
]
, 'week() on 1999-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 1999-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 1999-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 1999-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-12 Gregorian' );
Sterday 20 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062150400, 'utc_rd_as_seconds() on 1999-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729886,
  0,
  0
]
, 'utc_rd_values() on 1999-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 1999-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 1999-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-13 Gregorian' );
Sunday 21 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062236800, 'utc_rd_as_seconds() on 1999-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729887,
  0,
  0
]
, 'utc_rd_values() on 1999-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 1999-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 1999-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-14 Gregorian' );
Monday 22 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062323200, 'utc_rd_as_seconds() on 1999-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729888,
  0,
  0
]
, 'utc_rd_values() on 1999-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 1999-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 1999-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-15 Gregorian' );
Trewsday 23 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062409600, 'utc_rd_as_seconds() on 1999-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729889,
  0,
  0
]
, 'utc_rd_values() on 1999-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 1999-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 1999-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-16 Gregorian' );
Hevensday 24 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062496000, 'utc_rd_as_seconds() on 1999-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729890,
  0,
  0
]
, 'utc_rd_values() on 1999-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 1999-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 1999-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-17 Gregorian' );
Mersday 25 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062582400, 'utc_rd_as_seconds() on 1999-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729891,
  0,
  0
]
, 'utc_rd_values() on 1999-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 1999-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 1999-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-18 Gregorian' );
Highday 26 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062668800, 'utc_rd_as_seconds() on 1999-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729892,
  0,
  0
]
, 'utc_rd_values() on 1999-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  21
]
, 'week() on 1999-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 1999-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 1999-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 1999-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-19 Gregorian' );
Sterday 27 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062755200, 'utc_rd_as_seconds() on 1999-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729893,
  0,
  0
]
, 'utc_rd_values() on 1999-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 1999-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 1999-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-20 Gregorian' );
Sunday 28 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062841600, 'utc_rd_as_seconds() on 1999-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729894,
  0,
  0
]
, 'utc_rd_values() on 1999-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 1999-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 1999-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-21 Gregorian' );
Monday 29 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63062928000, 'utc_rd_as_seconds() on 1999-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729895,
  0,
  0
]
, 'utc_rd_values() on 1999-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 1999-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 1999-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 1999-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 1999-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-22 Gregorian' );
Trewsday 30 Thrimidge 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063014400, 'utc_rd_as_seconds() on 1999-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729896,
  0,
  0
]
, 'utc_rd_values() on 1999-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 1999-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 1999-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-23 Gregorian' );
Hevensday 1 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063100800, 'utc_rd_as_seconds() on 1999-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729897,
  0,
  0
]
, 'utc_rd_values() on 1999-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 1999-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 1999-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-24 Gregorian' );
Mersday 2 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063187200, 'utc_rd_as_seconds() on 1999-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729898,
  0,
  0
]
, 'utc_rd_values() on 1999-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 1999-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 1999-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-25 Gregorian' );
Highday 3 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063273600, 'utc_rd_as_seconds() on 1999-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729899,
  0,
  0
]
, 'utc_rd_values() on 1999-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  22
]
, 'week() on 1999-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 1999-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 1999-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 1999-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-26 Gregorian' );
Sterday 4 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063360000, 'utc_rd_as_seconds() on 1999-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729900,
  0,
  0
]
, 'utc_rd_values() on 1999-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 1999-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 1999-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-27 Gregorian' );
Sunday 5 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063446400, 'utc_rd_as_seconds() on 1999-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729901,
  0,
  0
]
, 'utc_rd_values() on 1999-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 1999-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 1999-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-28 Gregorian' );
Monday 6 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063532800, 'utc_rd_as_seconds() on 1999-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729902,
  0,
  0
]
, 'utc_rd_values() on 1999-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 1999-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 1999-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-29 Gregorian' );
Trewsday 7 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063619200, 'utc_rd_as_seconds() on 1999-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729903,
  0,
  0
]
, 'utc_rd_values() on 1999-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 1999-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 1999-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-30 Gregorian' );
Hevensday 8 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063705600, 'utc_rd_as_seconds() on 1999-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729904,
  0,
  0
]
, 'utc_rd_values() on 1999-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 1999-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 1999-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-05-31 Gregorian' );
Mersday 9 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063792000, 'utc_rd_as_seconds() on 1999-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729905,
  0,
  0
]
, 'utc_rd_values() on 1999-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 1999-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 1999-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-01 Gregorian' );
Highday 10 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063878400, 'utc_rd_as_seconds() on 1999-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729906,
  0,
  0
]
, 'utc_rd_values() on 1999-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  23
]
, 'week() on 1999-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 1999-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 1999-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 1999-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-02 Gregorian' );
Sterday 11 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63063964800, 'utc_rd_as_seconds() on 1999-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729907,
  0,
  0
]
, 'utc_rd_values() on 1999-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 1999-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 1999-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-03 Gregorian' );
Sunday 12 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064051200, 'utc_rd_as_seconds() on 1999-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729908,
  0,
  0
]
, 'utc_rd_values() on 1999-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 1999-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 1999-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-04 Gregorian' );
Monday 13 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064137600, 'utc_rd_as_seconds() on 1999-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729909,
  0,
  0
]
, 'utc_rd_values() on 1999-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 1999-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 1999-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-05 Gregorian' );
Trewsday 14 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064224000, 'utc_rd_as_seconds() on 1999-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729910,
  0,
  0
]
, 'utc_rd_values() on 1999-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 1999-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 1999-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-06 Gregorian' );
Hevensday 15 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064310400, 'utc_rd_as_seconds() on 1999-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729911,
  0,
  0
]
, 'utc_rd_values() on 1999-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 1999-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 1999-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-07 Gregorian' );
Mersday 16 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064396800, 'utc_rd_as_seconds() on 1999-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729912,
  0,
  0
]
, 'utc_rd_values() on 1999-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 1999-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 1999-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-08 Gregorian' );
Highday 17 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064483200, 'utc_rd_as_seconds() on 1999-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729913,
  0,
  0
]
, 'utc_rd_values() on 1999-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  24
]
, 'week() on 1999-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 1999-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 1999-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 1999-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-09 Gregorian' );
Sterday 18 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064569600, 'utc_rd_as_seconds() on 1999-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729914,
  0,
  0
]
, 'utc_rd_values() on 1999-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 1999-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 1999-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-10 Gregorian' );
Sunday 19 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064656000, 'utc_rd_as_seconds() on 1999-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729915,
  0,
  0
]
, 'utc_rd_values() on 1999-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 1999-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 1999-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-11 Gregorian' );
Monday 20 Forelithe 7463

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064742400, 'utc_rd_as_seconds() on 1999-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729916,
  0,
  0
]
, 'utc_rd_values() on 1999-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 1999-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 1999-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-12 Gregorian' );
Trewsday 21 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064828800, 'utc_rd_as_seconds() on 1999-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729917,
  0,
  0
]
, 'utc_rd_values() on 1999-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 1999-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 1999-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-13 Gregorian' );
Hevensday 22 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63064915200, 'utc_rd_as_seconds() on 1999-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729918,
  0,
  0
]
, 'utc_rd_values() on 1999-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 1999-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 1999-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-14 Gregorian' );
Mersday 23 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065001600, 'utc_rd_as_seconds() on 1999-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729919,
  0,
  0
]
, 'utc_rd_values() on 1999-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 1999-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 1999-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-15 Gregorian' );
Highday 24 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065088000, 'utc_rd_as_seconds() on 1999-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729920,
  0,
  0
]
, 'utc_rd_values() on 1999-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  25
]
, 'week() on 1999-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 1999-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 1999-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 1999-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-16 Gregorian' );
Sterday 25 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065174400, 'utc_rd_as_seconds() on 1999-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729921,
  0,
  0
]
, 'utc_rd_values() on 1999-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 1999-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 1999-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-17 Gregorian' );
Sunday 26 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065260800, 'utc_rd_as_seconds() on 1999-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729922,
  0,
  0
]
, 'utc_rd_values() on 1999-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 1999-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 1999-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-18 Gregorian' );
Monday 27 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065347200, 'utc_rd_as_seconds() on 1999-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729923,
  0,
  0
]
, 'utc_rd_values() on 1999-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 1999-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 1999-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-19 Gregorian' );
Trewsday 28 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065433600, 'utc_rd_as_seconds() on 1999-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729924,
  0,
  0
]
, 'utc_rd_values() on 1999-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 1999-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 1999-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-20 Gregorian' );
Hevensday 29 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065520000, 'utc_rd_as_seconds() on 1999-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729925,
  0,
  0
]
, 'utc_rd_values() on 1999-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 1999-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 1999-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 1999-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 1999-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-21 Gregorian' );
Mersday 30 Forelithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065606400, 'utc_rd_as_seconds() on 1999-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729926,
  0,
  0
]
, 'utc_rd_values() on 1999-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 1999-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 1999-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 1999-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 1999-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 1999-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 1999-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 1999-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 1999-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 1999-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-22 Gregorian' );
Highday 1 Lithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065692800, 'utc_rd_as_seconds() on 1999-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729927,
  0,
  0
]
, 'utc_rd_values() on 1999-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  26
]
, 'week() on 1999-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 1999-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 1999-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 1999-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 1999-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 1999-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 1999-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 1999-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 1999-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 1999-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 1999-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 1999-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 1999-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 1999-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 1999-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-23 Gregorian' );
Midyear's day 7463

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065779200, 'utc_rd_as_seconds() on 1999-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729928,
  0,
  0
]
, 'utc_rd_values() on 1999-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 1999-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  0
]
, 'week() on 1999-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 1999-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 1999-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 1999-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 1999-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 1999-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 1999-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 1999-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 1999-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 1999-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 1999-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-24 Gregorian' );
Sterday 2 Lithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065865600, 'utc_rd_as_seconds() on 1999-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729929,
  0,
  0
]
, 'utc_rd_values() on 1999-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 1999-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 1999-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-25 Gregorian' );
Sunday 1 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63065952000, 'utc_rd_as_seconds() on 1999-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729930,
  0,
  0
]
, 'utc_rd_values() on 1999-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 1999-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 1999-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-26 Gregorian' );
Monday 2 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066038400, 'utc_rd_as_seconds() on 1999-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729931,
  0,
  0
]
, 'utc_rd_values() on 1999-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 1999-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 1999-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-27 Gregorian' );
Trewsday 3 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066124800, 'utc_rd_as_seconds() on 1999-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729932,
  0,
  0
]
, 'utc_rd_values() on 1999-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 1999-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 1999-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-28 Gregorian' );
Hevensday 4 Afterlithe 7463

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066211200, 'utc_rd_as_seconds() on 1999-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729933,
  0,
  0
]
, 'utc_rd_values() on 1999-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 1999-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 1999-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-29 Gregorian' );
Mersday 5 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066297600, 'utc_rd_as_seconds() on 1999-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729934,
  0,
  0
]
, 'utc_rd_values() on 1999-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 1999-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 1999-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-06-30 Gregorian' );
Highday 6 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066384000, 'utc_rd_as_seconds() on 1999-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729935,
  0,
  0
]
, 'utc_rd_values() on 1999-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  27
]
, 'week() on 1999-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 1999-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 1999-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 1999-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-01 Gregorian' );
Sterday 7 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066470400, 'utc_rd_as_seconds() on 1999-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729936,
  0,
  0
]
, 'utc_rd_values() on 1999-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 1999-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 1999-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-02 Gregorian' );
Sunday 8 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066556800, 'utc_rd_as_seconds() on 1999-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729937,
  0,
  0
]
, 'utc_rd_values() on 1999-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 1999-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 1999-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-03 Gregorian' );
Monday 9 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066643200, 'utc_rd_as_seconds() on 1999-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729938,
  0,
  0
]
, 'utc_rd_values() on 1999-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 1999-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 1999-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-04 Gregorian' );
Trewsday 10 Afterlithe 7463

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066729600, 'utc_rd_as_seconds() on 1999-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729939,
  0,
  0
]
, 'utc_rd_values() on 1999-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 1999-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 1999-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-05 Gregorian' );
Hevensday 11 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066816000, 'utc_rd_as_seconds() on 1999-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729940,
  0,
  0
]
, 'utc_rd_values() on 1999-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 1999-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 1999-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-06 Gregorian' );
Mersday 12 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066902400, 'utc_rd_as_seconds() on 1999-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729941,
  0,
  0
]
, 'utc_rd_values() on 1999-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 1999-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 1999-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-07 Gregorian' );
Highday 13 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63066988800, 'utc_rd_as_seconds() on 1999-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729942,
  0,
  0
]
, 'utc_rd_values() on 1999-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  28
]
, 'week() on 1999-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 1999-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 1999-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 1999-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-08 Gregorian' );
Sterday 14 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067075200, 'utc_rd_as_seconds() on 1999-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729943,
  0,
  0
]
, 'utc_rd_values() on 1999-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 1999-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 1999-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-09 Gregorian' );
Sunday 15 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067161600, 'utc_rd_as_seconds() on 1999-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729944,
  0,
  0
]
, 'utc_rd_values() on 1999-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 1999-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 1999-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-10 Gregorian' );
Monday 16 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067248000, 'utc_rd_as_seconds() on 1999-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729945,
  0,
  0
]
, 'utc_rd_values() on 1999-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 1999-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 1999-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-11 Gregorian' );
Trewsday 17 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067334400, 'utc_rd_as_seconds() on 1999-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729946,
  0,
  0
]
, 'utc_rd_values() on 1999-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 1999-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 1999-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-12 Gregorian' );
Hevensday 18 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067420800, 'utc_rd_as_seconds() on 1999-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729947,
  0,
  0
]
, 'utc_rd_values() on 1999-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 1999-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 1999-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-13 Gregorian' );
Mersday 19 Afterlithe 7463

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067507200, 'utc_rd_as_seconds() on 1999-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729948,
  0,
  0
]
, 'utc_rd_values() on 1999-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 1999-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 1999-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-14 Gregorian' );
Highday 20 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067593600, 'utc_rd_as_seconds() on 1999-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729949,
  0,
  0
]
, 'utc_rd_values() on 1999-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  29
]
, 'week() on 1999-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 1999-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 1999-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 1999-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-15 Gregorian' );
Sterday 21 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067680000, 'utc_rd_as_seconds() on 1999-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729950,
  0,
  0
]
, 'utc_rd_values() on 1999-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 1999-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 1999-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-16 Gregorian' );
Sunday 22 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067766400, 'utc_rd_as_seconds() on 1999-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729951,
  0,
  0
]
, 'utc_rd_values() on 1999-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 1999-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 1999-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-17 Gregorian' );
Monday 23 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067852800, 'utc_rd_as_seconds() on 1999-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729952,
  0,
  0
]
, 'utc_rd_values() on 1999-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 1999-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 1999-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-18 Gregorian' );
Trewsday 24 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63067939200, 'utc_rd_as_seconds() on 1999-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729953,
  0,
  0
]
, 'utc_rd_values() on 1999-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 1999-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 1999-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-19 Gregorian' );
Hevensday 25 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068025600, 'utc_rd_as_seconds() on 1999-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729954,
  0,
  0
]
, 'utc_rd_values() on 1999-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 1999-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 1999-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-20 Gregorian' );
Mersday 26 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068112000, 'utc_rd_as_seconds() on 1999-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729955,
  0,
  0
]
, 'utc_rd_values() on 1999-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 1999-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 1999-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-21 Gregorian' );
Highday 27 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068198400, 'utc_rd_as_seconds() on 1999-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729956,
  0,
  0
]
, 'utc_rd_values() on 1999-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  30
]
, 'week() on 1999-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 1999-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 1999-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 1999-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-22 Gregorian' );
Sterday 28 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068284800, 'utc_rd_as_seconds() on 1999-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729957,
  0,
  0
]
, 'utc_rd_values() on 1999-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 1999-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 1999-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-23 Gregorian' );
Sunday 29 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068371200, 'utc_rd_as_seconds() on 1999-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729958,
  0,
  0
]
, 'utc_rd_values() on 1999-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 1999-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 1999-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 1999-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 1999-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-24 Gregorian' );
Monday 30 Afterlithe 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068457600, 'utc_rd_as_seconds() on 1999-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729959,
  0,
  0
]
, 'utc_rd_values() on 1999-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 1999-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 1999-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-25 Gregorian' );
Trewsday 1 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068544000, 'utc_rd_as_seconds() on 1999-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729960,
  0,
  0
]
, 'utc_rd_values() on 1999-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 1999-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 1999-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-26 Gregorian' );
Hevensday 2 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068630400, 'utc_rd_as_seconds() on 1999-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729961,
  0,
  0
]
, 'utc_rd_values() on 1999-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 1999-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 1999-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-27 Gregorian' );
Mersday 3 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068716800, 'utc_rd_as_seconds() on 1999-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729962,
  0,
  0
]
, 'utc_rd_values() on 1999-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 1999-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 1999-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-28 Gregorian' );
Highday 4 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068803200, 'utc_rd_as_seconds() on 1999-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729963,
  0,
  0
]
, 'utc_rd_values() on 1999-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  31
]
, 'week() on 1999-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 1999-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 1999-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 1999-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-29 Gregorian' );
Sterday 5 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068889600, 'utc_rd_as_seconds() on 1999-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729964,
  0,
  0
]
, 'utc_rd_values() on 1999-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 1999-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 1999-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-30 Gregorian' );
Sunday 6 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63068976000, 'utc_rd_as_seconds() on 1999-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729965,
  0,
  0
]
, 'utc_rd_values() on 1999-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 1999-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 1999-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-07-31 Gregorian' );
Monday 7 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069062400, 'utc_rd_as_seconds() on 1999-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729966,
  0,
  0
]
, 'utc_rd_values() on 1999-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 1999-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 1999-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-01 Gregorian' );
Trewsday 8 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069148800, 'utc_rd_as_seconds() on 1999-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729967,
  0,
  0
]
, 'utc_rd_values() on 1999-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 1999-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 1999-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-02 Gregorian' );
Hevensday 9 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069235200, 'utc_rd_as_seconds() on 1999-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729968,
  0,
  0
]
, 'utc_rd_values() on 1999-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 1999-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 1999-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-03 Gregorian' );
Mersday 10 Wedmath 7463

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069321600, 'utc_rd_as_seconds() on 1999-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729969,
  0,
  0
]
, 'utc_rd_values() on 1999-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 1999-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 1999-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-04 Gregorian' );
Highday 11 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069408000, 'utc_rd_as_seconds() on 1999-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729970,
  0,
  0
]
, 'utc_rd_values() on 1999-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  32
]
, 'week() on 1999-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 1999-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 1999-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 1999-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-05 Gregorian' );
Sterday 12 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069494400, 'utc_rd_as_seconds() on 1999-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729971,
  0,
  0
]
, 'utc_rd_values() on 1999-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 1999-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 1999-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-06 Gregorian' );
Sunday 13 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069580800, 'utc_rd_as_seconds() on 1999-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729972,
  0,
  0
]
, 'utc_rd_values() on 1999-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 1999-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 1999-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-07 Gregorian' );
Monday 14 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069667200, 'utc_rd_as_seconds() on 1999-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729973,
  0,
  0
]
, 'utc_rd_values() on 1999-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 1999-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 1999-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-08 Gregorian' );
Trewsday 15 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069753600, 'utc_rd_as_seconds() on 1999-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729974,
  0,
  0
]
, 'utc_rd_values() on 1999-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 1999-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 1999-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-09 Gregorian' );
Hevensday 16 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069840000, 'utc_rd_as_seconds() on 1999-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729975,
  0,
  0
]
, 'utc_rd_values() on 1999-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 1999-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 1999-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-10 Gregorian' );
Mersday 17 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63069926400, 'utc_rd_as_seconds() on 1999-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729976,
  0,
  0
]
, 'utc_rd_values() on 1999-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 1999-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 1999-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-11 Gregorian' );
Highday 18 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070012800, 'utc_rd_as_seconds() on 1999-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729977,
  0,
  0
]
, 'utc_rd_values() on 1999-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  33
]
, 'week() on 1999-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 1999-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 1999-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 1999-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-12 Gregorian' );
Sterday 19 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070099200, 'utc_rd_as_seconds() on 1999-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729978,
  0,
  0
]
, 'utc_rd_values() on 1999-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 1999-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 1999-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-13 Gregorian' );
Sunday 20 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070185600, 'utc_rd_as_seconds() on 1999-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729979,
  0,
  0
]
, 'utc_rd_values() on 1999-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 1999-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 1999-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-14 Gregorian' );
Monday 21 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070272000, 'utc_rd_as_seconds() on 1999-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729980,
  0,
  0
]
, 'utc_rd_values() on 1999-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 1999-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 1999-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-15 Gregorian' );
Trewsday 22 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070358400, 'utc_rd_as_seconds() on 1999-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729981,
  0,
  0
]
, 'utc_rd_values() on 1999-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 1999-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 1999-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-16 Gregorian' );
Hevensday 23 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070444800, 'utc_rd_as_seconds() on 1999-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729982,
  0,
  0
]
, 'utc_rd_values() on 1999-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 1999-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 1999-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-17 Gregorian' );
Mersday 24 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070531200, 'utc_rd_as_seconds() on 1999-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729983,
  0,
  0
]
, 'utc_rd_values() on 1999-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 1999-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 1999-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-18 Gregorian' );
Highday 25 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070617600, 'utc_rd_as_seconds() on 1999-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729984,
  0,
  0
]
, 'utc_rd_values() on 1999-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  34
]
, 'week() on 1999-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 1999-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 1999-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 1999-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-19 Gregorian' );
Sterday 26 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070704000, 'utc_rd_as_seconds() on 1999-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729985,
  0,
  0
]
, 'utc_rd_values() on 1999-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 1999-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 1999-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-20 Gregorian' );
Sunday 27 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070790400, 'utc_rd_as_seconds() on 1999-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729986,
  0,
  0
]
, 'utc_rd_values() on 1999-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 1999-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 1999-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-21 Gregorian' );
Monday 28 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070876800, 'utc_rd_as_seconds() on 1999-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729987,
  0,
  0
]
, 'utc_rd_values() on 1999-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 1999-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 1999-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-22 Gregorian' );
Trewsday 29 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63070963200, 'utc_rd_as_seconds() on 1999-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729988,
  0,
  0
]
, 'utc_rd_values() on 1999-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 1999-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 1999-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 1999-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 1999-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-23 Gregorian' );
Hevensday 30 Wedmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071049600, 'utc_rd_as_seconds() on 1999-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729989,
  0,
  0
]
, 'utc_rd_values() on 1999-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 1999-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 1999-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-24 Gregorian' );
Mersday 1 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071136000, 'utc_rd_as_seconds() on 1999-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729990,
  0,
  0
]
, 'utc_rd_values() on 1999-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 1999-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 1999-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-25 Gregorian' );
Highday 2 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071222400, 'utc_rd_as_seconds() on 1999-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729991,
  0,
  0
]
, 'utc_rd_values() on 1999-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  35
]
, 'week() on 1999-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 1999-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 1999-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 1999-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-26 Gregorian' );
Sterday 3 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071308800, 'utc_rd_as_seconds() on 1999-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729992,
  0,
  0
]
, 'utc_rd_values() on 1999-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 1999-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 1999-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-27 Gregorian' );
Sunday 4 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071395200, 'utc_rd_as_seconds() on 1999-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729993,
  0,
  0
]
, 'utc_rd_values() on 1999-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 1999-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 1999-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-28 Gregorian' );
Monday 5 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071481600, 'utc_rd_as_seconds() on 1999-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729994,
  0,
  0
]
, 'utc_rd_values() on 1999-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 1999-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 1999-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-29 Gregorian' );
Trewsday 6 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071568000, 'utc_rd_as_seconds() on 1999-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729995,
  0,
  0
]
, 'utc_rd_values() on 1999-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 1999-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 1999-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-30 Gregorian' );
Hevensday 7 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071654400, 'utc_rd_as_seconds() on 1999-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729996,
  0,
  0
]
, 'utc_rd_values() on 1999-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 1999-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 1999-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-08-31 Gregorian' );
Mersday 8 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071740800, 'utc_rd_as_seconds() on 1999-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729997,
  0,
  0
]
, 'utc_rd_values() on 1999-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 1999-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 1999-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-01 Gregorian' );
Highday 9 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071827200, 'utc_rd_as_seconds() on 1999-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729998,
  0,
  0
]
, 'utc_rd_values() on 1999-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  36
]
, 'week() on 1999-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 1999-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 1999-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 1999-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-02 Gregorian' );
Sterday 10 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63071913600, 'utc_rd_as_seconds() on 1999-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  729999,
  0,
  0
]
, 'utc_rd_values() on 1999-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 1999-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 1999-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-03 Gregorian' );
Sunday 11 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072000000, 'utc_rd_as_seconds() on 1999-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730000,
  0,
  0
]
, 'utc_rd_values() on 1999-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 1999-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 1999-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-04 Gregorian' );
Monday 12 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072086400, 'utc_rd_as_seconds() on 1999-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730001,
  0,
  0
]
, 'utc_rd_values() on 1999-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 1999-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 1999-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-05 Gregorian' );
Trewsday 13 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072172800, 'utc_rd_as_seconds() on 1999-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730002,
  0,
  0
]
, 'utc_rd_values() on 1999-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 1999-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 1999-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-06 Gregorian' );
Hevensday 14 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072259200, 'utc_rd_as_seconds() on 1999-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730003,
  0,
  0
]
, 'utc_rd_values() on 1999-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 1999-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 1999-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-07 Gregorian' );
Mersday 15 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072345600, 'utc_rd_as_seconds() on 1999-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730004,
  0,
  0
]
, 'utc_rd_values() on 1999-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 1999-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 1999-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-08 Gregorian' );
Highday 16 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072432000, 'utc_rd_as_seconds() on 1999-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730005,
  0,
  0
]
, 'utc_rd_values() on 1999-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  37
]
, 'week() on 1999-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 1999-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 1999-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 1999-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-09 Gregorian' );
Sterday 17 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072518400, 'utc_rd_as_seconds() on 1999-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730006,
  0,
  0
]
, 'utc_rd_values() on 1999-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 1999-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 1999-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-10 Gregorian' );
Sunday 18 Halimath 7463

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072604800, 'utc_rd_as_seconds() on 1999-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730007,
  0,
  0
]
, 'utc_rd_values() on 1999-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 1999-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 1999-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-11 Gregorian' );
Monday 19 Halimath 7463

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072691200, 'utc_rd_as_seconds() on 1999-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730008,
  0,
  0
]
, 'utc_rd_values() on 1999-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 1999-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 1999-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-12 Gregorian' );
Trewsday 20 Halimath 7463

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072777600, 'utc_rd_as_seconds() on 1999-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730009,
  0,
  0
]
, 'utc_rd_values() on 1999-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 1999-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 1999-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-13 Gregorian' );
Hevensday 21 Halimath 7463

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072864000, 'utc_rd_as_seconds() on 1999-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730010,
  0,
  0
]
, 'utc_rd_values() on 1999-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 1999-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 1999-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-14 Gregorian' );
Mersday 22 Halimath 7463

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63072950400, 'utc_rd_as_seconds() on 1999-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730011,
  0,
  0
]
, 'utc_rd_values() on 1999-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 1999-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 1999-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-15 Gregorian' );
Highday 23 Halimath 7463

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073036800, 'utc_rd_as_seconds() on 1999-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730012,
  0,
  0
]
, 'utc_rd_values() on 1999-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  38
]
, 'week() on 1999-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 1999-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 1999-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 1999-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-16 Gregorian' );
Sterday 24 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073123200, 'utc_rd_as_seconds() on 1999-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730013,
  0,
  0
]
, 'utc_rd_values() on 1999-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 1999-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 1999-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-17 Gregorian' );
Sunday 25 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073209600, 'utc_rd_as_seconds() on 1999-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730014,
  0,
  0
]
, 'utc_rd_values() on 1999-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 1999-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 1999-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-18 Gregorian' );
Monday 26 Halimath 7463

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073296000, 'utc_rd_as_seconds() on 1999-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730015,
  0,
  0
]
, 'utc_rd_values() on 1999-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 1999-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 1999-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-19 Gregorian' );
Trewsday 27 Halimath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073382400, 'utc_rd_as_seconds() on 1999-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730016,
  0,
  0
]
, 'utc_rd_values() on 1999-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 1999-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 1999-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-20 Gregorian' );
Hevensday 28 Halimath 7463

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073468800, 'utc_rd_as_seconds() on 1999-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730017,
  0,
  0
]
, 'utc_rd_values() on 1999-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 1999-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 1999-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-21 Gregorian' );
Mersday 29 Halimath 7463

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073555200, 'utc_rd_as_seconds() on 1999-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730018,
  0,
  0
]
, 'utc_rd_values() on 1999-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 1999-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 1999-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 1999-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 1999-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-22 Gregorian' );
Highday 30 Halimath 7463

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073641600, 'utc_rd_as_seconds() on 1999-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730019,
  0,
  0
]
, 'utc_rd_values() on 1999-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  39
]
, 'week() on 1999-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 1999-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 1999-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 1999-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-23 Gregorian' );
Sterday 1 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073728000, 'utc_rd_as_seconds() on 1999-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730020,
  0,
  0
]
, 'utc_rd_values() on 1999-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 1999-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 1999-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-24 Gregorian' );
Sunday 2 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073814400, 'utc_rd_as_seconds() on 1999-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730021,
  0,
  0
]
, 'utc_rd_values() on 1999-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 1999-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 1999-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-25 Gregorian' );
Monday 3 Winterfilth 7463

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073900800, 'utc_rd_as_seconds() on 1999-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730022,
  0,
  0
]
, 'utc_rd_values() on 1999-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 1999-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 1999-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-26 Gregorian' );
Trewsday 4 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63073987200, 'utc_rd_as_seconds() on 1999-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730023,
  0,
  0
]
, 'utc_rd_values() on 1999-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 1999-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 1999-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-27 Gregorian' );
Hevensday 5 Winterfilth 7463

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074073600, 'utc_rd_as_seconds() on 1999-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730024,
  0,
  0
]
, 'utc_rd_values() on 1999-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 1999-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 1999-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-28 Gregorian' );
Mersday 6 Winterfilth 7463

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074160000, 'utc_rd_as_seconds() on 1999-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730025,
  0,
  0
]
, 'utc_rd_values() on 1999-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 1999-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 1999-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-29 Gregorian' );
Highday 7 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074246400, 'utc_rd_as_seconds() on 1999-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730026,
  0,
  0
]
, 'utc_rd_values() on 1999-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  40
]
, 'week() on 1999-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 1999-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 1999-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 1999-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-09-30 Gregorian' );
Sterday 8 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074332800, 'utc_rd_as_seconds() on 1999-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730027,
  0,
  0
]
, 'utc_rd_values() on 1999-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 1999-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 1999-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-01 Gregorian' );
Sunday 9 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074419200, 'utc_rd_as_seconds() on 1999-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730028,
  0,
  0
]
, 'utc_rd_values() on 1999-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 1999-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 1999-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-02 Gregorian' );
Monday 10 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074505600, 'utc_rd_as_seconds() on 1999-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730029,
  0,
  0
]
, 'utc_rd_values() on 1999-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 1999-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 1999-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-03 Gregorian' );
Trewsday 11 Winterfilth 7463

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074592000, 'utc_rd_as_seconds() on 1999-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730030,
  0,
  0
]
, 'utc_rd_values() on 1999-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 1999-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 1999-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-04 Gregorian' );
Hevensday 12 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074678400, 'utc_rd_as_seconds() on 1999-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730031,
  0,
  0
]
, 'utc_rd_values() on 1999-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 1999-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 1999-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-05 Gregorian' );
Mersday 13 Winterfilth 7463

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074764800, 'utc_rd_as_seconds() on 1999-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730032,
  0,
  0
]
, 'utc_rd_values() on 1999-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 1999-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 1999-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-06 Gregorian' );
Highday 14 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074851200, 'utc_rd_as_seconds() on 1999-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730033,
  0,
  0
]
, 'utc_rd_values() on 1999-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  41
]
, 'week() on 1999-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 1999-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 1999-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 1999-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-07 Gregorian' );
Sterday 15 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63074937600, 'utc_rd_as_seconds() on 1999-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730034,
  0,
  0
]
, 'utc_rd_values() on 1999-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 1999-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 1999-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-08 Gregorian' );
Sunday 16 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075024000, 'utc_rd_as_seconds() on 1999-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730035,
  0,
  0
]
, 'utc_rd_values() on 1999-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 1999-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 1999-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-09 Gregorian' );
Monday 17 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075110400, 'utc_rd_as_seconds() on 1999-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730036,
  0,
  0
]
, 'utc_rd_values() on 1999-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 1999-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 1999-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-10 Gregorian' );
Trewsday 18 Winterfilth 7463

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075196800, 'utc_rd_as_seconds() on 1999-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730037,
  0,
  0
]
, 'utc_rd_values() on 1999-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 1999-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 1999-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-11 Gregorian' );
Hevensday 19 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075283200, 'utc_rd_as_seconds() on 1999-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730038,
  0,
  0
]
, 'utc_rd_values() on 1999-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 1999-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 1999-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-12 Gregorian' );
Mersday 20 Winterfilth 7463

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075369600, 'utc_rd_as_seconds() on 1999-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730039,
  0,
  0
]
, 'utc_rd_values() on 1999-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 1999-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 1999-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-13 Gregorian' );
Highday 21 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075456000, 'utc_rd_as_seconds() on 1999-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730040,
  0,
  0
]
, 'utc_rd_values() on 1999-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  42
]
, 'week() on 1999-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 1999-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 1999-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 1999-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-14 Gregorian' );
Sterday 22 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075542400, 'utc_rd_as_seconds() on 1999-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730041,
  0,
  0
]
, 'utc_rd_values() on 1999-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 1999-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 1999-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-15 Gregorian' );
Sunday 23 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075628800, 'utc_rd_as_seconds() on 1999-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730042,
  0,
  0
]
, 'utc_rd_values() on 1999-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 1999-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 1999-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-16 Gregorian' );
Monday 24 Winterfilth 7463

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075715200, 'utc_rd_as_seconds() on 1999-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730043,
  0,
  0
]
, 'utc_rd_values() on 1999-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 1999-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 1999-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-17 Gregorian' );
Trewsday 25 Winterfilth 7463

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075801600, 'utc_rd_as_seconds() on 1999-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730044,
  0,
  0
]
, 'utc_rd_values() on 1999-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 1999-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 1999-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-18 Gregorian' );
Hevensday 26 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075888000, 'utc_rd_as_seconds() on 1999-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730045,
  0,
  0
]
, 'utc_rd_values() on 1999-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 1999-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 1999-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-19 Gregorian' );
Mersday 27 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63075974400, 'utc_rd_as_seconds() on 1999-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730046,
  0,
  0
]
, 'utc_rd_values() on 1999-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 1999-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 1999-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-20 Gregorian' );
Highday 28 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076060800, 'utc_rd_as_seconds() on 1999-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730047,
  0,
  0
]
, 'utc_rd_values() on 1999-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  43
]
, 'week() on 1999-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 1999-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 1999-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 1999-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-21 Gregorian' );
Sterday 29 Winterfilth 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076147200, 'utc_rd_as_seconds() on 1999-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730048,
  0,
  0
]
, 'utc_rd_values() on 1999-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 1999-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 1999-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 1999-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 1999-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-22 Gregorian' );
Sunday 30 Winterfilth 7463

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076233600, 'utc_rd_as_seconds() on 1999-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730049,
  0,
  0
]
, 'utc_rd_values() on 1999-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 1999-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 1999-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-23 Gregorian' );
Monday 1 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076320000, 'utc_rd_as_seconds() on 1999-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730050,
  0,
  0
]
, 'utc_rd_values() on 1999-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 1999-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 1999-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-24 Gregorian' );
Trewsday 2 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076406400, 'utc_rd_as_seconds() on 1999-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730051,
  0,
  0
]
, 'utc_rd_values() on 1999-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 1999-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 1999-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-25 Gregorian' );
Hevensday 3 Blotmath 7463

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076492800, 'utc_rd_as_seconds() on 1999-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730052,
  0,
  0
]
, 'utc_rd_values() on 1999-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 1999-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 1999-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-26 Gregorian' );
Mersday 4 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076579200, 'utc_rd_as_seconds() on 1999-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730053,
  0,
  0
]
, 'utc_rd_values() on 1999-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 1999-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 1999-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-27 Gregorian' );
Highday 5 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076665600, 'utc_rd_as_seconds() on 1999-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730054,
  0,
  0
]
, 'utc_rd_values() on 1999-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  44
]
, 'week() on 1999-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 1999-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 1999-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 1999-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-28 Gregorian' );
Sterday 6 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076752000, 'utc_rd_as_seconds() on 1999-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730055,
  0,
  0
]
, 'utc_rd_values() on 1999-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 1999-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 1999-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-29 Gregorian' );
Sunday 7 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076838400, 'utc_rd_as_seconds() on 1999-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730056,
  0,
  0
]
, 'utc_rd_values() on 1999-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 1999-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 1999-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-30 Gregorian' );
Monday 8 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63076924800, 'utc_rd_as_seconds() on 1999-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730057,
  0,
  0
]
, 'utc_rd_values() on 1999-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 1999-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 1999-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-10-31 Gregorian' );
Trewsday 9 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077011200, 'utc_rd_as_seconds() on 1999-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730058,
  0,
  0
]
, 'utc_rd_values() on 1999-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 1999-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 1999-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-01 Gregorian' );
Hevensday 10 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077097600, 'utc_rd_as_seconds() on 1999-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730059,
  0,
  0
]
, 'utc_rd_values() on 1999-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 1999-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 1999-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-02 Gregorian' );
Mersday 11 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077184000, 'utc_rd_as_seconds() on 1999-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730060,
  0,
  0
]
, 'utc_rd_values() on 1999-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 1999-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 1999-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-03 Gregorian' );
Highday 12 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077270400, 'utc_rd_as_seconds() on 1999-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730061,
  0,
  0
]
, 'utc_rd_values() on 1999-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  45
]
, 'week() on 1999-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 1999-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 1999-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 1999-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-04 Gregorian' );
Sterday 13 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077356800, 'utc_rd_as_seconds() on 1999-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730062,
  0,
  0
]
, 'utc_rd_values() on 1999-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 1999-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 1999-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-05 Gregorian' );
Sunday 14 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077443200, 'utc_rd_as_seconds() on 1999-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730063,
  0,
  0
]
, 'utc_rd_values() on 1999-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 1999-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 1999-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-06 Gregorian' );
Monday 15 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077529600, 'utc_rd_as_seconds() on 1999-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730064,
  0,
  0
]
, 'utc_rd_values() on 1999-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 1999-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 1999-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-07 Gregorian' );
Trewsday 16 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077616000, 'utc_rd_as_seconds() on 1999-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730065,
  0,
  0
]
, 'utc_rd_values() on 1999-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 1999-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 1999-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-08 Gregorian' );
Hevensday 17 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077702400, 'utc_rd_as_seconds() on 1999-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730066,
  0,
  0
]
, 'utc_rd_values() on 1999-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 1999-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 1999-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-09 Gregorian' );
Mersday 18 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077788800, 'utc_rd_as_seconds() on 1999-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730067,
  0,
  0
]
, 'utc_rd_values() on 1999-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 1999-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 1999-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-10 Gregorian' );
Highday 19 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077875200, 'utc_rd_as_seconds() on 1999-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730068,
  0,
  0
]
, 'utc_rd_values() on 1999-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  46
]
, 'week() on 1999-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 1999-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 1999-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 1999-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-11 Gregorian' );
Sterday 20 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63077961600, 'utc_rd_as_seconds() on 1999-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730069,
  0,
  0
]
, 'utc_rd_values() on 1999-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 1999-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 1999-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-12 Gregorian' );
Sunday 21 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078048000, 'utc_rd_as_seconds() on 1999-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730070,
  0,
  0
]
, 'utc_rd_values() on 1999-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 1999-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 1999-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-13 Gregorian' );
Monday 22 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078134400, 'utc_rd_as_seconds() on 1999-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730071,
  0,
  0
]
, 'utc_rd_values() on 1999-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 1999-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 1999-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-14 Gregorian' );
Trewsday 23 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078220800, 'utc_rd_as_seconds() on 1999-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730072,
  0,
  0
]
, 'utc_rd_values() on 1999-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 1999-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 1999-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-15 Gregorian' );
Hevensday 24 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078307200, 'utc_rd_as_seconds() on 1999-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730073,
  0,
  0
]
, 'utc_rd_values() on 1999-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 1999-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 1999-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-16 Gregorian' );
Mersday 25 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078393600, 'utc_rd_as_seconds() on 1999-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730074,
  0,
  0
]
, 'utc_rd_values() on 1999-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 1999-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 1999-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-17 Gregorian' );
Highday 26 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078480000, 'utc_rd_as_seconds() on 1999-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730075,
  0,
  0
]
, 'utc_rd_values() on 1999-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  47
]
, 'week() on 1999-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 1999-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 1999-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 1999-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-18 Gregorian' );
Sterday 27 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078566400, 'utc_rd_as_seconds() on 1999-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730076,
  0,
  0
]
, 'utc_rd_values() on 1999-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 1999-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 1999-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-19 Gregorian' );
Sunday 28 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078652800, 'utc_rd_as_seconds() on 1999-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730077,
  0,
  0
]
, 'utc_rd_values() on 1999-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 1999-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 1999-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-20 Gregorian' );
Monday 29 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078739200, 'utc_rd_as_seconds() on 1999-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730078,
  0,
  0
]
, 'utc_rd_values() on 1999-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 1999-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 1999-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 1999-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 1999-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-21 Gregorian' );
Trewsday 30 Blotmath 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078825600, 'utc_rd_as_seconds() on 1999-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730079,
  0,
  0
]
, 'utc_rd_values() on 1999-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 1999-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 1999-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-22 Gregorian' );
Hevensday 1 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078912000, 'utc_rd_as_seconds() on 1999-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730080,
  0,
  0
]
, 'utc_rd_values() on 1999-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 1999-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 1999-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-23 Gregorian' );
Mersday 2 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63078998400, 'utc_rd_as_seconds() on 1999-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730081,
  0,
  0
]
, 'utc_rd_values() on 1999-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 1999-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 1999-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-24 Gregorian' );
Highday 3 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079084800, 'utc_rd_as_seconds() on 1999-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730082,
  0,
  0
]
, 'utc_rd_values() on 1999-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  48
]
, 'week() on 1999-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 1999-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 1999-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 1999-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-25 Gregorian' );
Sterday 4 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079171200, 'utc_rd_as_seconds() on 1999-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730083,
  0,
  0
]
, 'utc_rd_values() on 1999-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 1999-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 1999-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-26 Gregorian' );
Sunday 5 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079257600, 'utc_rd_as_seconds() on 1999-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730084,
  0,
  0
]
, 'utc_rd_values() on 1999-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 1999-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 1999-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-27 Gregorian' );
Monday 6 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079344000, 'utc_rd_as_seconds() on 1999-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730085,
  0,
  0
]
, 'utc_rd_values() on 1999-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 1999-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 1999-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-28 Gregorian' );
Trewsday 7 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079430400, 'utc_rd_as_seconds() on 1999-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730086,
  0,
  0
]
, 'utc_rd_values() on 1999-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 1999-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 1999-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-29 Gregorian' );
Hevensday 8 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079516800, 'utc_rd_as_seconds() on 1999-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730087,
  0,
  0
]
, 'utc_rd_values() on 1999-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 1999-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 1999-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 1999-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 1999-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 1999-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-11-30 Gregorian' );
Mersday 9 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079603200, 'utc_rd_as_seconds() on 1999-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730088,
  0,
  0
]
, 'utc_rd_values() on 1999-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 1999-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 1999-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 1999-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 1999-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 1999-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-01 Gregorian' );
Highday 10 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079689600, 'utc_rd_as_seconds() on 1999-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730089,
  0,
  0
]
, 'utc_rd_values() on 1999-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  49
]
, 'week() on 1999-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 1999-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 1999-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 1999-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 1999-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 1999-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 1999-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-02 Gregorian' );
Sterday 11 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079776000, 'utc_rd_as_seconds() on 1999-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730090,
  0,
  0
]
, 'utc_rd_values() on 1999-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 1999-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 1999-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 1999-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 1999-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 1999-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-03 Gregorian' );
Sunday 12 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079862400, 'utc_rd_as_seconds() on 1999-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730091,
  0,
  0
]
, 'utc_rd_values() on 1999-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 1999-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 1999-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 1999-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 1999-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 1999-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-04 Gregorian' );
Monday 13 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63079948800, 'utc_rd_as_seconds() on 1999-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730092,
  0,
  0
]
, 'utc_rd_values() on 1999-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 1999-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 1999-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 1999-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 1999-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 1999-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-05 Gregorian' );
Trewsday 14 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080035200, 'utc_rd_as_seconds() on 1999-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730093,
  0,
  0
]
, 'utc_rd_values() on 1999-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 1999-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 1999-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 1999-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 1999-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 1999-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-06 Gregorian' );
Hevensday 15 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080121600, 'utc_rd_as_seconds() on 1999-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730094,
  0,
  0
]
, 'utc_rd_values() on 1999-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 1999-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 1999-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 1999-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 1999-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 1999-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-07 Gregorian' );
Mersday 16 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080208000, 'utc_rd_as_seconds() on 1999-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730095,
  0,
  0
]
, 'utc_rd_values() on 1999-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 1999-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 1999-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 1999-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 1999-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 1999-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-08 Gregorian' );
Highday 17 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080294400, 'utc_rd_as_seconds() on 1999-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730096,
  0,
  0
]
, 'utc_rd_values() on 1999-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  50
]
, 'week() on 1999-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 1999-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 1999-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 1999-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 1999-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 1999-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 1999-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-09 Gregorian' );
Sterday 18 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080380800, 'utc_rd_as_seconds() on 1999-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730097,
  0,
  0
]
, 'utc_rd_values() on 1999-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 1999-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 1999-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 1999-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 1999-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 1999-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-10 Gregorian' );
Sunday 19 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080467200, 'utc_rd_as_seconds() on 1999-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730098,
  0,
  0
]
, 'utc_rd_values() on 1999-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 1999-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 1999-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 1999-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 1999-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 1999-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-11 Gregorian' );
Monday 20 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080553600, 'utc_rd_as_seconds() on 1999-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730099,
  0,
  0
]
, 'utc_rd_values() on 1999-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 1999-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 1999-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 1999-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 1999-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 1999-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-12 Gregorian' );
Trewsday 21 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080640000, 'utc_rd_as_seconds() on 1999-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730100,
  0,
  0
]
, 'utc_rd_values() on 1999-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 1999-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 1999-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 1999-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 1999-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 1999-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-13 Gregorian' );
Hevensday 22 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080726400, 'utc_rd_as_seconds() on 1999-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730101,
  0,
  0
]
, 'utc_rd_values() on 1999-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 1999-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 1999-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 1999-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 1999-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 1999-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-14 Gregorian' );
Mersday 23 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080812800, 'utc_rd_as_seconds() on 1999-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730102,
  0,
  0
]
, 'utc_rd_values() on 1999-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 1999-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 1999-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 1999-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 1999-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 1999-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-15 Gregorian' );
Highday 24 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080899200, 'utc_rd_as_seconds() on 1999-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730103,
  0,
  0
]
, 'utc_rd_values() on 1999-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  51
]
, 'week() on 1999-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 1999-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 1999-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 1999-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 1999-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 1999-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 1999-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-16 Gregorian' );
Sterday 25 Foreyule 7463

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63080985600, 'utc_rd_as_seconds() on 1999-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730104,
  0,
  0
]
, 'utc_rd_values() on 1999-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 1999-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 1999-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 1999-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 1999-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 1999-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-17 Gregorian' );
Sunday 26 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081072000, 'utc_rd_as_seconds() on 1999-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730105,
  0,
  0
]
, 'utc_rd_values() on 1999-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 1999-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 1999-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 1999-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 1999-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 1999-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-18 Gregorian' );
Monday 27 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081158400, 'utc_rd_as_seconds() on 1999-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730106,
  0,
  0
]
, 'utc_rd_values() on 1999-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 1999-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 1999-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 1999-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 1999-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 1999-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-19 Gregorian' );
Trewsday 28 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081244800, 'utc_rd_as_seconds() on 1999-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730107,
  0,
  0
]
, 'utc_rd_values() on 1999-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 1999-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 1999-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 1999-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 1999-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 1999-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-20 Gregorian' );
Hevensday 29 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081331200, 'utc_rd_as_seconds() on 1999-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730108,
  0,
  0
]
, 'utc_rd_values() on 1999-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 1999-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 1999-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 1999-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 1999-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 1999-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 1999-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 1999-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-21 Gregorian' );
Mersday 30 Foreyule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081417600, 'utc_rd_as_seconds() on 1999-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730109,
  0,
  0
]
, 'utc_rd_values() on 1999-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 1999-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 1999-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 1999-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 1999-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 1999-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 1999-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 1999-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 1999-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 1999-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 1999-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-22 Gregorian' );
Highday 1 Yule 7463
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081504000, 'utc_rd_as_seconds() on 1999-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730110,
  0,
  0
]
, 'utc_rd_values() on 1999-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7463,
  52
]
, 'week() on 1999-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 1999-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7463, 'week_year() on 1999-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7463, 'year() on 1999-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 1999-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 1999-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 1999-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 1999-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 1999-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 1999-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 1999-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 1999-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 1999-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-23 Gregorian' );
Sterday 2 Yule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081590400, 'utc_rd_as_seconds() on 1999-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730111,
  0,
  0
]
, 'utc_rd_values() on 1999-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 1999-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 1999-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 1999-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 1999-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 1999-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-24 Gregorian' );
Sunday 1 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081676800, 'utc_rd_as_seconds() on 1999-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730112,
  0,
  0
]
, 'utc_rd_values() on 1999-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 1999-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 1999-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 1999-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 1999-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 1999-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 1999-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 1999-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 1999-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 1999-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-25 Gregorian' );
Monday 2 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081763200, 'utc_rd_as_seconds() on 1999-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730113,
  0,
  0
]
, 'utc_rd_values() on 1999-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 1999-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 1999-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 1999-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 1999-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 1999-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 1999-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 1999-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 1999-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 1999-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 1999-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-26 Gregorian' );
Trewsday 3 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081849600, 'utc_rd_as_seconds() on 1999-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730114,
  0,
  0
]
, 'utc_rd_values() on 1999-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 1999-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 1999-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 1999-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 1999-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 1999-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 1999-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 1999-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 1999-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 1999-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 1999-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-27 Gregorian' );
Hevensday 4 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63081936000, 'utc_rd_as_seconds() on 1999-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730115,
  0,
  0
]
, 'utc_rd_values() on 1999-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 1999-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 1999-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 1999-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 1999-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 1999-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 1999-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 1999-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 1999-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 1999-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 1999-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-28 Gregorian' );
Mersday 5 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082022400, 'utc_rd_as_seconds() on 1999-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730116,
  0,
  0
]
, 'utc_rd_values() on 1999-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 1999-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 1999-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 1999-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 1999-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 1999-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 1999-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 1999-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 1999-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 1999-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 1999-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-29 Gregorian' );
Highday 6 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082108800, 'utc_rd_as_seconds() on 1999-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730117,
  0,
  0
]
, 'utc_rd_values() on 1999-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 1999-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  1
]
, 'week() on 1999-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 1999-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 1999-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 1999-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 1999-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 1999-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 1999-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 1999-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 1999-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 1999-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 1999-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-30 Gregorian' );
Sterday 7 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082195200, 'utc_rd_as_seconds() on 1999-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730118,
  0,
  0
]
, 'utc_rd_values() on 1999-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 1999-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 1999-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 1999 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 1999,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 1999-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 1999-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 1999-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 1999-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 1999-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 1999-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 1999-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 1999-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 1999-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 1999-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 1999-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 1999-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 1999-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 1999-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 1999-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 1999-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 1999-12-31 Gregorian' );
Sunday 8 Afteryule 7464

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082281600, 'utc_rd_as_seconds() on 1999-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730119,
  0,
  0
]
, 'utc_rd_values() on 1999-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 1999-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 1999-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 1999-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 1999-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 1999-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2000-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2000-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-01 Gregorian' );
Monday 9 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082368000, 'utc_rd_as_seconds() on 2000-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730120,
  0,
  0
]
, 'utc_rd_values() on 2000-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 2000-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2000-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2000-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-02 Gregorian' );
Trewsday 10 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082454400, 'utc_rd_as_seconds() on 2000-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730121,
  0,
  0
]
, 'utc_rd_values() on 2000-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 2000-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2000-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2000-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-03 Gregorian' );
Hevensday 11 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082540800, 'utc_rd_as_seconds() on 2000-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730122,
  0,
  0
]
, 'utc_rd_values() on 2000-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 2000-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2000-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2000-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-04 Gregorian' );
Mersday 12 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082627200, 'utc_rd_as_seconds() on 2000-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730123,
  0,
  0
]
, 'utc_rd_values() on 2000-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 2000-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2000-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2000-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-05 Gregorian' );
Highday 13 Afteryule 7464

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082713600, 'utc_rd_as_seconds() on 2000-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730124,
  0,
  0
]
, 'utc_rd_values() on 2000-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  2
]
, 'week() on 2000-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2000-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2000-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-06 Gregorian' );
Sterday 14 Afteryule 7464

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082800000, 'utc_rd_as_seconds() on 2000-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730125,
  0,
  0
]
, 'utc_rd_values() on 2000-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2000-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2000-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-07 Gregorian' );
Sunday 15 Afteryule 7464

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082886400, 'utc_rd_as_seconds() on 2000-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730126,
  0,
  0
]
, 'utc_rd_values() on 2000-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2000-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2000-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-08 Gregorian' );
Monday 16 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63082972800, 'utc_rd_as_seconds() on 2000-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730127,
  0,
  0
]
, 'utc_rd_values() on 2000-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2000-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2000-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-09 Gregorian' );
Trewsday 17 Afteryule 7464

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083059200, 'utc_rd_as_seconds() on 2000-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730128,
  0,
  0
]
, 'utc_rd_values() on 2000-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2000-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2000-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-10 Gregorian' );
Hevensday 18 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083145600, 'utc_rd_as_seconds() on 2000-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730129,
  0,
  0
]
, 'utc_rd_values() on 2000-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2000-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2000-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-11 Gregorian' );
Mersday 19 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083232000, 'utc_rd_as_seconds() on 2000-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730130,
  0,
  0
]
, 'utc_rd_values() on 2000-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2000-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2000-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-12 Gregorian' );
Highday 20 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083318400, 'utc_rd_as_seconds() on 2000-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730131,
  0,
  0
]
, 'utc_rd_values() on 2000-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  3
]
, 'week() on 2000-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2000-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2000-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2000-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-13 Gregorian' );
Sterday 21 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083404800, 'utc_rd_as_seconds() on 2000-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730132,
  0,
  0
]
, 'utc_rd_values() on 2000-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2000-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2000-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-14 Gregorian' );
Sunday 22 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083491200, 'utc_rd_as_seconds() on 2000-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730133,
  0,
  0
]
, 'utc_rd_values() on 2000-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2000-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2000-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-15 Gregorian' );
Monday 23 Afteryule 7464

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083577600, 'utc_rd_as_seconds() on 2000-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730134,
  0,
  0
]
, 'utc_rd_values() on 2000-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2000-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2000-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-16 Gregorian' );
Trewsday 24 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083664000, 'utc_rd_as_seconds() on 2000-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730135,
  0,
  0
]
, 'utc_rd_values() on 2000-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2000-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2000-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-17 Gregorian' );
Hevensday 25 Afteryule 7464

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083750400, 'utc_rd_as_seconds() on 2000-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730136,
  0,
  0
]
, 'utc_rd_values() on 2000-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2000-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2000-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-18 Gregorian' );
Mersday 26 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083836800, 'utc_rd_as_seconds() on 2000-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730137,
  0,
  0
]
, 'utc_rd_values() on 2000-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2000-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2000-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-19 Gregorian' );
Highday 27 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63083923200, 'utc_rd_as_seconds() on 2000-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730138,
  0,
  0
]
, 'utc_rd_values() on 2000-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  4
]
, 'week() on 2000-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2000-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2000-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2000-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-20 Gregorian' );
Sterday 28 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084009600, 'utc_rd_as_seconds() on 2000-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730139,
  0,
  0
]
, 'utc_rd_values() on 2000-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2000-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2000-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-21 Gregorian' );
Sunday 29 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084096000, 'utc_rd_as_seconds() on 2000-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730140,
  0,
  0
]
, 'utc_rd_values() on 2000-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2000-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2000-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-22 Gregorian' );
Monday 30 Afteryule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084182400, 'utc_rd_as_seconds() on 2000-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730141,
  0,
  0
]
, 'utc_rd_values() on 2000-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2000-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2000-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-23 Gregorian' );
Trewsday 1 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084268800, 'utc_rd_as_seconds() on 2000-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730142,
  0,
  0
]
, 'utc_rd_values() on 2000-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2000-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2000-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-24 Gregorian' );
Hevensday 2 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084355200, 'utc_rd_as_seconds() on 2000-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730143,
  0,
  0
]
, 'utc_rd_values() on 2000-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2000-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2000-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-25 Gregorian' );
Mersday 3 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084441600, 'utc_rd_as_seconds() on 2000-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730144,
  0,
  0
]
, 'utc_rd_values() on 2000-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2000-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2000-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-26 Gregorian' );
Highday 4 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084528000, 'utc_rd_as_seconds() on 2000-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730145,
  0,
  0
]
, 'utc_rd_values() on 2000-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  5
]
, 'week() on 2000-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2000-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2000-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2000-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-27 Gregorian' );
Sterday 5 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084614400, 'utc_rd_as_seconds() on 2000-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730146,
  0,
  0
]
, 'utc_rd_values() on 2000-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2000-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2000-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-28 Gregorian' );
Sunday 6 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084700800, 'utc_rd_as_seconds() on 2000-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730147,
  0,
  0
]
, 'utc_rd_values() on 2000-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2000-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2000-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-29 Gregorian' );
Monday 7 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084787200, 'utc_rd_as_seconds() on 2000-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730148,
  0,
  0
]
, 'utc_rd_values() on 2000-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2000-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2000-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-30 Gregorian' );
Trewsday 8 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084873600, 'utc_rd_as_seconds() on 2000-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730149,
  0,
  0
]
, 'utc_rd_values() on 2000-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2000-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2000-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-01-31 Gregorian' );
Hevensday 9 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63084960000, 'utc_rd_as_seconds() on 2000-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730150,
  0,
  0
]
, 'utc_rd_values() on 2000-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2000-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2000-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-01 Gregorian' );
Mersday 10 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085046400, 'utc_rd_as_seconds() on 2000-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730151,
  0,
  0
]
, 'utc_rd_values() on 2000-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2000-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2000-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-02 Gregorian' );
Highday 11 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085132800, 'utc_rd_as_seconds() on 2000-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730152,
  0,
  0
]
, 'utc_rd_values() on 2000-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  6
]
, 'week() on 2000-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2000-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2000-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2000-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-03 Gregorian' );
Sterday 12 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085219200, 'utc_rd_as_seconds() on 2000-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730153,
  0,
  0
]
, 'utc_rd_values() on 2000-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2000-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2000-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-04 Gregorian' );
Sunday 13 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085305600, 'utc_rd_as_seconds() on 2000-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730154,
  0,
  0
]
, 'utc_rd_values() on 2000-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2000-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2000-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-05 Gregorian' );
Monday 14 Solmath 7464

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085392000, 'utc_rd_as_seconds() on 2000-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730155,
  0,
  0
]
, 'utc_rd_values() on 2000-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2000-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2000-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-06 Gregorian' );
Trewsday 15 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085478400, 'utc_rd_as_seconds() on 2000-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730156,
  0,
  0
]
, 'utc_rd_values() on 2000-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2000-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2000-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-07 Gregorian' );
Hevensday 16 Solmath 7464

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085564800, 'utc_rd_as_seconds() on 2000-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730157,
  0,
  0
]
, 'utc_rd_values() on 2000-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2000-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2000-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-08 Gregorian' );
Mersday 17 Solmath 7464

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085651200, 'utc_rd_as_seconds() on 2000-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730158,
  0,
  0
]
, 'utc_rd_values() on 2000-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2000-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2000-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-09 Gregorian' );
Highday 18 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085737600, 'utc_rd_as_seconds() on 2000-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730159,
  0,
  0
]
, 'utc_rd_values() on 2000-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  7
]
, 'week() on 2000-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2000-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2000-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2000-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-10 Gregorian' );
Sterday 19 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085824000, 'utc_rd_as_seconds() on 2000-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730160,
  0,
  0
]
, 'utc_rd_values() on 2000-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2000-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2000-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-11 Gregorian' );
Sunday 20 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085910400, 'utc_rd_as_seconds() on 2000-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730161,
  0,
  0
]
, 'utc_rd_values() on 2000-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2000-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2000-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-12 Gregorian' );
Monday 21 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63085996800, 'utc_rd_as_seconds() on 2000-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730162,
  0,
  0
]
, 'utc_rd_values() on 2000-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2000-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2000-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-13 Gregorian' );
Trewsday 22 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086083200, 'utc_rd_as_seconds() on 2000-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730163,
  0,
  0
]
, 'utc_rd_values() on 2000-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2000-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2000-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-14 Gregorian' );
Hevensday 23 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086169600, 'utc_rd_as_seconds() on 2000-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730164,
  0,
  0
]
, 'utc_rd_values() on 2000-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2000-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2000-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-15 Gregorian' );
Mersday 24 Solmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086256000, 'utc_rd_as_seconds() on 2000-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730165,
  0,
  0
]
, 'utc_rd_values() on 2000-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2000-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2000-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-16 Gregorian' );
Highday 25 Solmath 7464

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086342400, 'utc_rd_as_seconds() on 2000-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730166,
  0,
  0
]
, 'utc_rd_values() on 2000-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  8
]
, 'week() on 2000-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2000-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2000-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2000-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-17 Gregorian' );
Sterday 26 Solmath 7464

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086428800, 'utc_rd_as_seconds() on 2000-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730167,
  0,
  0
]
, 'utc_rd_values() on 2000-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2000-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2000-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-18 Gregorian' );
Sunday 27 Solmath 7464

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086515200, 'utc_rd_as_seconds() on 2000-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730168,
  0,
  0
]
, 'utc_rd_values() on 2000-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2000-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2000-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-19 Gregorian' );
Monday 28 Solmath 7464

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086601600, 'utc_rd_as_seconds() on 2000-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730169,
  0,
  0
]
, 'utc_rd_values() on 2000-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2000-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2000-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-20 Gregorian' );
Trewsday 29 Solmath 7464

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086688000, 'utc_rd_as_seconds() on 2000-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730170,
  0,
  0
]
, 'utc_rd_values() on 2000-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2000-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2000-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2000-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2000-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-21 Gregorian' );
Hevensday 30 Solmath 7464

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086774400, 'utc_rd_as_seconds() on 2000-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730171,
  0,
  0
]
, 'utc_rd_values() on 2000-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2000-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2000-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-22 Gregorian' );
Mersday 1 Rethe 7464

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086860800, 'utc_rd_as_seconds() on 2000-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730172,
  0,
  0
]
, 'utc_rd_values() on 2000-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2000-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2000-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-23 Gregorian' );
Highday 2 Rethe 7464

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63086947200, 'utc_rd_as_seconds() on 2000-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730173,
  0,
  0
]
, 'utc_rd_values() on 2000-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  9
]
, 'week() on 2000-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2000-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2000-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2000-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-24 Gregorian' );
Sterday 3 Rethe 7464

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087033600, 'utc_rd_as_seconds() on 2000-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730174,
  0,
  0
]
, 'utc_rd_values() on 2000-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2000-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2000-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-25 Gregorian' );
Sunday 4 Rethe 7464

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087120000, 'utc_rd_as_seconds() on 2000-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730175,
  0,
  0
]
, 'utc_rd_values() on 2000-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2000-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2000-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-26 Gregorian' );
Monday 5 Rethe 7464

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087206400, 'utc_rd_as_seconds() on 2000-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730176,
  0,
  0
]
, 'utc_rd_values() on 2000-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2000-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2000-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-27 Gregorian' );
Trewsday 6 Rethe 7464

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087292800, 'utc_rd_as_seconds() on 2000-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730177,
  0,
  0
]
, 'utc_rd_values() on 2000-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2000-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2000-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-28 Gregorian' );
Hevensday 7 Rethe 7464

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087379200, 'utc_rd_as_seconds() on 2000-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730178,
  0,
  0
]
, 'utc_rd_values() on 2000-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 2 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 2,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-02-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-02-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-02-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-02-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-02-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2000-02-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-02-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2000-02-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-02-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-02-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-02-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-02-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-02-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-02-29 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-02-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-02-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-02-29 Gregorian' );
Mersday 8 Rethe 7464

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087465600, 'utc_rd_as_seconds() on 2000-02-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730179,
  0,
  0
]
, 'utc_rd_values() on 2000-02-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-02-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-02-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-02-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-02-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-02-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2000-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2000-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-01 Gregorian' );
Highday 9 Rethe 7464

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087552000, 'utc_rd_as_seconds() on 2000-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730180,
  0,
  0
]
, 'utc_rd_values() on 2000-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  10
]
, 'week() on 2000-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2000-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2000-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2000-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-02 Gregorian' );
Sterday 10 Rethe 7464

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087638400, 'utc_rd_as_seconds() on 2000-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730181,
  0,
  0
]
, 'utc_rd_values() on 2000-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2000-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2000-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-03 Gregorian' );
Sunday 11 Rethe 7464

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087724800, 'utc_rd_as_seconds() on 2000-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730182,
  0,
  0
]
, 'utc_rd_values() on 2000-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2000-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2000-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-04 Gregorian' );
Monday 12 Rethe 7464

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087811200, 'utc_rd_as_seconds() on 2000-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730183,
  0,
  0
]
, 'utc_rd_values() on 2000-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2000-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2000-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-05 Gregorian' );
Trewsday 13 Rethe 7464

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087897600, 'utc_rd_as_seconds() on 2000-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730184,
  0,
  0
]
, 'utc_rd_values() on 2000-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2000-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2000-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-06 Gregorian' );
Hevensday 14 Rethe 7464

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63087984000, 'utc_rd_as_seconds() on 2000-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730185,
  0,
  0
]
, 'utc_rd_values() on 2000-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2000-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2000-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-07 Gregorian' );
Mersday 15 Rethe 7464

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088070400, 'utc_rd_as_seconds() on 2000-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730186,
  0,
  0
]
, 'utc_rd_values() on 2000-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2000-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2000-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-08 Gregorian' );
Highday 16 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088156800, 'utc_rd_as_seconds() on 2000-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730187,
  0,
  0
]
, 'utc_rd_values() on 2000-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  11
]
, 'week() on 2000-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2000-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2000-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2000-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-09 Gregorian' );
Sterday 17 Rethe 7464

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088243200, 'utc_rd_as_seconds() on 2000-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730188,
  0,
  0
]
, 'utc_rd_values() on 2000-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2000-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2000-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-10 Gregorian' );
Sunday 18 Rethe 7464

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088329600, 'utc_rd_as_seconds() on 2000-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730189,
  0,
  0
]
, 'utc_rd_values() on 2000-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2000-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2000-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-11 Gregorian' );
Monday 19 Rethe 7464

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088416000, 'utc_rd_as_seconds() on 2000-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730190,
  0,
  0
]
, 'utc_rd_values() on 2000-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2000-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2000-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-12 Gregorian' );
Trewsday 20 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088502400, 'utc_rd_as_seconds() on 2000-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730191,
  0,
  0
]
, 'utc_rd_values() on 2000-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2000-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2000-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-13 Gregorian' );
Hevensday 21 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088588800, 'utc_rd_as_seconds() on 2000-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730192,
  0,
  0
]
, 'utc_rd_values() on 2000-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2000-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2000-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-14 Gregorian' );
Mersday 22 Rethe 7464

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088675200, 'utc_rd_as_seconds() on 2000-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730193,
  0,
  0
]
, 'utc_rd_values() on 2000-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2000-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2000-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-15 Gregorian' );
Highday 23 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088761600, 'utc_rd_as_seconds() on 2000-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730194,
  0,
  0
]
, 'utc_rd_values() on 2000-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  12
]
, 'week() on 2000-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2000-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2000-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2000-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-16 Gregorian' );
Sterday 24 Rethe 7464

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088848000, 'utc_rd_as_seconds() on 2000-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730195,
  0,
  0
]
, 'utc_rd_values() on 2000-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2000-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2000-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-17 Gregorian' );
Sunday 25 Rethe 7464

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63088934400, 'utc_rd_as_seconds() on 2000-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730196,
  0,
  0
]
, 'utc_rd_values() on 2000-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2000-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2000-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-18 Gregorian' );
Monday 26 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089020800, 'utc_rd_as_seconds() on 2000-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730197,
  0,
  0
]
, 'utc_rd_values() on 2000-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2000-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2000-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-19 Gregorian' );
Trewsday 27 Rethe 7464

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089107200, 'utc_rd_as_seconds() on 2000-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730198,
  0,
  0
]
, 'utc_rd_values() on 2000-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2000-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2000-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-20 Gregorian' );
Hevensday 28 Rethe 7464

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089193600, 'utc_rd_as_seconds() on 2000-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730199,
  0,
  0
]
, 'utc_rd_values() on 2000-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2000-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2000-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-21 Gregorian' );
Mersday 29 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089280000, 'utc_rd_as_seconds() on 2000-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730200,
  0,
  0
]
, 'utc_rd_values() on 2000-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2000-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2000-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2000-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2000-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-22 Gregorian' );
Highday 30 Rethe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089366400, 'utc_rd_as_seconds() on 2000-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730201,
  0,
  0
]
, 'utc_rd_values() on 2000-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  13
]
, 'week() on 2000-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2000-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2000-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2000-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-23 Gregorian' );
Sterday 1 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089452800, 'utc_rd_as_seconds() on 2000-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730202,
  0,
  0
]
, 'utc_rd_values() on 2000-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2000-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2000-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-24 Gregorian' );
Sunday 2 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089539200, 'utc_rd_as_seconds() on 2000-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730203,
  0,
  0
]
, 'utc_rd_values() on 2000-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2000-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2000-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-25 Gregorian' );
Monday 3 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089625600, 'utc_rd_as_seconds() on 2000-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730204,
  0,
  0
]
, 'utc_rd_values() on 2000-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2000-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2000-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-26 Gregorian' );
Trewsday 4 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089712000, 'utc_rd_as_seconds() on 2000-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730205,
  0,
  0
]
, 'utc_rd_values() on 2000-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2000-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2000-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-27 Gregorian' );
Hevensday 5 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089798400, 'utc_rd_as_seconds() on 2000-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730206,
  0,
  0
]
, 'utc_rd_values() on 2000-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2000-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2000-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-28 Gregorian' );
Mersday 6 Astron 7464

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089884800, 'utc_rd_as_seconds() on 2000-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730207,
  0,
  0
]
, 'utc_rd_values() on 2000-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2000-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2000-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-29 Gregorian' );
Highday 7 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63089971200, 'utc_rd_as_seconds() on 2000-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730208,
  0,
  0
]
, 'utc_rd_values() on 2000-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  14
]
, 'week() on 2000-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2000-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2000-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2000-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-30 Gregorian' );
Sterday 8 Astron 7464

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090057600, 'utc_rd_as_seconds() on 2000-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730209,
  0,
  0
]
, 'utc_rd_values() on 2000-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2000-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2000-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-03-31 Gregorian' );
Sunday 9 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090144000, 'utc_rd_as_seconds() on 2000-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730210,
  0,
  0
]
, 'utc_rd_values() on 2000-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2000-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2000-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-01 Gregorian' );
Monday 10 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090230400, 'utc_rd_as_seconds() on 2000-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730211,
  0,
  0
]
, 'utc_rd_values() on 2000-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2000-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2000-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-02 Gregorian' );
Trewsday 11 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090316800, 'utc_rd_as_seconds() on 2000-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730212,
  0,
  0
]
, 'utc_rd_values() on 2000-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2000-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2000-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-03 Gregorian' );
Hevensday 12 Astron 7464

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090403200, 'utc_rd_as_seconds() on 2000-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730213,
  0,
  0
]
, 'utc_rd_values() on 2000-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2000-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2000-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-04 Gregorian' );
Mersday 13 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090489600, 'utc_rd_as_seconds() on 2000-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730214,
  0,
  0
]
, 'utc_rd_values() on 2000-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2000-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2000-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-05 Gregorian' );
Highday 14 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090576000, 'utc_rd_as_seconds() on 2000-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730215,
  0,
  0
]
, 'utc_rd_values() on 2000-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  15
]
, 'week() on 2000-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2000-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2000-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2000-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-06 Gregorian' );
Sterday 15 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090662400, 'utc_rd_as_seconds() on 2000-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730216,
  0,
  0
]
, 'utc_rd_values() on 2000-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2000-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2000-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-07 Gregorian' );
Sunday 16 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090748800, 'utc_rd_as_seconds() on 2000-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730217,
  0,
  0
]
, 'utc_rd_values() on 2000-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2000-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2000-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-08 Gregorian' );
Monday 17 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090835200, 'utc_rd_as_seconds() on 2000-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730218,
  0,
  0
]
, 'utc_rd_values() on 2000-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2000-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2000-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-09 Gregorian' );
Trewsday 18 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63090921600, 'utc_rd_as_seconds() on 2000-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730219,
  0,
  0
]
, 'utc_rd_values() on 2000-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2000-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2000-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-10 Gregorian' );
Hevensday 19 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091008000, 'utc_rd_as_seconds() on 2000-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730220,
  0,
  0
]
, 'utc_rd_values() on 2000-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2000-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2000-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-11 Gregorian' );
Mersday 20 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091094400, 'utc_rd_as_seconds() on 2000-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730221,
  0,
  0
]
, 'utc_rd_values() on 2000-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2000-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2000-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-12 Gregorian' );
Highday 21 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091180800, 'utc_rd_as_seconds() on 2000-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730222,
  0,
  0
]
, 'utc_rd_values() on 2000-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  16
]
, 'week() on 2000-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2000-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2000-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2000-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-13 Gregorian' );
Sterday 22 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091267200, 'utc_rd_as_seconds() on 2000-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730223,
  0,
  0
]
, 'utc_rd_values() on 2000-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2000-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2000-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-14 Gregorian' );
Sunday 23 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091353600, 'utc_rd_as_seconds() on 2000-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730224,
  0,
  0
]
, 'utc_rd_values() on 2000-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2000-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2000-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-15 Gregorian' );
Monday 24 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091440000, 'utc_rd_as_seconds() on 2000-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730225,
  0,
  0
]
, 'utc_rd_values() on 2000-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2000-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2000-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-16 Gregorian' );
Trewsday 25 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091526400, 'utc_rd_as_seconds() on 2000-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730226,
  0,
  0
]
, 'utc_rd_values() on 2000-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2000-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2000-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-17 Gregorian' );
Hevensday 26 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091612800, 'utc_rd_as_seconds() on 2000-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730227,
  0,
  0
]
, 'utc_rd_values() on 2000-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2000-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2000-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-18 Gregorian' );
Mersday 27 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091699200, 'utc_rd_as_seconds() on 2000-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730228,
  0,
  0
]
, 'utc_rd_values() on 2000-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2000-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2000-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-19 Gregorian' );
Highday 28 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091785600, 'utc_rd_as_seconds() on 2000-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730229,
  0,
  0
]
, 'utc_rd_values() on 2000-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  17
]
, 'week() on 2000-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2000-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2000-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2000-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-20 Gregorian' );
Sterday 29 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091872000, 'utc_rd_as_seconds() on 2000-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730230,
  0,
  0
]
, 'utc_rd_values() on 2000-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2000-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2000-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2000-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2000-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-21 Gregorian' );
Sunday 30 Astron 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63091958400, 'utc_rd_as_seconds() on 2000-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730231,
  0,
  0
]
, 'utc_rd_values() on 2000-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2000-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2000-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-22 Gregorian' );
Monday 1 Thrimidge 7464

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092044800, 'utc_rd_as_seconds() on 2000-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730232,
  0,
  0
]
, 'utc_rd_values() on 2000-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2000-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2000-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-23 Gregorian' );
Trewsday 2 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092131200, 'utc_rd_as_seconds() on 2000-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730233,
  0,
  0
]
, 'utc_rd_values() on 2000-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2000-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2000-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-24 Gregorian' );
Hevensday 3 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092217600, 'utc_rd_as_seconds() on 2000-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730234,
  0,
  0
]
, 'utc_rd_values() on 2000-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2000-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2000-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-25 Gregorian' );
Mersday 4 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092304000, 'utc_rd_as_seconds() on 2000-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730235,
  0,
  0
]
, 'utc_rd_values() on 2000-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2000-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2000-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-26 Gregorian' );
Highday 5 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092390400, 'utc_rd_as_seconds() on 2000-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730236,
  0,
  0
]
, 'utc_rd_values() on 2000-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  18
]
, 'week() on 2000-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2000-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2000-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2000-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-27 Gregorian' );
Sterday 6 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092476800, 'utc_rd_as_seconds() on 2000-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730237,
  0,
  0
]
, 'utc_rd_values() on 2000-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2000-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2000-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-28 Gregorian' );
Sunday 7 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092563200, 'utc_rd_as_seconds() on 2000-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730238,
  0,
  0
]
, 'utc_rd_values() on 2000-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2000-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2000-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-29 Gregorian' );
Monday 8 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092649600, 'utc_rd_as_seconds() on 2000-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730239,
  0,
  0
]
, 'utc_rd_values() on 2000-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2000-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2000-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-04-30 Gregorian' );
Trewsday 9 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092736000, 'utc_rd_as_seconds() on 2000-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730240,
  0,
  0
]
, 'utc_rd_values() on 2000-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2000-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2000-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-01 Gregorian' );
Hevensday 10 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092822400, 'utc_rd_as_seconds() on 2000-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730241,
  0,
  0
]
, 'utc_rd_values() on 2000-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2000-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2000-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-02 Gregorian' );
Mersday 11 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092908800, 'utc_rd_as_seconds() on 2000-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730242,
  0,
  0
]
, 'utc_rd_values() on 2000-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2000-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2000-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-03 Gregorian' );
Highday 12 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63092995200, 'utc_rd_as_seconds() on 2000-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730243,
  0,
  0
]
, 'utc_rd_values() on 2000-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  19
]
, 'week() on 2000-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2000-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2000-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2000-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-04 Gregorian' );
Sterday 13 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093081600, 'utc_rd_as_seconds() on 2000-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730244,
  0,
  0
]
, 'utc_rd_values() on 2000-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2000-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2000-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-05 Gregorian' );
Sunday 14 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093168000, 'utc_rd_as_seconds() on 2000-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730245,
  0,
  0
]
, 'utc_rd_values() on 2000-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2000-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2000-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-06 Gregorian' );
Monday 15 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093254400, 'utc_rd_as_seconds() on 2000-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730246,
  0,
  0
]
, 'utc_rd_values() on 2000-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2000-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2000-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-07 Gregorian' );
Trewsday 16 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093340800, 'utc_rd_as_seconds() on 2000-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730247,
  0,
  0
]
, 'utc_rd_values() on 2000-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2000-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2000-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-08 Gregorian' );
Hevensday 17 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093427200, 'utc_rd_as_seconds() on 2000-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730248,
  0,
  0
]
, 'utc_rd_values() on 2000-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2000-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2000-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-09 Gregorian' );
Mersday 18 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093513600, 'utc_rd_as_seconds() on 2000-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730249,
  0,
  0
]
, 'utc_rd_values() on 2000-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2000-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2000-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-10 Gregorian' );
Highday 19 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093600000, 'utc_rd_as_seconds() on 2000-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730250,
  0,
  0
]
, 'utc_rd_values() on 2000-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  20
]
, 'week() on 2000-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2000-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2000-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2000-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-11 Gregorian' );
Sterday 20 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093686400, 'utc_rd_as_seconds() on 2000-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730251,
  0,
  0
]
, 'utc_rd_values() on 2000-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2000-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2000-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-12 Gregorian' );
Sunday 21 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093772800, 'utc_rd_as_seconds() on 2000-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730252,
  0,
  0
]
, 'utc_rd_values() on 2000-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2000-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2000-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-13 Gregorian' );
Monday 22 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093859200, 'utc_rd_as_seconds() on 2000-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730253,
  0,
  0
]
, 'utc_rd_values() on 2000-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2000-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2000-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-14 Gregorian' );
Trewsday 23 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63093945600, 'utc_rd_as_seconds() on 2000-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730254,
  0,
  0
]
, 'utc_rd_values() on 2000-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2000-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2000-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-15 Gregorian' );
Hevensday 24 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094032000, 'utc_rd_as_seconds() on 2000-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730255,
  0,
  0
]
, 'utc_rd_values() on 2000-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2000-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2000-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-16 Gregorian' );
Mersday 25 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094118400, 'utc_rd_as_seconds() on 2000-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730256,
  0,
  0
]
, 'utc_rd_values() on 2000-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2000-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2000-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-17 Gregorian' );
Highday 26 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094204800, 'utc_rd_as_seconds() on 2000-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730257,
  0,
  0
]
, 'utc_rd_values() on 2000-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  21
]
, 'week() on 2000-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2000-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2000-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2000-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-18 Gregorian' );
Sterday 27 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094291200, 'utc_rd_as_seconds() on 2000-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730258,
  0,
  0
]
, 'utc_rd_values() on 2000-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2000-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2000-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-19 Gregorian' );
Sunday 28 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094377600, 'utc_rd_as_seconds() on 2000-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730259,
  0,
  0
]
, 'utc_rd_values() on 2000-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2000-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2000-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-20 Gregorian' );
Monday 29 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094464000, 'utc_rd_as_seconds() on 2000-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730260,
  0,
  0
]
, 'utc_rd_values() on 2000-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2000-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2000-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2000-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2000-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-21 Gregorian' );
Trewsday 30 Thrimidge 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094550400, 'utc_rd_as_seconds() on 2000-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730261,
  0,
  0
]
, 'utc_rd_values() on 2000-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2000-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2000-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-22 Gregorian' );
Hevensday 1 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094636800, 'utc_rd_as_seconds() on 2000-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730262,
  0,
  0
]
, 'utc_rd_values() on 2000-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2000-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2000-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-23 Gregorian' );
Mersday 2 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094723200, 'utc_rd_as_seconds() on 2000-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730263,
  0,
  0
]
, 'utc_rd_values() on 2000-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2000-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2000-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-24 Gregorian' );
Highday 3 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094809600, 'utc_rd_as_seconds() on 2000-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730264,
  0,
  0
]
, 'utc_rd_values() on 2000-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  22
]
, 'week() on 2000-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2000-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2000-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2000-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-25 Gregorian' );
Sterday 4 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094896000, 'utc_rd_as_seconds() on 2000-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730265,
  0,
  0
]
, 'utc_rd_values() on 2000-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2000-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2000-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-26 Gregorian' );
Sunday 5 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63094982400, 'utc_rd_as_seconds() on 2000-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730266,
  0,
  0
]
, 'utc_rd_values() on 2000-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2000-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2000-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-27 Gregorian' );
Monday 6 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095068800, 'utc_rd_as_seconds() on 2000-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730267,
  0,
  0
]
, 'utc_rd_values() on 2000-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2000-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2000-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-28 Gregorian' );
Trewsday 7 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095155200, 'utc_rd_as_seconds() on 2000-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730268,
  0,
  0
]
, 'utc_rd_values() on 2000-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2000-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2000-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-29 Gregorian' );
Hevensday 8 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095241600, 'utc_rd_as_seconds() on 2000-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730269,
  0,
  0
]
, 'utc_rd_values() on 2000-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2000-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2000-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-30 Gregorian' );
Mersday 9 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095328000, 'utc_rd_as_seconds() on 2000-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730270,
  0,
  0
]
, 'utc_rd_values() on 2000-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2000-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2000-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-05-31 Gregorian' );
Highday 10 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095414400, 'utc_rd_as_seconds() on 2000-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730271,
  0,
  0
]
, 'utc_rd_values() on 2000-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  23
]
, 'week() on 2000-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2000-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2000-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2000-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-01 Gregorian' );
Sterday 11 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095500800, 'utc_rd_as_seconds() on 2000-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730272,
  0,
  0
]
, 'utc_rd_values() on 2000-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2000-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2000-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-02 Gregorian' );
Sunday 12 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095587200, 'utc_rd_as_seconds() on 2000-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730273,
  0,
  0
]
, 'utc_rd_values() on 2000-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2000-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2000-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-03 Gregorian' );
Monday 13 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095673600, 'utc_rd_as_seconds() on 2000-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730274,
  0,
  0
]
, 'utc_rd_values() on 2000-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2000-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2000-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-04 Gregorian' );
Trewsday 14 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095760000, 'utc_rd_as_seconds() on 2000-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730275,
  0,
  0
]
, 'utc_rd_values() on 2000-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2000-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2000-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-05 Gregorian' );
Hevensday 15 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095846400, 'utc_rd_as_seconds() on 2000-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730276,
  0,
  0
]
, 'utc_rd_values() on 2000-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2000-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2000-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-06 Gregorian' );
Mersday 16 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63095932800, 'utc_rd_as_seconds() on 2000-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730277,
  0,
  0
]
, 'utc_rd_values() on 2000-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2000-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2000-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-07 Gregorian' );
Highday 17 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096019200, 'utc_rd_as_seconds() on 2000-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730278,
  0,
  0
]
, 'utc_rd_values() on 2000-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  24
]
, 'week() on 2000-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2000-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2000-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2000-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-08 Gregorian' );
Sterday 18 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096105600, 'utc_rd_as_seconds() on 2000-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730279,
  0,
  0
]
, 'utc_rd_values() on 2000-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2000-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2000-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-09 Gregorian' );
Sunday 19 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096192000, 'utc_rd_as_seconds() on 2000-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730280,
  0,
  0
]
, 'utc_rd_values() on 2000-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2000-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2000-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-10 Gregorian' );
Monday 20 Forelithe 7464

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096278400, 'utc_rd_as_seconds() on 2000-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730281,
  0,
  0
]
, 'utc_rd_values() on 2000-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2000-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2000-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-11 Gregorian' );
Trewsday 21 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096364800, 'utc_rd_as_seconds() on 2000-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730282,
  0,
  0
]
, 'utc_rd_values() on 2000-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2000-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2000-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-12 Gregorian' );
Hevensday 22 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096451200, 'utc_rd_as_seconds() on 2000-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730283,
  0,
  0
]
, 'utc_rd_values() on 2000-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2000-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2000-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-13 Gregorian' );
Mersday 23 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096537600, 'utc_rd_as_seconds() on 2000-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730284,
  0,
  0
]
, 'utc_rd_values() on 2000-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2000-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2000-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-14 Gregorian' );
Highday 24 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096624000, 'utc_rd_as_seconds() on 2000-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730285,
  0,
  0
]
, 'utc_rd_values() on 2000-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  25
]
, 'week() on 2000-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2000-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2000-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2000-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-15 Gregorian' );
Sterday 25 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096710400, 'utc_rd_as_seconds() on 2000-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730286,
  0,
  0
]
, 'utc_rd_values() on 2000-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2000-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2000-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-16 Gregorian' );
Sunday 26 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096796800, 'utc_rd_as_seconds() on 2000-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730287,
  0,
  0
]
, 'utc_rd_values() on 2000-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2000-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2000-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-17 Gregorian' );
Monday 27 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096883200, 'utc_rd_as_seconds() on 2000-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730288,
  0,
  0
]
, 'utc_rd_values() on 2000-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2000-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2000-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-18 Gregorian' );
Trewsday 28 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63096969600, 'utc_rd_as_seconds() on 2000-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730289,
  0,
  0
]
, 'utc_rd_values() on 2000-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2000-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2000-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-19 Gregorian' );
Hevensday 29 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097056000, 'utc_rd_as_seconds() on 2000-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730290,
  0,
  0
]
, 'utc_rd_values() on 2000-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2000-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2000-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2000-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2000-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-20 Gregorian' );
Mersday 30 Forelithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097142400, 'utc_rd_as_seconds() on 2000-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730291,
  0,
  0
]
, 'utc_rd_values() on 2000-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2000-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2000-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2000-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2000-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-21 Gregorian' );
Highday 1 Lithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097228800, 'utc_rd_as_seconds() on 2000-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730292,
  0,
  0
]
, 'utc_rd_values() on 2000-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  26
]
, 'week() on 2000-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2000-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2000-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2000-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2000-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2000-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2000-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2000-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2000-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2000-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-22 Gregorian' );
Midyear's day 7464

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097315200, 'utc_rd_as_seconds() on 2000-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730293,
  0,
  0
]
, 'utc_rd_values() on 2000-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2000-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  0
]
, 'week() on 2000-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2000-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2000-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2000-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2000-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2000-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2000-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2000-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 4, 'holiday() on 2000-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Overlithe', 'holiday_name() on 2000-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-23 Gregorian' );
Overlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097401600, 'utc_rd_as_seconds() on 2000-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730294,
  0,
  0
]
, 'utc_rd_values() on 2000-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2000-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  0
]
, 'week() on 2000-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2000-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2000-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2000-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2000-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2000-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-24 Gregorian' );
Sterday 2 Lithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097488000, 'utc_rd_as_seconds() on 2000-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730295,
  0,
  0
]
, 'utc_rd_values() on 2000-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2000-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2000-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-25 Gregorian' );
Sunday 1 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097574400, 'utc_rd_as_seconds() on 2000-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730296,
  0,
  0
]
, 'utc_rd_values() on 2000-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2000-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2000-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-26 Gregorian' );
Monday 2 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097660800, 'utc_rd_as_seconds() on 2000-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730297,
  0,
  0
]
, 'utc_rd_values() on 2000-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2000-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2000-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-27 Gregorian' );
Trewsday 3 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097747200, 'utc_rd_as_seconds() on 2000-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730298,
  0,
  0
]
, 'utc_rd_values() on 2000-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2000-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2000-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-28 Gregorian' );
Hevensday 4 Afterlithe 7464

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097833600, 'utc_rd_as_seconds() on 2000-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730299,
  0,
  0
]
, 'utc_rd_values() on 2000-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2000-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2000-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-29 Gregorian' );
Mersday 5 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63097920000, 'utc_rd_as_seconds() on 2000-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730300,
  0,
  0
]
, 'utc_rd_values() on 2000-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2000-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2000-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-06-30 Gregorian' );
Highday 6 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098006400, 'utc_rd_as_seconds() on 2000-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730301,
  0,
  0
]
, 'utc_rd_values() on 2000-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  27
]
, 'week() on 2000-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2000-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2000-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2000-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-01 Gregorian' );
Sterday 7 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098092800, 'utc_rd_as_seconds() on 2000-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730302,
  0,
  0
]
, 'utc_rd_values() on 2000-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2000-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2000-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-02 Gregorian' );
Sunday 8 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098179200, 'utc_rd_as_seconds() on 2000-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730303,
  0,
  0
]
, 'utc_rd_values() on 2000-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2000-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2000-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-03 Gregorian' );
Monday 9 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098265600, 'utc_rd_as_seconds() on 2000-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730304,
  0,
  0
]
, 'utc_rd_values() on 2000-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2000-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2000-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-04 Gregorian' );
Trewsday 10 Afterlithe 7464

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098352000, 'utc_rd_as_seconds() on 2000-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730305,
  0,
  0
]
, 'utc_rd_values() on 2000-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2000-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2000-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-05 Gregorian' );
Hevensday 11 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098438400, 'utc_rd_as_seconds() on 2000-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730306,
  0,
  0
]
, 'utc_rd_values() on 2000-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2000-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2000-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-06 Gregorian' );
Mersday 12 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098524800, 'utc_rd_as_seconds() on 2000-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730307,
  0,
  0
]
, 'utc_rd_values() on 2000-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2000-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2000-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-07 Gregorian' );
Highday 13 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098611200, 'utc_rd_as_seconds() on 2000-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730308,
  0,
  0
]
, 'utc_rd_values() on 2000-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  28
]
, 'week() on 2000-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2000-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2000-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2000-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-08 Gregorian' );
Sterday 14 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098697600, 'utc_rd_as_seconds() on 2000-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730309,
  0,
  0
]
, 'utc_rd_values() on 2000-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2000-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2000-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-09 Gregorian' );
Sunday 15 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098784000, 'utc_rd_as_seconds() on 2000-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730310,
  0,
  0
]
, 'utc_rd_values() on 2000-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2000-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2000-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-10 Gregorian' );
Monday 16 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098870400, 'utc_rd_as_seconds() on 2000-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730311,
  0,
  0
]
, 'utc_rd_values() on 2000-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2000-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2000-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-11 Gregorian' );
Trewsday 17 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63098956800, 'utc_rd_as_seconds() on 2000-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730312,
  0,
  0
]
, 'utc_rd_values() on 2000-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2000-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2000-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-12 Gregorian' );
Hevensday 18 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099043200, 'utc_rd_as_seconds() on 2000-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730313,
  0,
  0
]
, 'utc_rd_values() on 2000-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2000-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2000-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-13 Gregorian' );
Mersday 19 Afterlithe 7464

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099129600, 'utc_rd_as_seconds() on 2000-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730314,
  0,
  0
]
, 'utc_rd_values() on 2000-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2000-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2000-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-14 Gregorian' );
Highday 20 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099216000, 'utc_rd_as_seconds() on 2000-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730315,
  0,
  0
]
, 'utc_rd_values() on 2000-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  29
]
, 'week() on 2000-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2000-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2000-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2000-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-15 Gregorian' );
Sterday 21 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099302400, 'utc_rd_as_seconds() on 2000-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730316,
  0,
  0
]
, 'utc_rd_values() on 2000-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2000-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2000-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-16 Gregorian' );
Sunday 22 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099388800, 'utc_rd_as_seconds() on 2000-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730317,
  0,
  0
]
, 'utc_rd_values() on 2000-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2000-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2000-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-17 Gregorian' );
Monday 23 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099475200, 'utc_rd_as_seconds() on 2000-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730318,
  0,
  0
]
, 'utc_rd_values() on 2000-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2000-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2000-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-18 Gregorian' );
Trewsday 24 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099561600, 'utc_rd_as_seconds() on 2000-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730319,
  0,
  0
]
, 'utc_rd_values() on 2000-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2000-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2000-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-19 Gregorian' );
Hevensday 25 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099648000, 'utc_rd_as_seconds() on 2000-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730320,
  0,
  0
]
, 'utc_rd_values() on 2000-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2000-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2000-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-20 Gregorian' );
Mersday 26 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099734400, 'utc_rd_as_seconds() on 2000-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730321,
  0,
  0
]
, 'utc_rd_values() on 2000-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2000-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2000-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-21 Gregorian' );
Highday 27 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099820800, 'utc_rd_as_seconds() on 2000-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730322,
  0,
  0
]
, 'utc_rd_values() on 2000-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  30
]
, 'week() on 2000-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2000-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2000-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2000-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-22 Gregorian' );
Sterday 28 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099907200, 'utc_rd_as_seconds() on 2000-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730323,
  0,
  0
]
, 'utc_rd_values() on 2000-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2000-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2000-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-23 Gregorian' );
Sunday 29 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63099993600, 'utc_rd_as_seconds() on 2000-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730324,
  0,
  0
]
, 'utc_rd_values() on 2000-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2000-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2000-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2000-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2000-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-24 Gregorian' );
Monday 30 Afterlithe 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100080000, 'utc_rd_as_seconds() on 2000-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730325,
  0,
  0
]
, 'utc_rd_values() on 2000-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2000-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2000-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-25 Gregorian' );
Trewsday 1 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100166400, 'utc_rd_as_seconds() on 2000-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730326,
  0,
  0
]
, 'utc_rd_values() on 2000-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2000-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2000-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-26 Gregorian' );
Hevensday 2 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100252800, 'utc_rd_as_seconds() on 2000-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730327,
  0,
  0
]
, 'utc_rd_values() on 2000-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2000-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2000-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-27 Gregorian' );
Mersday 3 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100339200, 'utc_rd_as_seconds() on 2000-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730328,
  0,
  0
]
, 'utc_rd_values() on 2000-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2000-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2000-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-28 Gregorian' );
Highday 4 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100425600, 'utc_rd_as_seconds() on 2000-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730329,
  0,
  0
]
, 'utc_rd_values() on 2000-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  31
]
, 'week() on 2000-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2000-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2000-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2000-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-29 Gregorian' );
Sterday 5 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100512000, 'utc_rd_as_seconds() on 2000-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730330,
  0,
  0
]
, 'utc_rd_values() on 2000-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2000-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2000-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-30 Gregorian' );
Sunday 6 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100598400, 'utc_rd_as_seconds() on 2000-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730331,
  0,
  0
]
, 'utc_rd_values() on 2000-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2000-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2000-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-07-31 Gregorian' );
Monday 7 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100684800, 'utc_rd_as_seconds() on 2000-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730332,
  0,
  0
]
, 'utc_rd_values() on 2000-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2000-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2000-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-01 Gregorian' );
Trewsday 8 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100771200, 'utc_rd_as_seconds() on 2000-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730333,
  0,
  0
]
, 'utc_rd_values() on 2000-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2000-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2000-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-02 Gregorian' );
Hevensday 9 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100857600, 'utc_rd_as_seconds() on 2000-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730334,
  0,
  0
]
, 'utc_rd_values() on 2000-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2000-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2000-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-03 Gregorian' );
Mersday 10 Wedmath 7464

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63100944000, 'utc_rd_as_seconds() on 2000-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730335,
  0,
  0
]
, 'utc_rd_values() on 2000-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2000-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2000-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-04 Gregorian' );
Highday 11 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101030400, 'utc_rd_as_seconds() on 2000-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730336,
  0,
  0
]
, 'utc_rd_values() on 2000-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  32
]
, 'week() on 2000-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2000-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2000-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2000-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-05 Gregorian' );
Sterday 12 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101116800, 'utc_rd_as_seconds() on 2000-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730337,
  0,
  0
]
, 'utc_rd_values() on 2000-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2000-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2000-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-06 Gregorian' );
Sunday 13 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101203200, 'utc_rd_as_seconds() on 2000-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730338,
  0,
  0
]
, 'utc_rd_values() on 2000-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2000-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2000-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-07 Gregorian' );
Monday 14 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101289600, 'utc_rd_as_seconds() on 2000-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730339,
  0,
  0
]
, 'utc_rd_values() on 2000-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2000-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2000-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-08 Gregorian' );
Trewsday 15 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101376000, 'utc_rd_as_seconds() on 2000-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730340,
  0,
  0
]
, 'utc_rd_values() on 2000-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2000-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2000-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-09 Gregorian' );
Hevensday 16 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101462400, 'utc_rd_as_seconds() on 2000-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730341,
  0,
  0
]
, 'utc_rd_values() on 2000-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2000-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2000-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-10 Gregorian' );
Mersday 17 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101548800, 'utc_rd_as_seconds() on 2000-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730342,
  0,
  0
]
, 'utc_rd_values() on 2000-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2000-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2000-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-11 Gregorian' );
Highday 18 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101635200, 'utc_rd_as_seconds() on 2000-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730343,
  0,
  0
]
, 'utc_rd_values() on 2000-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  33
]
, 'week() on 2000-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2000-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2000-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2000-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-12 Gregorian' );
Sterday 19 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101721600, 'utc_rd_as_seconds() on 2000-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730344,
  0,
  0
]
, 'utc_rd_values() on 2000-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2000-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2000-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-13 Gregorian' );
Sunday 20 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101808000, 'utc_rd_as_seconds() on 2000-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730345,
  0,
  0
]
, 'utc_rd_values() on 2000-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2000-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2000-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-14 Gregorian' );
Monday 21 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101894400, 'utc_rd_as_seconds() on 2000-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730346,
  0,
  0
]
, 'utc_rd_values() on 2000-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2000-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2000-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-15 Gregorian' );
Trewsday 22 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63101980800, 'utc_rd_as_seconds() on 2000-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730347,
  0,
  0
]
, 'utc_rd_values() on 2000-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2000-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2000-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-16 Gregorian' );
Hevensday 23 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102067200, 'utc_rd_as_seconds() on 2000-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730348,
  0,
  0
]
, 'utc_rd_values() on 2000-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2000-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2000-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-17 Gregorian' );
Mersday 24 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102153600, 'utc_rd_as_seconds() on 2000-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730349,
  0,
  0
]
, 'utc_rd_values() on 2000-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2000-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2000-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-18 Gregorian' );
Highday 25 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102240000, 'utc_rd_as_seconds() on 2000-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730350,
  0,
  0
]
, 'utc_rd_values() on 2000-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  34
]
, 'week() on 2000-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2000-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2000-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2000-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-19 Gregorian' );
Sterday 26 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102326400, 'utc_rd_as_seconds() on 2000-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730351,
  0,
  0
]
, 'utc_rd_values() on 2000-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2000-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2000-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-20 Gregorian' );
Sunday 27 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102412800, 'utc_rd_as_seconds() on 2000-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730352,
  0,
  0
]
, 'utc_rd_values() on 2000-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2000-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2000-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-21 Gregorian' );
Monday 28 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102499200, 'utc_rd_as_seconds() on 2000-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730353,
  0,
  0
]
, 'utc_rd_values() on 2000-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2000-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2000-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-22 Gregorian' );
Trewsday 29 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102585600, 'utc_rd_as_seconds() on 2000-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730354,
  0,
  0
]
, 'utc_rd_values() on 2000-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2000-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2000-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2000-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2000-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-23 Gregorian' );
Hevensday 30 Wedmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102672000, 'utc_rd_as_seconds() on 2000-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730355,
  0,
  0
]
, 'utc_rd_values() on 2000-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2000-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2000-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-24 Gregorian' );
Mersday 1 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102758400, 'utc_rd_as_seconds() on 2000-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730356,
  0,
  0
]
, 'utc_rd_values() on 2000-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2000-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2000-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-25 Gregorian' );
Highday 2 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102844800, 'utc_rd_as_seconds() on 2000-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730357,
  0,
  0
]
, 'utc_rd_values() on 2000-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  35
]
, 'week() on 2000-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2000-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2000-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2000-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-26 Gregorian' );
Sterday 3 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63102931200, 'utc_rd_as_seconds() on 2000-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730358,
  0,
  0
]
, 'utc_rd_values() on 2000-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2000-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2000-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-27 Gregorian' );
Sunday 4 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103017600, 'utc_rd_as_seconds() on 2000-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730359,
  0,
  0
]
, 'utc_rd_values() on 2000-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2000-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2000-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-28 Gregorian' );
Monday 5 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103104000, 'utc_rd_as_seconds() on 2000-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730360,
  0,
  0
]
, 'utc_rd_values() on 2000-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2000-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2000-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-29 Gregorian' );
Trewsday 6 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103190400, 'utc_rd_as_seconds() on 2000-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730361,
  0,
  0
]
, 'utc_rd_values() on 2000-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2000-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2000-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-30 Gregorian' );
Hevensday 7 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103276800, 'utc_rd_as_seconds() on 2000-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730362,
  0,
  0
]
, 'utc_rd_values() on 2000-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2000-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2000-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-08-31 Gregorian' );
Mersday 8 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103363200, 'utc_rd_as_seconds() on 2000-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730363,
  0,
  0
]
, 'utc_rd_values() on 2000-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2000-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2000-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-01 Gregorian' );
Highday 9 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103449600, 'utc_rd_as_seconds() on 2000-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730364,
  0,
  0
]
, 'utc_rd_values() on 2000-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  36
]
, 'week() on 2000-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2000-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2000-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2000-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-02 Gregorian' );
Sterday 10 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103536000, 'utc_rd_as_seconds() on 2000-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730365,
  0,
  0
]
, 'utc_rd_values() on 2000-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2000-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2000-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-03 Gregorian' );
Sunday 11 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103622400, 'utc_rd_as_seconds() on 2000-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730366,
  0,
  0
]
, 'utc_rd_values() on 2000-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2000-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2000-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-04 Gregorian' );
Monday 12 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103708800, 'utc_rd_as_seconds() on 2000-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730367,
  0,
  0
]
, 'utc_rd_values() on 2000-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2000-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2000-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-05 Gregorian' );
Trewsday 13 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103795200, 'utc_rd_as_seconds() on 2000-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730368,
  0,
  0
]
, 'utc_rd_values() on 2000-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2000-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2000-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-06 Gregorian' );
Hevensday 14 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103881600, 'utc_rd_as_seconds() on 2000-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730369,
  0,
  0
]
, 'utc_rd_values() on 2000-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2000-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2000-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-07 Gregorian' );
Mersday 15 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63103968000, 'utc_rd_as_seconds() on 2000-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730370,
  0,
  0
]
, 'utc_rd_values() on 2000-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2000-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2000-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-08 Gregorian' );
Highday 16 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104054400, 'utc_rd_as_seconds() on 2000-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730371,
  0,
  0
]
, 'utc_rd_values() on 2000-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  37
]
, 'week() on 2000-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2000-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2000-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2000-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-09 Gregorian' );
Sterday 17 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104140800, 'utc_rd_as_seconds() on 2000-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730372,
  0,
  0
]
, 'utc_rd_values() on 2000-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2000-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2000-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-10 Gregorian' );
Sunday 18 Halimath 7464

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104227200, 'utc_rd_as_seconds() on 2000-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730373,
  0,
  0
]
, 'utc_rd_values() on 2000-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2000-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2000-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-11 Gregorian' );
Monday 19 Halimath 7464

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104313600, 'utc_rd_as_seconds() on 2000-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730374,
  0,
  0
]
, 'utc_rd_values() on 2000-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2000-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2000-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-12 Gregorian' );
Trewsday 20 Halimath 7464

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104400000, 'utc_rd_as_seconds() on 2000-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730375,
  0,
  0
]
, 'utc_rd_values() on 2000-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2000-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2000-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-13 Gregorian' );
Hevensday 21 Halimath 7464

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104486400, 'utc_rd_as_seconds() on 2000-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730376,
  0,
  0
]
, 'utc_rd_values() on 2000-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2000-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2000-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-14 Gregorian' );
Mersday 22 Halimath 7464

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104572800, 'utc_rd_as_seconds() on 2000-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730377,
  0,
  0
]
, 'utc_rd_values() on 2000-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2000-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2000-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-15 Gregorian' );
Highday 23 Halimath 7464

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104659200, 'utc_rd_as_seconds() on 2000-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730378,
  0,
  0
]
, 'utc_rd_values() on 2000-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  38
]
, 'week() on 2000-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2000-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2000-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2000-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-16 Gregorian' );
Sterday 24 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104745600, 'utc_rd_as_seconds() on 2000-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730379,
  0,
  0
]
, 'utc_rd_values() on 2000-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2000-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2000-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-17 Gregorian' );
Sunday 25 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104832000, 'utc_rd_as_seconds() on 2000-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730380,
  0,
  0
]
, 'utc_rd_values() on 2000-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2000-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2000-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-18 Gregorian' );
Monday 26 Halimath 7464

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63104918400, 'utc_rd_as_seconds() on 2000-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730381,
  0,
  0
]
, 'utc_rd_values() on 2000-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2000-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2000-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-19 Gregorian' );
Trewsday 27 Halimath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105004800, 'utc_rd_as_seconds() on 2000-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730382,
  0,
  0
]
, 'utc_rd_values() on 2000-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2000-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2000-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-20 Gregorian' );
Hevensday 28 Halimath 7464

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105091200, 'utc_rd_as_seconds() on 2000-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730383,
  0,
  0
]
, 'utc_rd_values() on 2000-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2000-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2000-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-21 Gregorian' );
Mersday 29 Halimath 7464

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105177600, 'utc_rd_as_seconds() on 2000-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730384,
  0,
  0
]
, 'utc_rd_values() on 2000-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2000-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2000-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2000-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2000-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-22 Gregorian' );
Highday 30 Halimath 7464

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105264000, 'utc_rd_as_seconds() on 2000-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730385,
  0,
  0
]
, 'utc_rd_values() on 2000-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  39
]
, 'week() on 2000-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2000-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2000-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2000-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-23 Gregorian' );
Sterday 1 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105350400, 'utc_rd_as_seconds() on 2000-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730386,
  0,
  0
]
, 'utc_rd_values() on 2000-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2000-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2000-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-24 Gregorian' );
Sunday 2 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105436800, 'utc_rd_as_seconds() on 2000-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730387,
  0,
  0
]
, 'utc_rd_values() on 2000-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2000-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2000-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-25 Gregorian' );
Monday 3 Winterfilth 7464

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105523200, 'utc_rd_as_seconds() on 2000-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730388,
  0,
  0
]
, 'utc_rd_values() on 2000-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2000-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2000-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-26 Gregorian' );
Trewsday 4 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105609600, 'utc_rd_as_seconds() on 2000-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730389,
  0,
  0
]
, 'utc_rd_values() on 2000-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2000-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2000-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-27 Gregorian' );
Hevensday 5 Winterfilth 7464

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105696000, 'utc_rd_as_seconds() on 2000-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730390,
  0,
  0
]
, 'utc_rd_values() on 2000-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2000-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2000-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-28 Gregorian' );
Mersday 6 Winterfilth 7464

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105782400, 'utc_rd_as_seconds() on 2000-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730391,
  0,
  0
]
, 'utc_rd_values() on 2000-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2000-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2000-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-29 Gregorian' );
Highday 7 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105868800, 'utc_rd_as_seconds() on 2000-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730392,
  0,
  0
]
, 'utc_rd_values() on 2000-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  40
]
, 'week() on 2000-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2000-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2000-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2000-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-09-30 Gregorian' );
Sterday 8 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63105955200, 'utc_rd_as_seconds() on 2000-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730393,
  0,
  0
]
, 'utc_rd_values() on 2000-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2000-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2000-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-01 Gregorian' );
Sunday 9 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106041600, 'utc_rd_as_seconds() on 2000-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730394,
  0,
  0
]
, 'utc_rd_values() on 2000-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2000-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2000-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-02 Gregorian' );
Monday 10 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106128000, 'utc_rd_as_seconds() on 2000-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730395,
  0,
  0
]
, 'utc_rd_values() on 2000-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2000-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2000-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-03 Gregorian' );
Trewsday 11 Winterfilth 7464

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106214400, 'utc_rd_as_seconds() on 2000-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730396,
  0,
  0
]
, 'utc_rd_values() on 2000-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2000-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2000-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-04 Gregorian' );
Hevensday 12 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106300800, 'utc_rd_as_seconds() on 2000-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730397,
  0,
  0
]
, 'utc_rd_values() on 2000-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2000-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2000-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-05 Gregorian' );
Mersday 13 Winterfilth 7464

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106387200, 'utc_rd_as_seconds() on 2000-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730398,
  0,
  0
]
, 'utc_rd_values() on 2000-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2000-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2000-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-06 Gregorian' );
Highday 14 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106473600, 'utc_rd_as_seconds() on 2000-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730399,
  0,
  0
]
, 'utc_rd_values() on 2000-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  41
]
, 'week() on 2000-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2000-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2000-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2000-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-07 Gregorian' );
Sterday 15 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106560000, 'utc_rd_as_seconds() on 2000-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730400,
  0,
  0
]
, 'utc_rd_values() on 2000-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2000-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2000-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-08 Gregorian' );
Sunday 16 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106646400, 'utc_rd_as_seconds() on 2000-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730401,
  0,
  0
]
, 'utc_rd_values() on 2000-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2000-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2000-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-09 Gregorian' );
Monday 17 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106732800, 'utc_rd_as_seconds() on 2000-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730402,
  0,
  0
]
, 'utc_rd_values() on 2000-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2000-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2000-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-10 Gregorian' );
Trewsday 18 Winterfilth 7464

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106819200, 'utc_rd_as_seconds() on 2000-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730403,
  0,
  0
]
, 'utc_rd_values() on 2000-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2000-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2000-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-11 Gregorian' );
Hevensday 19 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106905600, 'utc_rd_as_seconds() on 2000-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730404,
  0,
  0
]
, 'utc_rd_values() on 2000-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2000-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2000-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-12 Gregorian' );
Mersday 20 Winterfilth 7464

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63106992000, 'utc_rd_as_seconds() on 2000-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730405,
  0,
  0
]
, 'utc_rd_values() on 2000-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2000-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2000-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-13 Gregorian' );
Highday 21 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107078400, 'utc_rd_as_seconds() on 2000-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730406,
  0,
  0
]
, 'utc_rd_values() on 2000-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  42
]
, 'week() on 2000-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2000-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2000-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2000-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-14 Gregorian' );
Sterday 22 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107164800, 'utc_rd_as_seconds() on 2000-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730407,
  0,
  0
]
, 'utc_rd_values() on 2000-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2000-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2000-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-15 Gregorian' );
Sunday 23 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107251200, 'utc_rd_as_seconds() on 2000-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730408,
  0,
  0
]
, 'utc_rd_values() on 2000-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2000-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2000-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-16 Gregorian' );
Monday 24 Winterfilth 7464

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107337600, 'utc_rd_as_seconds() on 2000-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730409,
  0,
  0
]
, 'utc_rd_values() on 2000-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2000-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2000-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-17 Gregorian' );
Trewsday 25 Winterfilth 7464

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107424000, 'utc_rd_as_seconds() on 2000-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730410,
  0,
  0
]
, 'utc_rd_values() on 2000-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2000-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2000-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-18 Gregorian' );
Hevensday 26 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107510400, 'utc_rd_as_seconds() on 2000-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730411,
  0,
  0
]
, 'utc_rd_values() on 2000-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2000-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2000-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-19 Gregorian' );
Mersday 27 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107596800, 'utc_rd_as_seconds() on 2000-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730412,
  0,
  0
]
, 'utc_rd_values() on 2000-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2000-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2000-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-20 Gregorian' );
Highday 28 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107683200, 'utc_rd_as_seconds() on 2000-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730413,
  0,
  0
]
, 'utc_rd_values() on 2000-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  43
]
, 'week() on 2000-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2000-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2000-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2000-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-21 Gregorian' );
Sterday 29 Winterfilth 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107769600, 'utc_rd_as_seconds() on 2000-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730414,
  0,
  0
]
, 'utc_rd_values() on 2000-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2000-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2000-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2000-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2000-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-22 Gregorian' );
Sunday 30 Winterfilth 7464

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107856000, 'utc_rd_as_seconds() on 2000-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730415,
  0,
  0
]
, 'utc_rd_values() on 2000-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2000-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2000-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-23 Gregorian' );
Monday 1 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63107942400, 'utc_rd_as_seconds() on 2000-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730416,
  0,
  0
]
, 'utc_rd_values() on 2000-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2000-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2000-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-24 Gregorian' );
Trewsday 2 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108028800, 'utc_rd_as_seconds() on 2000-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730417,
  0,
  0
]
, 'utc_rd_values() on 2000-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2000-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2000-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-25 Gregorian' );
Hevensday 3 Blotmath 7464

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108115200, 'utc_rd_as_seconds() on 2000-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730418,
  0,
  0
]
, 'utc_rd_values() on 2000-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2000-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2000-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-26 Gregorian' );
Mersday 4 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108201600, 'utc_rd_as_seconds() on 2000-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730419,
  0,
  0
]
, 'utc_rd_values() on 2000-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2000-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2000-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-27 Gregorian' );
Highday 5 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108288000, 'utc_rd_as_seconds() on 2000-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730420,
  0,
  0
]
, 'utc_rd_values() on 2000-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  44
]
, 'week() on 2000-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2000-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2000-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2000-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-28 Gregorian' );
Sterday 6 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108374400, 'utc_rd_as_seconds() on 2000-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730421,
  0,
  0
]
, 'utc_rd_values() on 2000-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2000-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2000-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-29 Gregorian' );
Sunday 7 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108460800, 'utc_rd_as_seconds() on 2000-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730422,
  0,
  0
]
, 'utc_rd_values() on 2000-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2000-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2000-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-30 Gregorian' );
Monday 8 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108547200, 'utc_rd_as_seconds() on 2000-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730423,
  0,
  0
]
, 'utc_rd_values() on 2000-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2000-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2000-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-10-31 Gregorian' );
Trewsday 9 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108633600, 'utc_rd_as_seconds() on 2000-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730424,
  0,
  0
]
, 'utc_rd_values() on 2000-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2000-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2000-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-01 Gregorian' );
Hevensday 10 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108720000, 'utc_rd_as_seconds() on 2000-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730425,
  0,
  0
]
, 'utc_rd_values() on 2000-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2000-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2000-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-02 Gregorian' );
Mersday 11 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108806400, 'utc_rd_as_seconds() on 2000-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730426,
  0,
  0
]
, 'utc_rd_values() on 2000-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2000-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2000-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-03 Gregorian' );
Highday 12 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108892800, 'utc_rd_as_seconds() on 2000-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730427,
  0,
  0
]
, 'utc_rd_values() on 2000-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  45
]
, 'week() on 2000-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2000-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2000-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2000-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-04 Gregorian' );
Sterday 13 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63108979200, 'utc_rd_as_seconds() on 2000-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730428,
  0,
  0
]
, 'utc_rd_values() on 2000-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2000-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2000-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-05 Gregorian' );
Sunday 14 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109065600, 'utc_rd_as_seconds() on 2000-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730429,
  0,
  0
]
, 'utc_rd_values() on 2000-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2000-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2000-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-06 Gregorian' );
Monday 15 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109152000, 'utc_rd_as_seconds() on 2000-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730430,
  0,
  0
]
, 'utc_rd_values() on 2000-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2000-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2000-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-07 Gregorian' );
Trewsday 16 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109238400, 'utc_rd_as_seconds() on 2000-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730431,
  0,
  0
]
, 'utc_rd_values() on 2000-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2000-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2000-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-08 Gregorian' );
Hevensday 17 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109324800, 'utc_rd_as_seconds() on 2000-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730432,
  0,
  0
]
, 'utc_rd_values() on 2000-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2000-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2000-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-09 Gregorian' );
Mersday 18 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109411200, 'utc_rd_as_seconds() on 2000-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730433,
  0,
  0
]
, 'utc_rd_values() on 2000-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2000-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2000-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-10 Gregorian' );
Highday 19 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109497600, 'utc_rd_as_seconds() on 2000-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730434,
  0,
  0
]
, 'utc_rd_values() on 2000-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  46
]
, 'week() on 2000-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2000-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2000-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2000-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-11 Gregorian' );
Sterday 20 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109584000, 'utc_rd_as_seconds() on 2000-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730435,
  0,
  0
]
, 'utc_rd_values() on 2000-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2000-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2000-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-12 Gregorian' );
Sunday 21 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109670400, 'utc_rd_as_seconds() on 2000-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730436,
  0,
  0
]
, 'utc_rd_values() on 2000-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2000-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2000-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-13 Gregorian' );
Monday 22 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109756800, 'utc_rd_as_seconds() on 2000-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730437,
  0,
  0
]
, 'utc_rd_values() on 2000-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2000-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2000-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-14 Gregorian' );
Trewsday 23 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109843200, 'utc_rd_as_seconds() on 2000-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730438,
  0,
  0
]
, 'utc_rd_values() on 2000-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2000-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2000-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-15 Gregorian' );
Hevensday 24 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63109929600, 'utc_rd_as_seconds() on 2000-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730439,
  0,
  0
]
, 'utc_rd_values() on 2000-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2000-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2000-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-16 Gregorian' );
Mersday 25 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110016000, 'utc_rd_as_seconds() on 2000-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730440,
  0,
  0
]
, 'utc_rd_values() on 2000-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2000-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2000-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-17 Gregorian' );
Highday 26 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110102400, 'utc_rd_as_seconds() on 2000-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730441,
  0,
  0
]
, 'utc_rd_values() on 2000-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  47
]
, 'week() on 2000-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2000-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2000-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2000-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-18 Gregorian' );
Sterday 27 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110188800, 'utc_rd_as_seconds() on 2000-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730442,
  0,
  0
]
, 'utc_rd_values() on 2000-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2000-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2000-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-19 Gregorian' );
Sunday 28 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110275200, 'utc_rd_as_seconds() on 2000-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730443,
  0,
  0
]
, 'utc_rd_values() on 2000-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2000-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2000-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-20 Gregorian' );
Monday 29 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110361600, 'utc_rd_as_seconds() on 2000-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730444,
  0,
  0
]
, 'utc_rd_values() on 2000-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2000-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2000-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2000-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2000-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-21 Gregorian' );
Trewsday 30 Blotmath 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110448000, 'utc_rd_as_seconds() on 2000-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730445,
  0,
  0
]
, 'utc_rd_values() on 2000-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2000-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2000-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-22 Gregorian' );
Hevensday 1 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110534400, 'utc_rd_as_seconds() on 2000-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730446,
  0,
  0
]
, 'utc_rd_values() on 2000-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2000-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2000-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-23 Gregorian' );
Mersday 2 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110620800, 'utc_rd_as_seconds() on 2000-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730447,
  0,
  0
]
, 'utc_rd_values() on 2000-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2000-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2000-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-24 Gregorian' );
Highday 3 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110707200, 'utc_rd_as_seconds() on 2000-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730448,
  0,
  0
]
, 'utc_rd_values() on 2000-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  48
]
, 'week() on 2000-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2000-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2000-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2000-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-25 Gregorian' );
Sterday 4 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110793600, 'utc_rd_as_seconds() on 2000-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730449,
  0,
  0
]
, 'utc_rd_values() on 2000-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2000-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2000-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-26 Gregorian' );
Sunday 5 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110880000, 'utc_rd_as_seconds() on 2000-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730450,
  0,
  0
]
, 'utc_rd_values() on 2000-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2000-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2000-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-27 Gregorian' );
Monday 6 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63110966400, 'utc_rd_as_seconds() on 2000-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730451,
  0,
  0
]
, 'utc_rd_values() on 2000-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2000-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2000-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-28 Gregorian' );
Trewsday 7 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111052800, 'utc_rd_as_seconds() on 2000-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730452,
  0,
  0
]
, 'utc_rd_values() on 2000-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2000-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2000-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-29 Gregorian' );
Hevensday 8 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111139200, 'utc_rd_as_seconds() on 2000-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730453,
  0,
  0
]
, 'utc_rd_values() on 2000-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2000-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2000-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2000-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2000-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2000-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-11-30 Gregorian' );
Mersday 9 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111225600, 'utc_rd_as_seconds() on 2000-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730454,
  0,
  0
]
, 'utc_rd_values() on 2000-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2000-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2000-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2000-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2000-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2000-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-01 Gregorian' );
Highday 10 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111312000, 'utc_rd_as_seconds() on 2000-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730455,
  0,
  0
]
, 'utc_rd_values() on 2000-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  49
]
, 'week() on 2000-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2000-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2000-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2000-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2000-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2000-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2000-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-02 Gregorian' );
Sterday 11 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111398400, 'utc_rd_as_seconds() on 2000-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730456,
  0,
  0
]
, 'utc_rd_values() on 2000-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2000-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2000-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2000-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2000-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2000-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-03 Gregorian' );
Sunday 12 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111484800, 'utc_rd_as_seconds() on 2000-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730457,
  0,
  0
]
, 'utc_rd_values() on 2000-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2000-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2000-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2000-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2000-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2000-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-04 Gregorian' );
Monday 13 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111571200, 'utc_rd_as_seconds() on 2000-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730458,
  0,
  0
]
, 'utc_rd_values() on 2000-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2000-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2000-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2000-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2000-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2000-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-05 Gregorian' );
Trewsday 14 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111657600, 'utc_rd_as_seconds() on 2000-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730459,
  0,
  0
]
, 'utc_rd_values() on 2000-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2000-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2000-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2000-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2000-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2000-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-06 Gregorian' );
Hevensday 15 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111744000, 'utc_rd_as_seconds() on 2000-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730460,
  0,
  0
]
, 'utc_rd_values() on 2000-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2000-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2000-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2000-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2000-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2000-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-07 Gregorian' );
Mersday 16 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111830400, 'utc_rd_as_seconds() on 2000-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730461,
  0,
  0
]
, 'utc_rd_values() on 2000-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2000-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2000-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2000-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2000-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2000-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-08 Gregorian' );
Highday 17 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63111916800, 'utc_rd_as_seconds() on 2000-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730462,
  0,
  0
]
, 'utc_rd_values() on 2000-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  50
]
, 'week() on 2000-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2000-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2000-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2000-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2000-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2000-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2000-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-09 Gregorian' );
Sterday 18 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112003200, 'utc_rd_as_seconds() on 2000-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730463,
  0,
  0
]
, 'utc_rd_values() on 2000-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2000-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2000-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2000-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2000-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2000-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-10 Gregorian' );
Sunday 19 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112089600, 'utc_rd_as_seconds() on 2000-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730464,
  0,
  0
]
, 'utc_rd_values() on 2000-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2000-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2000-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2000-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2000-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2000-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-11 Gregorian' );
Monday 20 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112176000, 'utc_rd_as_seconds() on 2000-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730465,
  0,
  0
]
, 'utc_rd_values() on 2000-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2000-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2000-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2000-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2000-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2000-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-12 Gregorian' );
Trewsday 21 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112262400, 'utc_rd_as_seconds() on 2000-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730466,
  0,
  0
]
, 'utc_rd_values() on 2000-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2000-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2000-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2000-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2000-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2000-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-13 Gregorian' );
Hevensday 22 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112348800, 'utc_rd_as_seconds() on 2000-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730467,
  0,
  0
]
, 'utc_rd_values() on 2000-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2000-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2000-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2000-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2000-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2000-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-14 Gregorian' );
Mersday 23 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112435200, 'utc_rd_as_seconds() on 2000-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730468,
  0,
  0
]
, 'utc_rd_values() on 2000-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2000-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2000-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2000-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2000-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2000-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-15 Gregorian' );
Highday 24 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112521600, 'utc_rd_as_seconds() on 2000-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730469,
  0,
  0
]
, 'utc_rd_values() on 2000-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  51
]
, 'week() on 2000-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2000-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2000-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2000-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2000-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2000-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2000-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-16 Gregorian' );
Sterday 25 Foreyule 7464

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112608000, 'utc_rd_as_seconds() on 2000-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730470,
  0,
  0
]
, 'utc_rd_values() on 2000-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2000-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2000-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2000-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2000-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2000-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-17 Gregorian' );
Sunday 26 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112694400, 'utc_rd_as_seconds() on 2000-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730471,
  0,
  0
]
, 'utc_rd_values() on 2000-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2000-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2000-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2000-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2000-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2000-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-18 Gregorian' );
Monday 27 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112780800, 'utc_rd_as_seconds() on 2000-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730472,
  0,
  0
]
, 'utc_rd_values() on 2000-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2000-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2000-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2000-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2000-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2000-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-19 Gregorian' );
Trewsday 28 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112867200, 'utc_rd_as_seconds() on 2000-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730473,
  0,
  0
]
, 'utc_rd_values() on 2000-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2000-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2000-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2000-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2000-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2000-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-20 Gregorian' );
Hevensday 29 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63112953600, 'utc_rd_as_seconds() on 2000-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730474,
  0,
  0
]
, 'utc_rd_values() on 2000-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2000-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2000-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2000-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2000-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2000-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2000-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2000-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-21 Gregorian' );
Mersday 30 Foreyule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113040000, 'utc_rd_as_seconds() on 2000-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730475,
  0,
  0
]
, 'utc_rd_values() on 2000-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 366, 'day_of_year() on 2000-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 366, 'doy() on 2000-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2000-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2000-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 1, 'is_leap_year() on 2000-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-22 Gregorian' );
Highday 1 Yule 7464
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113126400, 'utc_rd_as_seconds() on 2000-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730476,
  0,
  0
]
, 'utc_rd_values() on 2000-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7464,
  52
]
, 'week() on 2000-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2000-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7464, 'week_year() on 2000-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7464, 'year() on 2000-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2000-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2000-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2000-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2000-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2000-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2000-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2000-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2000-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2000-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-23 Gregorian' );
Sterday 2 Yule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113212800, 'utc_rd_as_seconds() on 2000-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730477,
  0,
  0
]
, 'utc_rd_values() on 2000-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2000-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2000-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2000-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2000-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2000-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-24 Gregorian' );
Sunday 1 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113299200, 'utc_rd_as_seconds() on 2000-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730478,
  0,
  0
]
, 'utc_rd_values() on 2000-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2000-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2000-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2000-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2000-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2000-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2000-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2000-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2000-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2000-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-25 Gregorian' );
Monday 2 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113385600, 'utc_rd_as_seconds() on 2000-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730479,
  0,
  0
]
, 'utc_rd_values() on 2000-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2000-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2000-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2000-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2000-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2000-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2000-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2000-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2000-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2000-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2000-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-26 Gregorian' );
Trewsday 3 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113472000, 'utc_rd_as_seconds() on 2000-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730480,
  0,
  0
]
, 'utc_rd_values() on 2000-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2000-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2000-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2000-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2000-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2000-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2000-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2000-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2000-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2000-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2000-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-27 Gregorian' );
Hevensday 4 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113558400, 'utc_rd_as_seconds() on 2000-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730481,
  0,
  0
]
, 'utc_rd_values() on 2000-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2000-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2000-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2000-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2000-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2000-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2000-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2000-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2000-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2000-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2000-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-28 Gregorian' );
Mersday 5 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113644800, 'utc_rd_as_seconds() on 2000-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730482,
  0,
  0
]
, 'utc_rd_values() on 2000-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2000-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2000-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2000-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2000-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2000-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2000-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2000-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2000-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2000-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2000-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-29 Gregorian' );
Highday 6 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113731200, 'utc_rd_as_seconds() on 2000-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730483,
  0,
  0
]
, 'utc_rd_values() on 2000-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2000-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  1
]
, 'week() on 2000-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2000-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2000-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2000-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2000-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2000-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2000-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2000-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2000-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2000-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2000-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-30 Gregorian' );
Sterday 7 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113817600, 'utc_rd_as_seconds() on 2000-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730484,
  0,
  0
]
, 'utc_rd_values() on 2000-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2000-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2000-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2000 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2000,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2000-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2000-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2000-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2000-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2000-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2000-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2000-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2000-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2000-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2000-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2000-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2000-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2000-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2000-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2000-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2000-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2000-12-31 Gregorian' );
Sunday 8 Afteryule 7465

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113904000, 'utc_rd_as_seconds() on 2000-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730485,
  0,
  0
]
, 'utc_rd_values() on 2000-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2000-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2000-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2000-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2000-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2000-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2001-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2001-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-01 Gregorian' );
Monday 9 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63113990400, 'utc_rd_as_seconds() on 2001-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730486,
  0,
  0
]
, 'utc_rd_values() on 2001-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2001-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2001-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2001-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-02 Gregorian' );
Trewsday 10 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114076800, 'utc_rd_as_seconds() on 2001-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730487,
  0,
  0
]
, 'utc_rd_values() on 2001-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2001-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2001-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2001-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-03 Gregorian' );
Hevensday 11 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114163200, 'utc_rd_as_seconds() on 2001-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730488,
  0,
  0
]
, 'utc_rd_values() on 2001-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2001-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2001-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2001-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-04 Gregorian' );
Mersday 12 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114249600, 'utc_rd_as_seconds() on 2001-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730489,
  0,
  0
]
, 'utc_rd_values() on 2001-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2001-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2001-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2001-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-05 Gregorian' );
Highday 13 Afteryule 7465

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114336000, 'utc_rd_as_seconds() on 2001-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730490,
  0,
  0
]
, 'utc_rd_values() on 2001-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  2
]
, 'week() on 2001-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2001-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2001-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-06 Gregorian' );
Sterday 14 Afteryule 7465

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114422400, 'utc_rd_as_seconds() on 2001-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730491,
  0,
  0
]
, 'utc_rd_values() on 2001-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2001-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2001-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-07 Gregorian' );
Sunday 15 Afteryule 7465

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114508800, 'utc_rd_as_seconds() on 2001-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730492,
  0,
  0
]
, 'utc_rd_values() on 2001-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2001-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2001-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-08 Gregorian' );
Monday 16 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114595200, 'utc_rd_as_seconds() on 2001-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730493,
  0,
  0
]
, 'utc_rd_values() on 2001-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2001-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2001-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-09 Gregorian' );
Trewsday 17 Afteryule 7465

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114681600, 'utc_rd_as_seconds() on 2001-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730494,
  0,
  0
]
, 'utc_rd_values() on 2001-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2001-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2001-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-10 Gregorian' );
Hevensday 18 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114768000, 'utc_rd_as_seconds() on 2001-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730495,
  0,
  0
]
, 'utc_rd_values() on 2001-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2001-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2001-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-11 Gregorian' );
Mersday 19 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114854400, 'utc_rd_as_seconds() on 2001-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730496,
  0,
  0
]
, 'utc_rd_values() on 2001-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2001-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2001-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-12 Gregorian' );
Highday 20 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63114940800, 'utc_rd_as_seconds() on 2001-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730497,
  0,
  0
]
, 'utc_rd_values() on 2001-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  3
]
, 'week() on 2001-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2001-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2001-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2001-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-13 Gregorian' );
Sterday 21 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115027200, 'utc_rd_as_seconds() on 2001-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730498,
  0,
  0
]
, 'utc_rd_values() on 2001-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2001-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2001-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-14 Gregorian' );
Sunday 22 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115113600, 'utc_rd_as_seconds() on 2001-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730499,
  0,
  0
]
, 'utc_rd_values() on 2001-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2001-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2001-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-15 Gregorian' );
Monday 23 Afteryule 7465

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115200000, 'utc_rd_as_seconds() on 2001-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730500,
  0,
  0
]
, 'utc_rd_values() on 2001-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2001-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2001-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-16 Gregorian' );
Trewsday 24 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115286400, 'utc_rd_as_seconds() on 2001-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730501,
  0,
  0
]
, 'utc_rd_values() on 2001-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2001-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2001-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-17 Gregorian' );
Hevensday 25 Afteryule 7465

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115372800, 'utc_rd_as_seconds() on 2001-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730502,
  0,
  0
]
, 'utc_rd_values() on 2001-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2001-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2001-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-18 Gregorian' );
Mersday 26 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115459200, 'utc_rd_as_seconds() on 2001-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730503,
  0,
  0
]
, 'utc_rd_values() on 2001-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2001-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2001-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-19 Gregorian' );
Highday 27 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115545600, 'utc_rd_as_seconds() on 2001-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730504,
  0,
  0
]
, 'utc_rd_values() on 2001-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  4
]
, 'week() on 2001-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2001-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2001-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2001-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-20 Gregorian' );
Sterday 28 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115632000, 'utc_rd_as_seconds() on 2001-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730505,
  0,
  0
]
, 'utc_rd_values() on 2001-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2001-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2001-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-21 Gregorian' );
Sunday 29 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115718400, 'utc_rd_as_seconds() on 2001-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730506,
  0,
  0
]
, 'utc_rd_values() on 2001-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2001-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2001-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-22 Gregorian' );
Monday 30 Afteryule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115804800, 'utc_rd_as_seconds() on 2001-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730507,
  0,
  0
]
, 'utc_rd_values() on 2001-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2001-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2001-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-23 Gregorian' );
Trewsday 1 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115891200, 'utc_rd_as_seconds() on 2001-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730508,
  0,
  0
]
, 'utc_rd_values() on 2001-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2001-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2001-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-24 Gregorian' );
Hevensday 2 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63115977600, 'utc_rd_as_seconds() on 2001-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730509,
  0,
  0
]
, 'utc_rd_values() on 2001-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2001-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2001-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-25 Gregorian' );
Mersday 3 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116064000, 'utc_rd_as_seconds() on 2001-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730510,
  0,
  0
]
, 'utc_rd_values() on 2001-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2001-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2001-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-26 Gregorian' );
Highday 4 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116150400, 'utc_rd_as_seconds() on 2001-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730511,
  0,
  0
]
, 'utc_rd_values() on 2001-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  5
]
, 'week() on 2001-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2001-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2001-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2001-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-27 Gregorian' );
Sterday 5 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116236800, 'utc_rd_as_seconds() on 2001-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730512,
  0,
  0
]
, 'utc_rd_values() on 2001-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2001-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2001-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-28 Gregorian' );
Sunday 6 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116323200, 'utc_rd_as_seconds() on 2001-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730513,
  0,
  0
]
, 'utc_rd_values() on 2001-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2001-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2001-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-29 Gregorian' );
Monday 7 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116409600, 'utc_rd_as_seconds() on 2001-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730514,
  0,
  0
]
, 'utc_rd_values() on 2001-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2001-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2001-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-30 Gregorian' );
Trewsday 8 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116496000, 'utc_rd_as_seconds() on 2001-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730515,
  0,
  0
]
, 'utc_rd_values() on 2001-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2001-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2001-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-01-31 Gregorian' );
Hevensday 9 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116582400, 'utc_rd_as_seconds() on 2001-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730516,
  0,
  0
]
, 'utc_rd_values() on 2001-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2001-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2001-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-01 Gregorian' );
Mersday 10 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116668800, 'utc_rd_as_seconds() on 2001-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730517,
  0,
  0
]
, 'utc_rd_values() on 2001-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2001-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2001-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-02 Gregorian' );
Highday 11 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116755200, 'utc_rd_as_seconds() on 2001-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730518,
  0,
  0
]
, 'utc_rd_values() on 2001-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  6
]
, 'week() on 2001-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2001-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2001-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2001-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-03 Gregorian' );
Sterday 12 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116841600, 'utc_rd_as_seconds() on 2001-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730519,
  0,
  0
]
, 'utc_rd_values() on 2001-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2001-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2001-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-04 Gregorian' );
Sunday 13 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63116928000, 'utc_rd_as_seconds() on 2001-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730520,
  0,
  0
]
, 'utc_rd_values() on 2001-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2001-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2001-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-05 Gregorian' );
Monday 14 Solmath 7465

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117014400, 'utc_rd_as_seconds() on 2001-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730521,
  0,
  0
]
, 'utc_rd_values() on 2001-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2001-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2001-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-06 Gregorian' );
Trewsday 15 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117100800, 'utc_rd_as_seconds() on 2001-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730522,
  0,
  0
]
, 'utc_rd_values() on 2001-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2001-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2001-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-07 Gregorian' );
Hevensday 16 Solmath 7465

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117187200, 'utc_rd_as_seconds() on 2001-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730523,
  0,
  0
]
, 'utc_rd_values() on 2001-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2001-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2001-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-08 Gregorian' );
Mersday 17 Solmath 7465

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117273600, 'utc_rd_as_seconds() on 2001-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730524,
  0,
  0
]
, 'utc_rd_values() on 2001-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2001-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2001-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-09 Gregorian' );
Highday 18 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117360000, 'utc_rd_as_seconds() on 2001-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730525,
  0,
  0
]
, 'utc_rd_values() on 2001-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  7
]
, 'week() on 2001-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2001-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2001-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2001-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-10 Gregorian' );
Sterday 19 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117446400, 'utc_rd_as_seconds() on 2001-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730526,
  0,
  0
]
, 'utc_rd_values() on 2001-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2001-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2001-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-11 Gregorian' );
Sunday 20 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117532800, 'utc_rd_as_seconds() on 2001-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730527,
  0,
  0
]
, 'utc_rd_values() on 2001-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2001-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2001-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-12 Gregorian' );
Monday 21 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117619200, 'utc_rd_as_seconds() on 2001-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730528,
  0,
  0
]
, 'utc_rd_values() on 2001-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2001-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2001-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-13 Gregorian' );
Trewsday 22 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117705600, 'utc_rd_as_seconds() on 2001-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730529,
  0,
  0
]
, 'utc_rd_values() on 2001-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2001-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2001-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-14 Gregorian' );
Hevensday 23 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117792000, 'utc_rd_as_seconds() on 2001-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730530,
  0,
  0
]
, 'utc_rd_values() on 2001-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2001-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2001-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-15 Gregorian' );
Mersday 24 Solmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117878400, 'utc_rd_as_seconds() on 2001-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730531,
  0,
  0
]
, 'utc_rd_values() on 2001-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2001-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2001-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-16 Gregorian' );
Highday 25 Solmath 7465

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63117964800, 'utc_rd_as_seconds() on 2001-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730532,
  0,
  0
]
, 'utc_rd_values() on 2001-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  8
]
, 'week() on 2001-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2001-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2001-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2001-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-17 Gregorian' );
Sterday 26 Solmath 7465

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118051200, 'utc_rd_as_seconds() on 2001-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730533,
  0,
  0
]
, 'utc_rd_values() on 2001-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2001-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2001-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-18 Gregorian' );
Sunday 27 Solmath 7465

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118137600, 'utc_rd_as_seconds() on 2001-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730534,
  0,
  0
]
, 'utc_rd_values() on 2001-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2001-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2001-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-19 Gregorian' );
Monday 28 Solmath 7465

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118224000, 'utc_rd_as_seconds() on 2001-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730535,
  0,
  0
]
, 'utc_rd_values() on 2001-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2001-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2001-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-20 Gregorian' );
Trewsday 29 Solmath 7465

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118310400, 'utc_rd_as_seconds() on 2001-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730536,
  0,
  0
]
, 'utc_rd_values() on 2001-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2001-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2001-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2001-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2001-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-21 Gregorian' );
Hevensday 30 Solmath 7465

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118396800, 'utc_rd_as_seconds() on 2001-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730537,
  0,
  0
]
, 'utc_rd_values() on 2001-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2001-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2001-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-22 Gregorian' );
Mersday 1 Rethe 7465

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118483200, 'utc_rd_as_seconds() on 2001-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730538,
  0,
  0
]
, 'utc_rd_values() on 2001-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2001-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2001-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-23 Gregorian' );
Highday 2 Rethe 7465

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118569600, 'utc_rd_as_seconds() on 2001-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730539,
  0,
  0
]
, 'utc_rd_values() on 2001-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  9
]
, 'week() on 2001-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2001-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2001-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2001-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-24 Gregorian' );
Sterday 3 Rethe 7465

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118656000, 'utc_rd_as_seconds() on 2001-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730540,
  0,
  0
]
, 'utc_rd_values() on 2001-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2001-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2001-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-25 Gregorian' );
Sunday 4 Rethe 7465

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118742400, 'utc_rd_as_seconds() on 2001-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730541,
  0,
  0
]
, 'utc_rd_values() on 2001-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2001-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2001-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-26 Gregorian' );
Monday 5 Rethe 7465

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118828800, 'utc_rd_as_seconds() on 2001-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730542,
  0,
  0
]
, 'utc_rd_values() on 2001-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2001-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2001-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-27 Gregorian' );
Trewsday 6 Rethe 7465

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63118915200, 'utc_rd_as_seconds() on 2001-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730543,
  0,
  0
]
, 'utc_rd_values() on 2001-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2001-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2001-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-02-28 Gregorian' );
Hevensday 7 Rethe 7465

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119001600, 'utc_rd_as_seconds() on 2001-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730544,
  0,
  0
]
, 'utc_rd_values() on 2001-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2001-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2001-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-01 Gregorian' );
Mersday 8 Rethe 7465

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119088000, 'utc_rd_as_seconds() on 2001-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730545,
  0,
  0
]
, 'utc_rd_values() on 2001-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2001-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2001-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-02 Gregorian' );
Highday 9 Rethe 7465

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119174400, 'utc_rd_as_seconds() on 2001-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730546,
  0,
  0
]
, 'utc_rd_values() on 2001-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  10
]
, 'week() on 2001-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2001-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2001-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2001-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-03 Gregorian' );
Sterday 10 Rethe 7465

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119260800, 'utc_rd_as_seconds() on 2001-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730547,
  0,
  0
]
, 'utc_rd_values() on 2001-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2001-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2001-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-04 Gregorian' );
Sunday 11 Rethe 7465

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119347200, 'utc_rd_as_seconds() on 2001-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730548,
  0,
  0
]
, 'utc_rd_values() on 2001-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2001-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2001-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-05 Gregorian' );
Monday 12 Rethe 7465

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119433600, 'utc_rd_as_seconds() on 2001-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730549,
  0,
  0
]
, 'utc_rd_values() on 2001-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2001-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2001-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-06 Gregorian' );
Trewsday 13 Rethe 7465

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119520000, 'utc_rd_as_seconds() on 2001-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730550,
  0,
  0
]
, 'utc_rd_values() on 2001-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2001-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2001-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-07 Gregorian' );
Hevensday 14 Rethe 7465

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119606400, 'utc_rd_as_seconds() on 2001-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730551,
  0,
  0
]
, 'utc_rd_values() on 2001-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2001-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2001-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-08 Gregorian' );
Mersday 15 Rethe 7465

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119692800, 'utc_rd_as_seconds() on 2001-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730552,
  0,
  0
]
, 'utc_rd_values() on 2001-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2001-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2001-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-09 Gregorian' );
Highday 16 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119779200, 'utc_rd_as_seconds() on 2001-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730553,
  0,
  0
]
, 'utc_rd_values() on 2001-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  11
]
, 'week() on 2001-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2001-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2001-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2001-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-10 Gregorian' );
Sterday 17 Rethe 7465

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119865600, 'utc_rd_as_seconds() on 2001-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730554,
  0,
  0
]
, 'utc_rd_values() on 2001-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2001-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2001-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-11 Gregorian' );
Sunday 18 Rethe 7465

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63119952000, 'utc_rd_as_seconds() on 2001-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730555,
  0,
  0
]
, 'utc_rd_values() on 2001-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2001-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2001-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-12 Gregorian' );
Monday 19 Rethe 7465

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120038400, 'utc_rd_as_seconds() on 2001-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730556,
  0,
  0
]
, 'utc_rd_values() on 2001-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2001-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2001-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-13 Gregorian' );
Trewsday 20 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120124800, 'utc_rd_as_seconds() on 2001-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730557,
  0,
  0
]
, 'utc_rd_values() on 2001-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2001-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2001-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-14 Gregorian' );
Hevensday 21 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120211200, 'utc_rd_as_seconds() on 2001-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730558,
  0,
  0
]
, 'utc_rd_values() on 2001-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2001-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2001-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-15 Gregorian' );
Mersday 22 Rethe 7465

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120297600, 'utc_rd_as_seconds() on 2001-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730559,
  0,
  0
]
, 'utc_rd_values() on 2001-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2001-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2001-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-16 Gregorian' );
Highday 23 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120384000, 'utc_rd_as_seconds() on 2001-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730560,
  0,
  0
]
, 'utc_rd_values() on 2001-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  12
]
, 'week() on 2001-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2001-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2001-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2001-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-17 Gregorian' );
Sterday 24 Rethe 7465

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120470400, 'utc_rd_as_seconds() on 2001-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730561,
  0,
  0
]
, 'utc_rd_values() on 2001-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2001-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2001-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-18 Gregorian' );
Sunday 25 Rethe 7465

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120556800, 'utc_rd_as_seconds() on 2001-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730562,
  0,
  0
]
, 'utc_rd_values() on 2001-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2001-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2001-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-19 Gregorian' );
Monday 26 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120643200, 'utc_rd_as_seconds() on 2001-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730563,
  0,
  0
]
, 'utc_rd_values() on 2001-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2001-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2001-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-20 Gregorian' );
Trewsday 27 Rethe 7465

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120729600, 'utc_rd_as_seconds() on 2001-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730564,
  0,
  0
]
, 'utc_rd_values() on 2001-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2001-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2001-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-21 Gregorian' );
Hevensday 28 Rethe 7465

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120816000, 'utc_rd_as_seconds() on 2001-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730565,
  0,
  0
]
, 'utc_rd_values() on 2001-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2001-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2001-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-22 Gregorian' );
Mersday 29 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120902400, 'utc_rd_as_seconds() on 2001-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730566,
  0,
  0
]
, 'utc_rd_values() on 2001-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2001-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2001-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2001-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2001-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-23 Gregorian' );
Highday 30 Rethe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63120988800, 'utc_rd_as_seconds() on 2001-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730567,
  0,
  0
]
, 'utc_rd_values() on 2001-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  13
]
, 'week() on 2001-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2001-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2001-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2001-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-24 Gregorian' );
Sterday 1 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121075200, 'utc_rd_as_seconds() on 2001-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730568,
  0,
  0
]
, 'utc_rd_values() on 2001-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2001-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2001-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-25 Gregorian' );
Sunday 2 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121161600, 'utc_rd_as_seconds() on 2001-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730569,
  0,
  0
]
, 'utc_rd_values() on 2001-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2001-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2001-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-26 Gregorian' );
Monday 3 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121248000, 'utc_rd_as_seconds() on 2001-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730570,
  0,
  0
]
, 'utc_rd_values() on 2001-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2001-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2001-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-27 Gregorian' );
Trewsday 4 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121334400, 'utc_rd_as_seconds() on 2001-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730571,
  0,
  0
]
, 'utc_rd_values() on 2001-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2001-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2001-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-28 Gregorian' );
Hevensday 5 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121420800, 'utc_rd_as_seconds() on 2001-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730572,
  0,
  0
]
, 'utc_rd_values() on 2001-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2001-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2001-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-29 Gregorian' );
Mersday 6 Astron 7465

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121507200, 'utc_rd_as_seconds() on 2001-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730573,
  0,
  0
]
, 'utc_rd_values() on 2001-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2001-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2001-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-30 Gregorian' );
Highday 7 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121593600, 'utc_rd_as_seconds() on 2001-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730574,
  0,
  0
]
, 'utc_rd_values() on 2001-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  14
]
, 'week() on 2001-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2001-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2001-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2001-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-03-31 Gregorian' );
Sterday 8 Astron 7465

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121680000, 'utc_rd_as_seconds() on 2001-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730575,
  0,
  0
]
, 'utc_rd_values() on 2001-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2001-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2001-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-01 Gregorian' );
Sunday 9 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121766400, 'utc_rd_as_seconds() on 2001-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730576,
  0,
  0
]
, 'utc_rd_values() on 2001-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2001-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2001-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-02 Gregorian' );
Monday 10 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121852800, 'utc_rd_as_seconds() on 2001-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730577,
  0,
  0
]
, 'utc_rd_values() on 2001-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2001-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2001-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-03 Gregorian' );
Trewsday 11 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63121939200, 'utc_rd_as_seconds() on 2001-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730578,
  0,
  0
]
, 'utc_rd_values() on 2001-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2001-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2001-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-04 Gregorian' );
Hevensday 12 Astron 7465

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122025600, 'utc_rd_as_seconds() on 2001-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730579,
  0,
  0
]
, 'utc_rd_values() on 2001-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2001-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2001-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-05 Gregorian' );
Mersday 13 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122112000, 'utc_rd_as_seconds() on 2001-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730580,
  0,
  0
]
, 'utc_rd_values() on 2001-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2001-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2001-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-06 Gregorian' );
Highday 14 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122198400, 'utc_rd_as_seconds() on 2001-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730581,
  0,
  0
]
, 'utc_rd_values() on 2001-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  15
]
, 'week() on 2001-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2001-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2001-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2001-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-07 Gregorian' );
Sterday 15 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122284800, 'utc_rd_as_seconds() on 2001-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730582,
  0,
  0
]
, 'utc_rd_values() on 2001-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2001-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2001-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-08 Gregorian' );
Sunday 16 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122371200, 'utc_rd_as_seconds() on 2001-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730583,
  0,
  0
]
, 'utc_rd_values() on 2001-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2001-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2001-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-09 Gregorian' );
Monday 17 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122457600, 'utc_rd_as_seconds() on 2001-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730584,
  0,
  0
]
, 'utc_rd_values() on 2001-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2001-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2001-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-10 Gregorian' );
Trewsday 18 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122544000, 'utc_rd_as_seconds() on 2001-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730585,
  0,
  0
]
, 'utc_rd_values() on 2001-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2001-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2001-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-11 Gregorian' );
Hevensday 19 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122630400, 'utc_rd_as_seconds() on 2001-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730586,
  0,
  0
]
, 'utc_rd_values() on 2001-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2001-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2001-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-12 Gregorian' );
Mersday 20 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122716800, 'utc_rd_as_seconds() on 2001-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730587,
  0,
  0
]
, 'utc_rd_values() on 2001-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2001-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2001-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-13 Gregorian' );
Highday 21 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122803200, 'utc_rd_as_seconds() on 2001-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730588,
  0,
  0
]
, 'utc_rd_values() on 2001-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  16
]
, 'week() on 2001-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2001-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2001-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2001-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-14 Gregorian' );
Sterday 22 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122889600, 'utc_rd_as_seconds() on 2001-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730589,
  0,
  0
]
, 'utc_rd_values() on 2001-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2001-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2001-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-15 Gregorian' );
Sunday 23 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63122976000, 'utc_rd_as_seconds() on 2001-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730590,
  0,
  0
]
, 'utc_rd_values() on 2001-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2001-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2001-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-16 Gregorian' );
Monday 24 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123062400, 'utc_rd_as_seconds() on 2001-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730591,
  0,
  0
]
, 'utc_rd_values() on 2001-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2001-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2001-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-17 Gregorian' );
Trewsday 25 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123148800, 'utc_rd_as_seconds() on 2001-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730592,
  0,
  0
]
, 'utc_rd_values() on 2001-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2001-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2001-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-18 Gregorian' );
Hevensday 26 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123235200, 'utc_rd_as_seconds() on 2001-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730593,
  0,
  0
]
, 'utc_rd_values() on 2001-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2001-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2001-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-19 Gregorian' );
Mersday 27 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123321600, 'utc_rd_as_seconds() on 2001-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730594,
  0,
  0
]
, 'utc_rd_values() on 2001-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2001-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2001-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-20 Gregorian' );
Highday 28 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123408000, 'utc_rd_as_seconds() on 2001-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730595,
  0,
  0
]
, 'utc_rd_values() on 2001-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  17
]
, 'week() on 2001-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2001-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2001-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2001-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-21 Gregorian' );
Sterday 29 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123494400, 'utc_rd_as_seconds() on 2001-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730596,
  0,
  0
]
, 'utc_rd_values() on 2001-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2001-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2001-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2001-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2001-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-22 Gregorian' );
Sunday 30 Astron 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123580800, 'utc_rd_as_seconds() on 2001-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730597,
  0,
  0
]
, 'utc_rd_values() on 2001-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2001-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2001-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-23 Gregorian' );
Monday 1 Thrimidge 7465

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123667200, 'utc_rd_as_seconds() on 2001-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730598,
  0,
  0
]
, 'utc_rd_values() on 2001-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2001-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2001-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-24 Gregorian' );
Trewsday 2 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123753600, 'utc_rd_as_seconds() on 2001-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730599,
  0,
  0
]
, 'utc_rd_values() on 2001-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2001-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2001-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-25 Gregorian' );
Hevensday 3 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123840000, 'utc_rd_as_seconds() on 2001-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730600,
  0,
  0
]
, 'utc_rd_values() on 2001-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2001-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2001-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-26 Gregorian' );
Mersday 4 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63123926400, 'utc_rd_as_seconds() on 2001-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730601,
  0,
  0
]
, 'utc_rd_values() on 2001-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2001-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2001-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-27 Gregorian' );
Highday 5 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124012800, 'utc_rd_as_seconds() on 2001-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730602,
  0,
  0
]
, 'utc_rd_values() on 2001-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  18
]
, 'week() on 2001-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2001-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2001-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2001-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-28 Gregorian' );
Sterday 6 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124099200, 'utc_rd_as_seconds() on 2001-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730603,
  0,
  0
]
, 'utc_rd_values() on 2001-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2001-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2001-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-29 Gregorian' );
Sunday 7 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124185600, 'utc_rd_as_seconds() on 2001-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730604,
  0,
  0
]
, 'utc_rd_values() on 2001-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2001-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2001-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-04-30 Gregorian' );
Monday 8 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124272000, 'utc_rd_as_seconds() on 2001-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730605,
  0,
  0
]
, 'utc_rd_values() on 2001-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2001-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2001-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-01 Gregorian' );
Trewsday 9 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124358400, 'utc_rd_as_seconds() on 2001-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730606,
  0,
  0
]
, 'utc_rd_values() on 2001-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2001-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2001-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-02 Gregorian' );
Hevensday 10 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124444800, 'utc_rd_as_seconds() on 2001-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730607,
  0,
  0
]
, 'utc_rd_values() on 2001-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2001-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2001-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-03 Gregorian' );
Mersday 11 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124531200, 'utc_rd_as_seconds() on 2001-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730608,
  0,
  0
]
, 'utc_rd_values() on 2001-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2001-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2001-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-04 Gregorian' );
Highday 12 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124617600, 'utc_rd_as_seconds() on 2001-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730609,
  0,
  0
]
, 'utc_rd_values() on 2001-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  19
]
, 'week() on 2001-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2001-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2001-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2001-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-05 Gregorian' );
Sterday 13 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124704000, 'utc_rd_as_seconds() on 2001-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730610,
  0,
  0
]
, 'utc_rd_values() on 2001-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2001-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2001-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-06 Gregorian' );
Sunday 14 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124790400, 'utc_rd_as_seconds() on 2001-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730611,
  0,
  0
]
, 'utc_rd_values() on 2001-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2001-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2001-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-07 Gregorian' );
Monday 15 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124876800, 'utc_rd_as_seconds() on 2001-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730612,
  0,
  0
]
, 'utc_rd_values() on 2001-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2001-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2001-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-08 Gregorian' );
Trewsday 16 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63124963200, 'utc_rd_as_seconds() on 2001-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730613,
  0,
  0
]
, 'utc_rd_values() on 2001-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2001-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2001-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-09 Gregorian' );
Hevensday 17 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125049600, 'utc_rd_as_seconds() on 2001-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730614,
  0,
  0
]
, 'utc_rd_values() on 2001-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2001-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2001-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-10 Gregorian' );
Mersday 18 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125136000, 'utc_rd_as_seconds() on 2001-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730615,
  0,
  0
]
, 'utc_rd_values() on 2001-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2001-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2001-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-11 Gregorian' );
Highday 19 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125222400, 'utc_rd_as_seconds() on 2001-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730616,
  0,
  0
]
, 'utc_rd_values() on 2001-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  20
]
, 'week() on 2001-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2001-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2001-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2001-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-12 Gregorian' );
Sterday 20 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125308800, 'utc_rd_as_seconds() on 2001-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730617,
  0,
  0
]
, 'utc_rd_values() on 2001-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2001-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2001-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-13 Gregorian' );
Sunday 21 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125395200, 'utc_rd_as_seconds() on 2001-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730618,
  0,
  0
]
, 'utc_rd_values() on 2001-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2001-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2001-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-14 Gregorian' );
Monday 22 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125481600, 'utc_rd_as_seconds() on 2001-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730619,
  0,
  0
]
, 'utc_rd_values() on 2001-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2001-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2001-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-15 Gregorian' );
Trewsday 23 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125568000, 'utc_rd_as_seconds() on 2001-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730620,
  0,
  0
]
, 'utc_rd_values() on 2001-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2001-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2001-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-16 Gregorian' );
Hevensday 24 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125654400, 'utc_rd_as_seconds() on 2001-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730621,
  0,
  0
]
, 'utc_rd_values() on 2001-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2001-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2001-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-17 Gregorian' );
Mersday 25 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125740800, 'utc_rd_as_seconds() on 2001-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730622,
  0,
  0
]
, 'utc_rd_values() on 2001-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2001-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2001-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-18 Gregorian' );
Highday 26 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125827200, 'utc_rd_as_seconds() on 2001-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730623,
  0,
  0
]
, 'utc_rd_values() on 2001-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  21
]
, 'week() on 2001-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2001-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2001-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2001-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-19 Gregorian' );
Sterday 27 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63125913600, 'utc_rd_as_seconds() on 2001-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730624,
  0,
  0
]
, 'utc_rd_values() on 2001-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2001-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2001-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-20 Gregorian' );
Sunday 28 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126000000, 'utc_rd_as_seconds() on 2001-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730625,
  0,
  0
]
, 'utc_rd_values() on 2001-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2001-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2001-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-21 Gregorian' );
Monday 29 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126086400, 'utc_rd_as_seconds() on 2001-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730626,
  0,
  0
]
, 'utc_rd_values() on 2001-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2001-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2001-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2001-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2001-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-22 Gregorian' );
Trewsday 30 Thrimidge 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126172800, 'utc_rd_as_seconds() on 2001-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730627,
  0,
  0
]
, 'utc_rd_values() on 2001-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2001-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2001-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-23 Gregorian' );
Hevensday 1 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126259200, 'utc_rd_as_seconds() on 2001-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730628,
  0,
  0
]
, 'utc_rd_values() on 2001-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2001-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2001-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-24 Gregorian' );
Mersday 2 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126345600, 'utc_rd_as_seconds() on 2001-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730629,
  0,
  0
]
, 'utc_rd_values() on 2001-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2001-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2001-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-25 Gregorian' );
Highday 3 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126432000, 'utc_rd_as_seconds() on 2001-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730630,
  0,
  0
]
, 'utc_rd_values() on 2001-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  22
]
, 'week() on 2001-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2001-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2001-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2001-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-26 Gregorian' );
Sterday 4 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126518400, 'utc_rd_as_seconds() on 2001-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730631,
  0,
  0
]
, 'utc_rd_values() on 2001-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2001-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2001-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-27 Gregorian' );
Sunday 5 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126604800, 'utc_rd_as_seconds() on 2001-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730632,
  0,
  0
]
, 'utc_rd_values() on 2001-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2001-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2001-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-28 Gregorian' );
Monday 6 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126691200, 'utc_rd_as_seconds() on 2001-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730633,
  0,
  0
]
, 'utc_rd_values() on 2001-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2001-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2001-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-29 Gregorian' );
Trewsday 7 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126777600, 'utc_rd_as_seconds() on 2001-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730634,
  0,
  0
]
, 'utc_rd_values() on 2001-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2001-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2001-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-30 Gregorian' );
Hevensday 8 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126864000, 'utc_rd_as_seconds() on 2001-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730635,
  0,
  0
]
, 'utc_rd_values() on 2001-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2001-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2001-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-05-31 Gregorian' );
Mersday 9 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63126950400, 'utc_rd_as_seconds() on 2001-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730636,
  0,
  0
]
, 'utc_rd_values() on 2001-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2001-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2001-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-01 Gregorian' );
Highday 10 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127036800, 'utc_rd_as_seconds() on 2001-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730637,
  0,
  0
]
, 'utc_rd_values() on 2001-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  23
]
, 'week() on 2001-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2001-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2001-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2001-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-02 Gregorian' );
Sterday 11 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127123200, 'utc_rd_as_seconds() on 2001-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730638,
  0,
  0
]
, 'utc_rd_values() on 2001-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2001-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2001-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-03 Gregorian' );
Sunday 12 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127209600, 'utc_rd_as_seconds() on 2001-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730639,
  0,
  0
]
, 'utc_rd_values() on 2001-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2001-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2001-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-04 Gregorian' );
Monday 13 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127296000, 'utc_rd_as_seconds() on 2001-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730640,
  0,
  0
]
, 'utc_rd_values() on 2001-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2001-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2001-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-05 Gregorian' );
Trewsday 14 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127382400, 'utc_rd_as_seconds() on 2001-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730641,
  0,
  0
]
, 'utc_rd_values() on 2001-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2001-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2001-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-06 Gregorian' );
Hevensday 15 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127468800, 'utc_rd_as_seconds() on 2001-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730642,
  0,
  0
]
, 'utc_rd_values() on 2001-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2001-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2001-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-07 Gregorian' );
Mersday 16 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127555200, 'utc_rd_as_seconds() on 2001-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730643,
  0,
  0
]
, 'utc_rd_values() on 2001-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2001-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2001-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-08 Gregorian' );
Highday 17 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127641600, 'utc_rd_as_seconds() on 2001-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730644,
  0,
  0
]
, 'utc_rd_values() on 2001-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  24
]
, 'week() on 2001-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2001-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2001-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2001-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-09 Gregorian' );
Sterday 18 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127728000, 'utc_rd_as_seconds() on 2001-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730645,
  0,
  0
]
, 'utc_rd_values() on 2001-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2001-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2001-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-10 Gregorian' );
Sunday 19 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127814400, 'utc_rd_as_seconds() on 2001-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730646,
  0,
  0
]
, 'utc_rd_values() on 2001-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2001-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2001-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-11 Gregorian' );
Monday 20 Forelithe 7465

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127900800, 'utc_rd_as_seconds() on 2001-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730647,
  0,
  0
]
, 'utc_rd_values() on 2001-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2001-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2001-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-12 Gregorian' );
Trewsday 21 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63127987200, 'utc_rd_as_seconds() on 2001-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730648,
  0,
  0
]
, 'utc_rd_values() on 2001-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2001-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2001-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-13 Gregorian' );
Hevensday 22 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128073600, 'utc_rd_as_seconds() on 2001-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730649,
  0,
  0
]
, 'utc_rd_values() on 2001-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2001-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2001-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-14 Gregorian' );
Mersday 23 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128160000, 'utc_rd_as_seconds() on 2001-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730650,
  0,
  0
]
, 'utc_rd_values() on 2001-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2001-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2001-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-15 Gregorian' );
Highday 24 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128246400, 'utc_rd_as_seconds() on 2001-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730651,
  0,
  0
]
, 'utc_rd_values() on 2001-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  25
]
, 'week() on 2001-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2001-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2001-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2001-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-16 Gregorian' );
Sterday 25 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128332800, 'utc_rd_as_seconds() on 2001-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730652,
  0,
  0
]
, 'utc_rd_values() on 2001-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2001-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2001-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-17 Gregorian' );
Sunday 26 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128419200, 'utc_rd_as_seconds() on 2001-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730653,
  0,
  0
]
, 'utc_rd_values() on 2001-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2001-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2001-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-18 Gregorian' );
Monday 27 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128505600, 'utc_rd_as_seconds() on 2001-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730654,
  0,
  0
]
, 'utc_rd_values() on 2001-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2001-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2001-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-19 Gregorian' );
Trewsday 28 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128592000, 'utc_rd_as_seconds() on 2001-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730655,
  0,
  0
]
, 'utc_rd_values() on 2001-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2001-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2001-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-20 Gregorian' );
Hevensday 29 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128678400, 'utc_rd_as_seconds() on 2001-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730656,
  0,
  0
]
, 'utc_rd_values() on 2001-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2001-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2001-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2001-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2001-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-21 Gregorian' );
Mersday 30 Forelithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128764800, 'utc_rd_as_seconds() on 2001-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730657,
  0,
  0
]
, 'utc_rd_values() on 2001-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2001-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2001-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2001-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2001-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2001-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2001-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2001-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2001-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2001-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-22 Gregorian' );
Highday 1 Lithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128851200, 'utc_rd_as_seconds() on 2001-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730658,
  0,
  0
]
, 'utc_rd_values() on 2001-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  26
]
, 'week() on 2001-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2001-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2001-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2001-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2001-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2001-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2001-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2001-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2001-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2001-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2001-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2001-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2001-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2001-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2001-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-23 Gregorian' );
Midyear's day 7465

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63128937600, 'utc_rd_as_seconds() on 2001-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730659,
  0,
  0
]
, 'utc_rd_values() on 2001-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2001-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  0
]
, 'week() on 2001-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2001-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2001-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2001-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2001-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2001-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2001-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2001-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2001-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2001-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2001-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-24 Gregorian' );
Sterday 2 Lithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129024000, 'utc_rd_as_seconds() on 2001-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730660,
  0,
  0
]
, 'utc_rd_values() on 2001-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2001-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2001-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-25 Gregorian' );
Sunday 1 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129110400, 'utc_rd_as_seconds() on 2001-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730661,
  0,
  0
]
, 'utc_rd_values() on 2001-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2001-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2001-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-26 Gregorian' );
Monday 2 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129196800, 'utc_rd_as_seconds() on 2001-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730662,
  0,
  0
]
, 'utc_rd_values() on 2001-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2001-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2001-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-27 Gregorian' );
Trewsday 3 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129283200, 'utc_rd_as_seconds() on 2001-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730663,
  0,
  0
]
, 'utc_rd_values() on 2001-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2001-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2001-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-28 Gregorian' );
Hevensday 4 Afterlithe 7465

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129369600, 'utc_rd_as_seconds() on 2001-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730664,
  0,
  0
]
, 'utc_rd_values() on 2001-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2001-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2001-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-29 Gregorian' );
Mersday 5 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129456000, 'utc_rd_as_seconds() on 2001-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730665,
  0,
  0
]
, 'utc_rd_values() on 2001-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2001-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2001-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-06-30 Gregorian' );
Highday 6 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129542400, 'utc_rd_as_seconds() on 2001-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730666,
  0,
  0
]
, 'utc_rd_values() on 2001-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  27
]
, 'week() on 2001-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2001-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2001-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2001-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-01 Gregorian' );
Sterday 7 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129628800, 'utc_rd_as_seconds() on 2001-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730667,
  0,
  0
]
, 'utc_rd_values() on 2001-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2001-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2001-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-02 Gregorian' );
Sunday 8 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129715200, 'utc_rd_as_seconds() on 2001-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730668,
  0,
  0
]
, 'utc_rd_values() on 2001-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2001-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2001-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-03 Gregorian' );
Monday 9 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129801600, 'utc_rd_as_seconds() on 2001-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730669,
  0,
  0
]
, 'utc_rd_values() on 2001-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2001-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2001-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-04 Gregorian' );
Trewsday 10 Afterlithe 7465

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129888000, 'utc_rd_as_seconds() on 2001-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730670,
  0,
  0
]
, 'utc_rd_values() on 2001-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2001-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2001-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-05 Gregorian' );
Hevensday 11 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63129974400, 'utc_rd_as_seconds() on 2001-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730671,
  0,
  0
]
, 'utc_rd_values() on 2001-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2001-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2001-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-06 Gregorian' );
Mersday 12 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130060800, 'utc_rd_as_seconds() on 2001-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730672,
  0,
  0
]
, 'utc_rd_values() on 2001-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2001-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2001-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-07 Gregorian' );
Highday 13 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130147200, 'utc_rd_as_seconds() on 2001-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730673,
  0,
  0
]
, 'utc_rd_values() on 2001-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  28
]
, 'week() on 2001-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2001-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2001-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2001-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-08 Gregorian' );
Sterday 14 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130233600, 'utc_rd_as_seconds() on 2001-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730674,
  0,
  0
]
, 'utc_rd_values() on 2001-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2001-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2001-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-09 Gregorian' );
Sunday 15 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130320000, 'utc_rd_as_seconds() on 2001-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730675,
  0,
  0
]
, 'utc_rd_values() on 2001-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2001-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2001-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-10 Gregorian' );
Monday 16 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130406400, 'utc_rd_as_seconds() on 2001-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730676,
  0,
  0
]
, 'utc_rd_values() on 2001-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2001-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2001-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-11 Gregorian' );
Trewsday 17 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130492800, 'utc_rd_as_seconds() on 2001-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730677,
  0,
  0
]
, 'utc_rd_values() on 2001-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2001-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2001-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-12 Gregorian' );
Hevensday 18 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130579200, 'utc_rd_as_seconds() on 2001-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730678,
  0,
  0
]
, 'utc_rd_values() on 2001-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2001-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2001-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-13 Gregorian' );
Mersday 19 Afterlithe 7465

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130665600, 'utc_rd_as_seconds() on 2001-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730679,
  0,
  0
]
, 'utc_rd_values() on 2001-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2001-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2001-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-14 Gregorian' );
Highday 20 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130752000, 'utc_rd_as_seconds() on 2001-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730680,
  0,
  0
]
, 'utc_rd_values() on 2001-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  29
]
, 'week() on 2001-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2001-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2001-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2001-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-15 Gregorian' );
Sterday 21 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130838400, 'utc_rd_as_seconds() on 2001-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730681,
  0,
  0
]
, 'utc_rd_values() on 2001-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2001-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2001-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-16 Gregorian' );
Sunday 22 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63130924800, 'utc_rd_as_seconds() on 2001-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730682,
  0,
  0
]
, 'utc_rd_values() on 2001-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2001-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2001-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-17 Gregorian' );
Monday 23 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131011200, 'utc_rd_as_seconds() on 2001-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730683,
  0,
  0
]
, 'utc_rd_values() on 2001-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2001-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2001-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-18 Gregorian' );
Trewsday 24 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131097600, 'utc_rd_as_seconds() on 2001-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730684,
  0,
  0
]
, 'utc_rd_values() on 2001-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2001-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2001-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-19 Gregorian' );
Hevensday 25 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131184000, 'utc_rd_as_seconds() on 2001-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730685,
  0,
  0
]
, 'utc_rd_values() on 2001-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2001-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2001-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-20 Gregorian' );
Mersday 26 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131270400, 'utc_rd_as_seconds() on 2001-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730686,
  0,
  0
]
, 'utc_rd_values() on 2001-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2001-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2001-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-21 Gregorian' );
Highday 27 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131356800, 'utc_rd_as_seconds() on 2001-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730687,
  0,
  0
]
, 'utc_rd_values() on 2001-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  30
]
, 'week() on 2001-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2001-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2001-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2001-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-22 Gregorian' );
Sterday 28 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131443200, 'utc_rd_as_seconds() on 2001-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730688,
  0,
  0
]
, 'utc_rd_values() on 2001-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2001-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2001-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-23 Gregorian' );
Sunday 29 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131529600, 'utc_rd_as_seconds() on 2001-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730689,
  0,
  0
]
, 'utc_rd_values() on 2001-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2001-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2001-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2001-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2001-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-24 Gregorian' );
Monday 30 Afterlithe 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131616000, 'utc_rd_as_seconds() on 2001-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730690,
  0,
  0
]
, 'utc_rd_values() on 2001-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2001-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2001-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-25 Gregorian' );
Trewsday 1 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131702400, 'utc_rd_as_seconds() on 2001-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730691,
  0,
  0
]
, 'utc_rd_values() on 2001-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2001-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2001-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-26 Gregorian' );
Hevensday 2 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131788800, 'utc_rd_as_seconds() on 2001-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730692,
  0,
  0
]
, 'utc_rd_values() on 2001-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2001-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2001-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-27 Gregorian' );
Mersday 3 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131875200, 'utc_rd_as_seconds() on 2001-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730693,
  0,
  0
]
, 'utc_rd_values() on 2001-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2001-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2001-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-28 Gregorian' );
Highday 4 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63131961600, 'utc_rd_as_seconds() on 2001-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730694,
  0,
  0
]
, 'utc_rd_values() on 2001-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  31
]
, 'week() on 2001-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2001-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2001-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2001-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-29 Gregorian' );
Sterday 5 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132048000, 'utc_rd_as_seconds() on 2001-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730695,
  0,
  0
]
, 'utc_rd_values() on 2001-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2001-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2001-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-30 Gregorian' );
Sunday 6 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132134400, 'utc_rd_as_seconds() on 2001-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730696,
  0,
  0
]
, 'utc_rd_values() on 2001-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2001-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2001-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-07-31 Gregorian' );
Monday 7 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132220800, 'utc_rd_as_seconds() on 2001-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730697,
  0,
  0
]
, 'utc_rd_values() on 2001-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2001-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2001-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-01 Gregorian' );
Trewsday 8 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132307200, 'utc_rd_as_seconds() on 2001-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730698,
  0,
  0
]
, 'utc_rd_values() on 2001-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2001-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2001-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-02 Gregorian' );
Hevensday 9 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132393600, 'utc_rd_as_seconds() on 2001-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730699,
  0,
  0
]
, 'utc_rd_values() on 2001-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2001-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2001-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-03 Gregorian' );
Mersday 10 Wedmath 7465

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132480000, 'utc_rd_as_seconds() on 2001-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730700,
  0,
  0
]
, 'utc_rd_values() on 2001-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2001-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2001-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-04 Gregorian' );
Highday 11 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132566400, 'utc_rd_as_seconds() on 2001-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730701,
  0,
  0
]
, 'utc_rd_values() on 2001-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  32
]
, 'week() on 2001-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2001-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2001-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2001-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-05 Gregorian' );
Sterday 12 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132652800, 'utc_rd_as_seconds() on 2001-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730702,
  0,
  0
]
, 'utc_rd_values() on 2001-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2001-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2001-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-06 Gregorian' );
Sunday 13 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132739200, 'utc_rd_as_seconds() on 2001-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730703,
  0,
  0
]
, 'utc_rd_values() on 2001-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2001-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2001-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-07 Gregorian' );
Monday 14 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132825600, 'utc_rd_as_seconds() on 2001-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730704,
  0,
  0
]
, 'utc_rd_values() on 2001-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2001-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2001-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-08 Gregorian' );
Trewsday 15 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132912000, 'utc_rd_as_seconds() on 2001-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730705,
  0,
  0
]
, 'utc_rd_values() on 2001-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2001-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2001-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-09 Gregorian' );
Hevensday 16 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63132998400, 'utc_rd_as_seconds() on 2001-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730706,
  0,
  0
]
, 'utc_rd_values() on 2001-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2001-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2001-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-10 Gregorian' );
Mersday 17 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133084800, 'utc_rd_as_seconds() on 2001-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730707,
  0,
  0
]
, 'utc_rd_values() on 2001-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2001-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2001-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-11 Gregorian' );
Highday 18 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133171200, 'utc_rd_as_seconds() on 2001-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730708,
  0,
  0
]
, 'utc_rd_values() on 2001-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  33
]
, 'week() on 2001-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2001-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2001-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2001-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-12 Gregorian' );
Sterday 19 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133257600, 'utc_rd_as_seconds() on 2001-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730709,
  0,
  0
]
, 'utc_rd_values() on 2001-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2001-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2001-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-13 Gregorian' );
Sunday 20 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133344000, 'utc_rd_as_seconds() on 2001-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730710,
  0,
  0
]
, 'utc_rd_values() on 2001-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2001-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2001-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-14 Gregorian' );
Monday 21 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133430400, 'utc_rd_as_seconds() on 2001-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730711,
  0,
  0
]
, 'utc_rd_values() on 2001-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2001-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2001-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-15 Gregorian' );
Trewsday 22 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133516800, 'utc_rd_as_seconds() on 2001-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730712,
  0,
  0
]
, 'utc_rd_values() on 2001-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2001-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2001-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-16 Gregorian' );
Hevensday 23 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133603200, 'utc_rd_as_seconds() on 2001-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730713,
  0,
  0
]
, 'utc_rd_values() on 2001-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2001-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2001-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-17 Gregorian' );
Mersday 24 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133689600, 'utc_rd_as_seconds() on 2001-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730714,
  0,
  0
]
, 'utc_rd_values() on 2001-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2001-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2001-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-18 Gregorian' );
Highday 25 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133776000, 'utc_rd_as_seconds() on 2001-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730715,
  0,
  0
]
, 'utc_rd_values() on 2001-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  34
]
, 'week() on 2001-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2001-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2001-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2001-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-19 Gregorian' );
Sterday 26 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133862400, 'utc_rd_as_seconds() on 2001-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730716,
  0,
  0
]
, 'utc_rd_values() on 2001-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2001-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2001-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-20 Gregorian' );
Sunday 27 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63133948800, 'utc_rd_as_seconds() on 2001-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730717,
  0,
  0
]
, 'utc_rd_values() on 2001-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2001-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2001-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-21 Gregorian' );
Monday 28 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134035200, 'utc_rd_as_seconds() on 2001-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730718,
  0,
  0
]
, 'utc_rd_values() on 2001-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2001-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2001-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-22 Gregorian' );
Trewsday 29 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134121600, 'utc_rd_as_seconds() on 2001-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730719,
  0,
  0
]
, 'utc_rd_values() on 2001-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2001-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2001-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2001-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2001-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-23 Gregorian' );
Hevensday 30 Wedmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134208000, 'utc_rd_as_seconds() on 2001-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730720,
  0,
  0
]
, 'utc_rd_values() on 2001-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2001-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2001-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-24 Gregorian' );
Mersday 1 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134294400, 'utc_rd_as_seconds() on 2001-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730721,
  0,
  0
]
, 'utc_rd_values() on 2001-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2001-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2001-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-25 Gregorian' );
Highday 2 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134380800, 'utc_rd_as_seconds() on 2001-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730722,
  0,
  0
]
, 'utc_rd_values() on 2001-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  35
]
, 'week() on 2001-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2001-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2001-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2001-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-26 Gregorian' );
Sterday 3 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134467200, 'utc_rd_as_seconds() on 2001-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730723,
  0,
  0
]
, 'utc_rd_values() on 2001-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2001-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2001-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-27 Gregorian' );
Sunday 4 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134553600, 'utc_rd_as_seconds() on 2001-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730724,
  0,
  0
]
, 'utc_rd_values() on 2001-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2001-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2001-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-28 Gregorian' );
Monday 5 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134640000, 'utc_rd_as_seconds() on 2001-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730725,
  0,
  0
]
, 'utc_rd_values() on 2001-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2001-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2001-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-29 Gregorian' );
Trewsday 6 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134726400, 'utc_rd_as_seconds() on 2001-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730726,
  0,
  0
]
, 'utc_rd_values() on 2001-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2001-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2001-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-30 Gregorian' );
Hevensday 7 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134812800, 'utc_rd_as_seconds() on 2001-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730727,
  0,
  0
]
, 'utc_rd_values() on 2001-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2001-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2001-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-08-31 Gregorian' );
Mersday 8 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134899200, 'utc_rd_as_seconds() on 2001-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730728,
  0,
  0
]
, 'utc_rd_values() on 2001-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2001-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2001-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-01 Gregorian' );
Highday 9 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63134985600, 'utc_rd_as_seconds() on 2001-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730729,
  0,
  0
]
, 'utc_rd_values() on 2001-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  36
]
, 'week() on 2001-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2001-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2001-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2001-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-02 Gregorian' );
Sterday 10 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135072000, 'utc_rd_as_seconds() on 2001-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730730,
  0,
  0
]
, 'utc_rd_values() on 2001-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2001-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2001-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-03 Gregorian' );
Sunday 11 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135158400, 'utc_rd_as_seconds() on 2001-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730731,
  0,
  0
]
, 'utc_rd_values() on 2001-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2001-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2001-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-04 Gregorian' );
Monday 12 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135244800, 'utc_rd_as_seconds() on 2001-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730732,
  0,
  0
]
, 'utc_rd_values() on 2001-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2001-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2001-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-05 Gregorian' );
Trewsday 13 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135331200, 'utc_rd_as_seconds() on 2001-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730733,
  0,
  0
]
, 'utc_rd_values() on 2001-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2001-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2001-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-06 Gregorian' );
Hevensday 14 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135417600, 'utc_rd_as_seconds() on 2001-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730734,
  0,
  0
]
, 'utc_rd_values() on 2001-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2001-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2001-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-07 Gregorian' );
Mersday 15 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135504000, 'utc_rd_as_seconds() on 2001-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730735,
  0,
  0
]
, 'utc_rd_values() on 2001-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2001-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2001-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-08 Gregorian' );
Highday 16 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135590400, 'utc_rd_as_seconds() on 2001-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730736,
  0,
  0
]
, 'utc_rd_values() on 2001-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  37
]
, 'week() on 2001-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2001-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2001-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2001-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-09 Gregorian' );
Sterday 17 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135676800, 'utc_rd_as_seconds() on 2001-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730737,
  0,
  0
]
, 'utc_rd_values() on 2001-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2001-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2001-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-10 Gregorian' );
Sunday 18 Halimath 7465

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135763200, 'utc_rd_as_seconds() on 2001-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730738,
  0,
  0
]
, 'utc_rd_values() on 2001-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2001-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2001-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-11 Gregorian' );
Monday 19 Halimath 7465

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135849600, 'utc_rd_as_seconds() on 2001-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730739,
  0,
  0
]
, 'utc_rd_values() on 2001-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2001-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2001-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-12 Gregorian' );
Trewsday 20 Halimath 7465

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63135936000, 'utc_rd_as_seconds() on 2001-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730740,
  0,
  0
]
, 'utc_rd_values() on 2001-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2001-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2001-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-13 Gregorian' );
Hevensday 21 Halimath 7465

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136022400, 'utc_rd_as_seconds() on 2001-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730741,
  0,
  0
]
, 'utc_rd_values() on 2001-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2001-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2001-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-14 Gregorian' );
Mersday 22 Halimath 7465

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136108800, 'utc_rd_as_seconds() on 2001-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730742,
  0,
  0
]
, 'utc_rd_values() on 2001-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2001-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2001-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-15 Gregorian' );
Highday 23 Halimath 7465

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136195200, 'utc_rd_as_seconds() on 2001-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730743,
  0,
  0
]
, 'utc_rd_values() on 2001-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  38
]
, 'week() on 2001-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2001-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2001-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2001-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-16 Gregorian' );
Sterday 24 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136281600, 'utc_rd_as_seconds() on 2001-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730744,
  0,
  0
]
, 'utc_rd_values() on 2001-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2001-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2001-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-17 Gregorian' );
Sunday 25 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136368000, 'utc_rd_as_seconds() on 2001-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730745,
  0,
  0
]
, 'utc_rd_values() on 2001-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2001-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2001-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-18 Gregorian' );
Monday 26 Halimath 7465

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136454400, 'utc_rd_as_seconds() on 2001-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730746,
  0,
  0
]
, 'utc_rd_values() on 2001-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2001-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2001-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-19 Gregorian' );
Trewsday 27 Halimath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136540800, 'utc_rd_as_seconds() on 2001-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730747,
  0,
  0
]
, 'utc_rd_values() on 2001-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2001-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2001-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-20 Gregorian' );
Hevensday 28 Halimath 7465

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136627200, 'utc_rd_as_seconds() on 2001-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730748,
  0,
  0
]
, 'utc_rd_values() on 2001-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2001-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2001-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-21 Gregorian' );
Mersday 29 Halimath 7465

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136713600, 'utc_rd_as_seconds() on 2001-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730749,
  0,
  0
]
, 'utc_rd_values() on 2001-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2001-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2001-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2001-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2001-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-22 Gregorian' );
Highday 30 Halimath 7465

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136800000, 'utc_rd_as_seconds() on 2001-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730750,
  0,
  0
]
, 'utc_rd_values() on 2001-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  39
]
, 'week() on 2001-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2001-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2001-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2001-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-23 Gregorian' );
Sterday 1 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136886400, 'utc_rd_as_seconds() on 2001-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730751,
  0,
  0
]
, 'utc_rd_values() on 2001-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2001-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2001-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-24 Gregorian' );
Sunday 2 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63136972800, 'utc_rd_as_seconds() on 2001-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730752,
  0,
  0
]
, 'utc_rd_values() on 2001-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2001-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2001-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-25 Gregorian' );
Monday 3 Winterfilth 7465

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137059200, 'utc_rd_as_seconds() on 2001-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730753,
  0,
  0
]
, 'utc_rd_values() on 2001-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2001-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2001-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-26 Gregorian' );
Trewsday 4 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137145600, 'utc_rd_as_seconds() on 2001-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730754,
  0,
  0
]
, 'utc_rd_values() on 2001-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2001-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2001-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-27 Gregorian' );
Hevensday 5 Winterfilth 7465

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137232000, 'utc_rd_as_seconds() on 2001-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730755,
  0,
  0
]
, 'utc_rd_values() on 2001-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2001-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2001-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-28 Gregorian' );
Mersday 6 Winterfilth 7465

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137318400, 'utc_rd_as_seconds() on 2001-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730756,
  0,
  0
]
, 'utc_rd_values() on 2001-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2001-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2001-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-29 Gregorian' );
Highday 7 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137404800, 'utc_rd_as_seconds() on 2001-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730757,
  0,
  0
]
, 'utc_rd_values() on 2001-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  40
]
, 'week() on 2001-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2001-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2001-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2001-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-09-30 Gregorian' );
Sterday 8 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137491200, 'utc_rd_as_seconds() on 2001-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730758,
  0,
  0
]
, 'utc_rd_values() on 2001-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2001-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2001-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-01 Gregorian' );
Sunday 9 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137577600, 'utc_rd_as_seconds() on 2001-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730759,
  0,
  0
]
, 'utc_rd_values() on 2001-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2001-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2001-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-02 Gregorian' );
Monday 10 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137664000, 'utc_rd_as_seconds() on 2001-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730760,
  0,
  0
]
, 'utc_rd_values() on 2001-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2001-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2001-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-03 Gregorian' );
Trewsday 11 Winterfilth 7465

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137750400, 'utc_rd_as_seconds() on 2001-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730761,
  0,
  0
]
, 'utc_rd_values() on 2001-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2001-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2001-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-04 Gregorian' );
Hevensday 12 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137836800, 'utc_rd_as_seconds() on 2001-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730762,
  0,
  0
]
, 'utc_rd_values() on 2001-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2001-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2001-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-05 Gregorian' );
Mersday 13 Winterfilth 7465

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63137923200, 'utc_rd_as_seconds() on 2001-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730763,
  0,
  0
]
, 'utc_rd_values() on 2001-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2001-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2001-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-06 Gregorian' );
Highday 14 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138009600, 'utc_rd_as_seconds() on 2001-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730764,
  0,
  0
]
, 'utc_rd_values() on 2001-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  41
]
, 'week() on 2001-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2001-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2001-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2001-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-07 Gregorian' );
Sterday 15 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138096000, 'utc_rd_as_seconds() on 2001-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730765,
  0,
  0
]
, 'utc_rd_values() on 2001-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2001-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2001-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-08 Gregorian' );
Sunday 16 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138182400, 'utc_rd_as_seconds() on 2001-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730766,
  0,
  0
]
, 'utc_rd_values() on 2001-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2001-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2001-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-09 Gregorian' );
Monday 17 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138268800, 'utc_rd_as_seconds() on 2001-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730767,
  0,
  0
]
, 'utc_rd_values() on 2001-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2001-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2001-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-10 Gregorian' );
Trewsday 18 Winterfilth 7465

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138355200, 'utc_rd_as_seconds() on 2001-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730768,
  0,
  0
]
, 'utc_rd_values() on 2001-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2001-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2001-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-11 Gregorian' );
Hevensday 19 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138441600, 'utc_rd_as_seconds() on 2001-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730769,
  0,
  0
]
, 'utc_rd_values() on 2001-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2001-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2001-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-12 Gregorian' );
Mersday 20 Winterfilth 7465

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138528000, 'utc_rd_as_seconds() on 2001-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730770,
  0,
  0
]
, 'utc_rd_values() on 2001-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2001-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2001-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-13 Gregorian' );
Highday 21 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138614400, 'utc_rd_as_seconds() on 2001-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730771,
  0,
  0
]
, 'utc_rd_values() on 2001-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  42
]
, 'week() on 2001-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2001-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2001-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2001-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-14 Gregorian' );
Sterday 22 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138700800, 'utc_rd_as_seconds() on 2001-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730772,
  0,
  0
]
, 'utc_rd_values() on 2001-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2001-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2001-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-15 Gregorian' );
Sunday 23 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138787200, 'utc_rd_as_seconds() on 2001-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730773,
  0,
  0
]
, 'utc_rd_values() on 2001-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2001-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2001-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-16 Gregorian' );
Monday 24 Winterfilth 7465

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138873600, 'utc_rd_as_seconds() on 2001-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730774,
  0,
  0
]
, 'utc_rd_values() on 2001-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2001-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2001-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-17 Gregorian' );
Trewsday 25 Winterfilth 7465

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63138960000, 'utc_rd_as_seconds() on 2001-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730775,
  0,
  0
]
, 'utc_rd_values() on 2001-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2001-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2001-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-18 Gregorian' );
Hevensday 26 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139046400, 'utc_rd_as_seconds() on 2001-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730776,
  0,
  0
]
, 'utc_rd_values() on 2001-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2001-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2001-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-19 Gregorian' );
Mersday 27 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139132800, 'utc_rd_as_seconds() on 2001-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730777,
  0,
  0
]
, 'utc_rd_values() on 2001-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2001-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2001-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-20 Gregorian' );
Highday 28 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139219200, 'utc_rd_as_seconds() on 2001-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730778,
  0,
  0
]
, 'utc_rd_values() on 2001-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  43
]
, 'week() on 2001-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2001-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2001-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2001-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-21 Gregorian' );
Sterday 29 Winterfilth 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139305600, 'utc_rd_as_seconds() on 2001-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730779,
  0,
  0
]
, 'utc_rd_values() on 2001-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2001-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2001-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2001-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2001-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-22 Gregorian' );
Sunday 30 Winterfilth 7465

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139392000, 'utc_rd_as_seconds() on 2001-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730780,
  0,
  0
]
, 'utc_rd_values() on 2001-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2001-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2001-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-23 Gregorian' );
Monday 1 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139478400, 'utc_rd_as_seconds() on 2001-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730781,
  0,
  0
]
, 'utc_rd_values() on 2001-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2001-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2001-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-24 Gregorian' );
Trewsday 2 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139564800, 'utc_rd_as_seconds() on 2001-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730782,
  0,
  0
]
, 'utc_rd_values() on 2001-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2001-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2001-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-25 Gregorian' );
Hevensday 3 Blotmath 7465

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139651200, 'utc_rd_as_seconds() on 2001-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730783,
  0,
  0
]
, 'utc_rd_values() on 2001-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2001-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2001-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-26 Gregorian' );
Mersday 4 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139737600, 'utc_rd_as_seconds() on 2001-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730784,
  0,
  0
]
, 'utc_rd_values() on 2001-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2001-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2001-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-27 Gregorian' );
Highday 5 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139824000, 'utc_rd_as_seconds() on 2001-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730785,
  0,
  0
]
, 'utc_rd_values() on 2001-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  44
]
, 'week() on 2001-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2001-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2001-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2001-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-28 Gregorian' );
Sterday 6 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139910400, 'utc_rd_as_seconds() on 2001-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730786,
  0,
  0
]
, 'utc_rd_values() on 2001-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2001-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2001-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-29 Gregorian' );
Sunday 7 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63139996800, 'utc_rd_as_seconds() on 2001-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730787,
  0,
  0
]
, 'utc_rd_values() on 2001-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2001-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2001-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-30 Gregorian' );
Monday 8 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140083200, 'utc_rd_as_seconds() on 2001-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730788,
  0,
  0
]
, 'utc_rd_values() on 2001-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2001-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2001-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-10-31 Gregorian' );
Trewsday 9 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140169600, 'utc_rd_as_seconds() on 2001-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730789,
  0,
  0
]
, 'utc_rd_values() on 2001-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2001-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2001-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-01 Gregorian' );
Hevensday 10 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140256000, 'utc_rd_as_seconds() on 2001-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730790,
  0,
  0
]
, 'utc_rd_values() on 2001-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2001-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2001-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-02 Gregorian' );
Mersday 11 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140342400, 'utc_rd_as_seconds() on 2001-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730791,
  0,
  0
]
, 'utc_rd_values() on 2001-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2001-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2001-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-03 Gregorian' );
Highday 12 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140428800, 'utc_rd_as_seconds() on 2001-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730792,
  0,
  0
]
, 'utc_rd_values() on 2001-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  45
]
, 'week() on 2001-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2001-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2001-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2001-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-04 Gregorian' );
Sterday 13 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140515200, 'utc_rd_as_seconds() on 2001-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730793,
  0,
  0
]
, 'utc_rd_values() on 2001-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2001-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2001-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-05 Gregorian' );
Sunday 14 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140601600, 'utc_rd_as_seconds() on 2001-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730794,
  0,
  0
]
, 'utc_rd_values() on 2001-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2001-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2001-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-06 Gregorian' );
Monday 15 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140688000, 'utc_rd_as_seconds() on 2001-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730795,
  0,
  0
]
, 'utc_rd_values() on 2001-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2001-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2001-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-07 Gregorian' );
Trewsday 16 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140774400, 'utc_rd_as_seconds() on 2001-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730796,
  0,
  0
]
, 'utc_rd_values() on 2001-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2001-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2001-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-08 Gregorian' );
Hevensday 17 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140860800, 'utc_rd_as_seconds() on 2001-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730797,
  0,
  0
]
, 'utc_rd_values() on 2001-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2001-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2001-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-09 Gregorian' );
Mersday 18 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63140947200, 'utc_rd_as_seconds() on 2001-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730798,
  0,
  0
]
, 'utc_rd_values() on 2001-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2001-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2001-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-10 Gregorian' );
Highday 19 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141033600, 'utc_rd_as_seconds() on 2001-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730799,
  0,
  0
]
, 'utc_rd_values() on 2001-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  46
]
, 'week() on 2001-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2001-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2001-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2001-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-11 Gregorian' );
Sterday 20 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141120000, 'utc_rd_as_seconds() on 2001-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730800,
  0,
  0
]
, 'utc_rd_values() on 2001-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2001-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2001-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-12 Gregorian' );
Sunday 21 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141206400, 'utc_rd_as_seconds() on 2001-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730801,
  0,
  0
]
, 'utc_rd_values() on 2001-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2001-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2001-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-13 Gregorian' );
Monday 22 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141292800, 'utc_rd_as_seconds() on 2001-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730802,
  0,
  0
]
, 'utc_rd_values() on 2001-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2001-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2001-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-14 Gregorian' );
Trewsday 23 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141379200, 'utc_rd_as_seconds() on 2001-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730803,
  0,
  0
]
, 'utc_rd_values() on 2001-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2001-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2001-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-15 Gregorian' );
Hevensday 24 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141465600, 'utc_rd_as_seconds() on 2001-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730804,
  0,
  0
]
, 'utc_rd_values() on 2001-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2001-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2001-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-16 Gregorian' );
Mersday 25 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141552000, 'utc_rd_as_seconds() on 2001-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730805,
  0,
  0
]
, 'utc_rd_values() on 2001-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2001-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2001-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-17 Gregorian' );
Highday 26 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141638400, 'utc_rd_as_seconds() on 2001-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730806,
  0,
  0
]
, 'utc_rd_values() on 2001-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  47
]
, 'week() on 2001-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2001-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2001-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2001-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-18 Gregorian' );
Sterday 27 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141724800, 'utc_rd_as_seconds() on 2001-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730807,
  0,
  0
]
, 'utc_rd_values() on 2001-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2001-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2001-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-19 Gregorian' );
Sunday 28 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141811200, 'utc_rd_as_seconds() on 2001-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730808,
  0,
  0
]
, 'utc_rd_values() on 2001-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2001-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2001-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-20 Gregorian' );
Monday 29 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141897600, 'utc_rd_as_seconds() on 2001-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730809,
  0,
  0
]
, 'utc_rd_values() on 2001-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2001-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2001-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2001-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2001-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-21 Gregorian' );
Trewsday 30 Blotmath 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63141984000, 'utc_rd_as_seconds() on 2001-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730810,
  0,
  0
]
, 'utc_rd_values() on 2001-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2001-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2001-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-22 Gregorian' );
Hevensday 1 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142070400, 'utc_rd_as_seconds() on 2001-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730811,
  0,
  0
]
, 'utc_rd_values() on 2001-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2001-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2001-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-23 Gregorian' );
Mersday 2 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142156800, 'utc_rd_as_seconds() on 2001-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730812,
  0,
  0
]
, 'utc_rd_values() on 2001-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2001-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2001-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-24 Gregorian' );
Highday 3 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142243200, 'utc_rd_as_seconds() on 2001-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730813,
  0,
  0
]
, 'utc_rd_values() on 2001-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  48
]
, 'week() on 2001-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2001-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2001-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2001-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-25 Gregorian' );
Sterday 4 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142329600, 'utc_rd_as_seconds() on 2001-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730814,
  0,
  0
]
, 'utc_rd_values() on 2001-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2001-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2001-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-26 Gregorian' );
Sunday 5 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142416000, 'utc_rd_as_seconds() on 2001-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730815,
  0,
  0
]
, 'utc_rd_values() on 2001-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2001-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2001-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-27 Gregorian' );
Monday 6 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142502400, 'utc_rd_as_seconds() on 2001-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730816,
  0,
  0
]
, 'utc_rd_values() on 2001-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2001-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2001-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-28 Gregorian' );
Trewsday 7 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142588800, 'utc_rd_as_seconds() on 2001-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730817,
  0,
  0
]
, 'utc_rd_values() on 2001-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2001-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2001-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-29 Gregorian' );
Hevensday 8 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142675200, 'utc_rd_as_seconds() on 2001-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730818,
  0,
  0
]
, 'utc_rd_values() on 2001-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2001-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2001-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2001-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2001-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2001-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-11-30 Gregorian' );
Mersday 9 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142761600, 'utc_rd_as_seconds() on 2001-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730819,
  0,
  0
]
, 'utc_rd_values() on 2001-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2001-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2001-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2001-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2001-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2001-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-01 Gregorian' );
Highday 10 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142848000, 'utc_rd_as_seconds() on 2001-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730820,
  0,
  0
]
, 'utc_rd_values() on 2001-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  49
]
, 'week() on 2001-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2001-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2001-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2001-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2001-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2001-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2001-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-02 Gregorian' );
Sterday 11 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63142934400, 'utc_rd_as_seconds() on 2001-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730821,
  0,
  0
]
, 'utc_rd_values() on 2001-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2001-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2001-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2001-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2001-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2001-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-03 Gregorian' );
Sunday 12 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143020800, 'utc_rd_as_seconds() on 2001-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730822,
  0,
  0
]
, 'utc_rd_values() on 2001-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2001-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2001-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2001-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2001-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2001-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-04 Gregorian' );
Monday 13 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143107200, 'utc_rd_as_seconds() on 2001-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730823,
  0,
  0
]
, 'utc_rd_values() on 2001-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2001-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2001-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2001-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2001-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2001-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-05 Gregorian' );
Trewsday 14 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143193600, 'utc_rd_as_seconds() on 2001-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730824,
  0,
  0
]
, 'utc_rd_values() on 2001-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2001-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2001-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2001-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2001-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2001-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-06 Gregorian' );
Hevensday 15 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143280000, 'utc_rd_as_seconds() on 2001-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730825,
  0,
  0
]
, 'utc_rd_values() on 2001-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2001-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2001-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2001-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2001-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2001-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-07 Gregorian' );
Mersday 16 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143366400, 'utc_rd_as_seconds() on 2001-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730826,
  0,
  0
]
, 'utc_rd_values() on 2001-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2001-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2001-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2001-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2001-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2001-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-08 Gregorian' );
Highday 17 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143452800, 'utc_rd_as_seconds() on 2001-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730827,
  0,
  0
]
, 'utc_rd_values() on 2001-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  50
]
, 'week() on 2001-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2001-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2001-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2001-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2001-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2001-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2001-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-09 Gregorian' );
Sterday 18 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143539200, 'utc_rd_as_seconds() on 2001-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730828,
  0,
  0
]
, 'utc_rd_values() on 2001-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2001-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2001-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2001-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2001-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2001-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-10 Gregorian' );
Sunday 19 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143625600, 'utc_rd_as_seconds() on 2001-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730829,
  0,
  0
]
, 'utc_rd_values() on 2001-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2001-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2001-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2001-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2001-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2001-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-11 Gregorian' );
Monday 20 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143712000, 'utc_rd_as_seconds() on 2001-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730830,
  0,
  0
]
, 'utc_rd_values() on 2001-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2001-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2001-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2001-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2001-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2001-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-12 Gregorian' );
Trewsday 21 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143798400, 'utc_rd_as_seconds() on 2001-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730831,
  0,
  0
]
, 'utc_rd_values() on 2001-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2001-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2001-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2001-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2001-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2001-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-13 Gregorian' );
Hevensday 22 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143884800, 'utc_rd_as_seconds() on 2001-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730832,
  0,
  0
]
, 'utc_rd_values() on 2001-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2001-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2001-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2001-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2001-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2001-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-14 Gregorian' );
Mersday 23 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63143971200, 'utc_rd_as_seconds() on 2001-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730833,
  0,
  0
]
, 'utc_rd_values() on 2001-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2001-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2001-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2001-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2001-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2001-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-15 Gregorian' );
Highday 24 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144057600, 'utc_rd_as_seconds() on 2001-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730834,
  0,
  0
]
, 'utc_rd_values() on 2001-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  51
]
, 'week() on 2001-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2001-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2001-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2001-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2001-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2001-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2001-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-16 Gregorian' );
Sterday 25 Foreyule 7465

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144144000, 'utc_rd_as_seconds() on 2001-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730835,
  0,
  0
]
, 'utc_rd_values() on 2001-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2001-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2001-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2001-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2001-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2001-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-17 Gregorian' );
Sunday 26 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144230400, 'utc_rd_as_seconds() on 2001-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730836,
  0,
  0
]
, 'utc_rd_values() on 2001-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2001-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2001-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2001-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2001-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2001-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-18 Gregorian' );
Monday 27 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144316800, 'utc_rd_as_seconds() on 2001-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730837,
  0,
  0
]
, 'utc_rd_values() on 2001-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2001-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2001-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2001-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2001-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2001-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-19 Gregorian' );
Trewsday 28 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144403200, 'utc_rd_as_seconds() on 2001-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730838,
  0,
  0
]
, 'utc_rd_values() on 2001-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2001-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2001-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2001-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2001-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2001-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-20 Gregorian' );
Hevensday 29 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144489600, 'utc_rd_as_seconds() on 2001-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730839,
  0,
  0
]
, 'utc_rd_values() on 2001-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2001-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2001-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2001-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2001-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2001-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2001-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2001-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-21 Gregorian' );
Mersday 30 Foreyule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144576000, 'utc_rd_as_seconds() on 2001-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730840,
  0,
  0
]
, 'utc_rd_values() on 2001-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2001-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2001-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2001-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2001-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2001-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2001-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2001-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2001-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2001-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-22 Gregorian' );
Highday 1 Yule 7465
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144662400, 'utc_rd_as_seconds() on 2001-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730841,
  0,
  0
]
, 'utc_rd_values() on 2001-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7465,
  52
]
, 'week() on 2001-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2001-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7465, 'week_year() on 2001-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7465, 'year() on 2001-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2001-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2001-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2001-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2001-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2001-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2001-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2001-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2001-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2001-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-23 Gregorian' );
Sterday 2 Yule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144748800, 'utc_rd_as_seconds() on 2001-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730842,
  0,
  0
]
, 'utc_rd_values() on 2001-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2001-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2001-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2001-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2001-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2001-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-24 Gregorian' );
Sunday 1 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144835200, 'utc_rd_as_seconds() on 2001-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730843,
  0,
  0
]
, 'utc_rd_values() on 2001-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2001-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2001-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2001-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2001-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2001-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2001-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2001-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2001-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2001-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-25 Gregorian' );
Monday 2 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63144921600, 'utc_rd_as_seconds() on 2001-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730844,
  0,
  0
]
, 'utc_rd_values() on 2001-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2001-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2001-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2001-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2001-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2001-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2001-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2001-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2001-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2001-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2001-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-26 Gregorian' );
Trewsday 3 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145008000, 'utc_rd_as_seconds() on 2001-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730845,
  0,
  0
]
, 'utc_rd_values() on 2001-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2001-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2001-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2001-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2001-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2001-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2001-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2001-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2001-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2001-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2001-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-27 Gregorian' );
Hevensday 4 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145094400, 'utc_rd_as_seconds() on 2001-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730846,
  0,
  0
]
, 'utc_rd_values() on 2001-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2001-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2001-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2001-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2001-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2001-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2001-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2001-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2001-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2001-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2001-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-28 Gregorian' );
Mersday 5 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145180800, 'utc_rd_as_seconds() on 2001-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730847,
  0,
  0
]
, 'utc_rd_values() on 2001-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2001-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2001-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2001-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2001-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2001-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2001-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2001-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2001-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2001-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2001-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-29 Gregorian' );
Highday 6 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145267200, 'utc_rd_as_seconds() on 2001-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730848,
  0,
  0
]
, 'utc_rd_values() on 2001-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2001-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  1
]
, 'week() on 2001-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2001-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2001-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2001-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2001-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2001-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2001-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2001-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2001-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2001-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2001-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-30 Gregorian' );
Sterday 7 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145353600, 'utc_rd_as_seconds() on 2001-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730849,
  0,
  0
]
, 'utc_rd_values() on 2001-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2001-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2001-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2001 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2001,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2001-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2001-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2001-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2001-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2001-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2001-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2001-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2001-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2001-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2001-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2001-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2001-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2001-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2001-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2001-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2001-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2001-12-31 Gregorian' );
Sunday 8 Afteryule 7466

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145440000, 'utc_rd_as_seconds() on 2001-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730850,
  0,
  0
]
, 'utc_rd_values() on 2001-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2001-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2001-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2001-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2001-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2001-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2002-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2002-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-01 Gregorian' );
Monday 9 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145526400, 'utc_rd_as_seconds() on 2002-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730851,
  0,
  0
]
, 'utc_rd_values() on 2002-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2002-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2002-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2002-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-02 Gregorian' );
Trewsday 10 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145612800, 'utc_rd_as_seconds() on 2002-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730852,
  0,
  0
]
, 'utc_rd_values() on 2002-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2002-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2002-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2002-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-03 Gregorian' );
Hevensday 11 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145699200, 'utc_rd_as_seconds() on 2002-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730853,
  0,
  0
]
, 'utc_rd_values() on 2002-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2002-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2002-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2002-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-04 Gregorian' );
Mersday 12 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145785600, 'utc_rd_as_seconds() on 2002-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730854,
  0,
  0
]
, 'utc_rd_values() on 2002-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2002-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2002-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2002-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-05 Gregorian' );
Highday 13 Afteryule 7466

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145872000, 'utc_rd_as_seconds() on 2002-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730855,
  0,
  0
]
, 'utc_rd_values() on 2002-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  2
]
, 'week() on 2002-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2002-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2002-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-06 Gregorian' );
Sterday 14 Afteryule 7466

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63145958400, 'utc_rd_as_seconds() on 2002-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730856,
  0,
  0
]
, 'utc_rd_values() on 2002-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2002-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2002-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-07 Gregorian' );
Sunday 15 Afteryule 7466

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146044800, 'utc_rd_as_seconds() on 2002-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730857,
  0,
  0
]
, 'utc_rd_values() on 2002-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2002-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2002-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-08 Gregorian' );
Monday 16 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146131200, 'utc_rd_as_seconds() on 2002-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730858,
  0,
  0
]
, 'utc_rd_values() on 2002-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2002-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2002-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-09 Gregorian' );
Trewsday 17 Afteryule 7466

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146217600, 'utc_rd_as_seconds() on 2002-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730859,
  0,
  0
]
, 'utc_rd_values() on 2002-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2002-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2002-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-10 Gregorian' );
Hevensday 18 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146304000, 'utc_rd_as_seconds() on 2002-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730860,
  0,
  0
]
, 'utc_rd_values() on 2002-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2002-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2002-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-11 Gregorian' );
Mersday 19 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146390400, 'utc_rd_as_seconds() on 2002-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730861,
  0,
  0
]
, 'utc_rd_values() on 2002-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2002-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2002-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-12 Gregorian' );
Highday 20 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146476800, 'utc_rd_as_seconds() on 2002-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730862,
  0,
  0
]
, 'utc_rd_values() on 2002-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  3
]
, 'week() on 2002-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2002-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2002-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2002-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-13 Gregorian' );
Sterday 21 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146563200, 'utc_rd_as_seconds() on 2002-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730863,
  0,
  0
]
, 'utc_rd_values() on 2002-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2002-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2002-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-14 Gregorian' );
Sunday 22 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146649600, 'utc_rd_as_seconds() on 2002-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730864,
  0,
  0
]
, 'utc_rd_values() on 2002-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2002-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2002-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-15 Gregorian' );
Monday 23 Afteryule 7466

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146736000, 'utc_rd_as_seconds() on 2002-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730865,
  0,
  0
]
, 'utc_rd_values() on 2002-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2002-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2002-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-16 Gregorian' );
Trewsday 24 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146822400, 'utc_rd_as_seconds() on 2002-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730866,
  0,
  0
]
, 'utc_rd_values() on 2002-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2002-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2002-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-17 Gregorian' );
Hevensday 25 Afteryule 7466

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146908800, 'utc_rd_as_seconds() on 2002-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730867,
  0,
  0
]
, 'utc_rd_values() on 2002-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2002-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2002-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-18 Gregorian' );
Mersday 26 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63146995200, 'utc_rd_as_seconds() on 2002-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730868,
  0,
  0
]
, 'utc_rd_values() on 2002-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2002-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2002-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-19 Gregorian' );
Highday 27 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147081600, 'utc_rd_as_seconds() on 2002-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730869,
  0,
  0
]
, 'utc_rd_values() on 2002-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  4
]
, 'week() on 2002-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2002-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2002-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2002-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-20 Gregorian' );
Sterday 28 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147168000, 'utc_rd_as_seconds() on 2002-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730870,
  0,
  0
]
, 'utc_rd_values() on 2002-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2002-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2002-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-21 Gregorian' );
Sunday 29 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147254400, 'utc_rd_as_seconds() on 2002-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730871,
  0,
  0
]
, 'utc_rd_values() on 2002-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2002-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2002-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-22 Gregorian' );
Monday 30 Afteryule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147340800, 'utc_rd_as_seconds() on 2002-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730872,
  0,
  0
]
, 'utc_rd_values() on 2002-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2002-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2002-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-23 Gregorian' );
Trewsday 1 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147427200, 'utc_rd_as_seconds() on 2002-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730873,
  0,
  0
]
, 'utc_rd_values() on 2002-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2002-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2002-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-24 Gregorian' );
Hevensday 2 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147513600, 'utc_rd_as_seconds() on 2002-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730874,
  0,
  0
]
, 'utc_rd_values() on 2002-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2002-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2002-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-25 Gregorian' );
Mersday 3 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147600000, 'utc_rd_as_seconds() on 2002-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730875,
  0,
  0
]
, 'utc_rd_values() on 2002-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2002-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2002-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-26 Gregorian' );
Highday 4 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147686400, 'utc_rd_as_seconds() on 2002-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730876,
  0,
  0
]
, 'utc_rd_values() on 2002-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  5
]
, 'week() on 2002-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2002-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2002-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2002-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-27 Gregorian' );
Sterday 5 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147772800, 'utc_rd_as_seconds() on 2002-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730877,
  0,
  0
]
, 'utc_rd_values() on 2002-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2002-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2002-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-28 Gregorian' );
Sunday 6 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147859200, 'utc_rd_as_seconds() on 2002-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730878,
  0,
  0
]
, 'utc_rd_values() on 2002-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2002-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2002-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-29 Gregorian' );
Monday 7 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63147945600, 'utc_rd_as_seconds() on 2002-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730879,
  0,
  0
]
, 'utc_rd_values() on 2002-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2002-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2002-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-30 Gregorian' );
Trewsday 8 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148032000, 'utc_rd_as_seconds() on 2002-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730880,
  0,
  0
]
, 'utc_rd_values() on 2002-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2002-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2002-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-01-31 Gregorian' );
Hevensday 9 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148118400, 'utc_rd_as_seconds() on 2002-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730881,
  0,
  0
]
, 'utc_rd_values() on 2002-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2002-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2002-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-01 Gregorian' );
Mersday 10 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148204800, 'utc_rd_as_seconds() on 2002-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730882,
  0,
  0
]
, 'utc_rd_values() on 2002-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2002-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2002-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-02 Gregorian' );
Highday 11 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148291200, 'utc_rd_as_seconds() on 2002-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730883,
  0,
  0
]
, 'utc_rd_values() on 2002-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  6
]
, 'week() on 2002-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2002-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2002-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2002-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-03 Gregorian' );
Sterday 12 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148377600, 'utc_rd_as_seconds() on 2002-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730884,
  0,
  0
]
, 'utc_rd_values() on 2002-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2002-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2002-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-04 Gregorian' );
Sunday 13 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148464000, 'utc_rd_as_seconds() on 2002-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730885,
  0,
  0
]
, 'utc_rd_values() on 2002-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2002-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2002-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-05 Gregorian' );
Monday 14 Solmath 7466

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148550400, 'utc_rd_as_seconds() on 2002-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730886,
  0,
  0
]
, 'utc_rd_values() on 2002-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2002-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2002-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-06 Gregorian' );
Trewsday 15 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148636800, 'utc_rd_as_seconds() on 2002-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730887,
  0,
  0
]
, 'utc_rd_values() on 2002-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2002-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2002-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-07 Gregorian' );
Hevensday 16 Solmath 7466

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148723200, 'utc_rd_as_seconds() on 2002-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730888,
  0,
  0
]
, 'utc_rd_values() on 2002-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2002-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2002-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-08 Gregorian' );
Mersday 17 Solmath 7466

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148809600, 'utc_rd_as_seconds() on 2002-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730889,
  0,
  0
]
, 'utc_rd_values() on 2002-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2002-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2002-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-09 Gregorian' );
Highday 18 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148896000, 'utc_rd_as_seconds() on 2002-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730890,
  0,
  0
]
, 'utc_rd_values() on 2002-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  7
]
, 'week() on 2002-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2002-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2002-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2002-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-10 Gregorian' );
Sterday 19 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63148982400, 'utc_rd_as_seconds() on 2002-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730891,
  0,
  0
]
, 'utc_rd_values() on 2002-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2002-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2002-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-11 Gregorian' );
Sunday 20 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149068800, 'utc_rd_as_seconds() on 2002-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730892,
  0,
  0
]
, 'utc_rd_values() on 2002-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2002-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2002-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-12 Gregorian' );
Monday 21 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149155200, 'utc_rd_as_seconds() on 2002-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730893,
  0,
  0
]
, 'utc_rd_values() on 2002-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2002-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2002-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-13 Gregorian' );
Trewsday 22 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149241600, 'utc_rd_as_seconds() on 2002-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730894,
  0,
  0
]
, 'utc_rd_values() on 2002-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2002-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2002-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-14 Gregorian' );
Hevensday 23 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149328000, 'utc_rd_as_seconds() on 2002-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730895,
  0,
  0
]
, 'utc_rd_values() on 2002-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2002-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2002-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-15 Gregorian' );
Mersday 24 Solmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149414400, 'utc_rd_as_seconds() on 2002-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730896,
  0,
  0
]
, 'utc_rd_values() on 2002-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2002-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2002-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-16 Gregorian' );
Highday 25 Solmath 7466

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149500800, 'utc_rd_as_seconds() on 2002-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730897,
  0,
  0
]
, 'utc_rd_values() on 2002-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  8
]
, 'week() on 2002-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2002-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2002-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2002-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-17 Gregorian' );
Sterday 26 Solmath 7466

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149587200, 'utc_rd_as_seconds() on 2002-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730898,
  0,
  0
]
, 'utc_rd_values() on 2002-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2002-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2002-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-18 Gregorian' );
Sunday 27 Solmath 7466

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149673600, 'utc_rd_as_seconds() on 2002-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730899,
  0,
  0
]
, 'utc_rd_values() on 2002-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2002-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2002-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-19 Gregorian' );
Monday 28 Solmath 7466

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149760000, 'utc_rd_as_seconds() on 2002-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730900,
  0,
  0
]
, 'utc_rd_values() on 2002-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2002-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2002-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-20 Gregorian' );
Trewsday 29 Solmath 7466

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149846400, 'utc_rd_as_seconds() on 2002-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730901,
  0,
  0
]
, 'utc_rd_values() on 2002-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2002-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2002-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2002-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2002-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-21 Gregorian' );
Hevensday 30 Solmath 7466

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63149932800, 'utc_rd_as_seconds() on 2002-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730902,
  0,
  0
]
, 'utc_rd_values() on 2002-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2002-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2002-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-22 Gregorian' );
Mersday 1 Rethe 7466

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150019200, 'utc_rd_as_seconds() on 2002-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730903,
  0,
  0
]
, 'utc_rd_values() on 2002-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2002-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2002-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-23 Gregorian' );
Highday 2 Rethe 7466

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150105600, 'utc_rd_as_seconds() on 2002-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730904,
  0,
  0
]
, 'utc_rd_values() on 2002-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  9
]
, 'week() on 2002-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2002-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2002-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2002-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-24 Gregorian' );
Sterday 3 Rethe 7466

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150192000, 'utc_rd_as_seconds() on 2002-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730905,
  0,
  0
]
, 'utc_rd_values() on 2002-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2002-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2002-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-25 Gregorian' );
Sunday 4 Rethe 7466

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150278400, 'utc_rd_as_seconds() on 2002-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730906,
  0,
  0
]
, 'utc_rd_values() on 2002-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2002-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2002-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-26 Gregorian' );
Monday 5 Rethe 7466

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150364800, 'utc_rd_as_seconds() on 2002-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730907,
  0,
  0
]
, 'utc_rd_values() on 2002-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2002-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2002-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-27 Gregorian' );
Trewsday 6 Rethe 7466

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150451200, 'utc_rd_as_seconds() on 2002-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730908,
  0,
  0
]
, 'utc_rd_values() on 2002-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2002-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2002-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-02-28 Gregorian' );
Hevensday 7 Rethe 7466

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150537600, 'utc_rd_as_seconds() on 2002-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730909,
  0,
  0
]
, 'utc_rd_values() on 2002-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2002-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2002-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-01 Gregorian' );
Mersday 8 Rethe 7466

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150624000, 'utc_rd_as_seconds() on 2002-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730910,
  0,
  0
]
, 'utc_rd_values() on 2002-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2002-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2002-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-02 Gregorian' );
Highday 9 Rethe 7466

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150710400, 'utc_rd_as_seconds() on 2002-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730911,
  0,
  0
]
, 'utc_rd_values() on 2002-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  10
]
, 'week() on 2002-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2002-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2002-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2002-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-03 Gregorian' );
Sterday 10 Rethe 7466

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150796800, 'utc_rd_as_seconds() on 2002-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730912,
  0,
  0
]
, 'utc_rd_values() on 2002-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2002-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2002-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-04 Gregorian' );
Sunday 11 Rethe 7466

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150883200, 'utc_rd_as_seconds() on 2002-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730913,
  0,
  0
]
, 'utc_rd_values() on 2002-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2002-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2002-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-05 Gregorian' );
Monday 12 Rethe 7466

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63150969600, 'utc_rd_as_seconds() on 2002-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730914,
  0,
  0
]
, 'utc_rd_values() on 2002-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2002-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2002-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-06 Gregorian' );
Trewsday 13 Rethe 7466

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151056000, 'utc_rd_as_seconds() on 2002-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730915,
  0,
  0
]
, 'utc_rd_values() on 2002-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2002-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2002-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-07 Gregorian' );
Hevensday 14 Rethe 7466

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151142400, 'utc_rd_as_seconds() on 2002-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730916,
  0,
  0
]
, 'utc_rd_values() on 2002-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2002-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2002-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-08 Gregorian' );
Mersday 15 Rethe 7466

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151228800, 'utc_rd_as_seconds() on 2002-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730917,
  0,
  0
]
, 'utc_rd_values() on 2002-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2002-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2002-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-09 Gregorian' );
Highday 16 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151315200, 'utc_rd_as_seconds() on 2002-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730918,
  0,
  0
]
, 'utc_rd_values() on 2002-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  11
]
, 'week() on 2002-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2002-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2002-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2002-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-10 Gregorian' );
Sterday 17 Rethe 7466

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151401600, 'utc_rd_as_seconds() on 2002-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730919,
  0,
  0
]
, 'utc_rd_values() on 2002-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2002-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2002-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-11 Gregorian' );
Sunday 18 Rethe 7466

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151488000, 'utc_rd_as_seconds() on 2002-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730920,
  0,
  0
]
, 'utc_rd_values() on 2002-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2002-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2002-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-12 Gregorian' );
Monday 19 Rethe 7466

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151574400, 'utc_rd_as_seconds() on 2002-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730921,
  0,
  0
]
, 'utc_rd_values() on 2002-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2002-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2002-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-13 Gregorian' );
Trewsday 20 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151660800, 'utc_rd_as_seconds() on 2002-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730922,
  0,
  0
]
, 'utc_rd_values() on 2002-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2002-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2002-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-14 Gregorian' );
Hevensday 21 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151747200, 'utc_rd_as_seconds() on 2002-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730923,
  0,
  0
]
, 'utc_rd_values() on 2002-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2002-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2002-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-15 Gregorian' );
Mersday 22 Rethe 7466

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151833600, 'utc_rd_as_seconds() on 2002-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730924,
  0,
  0
]
, 'utc_rd_values() on 2002-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2002-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2002-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-16 Gregorian' );
Highday 23 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63151920000, 'utc_rd_as_seconds() on 2002-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730925,
  0,
  0
]
, 'utc_rd_values() on 2002-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  12
]
, 'week() on 2002-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2002-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2002-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2002-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-17 Gregorian' );
Sterday 24 Rethe 7466

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152006400, 'utc_rd_as_seconds() on 2002-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730926,
  0,
  0
]
, 'utc_rd_values() on 2002-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2002-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2002-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-18 Gregorian' );
Sunday 25 Rethe 7466

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152092800, 'utc_rd_as_seconds() on 2002-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730927,
  0,
  0
]
, 'utc_rd_values() on 2002-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2002-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2002-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-19 Gregorian' );
Monday 26 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152179200, 'utc_rd_as_seconds() on 2002-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730928,
  0,
  0
]
, 'utc_rd_values() on 2002-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2002-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2002-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-20 Gregorian' );
Trewsday 27 Rethe 7466

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152265600, 'utc_rd_as_seconds() on 2002-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730929,
  0,
  0
]
, 'utc_rd_values() on 2002-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2002-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2002-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-21 Gregorian' );
Hevensday 28 Rethe 7466

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152352000, 'utc_rd_as_seconds() on 2002-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730930,
  0,
  0
]
, 'utc_rd_values() on 2002-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2002-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2002-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-22 Gregorian' );
Mersday 29 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152438400, 'utc_rd_as_seconds() on 2002-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730931,
  0,
  0
]
, 'utc_rd_values() on 2002-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2002-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2002-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2002-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2002-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-23 Gregorian' );
Highday 30 Rethe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152524800, 'utc_rd_as_seconds() on 2002-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730932,
  0,
  0
]
, 'utc_rd_values() on 2002-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  13
]
, 'week() on 2002-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2002-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2002-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2002-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-24 Gregorian' );
Sterday 1 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152611200, 'utc_rd_as_seconds() on 2002-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730933,
  0,
  0
]
, 'utc_rd_values() on 2002-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2002-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2002-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-25 Gregorian' );
Sunday 2 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152697600, 'utc_rd_as_seconds() on 2002-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730934,
  0,
  0
]
, 'utc_rd_values() on 2002-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2002-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2002-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-26 Gregorian' );
Monday 3 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152784000, 'utc_rd_as_seconds() on 2002-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730935,
  0,
  0
]
, 'utc_rd_values() on 2002-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2002-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2002-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-27 Gregorian' );
Trewsday 4 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152870400, 'utc_rd_as_seconds() on 2002-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730936,
  0,
  0
]
, 'utc_rd_values() on 2002-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2002-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2002-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-28 Gregorian' );
Hevensday 5 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63152956800, 'utc_rd_as_seconds() on 2002-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730937,
  0,
  0
]
, 'utc_rd_values() on 2002-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2002-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2002-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-29 Gregorian' );
Mersday 6 Astron 7466

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153043200, 'utc_rd_as_seconds() on 2002-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730938,
  0,
  0
]
, 'utc_rd_values() on 2002-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2002-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2002-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-30 Gregorian' );
Highday 7 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153129600, 'utc_rd_as_seconds() on 2002-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730939,
  0,
  0
]
, 'utc_rd_values() on 2002-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  14
]
, 'week() on 2002-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2002-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2002-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2002-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-03-31 Gregorian' );
Sterday 8 Astron 7466

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153216000, 'utc_rd_as_seconds() on 2002-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730940,
  0,
  0
]
, 'utc_rd_values() on 2002-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2002-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2002-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-01 Gregorian' );
Sunday 9 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153302400, 'utc_rd_as_seconds() on 2002-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730941,
  0,
  0
]
, 'utc_rd_values() on 2002-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2002-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2002-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-02 Gregorian' );
Monday 10 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153388800, 'utc_rd_as_seconds() on 2002-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730942,
  0,
  0
]
, 'utc_rd_values() on 2002-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2002-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2002-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-03 Gregorian' );
Trewsday 11 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153475200, 'utc_rd_as_seconds() on 2002-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730943,
  0,
  0
]
, 'utc_rd_values() on 2002-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2002-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2002-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-04 Gregorian' );
Hevensday 12 Astron 7466

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153561600, 'utc_rd_as_seconds() on 2002-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730944,
  0,
  0
]
, 'utc_rd_values() on 2002-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2002-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2002-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-05 Gregorian' );
Mersday 13 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153648000, 'utc_rd_as_seconds() on 2002-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730945,
  0,
  0
]
, 'utc_rd_values() on 2002-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2002-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2002-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-06 Gregorian' );
Highday 14 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153734400, 'utc_rd_as_seconds() on 2002-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730946,
  0,
  0
]
, 'utc_rd_values() on 2002-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  15
]
, 'week() on 2002-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2002-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2002-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2002-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-07 Gregorian' );
Sterday 15 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153820800, 'utc_rd_as_seconds() on 2002-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730947,
  0,
  0
]
, 'utc_rd_values() on 2002-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2002-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2002-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-08 Gregorian' );
Sunday 16 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153907200, 'utc_rd_as_seconds() on 2002-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730948,
  0,
  0
]
, 'utc_rd_values() on 2002-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2002-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2002-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-09 Gregorian' );
Monday 17 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63153993600, 'utc_rd_as_seconds() on 2002-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730949,
  0,
  0
]
, 'utc_rd_values() on 2002-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2002-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2002-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-10 Gregorian' );
Trewsday 18 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154080000, 'utc_rd_as_seconds() on 2002-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730950,
  0,
  0
]
, 'utc_rd_values() on 2002-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2002-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2002-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-11 Gregorian' );
Hevensday 19 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154166400, 'utc_rd_as_seconds() on 2002-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730951,
  0,
  0
]
, 'utc_rd_values() on 2002-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2002-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2002-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-12 Gregorian' );
Mersday 20 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154252800, 'utc_rd_as_seconds() on 2002-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730952,
  0,
  0
]
, 'utc_rd_values() on 2002-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2002-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2002-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-13 Gregorian' );
Highday 21 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154339200, 'utc_rd_as_seconds() on 2002-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730953,
  0,
  0
]
, 'utc_rd_values() on 2002-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  16
]
, 'week() on 2002-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2002-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2002-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2002-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-14 Gregorian' );
Sterday 22 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154425600, 'utc_rd_as_seconds() on 2002-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730954,
  0,
  0
]
, 'utc_rd_values() on 2002-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2002-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2002-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-15 Gregorian' );
Sunday 23 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154512000, 'utc_rd_as_seconds() on 2002-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730955,
  0,
  0
]
, 'utc_rd_values() on 2002-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2002-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2002-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-16 Gregorian' );
Monday 24 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154598400, 'utc_rd_as_seconds() on 2002-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730956,
  0,
  0
]
, 'utc_rd_values() on 2002-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2002-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2002-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-17 Gregorian' );
Trewsday 25 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154684800, 'utc_rd_as_seconds() on 2002-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730957,
  0,
  0
]
, 'utc_rd_values() on 2002-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2002-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2002-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-18 Gregorian' );
Hevensday 26 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154771200, 'utc_rd_as_seconds() on 2002-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730958,
  0,
  0
]
, 'utc_rd_values() on 2002-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2002-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2002-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-19 Gregorian' );
Mersday 27 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154857600, 'utc_rd_as_seconds() on 2002-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730959,
  0,
  0
]
, 'utc_rd_values() on 2002-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2002-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2002-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-20 Gregorian' );
Highday 28 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63154944000, 'utc_rd_as_seconds() on 2002-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730960,
  0,
  0
]
, 'utc_rd_values() on 2002-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  17
]
, 'week() on 2002-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2002-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2002-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2002-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-21 Gregorian' );
Sterday 29 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155030400, 'utc_rd_as_seconds() on 2002-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730961,
  0,
  0
]
, 'utc_rd_values() on 2002-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2002-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2002-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2002-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2002-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-22 Gregorian' );
Sunday 30 Astron 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155116800, 'utc_rd_as_seconds() on 2002-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730962,
  0,
  0
]
, 'utc_rd_values() on 2002-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2002-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2002-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-23 Gregorian' );
Monday 1 Thrimidge 7466

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155203200, 'utc_rd_as_seconds() on 2002-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730963,
  0,
  0
]
, 'utc_rd_values() on 2002-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2002-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2002-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-24 Gregorian' );
Trewsday 2 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155289600, 'utc_rd_as_seconds() on 2002-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730964,
  0,
  0
]
, 'utc_rd_values() on 2002-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2002-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2002-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-25 Gregorian' );
Hevensday 3 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155376000, 'utc_rd_as_seconds() on 2002-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730965,
  0,
  0
]
, 'utc_rd_values() on 2002-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2002-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2002-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-26 Gregorian' );
Mersday 4 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155462400, 'utc_rd_as_seconds() on 2002-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730966,
  0,
  0
]
, 'utc_rd_values() on 2002-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2002-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2002-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-27 Gregorian' );
Highday 5 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155548800, 'utc_rd_as_seconds() on 2002-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730967,
  0,
  0
]
, 'utc_rd_values() on 2002-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  18
]
, 'week() on 2002-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2002-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2002-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2002-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-28 Gregorian' );
Sterday 6 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155635200, 'utc_rd_as_seconds() on 2002-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730968,
  0,
  0
]
, 'utc_rd_values() on 2002-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2002-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2002-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-29 Gregorian' );
Sunday 7 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155721600, 'utc_rd_as_seconds() on 2002-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730969,
  0,
  0
]
, 'utc_rd_values() on 2002-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2002-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2002-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-04-30 Gregorian' );
Monday 8 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155808000, 'utc_rd_as_seconds() on 2002-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730970,
  0,
  0
]
, 'utc_rd_values() on 2002-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2002-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2002-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-01 Gregorian' );
Trewsday 9 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155894400, 'utc_rd_as_seconds() on 2002-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730971,
  0,
  0
]
, 'utc_rd_values() on 2002-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2002-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2002-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-02 Gregorian' );
Hevensday 10 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63155980800, 'utc_rd_as_seconds() on 2002-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730972,
  0,
  0
]
, 'utc_rd_values() on 2002-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2002-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2002-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-03 Gregorian' );
Mersday 11 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156067200, 'utc_rd_as_seconds() on 2002-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730973,
  0,
  0
]
, 'utc_rd_values() on 2002-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2002-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2002-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-04 Gregorian' );
Highday 12 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156153600, 'utc_rd_as_seconds() on 2002-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730974,
  0,
  0
]
, 'utc_rd_values() on 2002-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  19
]
, 'week() on 2002-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2002-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2002-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2002-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-05 Gregorian' );
Sterday 13 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156240000, 'utc_rd_as_seconds() on 2002-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730975,
  0,
  0
]
, 'utc_rd_values() on 2002-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2002-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2002-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-06 Gregorian' );
Sunday 14 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156326400, 'utc_rd_as_seconds() on 2002-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730976,
  0,
  0
]
, 'utc_rd_values() on 2002-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2002-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2002-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-07 Gregorian' );
Monday 15 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156412800, 'utc_rd_as_seconds() on 2002-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730977,
  0,
  0
]
, 'utc_rd_values() on 2002-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2002-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2002-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-08 Gregorian' );
Trewsday 16 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156499200, 'utc_rd_as_seconds() on 2002-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730978,
  0,
  0
]
, 'utc_rd_values() on 2002-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2002-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2002-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-09 Gregorian' );
Hevensday 17 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156585600, 'utc_rd_as_seconds() on 2002-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730979,
  0,
  0
]
, 'utc_rd_values() on 2002-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2002-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2002-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-10 Gregorian' );
Mersday 18 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156672000, 'utc_rd_as_seconds() on 2002-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730980,
  0,
  0
]
, 'utc_rd_values() on 2002-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2002-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2002-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-11 Gregorian' );
Highday 19 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156758400, 'utc_rd_as_seconds() on 2002-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730981,
  0,
  0
]
, 'utc_rd_values() on 2002-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  20
]
, 'week() on 2002-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2002-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2002-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2002-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-12 Gregorian' );
Sterday 20 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156844800, 'utc_rd_as_seconds() on 2002-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730982,
  0,
  0
]
, 'utc_rd_values() on 2002-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2002-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2002-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-13 Gregorian' );
Sunday 21 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63156931200, 'utc_rd_as_seconds() on 2002-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730983,
  0,
  0
]
, 'utc_rd_values() on 2002-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2002-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2002-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-14 Gregorian' );
Monday 22 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157017600, 'utc_rd_as_seconds() on 2002-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730984,
  0,
  0
]
, 'utc_rd_values() on 2002-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2002-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2002-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-15 Gregorian' );
Trewsday 23 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157104000, 'utc_rd_as_seconds() on 2002-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730985,
  0,
  0
]
, 'utc_rd_values() on 2002-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2002-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2002-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-16 Gregorian' );
Hevensday 24 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157190400, 'utc_rd_as_seconds() on 2002-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730986,
  0,
  0
]
, 'utc_rd_values() on 2002-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2002-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2002-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-17 Gregorian' );
Mersday 25 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157276800, 'utc_rd_as_seconds() on 2002-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730987,
  0,
  0
]
, 'utc_rd_values() on 2002-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2002-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2002-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-18 Gregorian' );
Highday 26 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157363200, 'utc_rd_as_seconds() on 2002-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730988,
  0,
  0
]
, 'utc_rd_values() on 2002-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  21
]
, 'week() on 2002-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2002-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2002-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2002-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-19 Gregorian' );
Sterday 27 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157449600, 'utc_rd_as_seconds() on 2002-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730989,
  0,
  0
]
, 'utc_rd_values() on 2002-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2002-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2002-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-20 Gregorian' );
Sunday 28 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157536000, 'utc_rd_as_seconds() on 2002-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730990,
  0,
  0
]
, 'utc_rd_values() on 2002-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2002-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2002-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-21 Gregorian' );
Monday 29 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157622400, 'utc_rd_as_seconds() on 2002-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730991,
  0,
  0
]
, 'utc_rd_values() on 2002-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2002-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2002-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2002-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2002-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-22 Gregorian' );
Trewsday 30 Thrimidge 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157708800, 'utc_rd_as_seconds() on 2002-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730992,
  0,
  0
]
, 'utc_rd_values() on 2002-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2002-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2002-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-23 Gregorian' );
Hevensday 1 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157795200, 'utc_rd_as_seconds() on 2002-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730993,
  0,
  0
]
, 'utc_rd_values() on 2002-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2002-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2002-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-24 Gregorian' );
Mersday 2 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157881600, 'utc_rd_as_seconds() on 2002-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730994,
  0,
  0
]
, 'utc_rd_values() on 2002-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2002-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2002-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-25 Gregorian' );
Highday 3 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63157968000, 'utc_rd_as_seconds() on 2002-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730995,
  0,
  0
]
, 'utc_rd_values() on 2002-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  22
]
, 'week() on 2002-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2002-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2002-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2002-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-26 Gregorian' );
Sterday 4 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158054400, 'utc_rd_as_seconds() on 2002-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730996,
  0,
  0
]
, 'utc_rd_values() on 2002-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2002-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2002-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-27 Gregorian' );
Sunday 5 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158140800, 'utc_rd_as_seconds() on 2002-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730997,
  0,
  0
]
, 'utc_rd_values() on 2002-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2002-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2002-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-28 Gregorian' );
Monday 6 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158227200, 'utc_rd_as_seconds() on 2002-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730998,
  0,
  0
]
, 'utc_rd_values() on 2002-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2002-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2002-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-29 Gregorian' );
Trewsday 7 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158313600, 'utc_rd_as_seconds() on 2002-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  730999,
  0,
  0
]
, 'utc_rd_values() on 2002-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2002-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2002-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-30 Gregorian' );
Hevensday 8 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158400000, 'utc_rd_as_seconds() on 2002-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731000,
  0,
  0
]
, 'utc_rd_values() on 2002-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2002-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2002-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-05-31 Gregorian' );
Mersday 9 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158486400, 'utc_rd_as_seconds() on 2002-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731001,
  0,
  0
]
, 'utc_rd_values() on 2002-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2002-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2002-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-01 Gregorian' );
Highday 10 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158572800, 'utc_rd_as_seconds() on 2002-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731002,
  0,
  0
]
, 'utc_rd_values() on 2002-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  23
]
, 'week() on 2002-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2002-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2002-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2002-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-02 Gregorian' );
Sterday 11 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158659200, 'utc_rd_as_seconds() on 2002-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731003,
  0,
  0
]
, 'utc_rd_values() on 2002-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2002-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2002-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-03 Gregorian' );
Sunday 12 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158745600, 'utc_rd_as_seconds() on 2002-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731004,
  0,
  0
]
, 'utc_rd_values() on 2002-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2002-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2002-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-04 Gregorian' );
Monday 13 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158832000, 'utc_rd_as_seconds() on 2002-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731005,
  0,
  0
]
, 'utc_rd_values() on 2002-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2002-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2002-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-05 Gregorian' );
Trewsday 14 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63158918400, 'utc_rd_as_seconds() on 2002-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731006,
  0,
  0
]
, 'utc_rd_values() on 2002-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2002-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2002-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-06 Gregorian' );
Hevensday 15 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159004800, 'utc_rd_as_seconds() on 2002-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731007,
  0,
  0
]
, 'utc_rd_values() on 2002-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2002-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2002-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-07 Gregorian' );
Mersday 16 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159091200, 'utc_rd_as_seconds() on 2002-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731008,
  0,
  0
]
, 'utc_rd_values() on 2002-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2002-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2002-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-08 Gregorian' );
Highday 17 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159177600, 'utc_rd_as_seconds() on 2002-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731009,
  0,
  0
]
, 'utc_rd_values() on 2002-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  24
]
, 'week() on 2002-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2002-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2002-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2002-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-09 Gregorian' );
Sterday 18 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159264000, 'utc_rd_as_seconds() on 2002-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731010,
  0,
  0
]
, 'utc_rd_values() on 2002-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2002-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2002-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-10 Gregorian' );
Sunday 19 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159350400, 'utc_rd_as_seconds() on 2002-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731011,
  0,
  0
]
, 'utc_rd_values() on 2002-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2002-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2002-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-11 Gregorian' );
Monday 20 Forelithe 7466

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159436800, 'utc_rd_as_seconds() on 2002-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731012,
  0,
  0
]
, 'utc_rd_values() on 2002-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2002-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2002-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-12 Gregorian' );
Trewsday 21 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159523200, 'utc_rd_as_seconds() on 2002-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731013,
  0,
  0
]
, 'utc_rd_values() on 2002-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2002-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2002-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-13 Gregorian' );
Hevensday 22 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159609600, 'utc_rd_as_seconds() on 2002-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731014,
  0,
  0
]
, 'utc_rd_values() on 2002-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2002-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2002-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-14 Gregorian' );
Mersday 23 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159696000, 'utc_rd_as_seconds() on 2002-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731015,
  0,
  0
]
, 'utc_rd_values() on 2002-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2002-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2002-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-15 Gregorian' );
Highday 24 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159782400, 'utc_rd_as_seconds() on 2002-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731016,
  0,
  0
]
, 'utc_rd_values() on 2002-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  25
]
, 'week() on 2002-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2002-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2002-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2002-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-16 Gregorian' );
Sterday 25 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159868800, 'utc_rd_as_seconds() on 2002-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731017,
  0,
  0
]
, 'utc_rd_values() on 2002-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2002-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2002-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-17 Gregorian' );
Sunday 26 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63159955200, 'utc_rd_as_seconds() on 2002-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731018,
  0,
  0
]
, 'utc_rd_values() on 2002-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2002-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2002-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-18 Gregorian' );
Monday 27 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160041600, 'utc_rd_as_seconds() on 2002-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731019,
  0,
  0
]
, 'utc_rd_values() on 2002-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2002-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2002-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-19 Gregorian' );
Trewsday 28 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160128000, 'utc_rd_as_seconds() on 2002-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731020,
  0,
  0
]
, 'utc_rd_values() on 2002-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2002-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2002-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-20 Gregorian' );
Hevensday 29 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160214400, 'utc_rd_as_seconds() on 2002-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731021,
  0,
  0
]
, 'utc_rd_values() on 2002-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2002-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2002-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2002-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2002-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-21 Gregorian' );
Mersday 30 Forelithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160300800, 'utc_rd_as_seconds() on 2002-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731022,
  0,
  0
]
, 'utc_rd_values() on 2002-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2002-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2002-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2002-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2002-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2002-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2002-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2002-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2002-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2002-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-22 Gregorian' );
Highday 1 Lithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160387200, 'utc_rd_as_seconds() on 2002-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731023,
  0,
  0
]
, 'utc_rd_values() on 2002-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  26
]
, 'week() on 2002-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2002-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2002-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2002-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2002-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2002-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2002-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2002-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2002-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2002-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2002-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2002-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2002-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2002-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2002-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-23 Gregorian' );
Midyear's day 7466

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160473600, 'utc_rd_as_seconds() on 2002-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731024,
  0,
  0
]
, 'utc_rd_values() on 2002-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2002-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  0
]
, 'week() on 2002-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2002-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2002-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2002-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2002-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2002-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2002-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2002-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2002-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2002-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2002-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-24 Gregorian' );
Sterday 2 Lithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160560000, 'utc_rd_as_seconds() on 2002-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731025,
  0,
  0
]
, 'utc_rd_values() on 2002-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2002-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2002-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-25 Gregorian' );
Sunday 1 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160646400, 'utc_rd_as_seconds() on 2002-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731026,
  0,
  0
]
, 'utc_rd_values() on 2002-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2002-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2002-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-26 Gregorian' );
Monday 2 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160732800, 'utc_rd_as_seconds() on 2002-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731027,
  0,
  0
]
, 'utc_rd_values() on 2002-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2002-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2002-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-27 Gregorian' );
Trewsday 3 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160819200, 'utc_rd_as_seconds() on 2002-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731028,
  0,
  0
]
, 'utc_rd_values() on 2002-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2002-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2002-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-28 Gregorian' );
Hevensday 4 Afterlithe 7466

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160905600, 'utc_rd_as_seconds() on 2002-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731029,
  0,
  0
]
, 'utc_rd_values() on 2002-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2002-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2002-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-29 Gregorian' );
Mersday 5 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63160992000, 'utc_rd_as_seconds() on 2002-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731030,
  0,
  0
]
, 'utc_rd_values() on 2002-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2002-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2002-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-06-30 Gregorian' );
Highday 6 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161078400, 'utc_rd_as_seconds() on 2002-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731031,
  0,
  0
]
, 'utc_rd_values() on 2002-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  27
]
, 'week() on 2002-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2002-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2002-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2002-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-01 Gregorian' );
Sterday 7 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161164800, 'utc_rd_as_seconds() on 2002-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731032,
  0,
  0
]
, 'utc_rd_values() on 2002-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2002-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2002-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-02 Gregorian' );
Sunday 8 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161251200, 'utc_rd_as_seconds() on 2002-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731033,
  0,
  0
]
, 'utc_rd_values() on 2002-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2002-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2002-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-03 Gregorian' );
Monday 9 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161337600, 'utc_rd_as_seconds() on 2002-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731034,
  0,
  0
]
, 'utc_rd_values() on 2002-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2002-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2002-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-04 Gregorian' );
Trewsday 10 Afterlithe 7466

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161424000, 'utc_rd_as_seconds() on 2002-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731035,
  0,
  0
]
, 'utc_rd_values() on 2002-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2002-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2002-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-05 Gregorian' );
Hevensday 11 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161510400, 'utc_rd_as_seconds() on 2002-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731036,
  0,
  0
]
, 'utc_rd_values() on 2002-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2002-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2002-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-06 Gregorian' );
Mersday 12 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161596800, 'utc_rd_as_seconds() on 2002-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731037,
  0,
  0
]
, 'utc_rd_values() on 2002-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2002-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2002-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-07 Gregorian' );
Highday 13 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161683200, 'utc_rd_as_seconds() on 2002-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731038,
  0,
  0
]
, 'utc_rd_values() on 2002-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  28
]
, 'week() on 2002-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2002-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2002-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2002-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-08 Gregorian' );
Sterday 14 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161769600, 'utc_rd_as_seconds() on 2002-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731039,
  0,
  0
]
, 'utc_rd_values() on 2002-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2002-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2002-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-09 Gregorian' );
Sunday 15 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161856000, 'utc_rd_as_seconds() on 2002-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731040,
  0,
  0
]
, 'utc_rd_values() on 2002-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2002-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2002-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-10 Gregorian' );
Monday 16 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63161942400, 'utc_rd_as_seconds() on 2002-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731041,
  0,
  0
]
, 'utc_rd_values() on 2002-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2002-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2002-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-11 Gregorian' );
Trewsday 17 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162028800, 'utc_rd_as_seconds() on 2002-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731042,
  0,
  0
]
, 'utc_rd_values() on 2002-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2002-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2002-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-12 Gregorian' );
Hevensday 18 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162115200, 'utc_rd_as_seconds() on 2002-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731043,
  0,
  0
]
, 'utc_rd_values() on 2002-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2002-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2002-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-13 Gregorian' );
Mersday 19 Afterlithe 7466

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162201600, 'utc_rd_as_seconds() on 2002-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731044,
  0,
  0
]
, 'utc_rd_values() on 2002-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2002-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2002-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-14 Gregorian' );
Highday 20 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162288000, 'utc_rd_as_seconds() on 2002-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731045,
  0,
  0
]
, 'utc_rd_values() on 2002-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  29
]
, 'week() on 2002-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2002-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2002-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2002-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-15 Gregorian' );
Sterday 21 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162374400, 'utc_rd_as_seconds() on 2002-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731046,
  0,
  0
]
, 'utc_rd_values() on 2002-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2002-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2002-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-16 Gregorian' );
Sunday 22 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162460800, 'utc_rd_as_seconds() on 2002-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731047,
  0,
  0
]
, 'utc_rd_values() on 2002-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2002-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2002-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-17 Gregorian' );
Monday 23 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162547200, 'utc_rd_as_seconds() on 2002-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731048,
  0,
  0
]
, 'utc_rd_values() on 2002-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2002-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2002-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-18 Gregorian' );
Trewsday 24 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162633600, 'utc_rd_as_seconds() on 2002-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731049,
  0,
  0
]
, 'utc_rd_values() on 2002-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2002-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2002-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-19 Gregorian' );
Hevensday 25 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162720000, 'utc_rd_as_seconds() on 2002-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731050,
  0,
  0
]
, 'utc_rd_values() on 2002-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2002-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2002-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-20 Gregorian' );
Mersday 26 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162806400, 'utc_rd_as_seconds() on 2002-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731051,
  0,
  0
]
, 'utc_rd_values() on 2002-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2002-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2002-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-21 Gregorian' );
Highday 27 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162892800, 'utc_rd_as_seconds() on 2002-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731052,
  0,
  0
]
, 'utc_rd_values() on 2002-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  30
]
, 'week() on 2002-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2002-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2002-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2002-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-22 Gregorian' );
Sterday 28 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63162979200, 'utc_rd_as_seconds() on 2002-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731053,
  0,
  0
]
, 'utc_rd_values() on 2002-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2002-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2002-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-23 Gregorian' );
Sunday 29 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163065600, 'utc_rd_as_seconds() on 2002-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731054,
  0,
  0
]
, 'utc_rd_values() on 2002-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2002-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2002-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2002-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2002-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-24 Gregorian' );
Monday 30 Afterlithe 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163152000, 'utc_rd_as_seconds() on 2002-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731055,
  0,
  0
]
, 'utc_rd_values() on 2002-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2002-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2002-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-25 Gregorian' );
Trewsday 1 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163238400, 'utc_rd_as_seconds() on 2002-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731056,
  0,
  0
]
, 'utc_rd_values() on 2002-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2002-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2002-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-26 Gregorian' );
Hevensday 2 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163324800, 'utc_rd_as_seconds() on 2002-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731057,
  0,
  0
]
, 'utc_rd_values() on 2002-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2002-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2002-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-27 Gregorian' );
Mersday 3 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163411200, 'utc_rd_as_seconds() on 2002-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731058,
  0,
  0
]
, 'utc_rd_values() on 2002-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2002-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2002-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-28 Gregorian' );
Highday 4 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163497600, 'utc_rd_as_seconds() on 2002-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731059,
  0,
  0
]
, 'utc_rd_values() on 2002-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  31
]
, 'week() on 2002-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2002-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2002-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2002-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-29 Gregorian' );
Sterday 5 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163584000, 'utc_rd_as_seconds() on 2002-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731060,
  0,
  0
]
, 'utc_rd_values() on 2002-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2002-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2002-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-30 Gregorian' );
Sunday 6 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163670400, 'utc_rd_as_seconds() on 2002-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731061,
  0,
  0
]
, 'utc_rd_values() on 2002-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2002-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2002-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-07-31 Gregorian' );
Monday 7 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163756800, 'utc_rd_as_seconds() on 2002-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731062,
  0,
  0
]
, 'utc_rd_values() on 2002-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2002-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2002-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-01 Gregorian' );
Trewsday 8 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163843200, 'utc_rd_as_seconds() on 2002-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731063,
  0,
  0
]
, 'utc_rd_values() on 2002-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2002-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2002-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-02 Gregorian' );
Hevensday 9 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63163929600, 'utc_rd_as_seconds() on 2002-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731064,
  0,
  0
]
, 'utc_rd_values() on 2002-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2002-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2002-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-03 Gregorian' );
Mersday 10 Wedmath 7466

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164016000, 'utc_rd_as_seconds() on 2002-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731065,
  0,
  0
]
, 'utc_rd_values() on 2002-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2002-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2002-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-04 Gregorian' );
Highday 11 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164102400, 'utc_rd_as_seconds() on 2002-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731066,
  0,
  0
]
, 'utc_rd_values() on 2002-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  32
]
, 'week() on 2002-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2002-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2002-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2002-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-05 Gregorian' );
Sterday 12 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164188800, 'utc_rd_as_seconds() on 2002-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731067,
  0,
  0
]
, 'utc_rd_values() on 2002-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2002-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2002-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-06 Gregorian' );
Sunday 13 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164275200, 'utc_rd_as_seconds() on 2002-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731068,
  0,
  0
]
, 'utc_rd_values() on 2002-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2002-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2002-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-07 Gregorian' );
Monday 14 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164361600, 'utc_rd_as_seconds() on 2002-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731069,
  0,
  0
]
, 'utc_rd_values() on 2002-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2002-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2002-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-08 Gregorian' );
Trewsday 15 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164448000, 'utc_rd_as_seconds() on 2002-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731070,
  0,
  0
]
, 'utc_rd_values() on 2002-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2002-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2002-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-09 Gregorian' );
Hevensday 16 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164534400, 'utc_rd_as_seconds() on 2002-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731071,
  0,
  0
]
, 'utc_rd_values() on 2002-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2002-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2002-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-10 Gregorian' );
Mersday 17 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164620800, 'utc_rd_as_seconds() on 2002-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731072,
  0,
  0
]
, 'utc_rd_values() on 2002-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2002-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2002-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-11 Gregorian' );
Highday 18 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164707200, 'utc_rd_as_seconds() on 2002-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731073,
  0,
  0
]
, 'utc_rd_values() on 2002-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  33
]
, 'week() on 2002-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2002-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2002-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2002-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-12 Gregorian' );
Sterday 19 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164793600, 'utc_rd_as_seconds() on 2002-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731074,
  0,
  0
]
, 'utc_rd_values() on 2002-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2002-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2002-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-13 Gregorian' );
Sunday 20 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164880000, 'utc_rd_as_seconds() on 2002-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731075,
  0,
  0
]
, 'utc_rd_values() on 2002-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2002-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2002-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-14 Gregorian' );
Monday 21 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63164966400, 'utc_rd_as_seconds() on 2002-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731076,
  0,
  0
]
, 'utc_rd_values() on 2002-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2002-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2002-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-15 Gregorian' );
Trewsday 22 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165052800, 'utc_rd_as_seconds() on 2002-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731077,
  0,
  0
]
, 'utc_rd_values() on 2002-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2002-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2002-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-16 Gregorian' );
Hevensday 23 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165139200, 'utc_rd_as_seconds() on 2002-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731078,
  0,
  0
]
, 'utc_rd_values() on 2002-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2002-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2002-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-17 Gregorian' );
Mersday 24 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165225600, 'utc_rd_as_seconds() on 2002-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731079,
  0,
  0
]
, 'utc_rd_values() on 2002-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2002-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2002-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-18 Gregorian' );
Highday 25 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165312000, 'utc_rd_as_seconds() on 2002-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731080,
  0,
  0
]
, 'utc_rd_values() on 2002-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  34
]
, 'week() on 2002-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2002-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2002-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2002-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-19 Gregorian' );
Sterday 26 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165398400, 'utc_rd_as_seconds() on 2002-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731081,
  0,
  0
]
, 'utc_rd_values() on 2002-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2002-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2002-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-20 Gregorian' );
Sunday 27 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165484800, 'utc_rd_as_seconds() on 2002-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731082,
  0,
  0
]
, 'utc_rd_values() on 2002-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2002-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2002-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-21 Gregorian' );
Monday 28 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165571200, 'utc_rd_as_seconds() on 2002-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731083,
  0,
  0
]
, 'utc_rd_values() on 2002-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2002-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2002-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-22 Gregorian' );
Trewsday 29 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165657600, 'utc_rd_as_seconds() on 2002-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731084,
  0,
  0
]
, 'utc_rd_values() on 2002-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2002-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2002-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2002-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2002-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-23 Gregorian' );
Hevensday 30 Wedmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165744000, 'utc_rd_as_seconds() on 2002-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731085,
  0,
  0
]
, 'utc_rd_values() on 2002-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2002-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2002-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-24 Gregorian' );
Mersday 1 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165830400, 'utc_rd_as_seconds() on 2002-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731086,
  0,
  0
]
, 'utc_rd_values() on 2002-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2002-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2002-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-25 Gregorian' );
Highday 2 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63165916800, 'utc_rd_as_seconds() on 2002-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731087,
  0,
  0
]
, 'utc_rd_values() on 2002-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  35
]
, 'week() on 2002-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2002-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2002-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2002-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-26 Gregorian' );
Sterday 3 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166003200, 'utc_rd_as_seconds() on 2002-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731088,
  0,
  0
]
, 'utc_rd_values() on 2002-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2002-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2002-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-27 Gregorian' );
Sunday 4 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166089600, 'utc_rd_as_seconds() on 2002-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731089,
  0,
  0
]
, 'utc_rd_values() on 2002-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2002-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2002-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-28 Gregorian' );
Monday 5 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166176000, 'utc_rd_as_seconds() on 2002-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731090,
  0,
  0
]
, 'utc_rd_values() on 2002-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2002-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2002-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-29 Gregorian' );
Trewsday 6 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166262400, 'utc_rd_as_seconds() on 2002-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731091,
  0,
  0
]
, 'utc_rd_values() on 2002-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2002-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2002-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-30 Gregorian' );
Hevensday 7 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166348800, 'utc_rd_as_seconds() on 2002-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731092,
  0,
  0
]
, 'utc_rd_values() on 2002-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2002-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2002-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-08-31 Gregorian' );
Mersday 8 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166435200, 'utc_rd_as_seconds() on 2002-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731093,
  0,
  0
]
, 'utc_rd_values() on 2002-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2002-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2002-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-01 Gregorian' );
Highday 9 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166521600, 'utc_rd_as_seconds() on 2002-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731094,
  0,
  0
]
, 'utc_rd_values() on 2002-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  36
]
, 'week() on 2002-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2002-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2002-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2002-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-02 Gregorian' );
Sterday 10 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166608000, 'utc_rd_as_seconds() on 2002-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731095,
  0,
  0
]
, 'utc_rd_values() on 2002-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2002-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2002-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-03 Gregorian' );
Sunday 11 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166694400, 'utc_rd_as_seconds() on 2002-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731096,
  0,
  0
]
, 'utc_rd_values() on 2002-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2002-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2002-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-04 Gregorian' );
Monday 12 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166780800, 'utc_rd_as_seconds() on 2002-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731097,
  0,
  0
]
, 'utc_rd_values() on 2002-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2002-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2002-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-05 Gregorian' );
Trewsday 13 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166867200, 'utc_rd_as_seconds() on 2002-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731098,
  0,
  0
]
, 'utc_rd_values() on 2002-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2002-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2002-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-06 Gregorian' );
Hevensday 14 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63166953600, 'utc_rd_as_seconds() on 2002-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731099,
  0,
  0
]
, 'utc_rd_values() on 2002-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2002-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2002-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-07 Gregorian' );
Mersday 15 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167040000, 'utc_rd_as_seconds() on 2002-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731100,
  0,
  0
]
, 'utc_rd_values() on 2002-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2002-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2002-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-08 Gregorian' );
Highday 16 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167126400, 'utc_rd_as_seconds() on 2002-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731101,
  0,
  0
]
, 'utc_rd_values() on 2002-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  37
]
, 'week() on 2002-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2002-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2002-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2002-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-09 Gregorian' );
Sterday 17 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167212800, 'utc_rd_as_seconds() on 2002-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731102,
  0,
  0
]
, 'utc_rd_values() on 2002-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2002-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2002-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-10 Gregorian' );
Sunday 18 Halimath 7466

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167299200, 'utc_rd_as_seconds() on 2002-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731103,
  0,
  0
]
, 'utc_rd_values() on 2002-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2002-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2002-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-11 Gregorian' );
Monday 19 Halimath 7466

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167385600, 'utc_rd_as_seconds() on 2002-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731104,
  0,
  0
]
, 'utc_rd_values() on 2002-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2002-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2002-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-12 Gregorian' );
Trewsday 20 Halimath 7466

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167472000, 'utc_rd_as_seconds() on 2002-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731105,
  0,
  0
]
, 'utc_rd_values() on 2002-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2002-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2002-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-13 Gregorian' );
Hevensday 21 Halimath 7466

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167558400, 'utc_rd_as_seconds() on 2002-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731106,
  0,
  0
]
, 'utc_rd_values() on 2002-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2002-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2002-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-14 Gregorian' );
Mersday 22 Halimath 7466

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167644800, 'utc_rd_as_seconds() on 2002-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731107,
  0,
  0
]
, 'utc_rd_values() on 2002-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2002-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2002-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-15 Gregorian' );
Highday 23 Halimath 7466

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167731200, 'utc_rd_as_seconds() on 2002-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731108,
  0,
  0
]
, 'utc_rd_values() on 2002-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  38
]
, 'week() on 2002-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2002-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2002-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2002-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-16 Gregorian' );
Sterday 24 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167817600, 'utc_rd_as_seconds() on 2002-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731109,
  0,
  0
]
, 'utc_rd_values() on 2002-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2002-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2002-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-17 Gregorian' );
Sunday 25 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167904000, 'utc_rd_as_seconds() on 2002-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731110,
  0,
  0
]
, 'utc_rd_values() on 2002-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2002-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2002-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-18 Gregorian' );
Monday 26 Halimath 7466

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63167990400, 'utc_rd_as_seconds() on 2002-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731111,
  0,
  0
]
, 'utc_rd_values() on 2002-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2002-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2002-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-19 Gregorian' );
Trewsday 27 Halimath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168076800, 'utc_rd_as_seconds() on 2002-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731112,
  0,
  0
]
, 'utc_rd_values() on 2002-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2002-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2002-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-20 Gregorian' );
Hevensday 28 Halimath 7466

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168163200, 'utc_rd_as_seconds() on 2002-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731113,
  0,
  0
]
, 'utc_rd_values() on 2002-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2002-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2002-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-21 Gregorian' );
Mersday 29 Halimath 7466

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168249600, 'utc_rd_as_seconds() on 2002-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731114,
  0,
  0
]
, 'utc_rd_values() on 2002-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2002-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2002-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2002-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2002-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-22 Gregorian' );
Highday 30 Halimath 7466

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168336000, 'utc_rd_as_seconds() on 2002-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731115,
  0,
  0
]
, 'utc_rd_values() on 2002-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  39
]
, 'week() on 2002-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2002-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2002-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2002-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-23 Gregorian' );
Sterday 1 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168422400, 'utc_rd_as_seconds() on 2002-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731116,
  0,
  0
]
, 'utc_rd_values() on 2002-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2002-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2002-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-24 Gregorian' );
Sunday 2 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168508800, 'utc_rd_as_seconds() on 2002-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731117,
  0,
  0
]
, 'utc_rd_values() on 2002-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2002-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2002-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-25 Gregorian' );
Monday 3 Winterfilth 7466

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168595200, 'utc_rd_as_seconds() on 2002-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731118,
  0,
  0
]
, 'utc_rd_values() on 2002-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2002-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2002-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-26 Gregorian' );
Trewsday 4 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168681600, 'utc_rd_as_seconds() on 2002-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731119,
  0,
  0
]
, 'utc_rd_values() on 2002-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2002-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2002-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-27 Gregorian' );
Hevensday 5 Winterfilth 7466

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168768000, 'utc_rd_as_seconds() on 2002-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731120,
  0,
  0
]
, 'utc_rd_values() on 2002-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2002-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2002-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-28 Gregorian' );
Mersday 6 Winterfilth 7466

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168854400, 'utc_rd_as_seconds() on 2002-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731121,
  0,
  0
]
, 'utc_rd_values() on 2002-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2002-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2002-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-29 Gregorian' );
Highday 7 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63168940800, 'utc_rd_as_seconds() on 2002-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731122,
  0,
  0
]
, 'utc_rd_values() on 2002-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  40
]
, 'week() on 2002-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2002-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2002-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2002-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-09-30 Gregorian' );
Sterday 8 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169027200, 'utc_rd_as_seconds() on 2002-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731123,
  0,
  0
]
, 'utc_rd_values() on 2002-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2002-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2002-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-01 Gregorian' );
Sunday 9 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169113600, 'utc_rd_as_seconds() on 2002-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731124,
  0,
  0
]
, 'utc_rd_values() on 2002-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2002-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2002-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-02 Gregorian' );
Monday 10 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169200000, 'utc_rd_as_seconds() on 2002-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731125,
  0,
  0
]
, 'utc_rd_values() on 2002-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2002-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2002-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-03 Gregorian' );
Trewsday 11 Winterfilth 7466

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169286400, 'utc_rd_as_seconds() on 2002-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731126,
  0,
  0
]
, 'utc_rd_values() on 2002-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2002-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2002-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-04 Gregorian' );
Hevensday 12 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169372800, 'utc_rd_as_seconds() on 2002-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731127,
  0,
  0
]
, 'utc_rd_values() on 2002-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2002-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2002-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-05 Gregorian' );
Mersday 13 Winterfilth 7466

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169459200, 'utc_rd_as_seconds() on 2002-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731128,
  0,
  0
]
, 'utc_rd_values() on 2002-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2002-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2002-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-06 Gregorian' );
Highday 14 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169545600, 'utc_rd_as_seconds() on 2002-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731129,
  0,
  0
]
, 'utc_rd_values() on 2002-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  41
]
, 'week() on 2002-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2002-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2002-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2002-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-07 Gregorian' );
Sterday 15 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169632000, 'utc_rd_as_seconds() on 2002-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731130,
  0,
  0
]
, 'utc_rd_values() on 2002-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2002-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2002-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-08 Gregorian' );
Sunday 16 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169718400, 'utc_rd_as_seconds() on 2002-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731131,
  0,
  0
]
, 'utc_rd_values() on 2002-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2002-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2002-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-09 Gregorian' );
Monday 17 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169804800, 'utc_rd_as_seconds() on 2002-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731132,
  0,
  0
]
, 'utc_rd_values() on 2002-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2002-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2002-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-10 Gregorian' );
Trewsday 18 Winterfilth 7466

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169891200, 'utc_rd_as_seconds() on 2002-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731133,
  0,
  0
]
, 'utc_rd_values() on 2002-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2002-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2002-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-11 Gregorian' );
Hevensday 19 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63169977600, 'utc_rd_as_seconds() on 2002-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731134,
  0,
  0
]
, 'utc_rd_values() on 2002-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2002-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2002-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-12 Gregorian' );
Mersday 20 Winterfilth 7466

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170064000, 'utc_rd_as_seconds() on 2002-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731135,
  0,
  0
]
, 'utc_rd_values() on 2002-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2002-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2002-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-13 Gregorian' );
Highday 21 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170150400, 'utc_rd_as_seconds() on 2002-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731136,
  0,
  0
]
, 'utc_rd_values() on 2002-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  42
]
, 'week() on 2002-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2002-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2002-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2002-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-14 Gregorian' );
Sterday 22 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170236800, 'utc_rd_as_seconds() on 2002-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731137,
  0,
  0
]
, 'utc_rd_values() on 2002-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2002-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2002-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-15 Gregorian' );
Sunday 23 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170323200, 'utc_rd_as_seconds() on 2002-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731138,
  0,
  0
]
, 'utc_rd_values() on 2002-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2002-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2002-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-16 Gregorian' );
Monday 24 Winterfilth 7466

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170409600, 'utc_rd_as_seconds() on 2002-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731139,
  0,
  0
]
, 'utc_rd_values() on 2002-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2002-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2002-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-17 Gregorian' );
Trewsday 25 Winterfilth 7466

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170496000, 'utc_rd_as_seconds() on 2002-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731140,
  0,
  0
]
, 'utc_rd_values() on 2002-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2002-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2002-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-18 Gregorian' );
Hevensday 26 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170582400, 'utc_rd_as_seconds() on 2002-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731141,
  0,
  0
]
, 'utc_rd_values() on 2002-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2002-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2002-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-19 Gregorian' );
Mersday 27 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170668800, 'utc_rd_as_seconds() on 2002-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731142,
  0,
  0
]
, 'utc_rd_values() on 2002-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2002-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2002-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-20 Gregorian' );
Highday 28 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170755200, 'utc_rd_as_seconds() on 2002-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731143,
  0,
  0
]
, 'utc_rd_values() on 2002-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  43
]
, 'week() on 2002-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2002-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2002-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2002-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-21 Gregorian' );
Sterday 29 Winterfilth 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170841600, 'utc_rd_as_seconds() on 2002-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731144,
  0,
  0
]
, 'utc_rd_values() on 2002-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2002-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2002-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2002-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2002-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-22 Gregorian' );
Sunday 30 Winterfilth 7466

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63170928000, 'utc_rd_as_seconds() on 2002-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731145,
  0,
  0
]
, 'utc_rd_values() on 2002-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2002-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2002-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-23 Gregorian' );
Monday 1 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171014400, 'utc_rd_as_seconds() on 2002-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731146,
  0,
  0
]
, 'utc_rd_values() on 2002-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2002-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2002-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-24 Gregorian' );
Trewsday 2 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171100800, 'utc_rd_as_seconds() on 2002-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731147,
  0,
  0
]
, 'utc_rd_values() on 2002-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2002-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2002-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-25 Gregorian' );
Hevensday 3 Blotmath 7466

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171187200, 'utc_rd_as_seconds() on 2002-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731148,
  0,
  0
]
, 'utc_rd_values() on 2002-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2002-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2002-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-26 Gregorian' );
Mersday 4 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171273600, 'utc_rd_as_seconds() on 2002-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731149,
  0,
  0
]
, 'utc_rd_values() on 2002-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2002-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2002-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-27 Gregorian' );
Highday 5 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171360000, 'utc_rd_as_seconds() on 2002-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731150,
  0,
  0
]
, 'utc_rd_values() on 2002-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  44
]
, 'week() on 2002-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2002-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2002-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2002-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-28 Gregorian' );
Sterday 6 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171446400, 'utc_rd_as_seconds() on 2002-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731151,
  0,
  0
]
, 'utc_rd_values() on 2002-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2002-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2002-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-29 Gregorian' );
Sunday 7 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171532800, 'utc_rd_as_seconds() on 2002-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731152,
  0,
  0
]
, 'utc_rd_values() on 2002-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2002-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2002-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-30 Gregorian' );
Monday 8 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171619200, 'utc_rd_as_seconds() on 2002-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731153,
  0,
  0
]
, 'utc_rd_values() on 2002-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2002-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2002-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-10-31 Gregorian' );
Trewsday 9 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171705600, 'utc_rd_as_seconds() on 2002-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731154,
  0,
  0
]
, 'utc_rd_values() on 2002-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2002-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2002-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-01 Gregorian' );
Hevensday 10 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171792000, 'utc_rd_as_seconds() on 2002-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731155,
  0,
  0
]
, 'utc_rd_values() on 2002-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2002-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2002-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-02 Gregorian' );
Mersday 11 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171878400, 'utc_rd_as_seconds() on 2002-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731156,
  0,
  0
]
, 'utc_rd_values() on 2002-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2002-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2002-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-03 Gregorian' );
Highday 12 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63171964800, 'utc_rd_as_seconds() on 2002-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731157,
  0,
  0
]
, 'utc_rd_values() on 2002-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  45
]
, 'week() on 2002-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2002-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2002-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2002-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-04 Gregorian' );
Sterday 13 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172051200, 'utc_rd_as_seconds() on 2002-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731158,
  0,
  0
]
, 'utc_rd_values() on 2002-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2002-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2002-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-05 Gregorian' );
Sunday 14 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172137600, 'utc_rd_as_seconds() on 2002-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731159,
  0,
  0
]
, 'utc_rd_values() on 2002-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2002-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2002-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-06 Gregorian' );
Monday 15 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172224000, 'utc_rd_as_seconds() on 2002-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731160,
  0,
  0
]
, 'utc_rd_values() on 2002-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2002-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2002-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-07 Gregorian' );
Trewsday 16 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172310400, 'utc_rd_as_seconds() on 2002-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731161,
  0,
  0
]
, 'utc_rd_values() on 2002-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2002-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2002-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-08 Gregorian' );
Hevensday 17 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172396800, 'utc_rd_as_seconds() on 2002-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731162,
  0,
  0
]
, 'utc_rd_values() on 2002-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2002-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2002-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-09 Gregorian' );
Mersday 18 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172483200, 'utc_rd_as_seconds() on 2002-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731163,
  0,
  0
]
, 'utc_rd_values() on 2002-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2002-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2002-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-10 Gregorian' );
Highday 19 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172569600, 'utc_rd_as_seconds() on 2002-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731164,
  0,
  0
]
, 'utc_rd_values() on 2002-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  46
]
, 'week() on 2002-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2002-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2002-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2002-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-11 Gregorian' );
Sterday 20 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172656000, 'utc_rd_as_seconds() on 2002-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731165,
  0,
  0
]
, 'utc_rd_values() on 2002-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2002-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2002-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-12 Gregorian' );
Sunday 21 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172742400, 'utc_rd_as_seconds() on 2002-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731166,
  0,
  0
]
, 'utc_rd_values() on 2002-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2002-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2002-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-13 Gregorian' );
Monday 22 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172828800, 'utc_rd_as_seconds() on 2002-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731167,
  0,
  0
]
, 'utc_rd_values() on 2002-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2002-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2002-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-14 Gregorian' );
Trewsday 23 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63172915200, 'utc_rd_as_seconds() on 2002-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731168,
  0,
  0
]
, 'utc_rd_values() on 2002-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2002-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2002-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-15 Gregorian' );
Hevensday 24 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173001600, 'utc_rd_as_seconds() on 2002-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731169,
  0,
  0
]
, 'utc_rd_values() on 2002-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2002-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2002-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-16 Gregorian' );
Mersday 25 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173088000, 'utc_rd_as_seconds() on 2002-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731170,
  0,
  0
]
, 'utc_rd_values() on 2002-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2002-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2002-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-17 Gregorian' );
Highday 26 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173174400, 'utc_rd_as_seconds() on 2002-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731171,
  0,
  0
]
, 'utc_rd_values() on 2002-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  47
]
, 'week() on 2002-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2002-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2002-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2002-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-18 Gregorian' );
Sterday 27 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173260800, 'utc_rd_as_seconds() on 2002-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731172,
  0,
  0
]
, 'utc_rd_values() on 2002-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2002-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2002-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-19 Gregorian' );
Sunday 28 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173347200, 'utc_rd_as_seconds() on 2002-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731173,
  0,
  0
]
, 'utc_rd_values() on 2002-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2002-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2002-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-20 Gregorian' );
Monday 29 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173433600, 'utc_rd_as_seconds() on 2002-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731174,
  0,
  0
]
, 'utc_rd_values() on 2002-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2002-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2002-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2002-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2002-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-21 Gregorian' );
Trewsday 30 Blotmath 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173520000, 'utc_rd_as_seconds() on 2002-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731175,
  0,
  0
]
, 'utc_rd_values() on 2002-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2002-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2002-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-22 Gregorian' );
Hevensday 1 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173606400, 'utc_rd_as_seconds() on 2002-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731176,
  0,
  0
]
, 'utc_rd_values() on 2002-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2002-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2002-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-23 Gregorian' );
Mersday 2 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173692800, 'utc_rd_as_seconds() on 2002-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731177,
  0,
  0
]
, 'utc_rd_values() on 2002-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2002-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2002-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-24 Gregorian' );
Highday 3 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173779200, 'utc_rd_as_seconds() on 2002-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731178,
  0,
  0
]
, 'utc_rd_values() on 2002-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  48
]
, 'week() on 2002-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2002-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2002-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2002-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-25 Gregorian' );
Sterday 4 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173865600, 'utc_rd_as_seconds() on 2002-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731179,
  0,
  0
]
, 'utc_rd_values() on 2002-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2002-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2002-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-26 Gregorian' );
Sunday 5 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63173952000, 'utc_rd_as_seconds() on 2002-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731180,
  0,
  0
]
, 'utc_rd_values() on 2002-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2002-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2002-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-27 Gregorian' );
Monday 6 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174038400, 'utc_rd_as_seconds() on 2002-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731181,
  0,
  0
]
, 'utc_rd_values() on 2002-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2002-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2002-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-28 Gregorian' );
Trewsday 7 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174124800, 'utc_rd_as_seconds() on 2002-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731182,
  0,
  0
]
, 'utc_rd_values() on 2002-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2002-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2002-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-29 Gregorian' );
Hevensday 8 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174211200, 'utc_rd_as_seconds() on 2002-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731183,
  0,
  0
]
, 'utc_rd_values() on 2002-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2002-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2002-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2002-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2002-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2002-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-11-30 Gregorian' );
Mersday 9 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174297600, 'utc_rd_as_seconds() on 2002-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731184,
  0,
  0
]
, 'utc_rd_values() on 2002-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2002-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2002-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2002-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2002-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2002-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-01 Gregorian' );
Highday 10 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174384000, 'utc_rd_as_seconds() on 2002-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731185,
  0,
  0
]
, 'utc_rd_values() on 2002-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  49
]
, 'week() on 2002-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2002-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2002-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2002-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2002-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2002-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2002-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-02 Gregorian' );
Sterday 11 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174470400, 'utc_rd_as_seconds() on 2002-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731186,
  0,
  0
]
, 'utc_rd_values() on 2002-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2002-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2002-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2002-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2002-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2002-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-03 Gregorian' );
Sunday 12 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174556800, 'utc_rd_as_seconds() on 2002-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731187,
  0,
  0
]
, 'utc_rd_values() on 2002-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2002-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2002-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2002-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2002-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2002-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-04 Gregorian' );
Monday 13 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174643200, 'utc_rd_as_seconds() on 2002-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731188,
  0,
  0
]
, 'utc_rd_values() on 2002-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2002-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2002-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2002-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2002-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2002-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-05 Gregorian' );
Trewsday 14 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174729600, 'utc_rd_as_seconds() on 2002-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731189,
  0,
  0
]
, 'utc_rd_values() on 2002-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2002-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2002-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2002-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2002-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2002-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-06 Gregorian' );
Hevensday 15 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174816000, 'utc_rd_as_seconds() on 2002-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731190,
  0,
  0
]
, 'utc_rd_values() on 2002-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2002-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2002-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2002-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2002-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2002-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-07 Gregorian' );
Mersday 16 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174902400, 'utc_rd_as_seconds() on 2002-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731191,
  0,
  0
]
, 'utc_rd_values() on 2002-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2002-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2002-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2002-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2002-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2002-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-08 Gregorian' );
Highday 17 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63174988800, 'utc_rd_as_seconds() on 2002-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731192,
  0,
  0
]
, 'utc_rd_values() on 2002-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  50
]
, 'week() on 2002-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2002-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2002-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2002-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2002-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2002-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2002-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-09 Gregorian' );
Sterday 18 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175075200, 'utc_rd_as_seconds() on 2002-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731193,
  0,
  0
]
, 'utc_rd_values() on 2002-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2002-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2002-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2002-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2002-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2002-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-10 Gregorian' );
Sunday 19 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175161600, 'utc_rd_as_seconds() on 2002-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731194,
  0,
  0
]
, 'utc_rd_values() on 2002-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2002-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2002-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2002-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2002-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2002-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-11 Gregorian' );
Monday 20 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175248000, 'utc_rd_as_seconds() on 2002-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731195,
  0,
  0
]
, 'utc_rd_values() on 2002-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2002-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2002-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2002-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2002-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2002-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-12 Gregorian' );
Trewsday 21 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175334400, 'utc_rd_as_seconds() on 2002-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731196,
  0,
  0
]
, 'utc_rd_values() on 2002-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2002-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2002-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2002-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2002-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2002-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-13 Gregorian' );
Hevensday 22 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175420800, 'utc_rd_as_seconds() on 2002-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731197,
  0,
  0
]
, 'utc_rd_values() on 2002-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2002-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2002-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2002-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2002-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2002-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-14 Gregorian' );
Mersday 23 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175507200, 'utc_rd_as_seconds() on 2002-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731198,
  0,
  0
]
, 'utc_rd_values() on 2002-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2002-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2002-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2002-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2002-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2002-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-15 Gregorian' );
Highday 24 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175593600, 'utc_rd_as_seconds() on 2002-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731199,
  0,
  0
]
, 'utc_rd_values() on 2002-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  51
]
, 'week() on 2002-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2002-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2002-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2002-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2002-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2002-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2002-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-16 Gregorian' );
Sterday 25 Foreyule 7466

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175680000, 'utc_rd_as_seconds() on 2002-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731200,
  0,
  0
]
, 'utc_rd_values() on 2002-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2002-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2002-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2002-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2002-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2002-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-17 Gregorian' );
Sunday 26 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175766400, 'utc_rd_as_seconds() on 2002-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731201,
  0,
  0
]
, 'utc_rd_values() on 2002-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2002-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2002-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2002-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2002-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2002-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-18 Gregorian' );
Monday 27 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175852800, 'utc_rd_as_seconds() on 2002-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731202,
  0,
  0
]
, 'utc_rd_values() on 2002-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2002-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2002-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2002-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2002-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2002-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-19 Gregorian' );
Trewsday 28 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63175939200, 'utc_rd_as_seconds() on 2002-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731203,
  0,
  0
]
, 'utc_rd_values() on 2002-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2002-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2002-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2002-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2002-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2002-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-20 Gregorian' );
Hevensday 29 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176025600, 'utc_rd_as_seconds() on 2002-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731204,
  0,
  0
]
, 'utc_rd_values() on 2002-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2002-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2002-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2002-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2002-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2002-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2002-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2002-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-21 Gregorian' );
Mersday 30 Foreyule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176112000, 'utc_rd_as_seconds() on 2002-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731205,
  0,
  0
]
, 'utc_rd_values() on 2002-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2002-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2002-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2002-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2002-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2002-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2002-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2002-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2002-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2002-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-22 Gregorian' );
Highday 1 Yule 7466
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176198400, 'utc_rd_as_seconds() on 2002-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731206,
  0,
  0
]
, 'utc_rd_values() on 2002-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7466,
  52
]
, 'week() on 2002-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2002-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7466, 'week_year() on 2002-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7466, 'year() on 2002-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2002-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2002-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2002-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2002-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2002-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2002-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2002-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2002-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2002-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-23 Gregorian' );
Sterday 2 Yule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176284800, 'utc_rd_as_seconds() on 2002-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731207,
  0,
  0
]
, 'utc_rd_values() on 2002-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2002-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2002-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2002-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2002-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2002-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-24 Gregorian' );
Sunday 1 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176371200, 'utc_rd_as_seconds() on 2002-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731208,
  0,
  0
]
, 'utc_rd_values() on 2002-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2002-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2002-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2002-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2002-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2002-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2002-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2002-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2002-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2002-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-25 Gregorian' );
Monday 2 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176457600, 'utc_rd_as_seconds() on 2002-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731209,
  0,
  0
]
, 'utc_rd_values() on 2002-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2002-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2002-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2002-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2002-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2002-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2002-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2002-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2002-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2002-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2002-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-26 Gregorian' );
Trewsday 3 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176544000, 'utc_rd_as_seconds() on 2002-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731210,
  0,
  0
]
, 'utc_rd_values() on 2002-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2002-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2002-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2002-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2002-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2002-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2002-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2002-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2002-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2002-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2002-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-27 Gregorian' );
Hevensday 4 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176630400, 'utc_rd_as_seconds() on 2002-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731211,
  0,
  0
]
, 'utc_rd_values() on 2002-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2002-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2002-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2002-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2002-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2002-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2002-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2002-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2002-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2002-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2002-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-28 Gregorian' );
Mersday 5 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176716800, 'utc_rd_as_seconds() on 2002-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731212,
  0,
  0
]
, 'utc_rd_values() on 2002-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2002-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2002-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2002-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2002-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2002-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2002-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2002-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2002-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2002-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2002-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-29 Gregorian' );
Highday 6 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176803200, 'utc_rd_as_seconds() on 2002-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731213,
  0,
  0
]
, 'utc_rd_values() on 2002-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2002-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  1
]
, 'week() on 2002-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2002-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2002-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2002-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2002-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2002-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2002-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2002-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2002-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2002-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2002-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-30 Gregorian' );
Sterday 7 Afteryule 7467
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176889600, 'utc_rd_as_seconds() on 2002-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731214,
  0,
  0
]
, 'utc_rd_values() on 2002-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2002-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  2
]
, 'week() on 2002-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2002 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2002,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2002-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2002-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2002-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2002-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2002-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2002-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2002-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2002-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2002-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2002-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2002-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2002-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2002-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2002-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2002-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2002-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2002-12-31 Gregorian' );
Sunday 8 Afteryule 7467

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 63176976000, 'utc_rd_as_seconds() on 2002-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  731215,
  0,
  0
]
, 'utc_rd_values() on 2002-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2002-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7467,
  2
]
, 'week() on 2002-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2002-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7467, 'week_year() on 2002-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7467, 'year() on 2002-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2035-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2035-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-01 Gregorian' );
Monday 9 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64186905600, 'utc_rd_as_seconds() on 2035-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742904,
  0,
  0
]
, 'utc_rd_values() on 2035-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  2
]
, 'week() on 2035-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2035-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2035-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-02 Gregorian' );
Trewsday 10 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64186992000, 'utc_rd_as_seconds() on 2035-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742905,
  0,
  0
]
, 'utc_rd_values() on 2035-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  2
]
, 'week() on 2035-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2035-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2035-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-03 Gregorian' );
Hevensday 11 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187078400, 'utc_rd_as_seconds() on 2035-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742906,
  0,
  0
]
, 'utc_rd_values() on 2035-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  2
]
, 'week() on 2035-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2035-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2035-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-04 Gregorian' );
Mersday 12 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187164800, 'utc_rd_as_seconds() on 2035-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742907,
  0,
  0
]
, 'utc_rd_values() on 2035-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  2
]
, 'week() on 2035-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2035-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2035-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-05 Gregorian' );
Highday 13 Afteryule 7499

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187251200, 'utc_rd_as_seconds() on 2035-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742908,
  0,
  0
]
, 'utc_rd_values() on 2035-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  2
]
, 'week() on 2035-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2035-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2035-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-06 Gregorian' );
Sterday 14 Afteryule 7499

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187337600, 'utc_rd_as_seconds() on 2035-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742909,
  0,
  0
]
, 'utc_rd_values() on 2035-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2035-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2035-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-07 Gregorian' );
Sunday 15 Afteryule 7499

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187424000, 'utc_rd_as_seconds() on 2035-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742910,
  0,
  0
]
, 'utc_rd_values() on 2035-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2035-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2035-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-08 Gregorian' );
Monday 16 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187510400, 'utc_rd_as_seconds() on 2035-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742911,
  0,
  0
]
, 'utc_rd_values() on 2035-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2035-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2035-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-09 Gregorian' );
Trewsday 17 Afteryule 7499

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187596800, 'utc_rd_as_seconds() on 2035-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742912,
  0,
  0
]
, 'utc_rd_values() on 2035-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2035-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2035-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-10 Gregorian' );
Hevensday 18 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187683200, 'utc_rd_as_seconds() on 2035-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742913,
  0,
  0
]
, 'utc_rd_values() on 2035-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2035-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2035-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-11 Gregorian' );
Mersday 19 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187769600, 'utc_rd_as_seconds() on 2035-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742914,
  0,
  0
]
, 'utc_rd_values() on 2035-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2035-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2035-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-12 Gregorian' );
Highday 20 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187856000, 'utc_rd_as_seconds() on 2035-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742915,
  0,
  0
]
, 'utc_rd_values() on 2035-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  3
]
, 'week() on 2035-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2035-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2035-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2035-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-13 Gregorian' );
Sterday 21 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64187942400, 'utc_rd_as_seconds() on 2035-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742916,
  0,
  0
]
, 'utc_rd_values() on 2035-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2035-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2035-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-14 Gregorian' );
Sunday 22 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188028800, 'utc_rd_as_seconds() on 2035-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742917,
  0,
  0
]
, 'utc_rd_values() on 2035-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2035-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2035-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-15 Gregorian' );
Monday 23 Afteryule 7499

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188115200, 'utc_rd_as_seconds() on 2035-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742918,
  0,
  0
]
, 'utc_rd_values() on 2035-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2035-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2035-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-16 Gregorian' );
Trewsday 24 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188201600, 'utc_rd_as_seconds() on 2035-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742919,
  0,
  0
]
, 'utc_rd_values() on 2035-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2035-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2035-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-17 Gregorian' );
Hevensday 25 Afteryule 7499

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188288000, 'utc_rd_as_seconds() on 2035-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742920,
  0,
  0
]
, 'utc_rd_values() on 2035-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2035-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2035-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-18 Gregorian' );
Mersday 26 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188374400, 'utc_rd_as_seconds() on 2035-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742921,
  0,
  0
]
, 'utc_rd_values() on 2035-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2035-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2035-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-19 Gregorian' );
Highday 27 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188460800, 'utc_rd_as_seconds() on 2035-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742922,
  0,
  0
]
, 'utc_rd_values() on 2035-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  4
]
, 'week() on 2035-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2035-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2035-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2035-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-20 Gregorian' );
Sterday 28 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188547200, 'utc_rd_as_seconds() on 2035-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742923,
  0,
  0
]
, 'utc_rd_values() on 2035-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2035-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2035-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-21 Gregorian' );
Sunday 29 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188633600, 'utc_rd_as_seconds() on 2035-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742924,
  0,
  0
]
, 'utc_rd_values() on 2035-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2035-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2035-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-22 Gregorian' );
Monday 30 Afteryule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188720000, 'utc_rd_as_seconds() on 2035-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742925,
  0,
  0
]
, 'utc_rd_values() on 2035-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2035-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2035-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-23 Gregorian' );
Trewsday 1 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188806400, 'utc_rd_as_seconds() on 2035-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742926,
  0,
  0
]
, 'utc_rd_values() on 2035-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2035-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2035-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-24 Gregorian' );
Hevensday 2 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188892800, 'utc_rd_as_seconds() on 2035-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742927,
  0,
  0
]
, 'utc_rd_values() on 2035-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2035-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2035-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-25 Gregorian' );
Mersday 3 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64188979200, 'utc_rd_as_seconds() on 2035-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742928,
  0,
  0
]
, 'utc_rd_values() on 2035-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2035-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2035-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-26 Gregorian' );
Highday 4 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189065600, 'utc_rd_as_seconds() on 2035-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742929,
  0,
  0
]
, 'utc_rd_values() on 2035-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  5
]
, 'week() on 2035-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2035-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2035-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2035-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-27 Gregorian' );
Sterday 5 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189152000, 'utc_rd_as_seconds() on 2035-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742930,
  0,
  0
]
, 'utc_rd_values() on 2035-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2035-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2035-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-28 Gregorian' );
Sunday 6 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189238400, 'utc_rd_as_seconds() on 2035-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742931,
  0,
  0
]
, 'utc_rd_values() on 2035-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2035-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2035-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-29 Gregorian' );
Monday 7 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189324800, 'utc_rd_as_seconds() on 2035-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742932,
  0,
  0
]
, 'utc_rd_values() on 2035-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2035-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2035-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-30 Gregorian' );
Trewsday 8 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189411200, 'utc_rd_as_seconds() on 2035-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742933,
  0,
  0
]
, 'utc_rd_values() on 2035-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2035-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2035-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-01-31 Gregorian' );
Hevensday 9 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189497600, 'utc_rd_as_seconds() on 2035-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742934,
  0,
  0
]
, 'utc_rd_values() on 2035-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2035-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2035-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-01 Gregorian' );
Mersday 10 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189584000, 'utc_rd_as_seconds() on 2035-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742935,
  0,
  0
]
, 'utc_rd_values() on 2035-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2035-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2035-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-02 Gregorian' );
Highday 11 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189670400, 'utc_rd_as_seconds() on 2035-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742936,
  0,
  0
]
, 'utc_rd_values() on 2035-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  6
]
, 'week() on 2035-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2035-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2035-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2035-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-03 Gregorian' );
Sterday 12 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189756800, 'utc_rd_as_seconds() on 2035-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742937,
  0,
  0
]
, 'utc_rd_values() on 2035-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2035-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2035-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-04 Gregorian' );
Sunday 13 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189843200, 'utc_rd_as_seconds() on 2035-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742938,
  0,
  0
]
, 'utc_rd_values() on 2035-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2035-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2035-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-05 Gregorian' );
Monday 14 Solmath 7499

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64189929600, 'utc_rd_as_seconds() on 2035-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742939,
  0,
  0
]
, 'utc_rd_values() on 2035-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2035-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2035-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-06 Gregorian' );
Trewsday 15 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190016000, 'utc_rd_as_seconds() on 2035-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742940,
  0,
  0
]
, 'utc_rd_values() on 2035-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2035-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2035-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-07 Gregorian' );
Hevensday 16 Solmath 7499

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190102400, 'utc_rd_as_seconds() on 2035-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742941,
  0,
  0
]
, 'utc_rd_values() on 2035-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2035-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2035-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-08 Gregorian' );
Mersday 17 Solmath 7499

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190188800, 'utc_rd_as_seconds() on 2035-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742942,
  0,
  0
]
, 'utc_rd_values() on 2035-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2035-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2035-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-09 Gregorian' );
Highday 18 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190275200, 'utc_rd_as_seconds() on 2035-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742943,
  0,
  0
]
, 'utc_rd_values() on 2035-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  7
]
, 'week() on 2035-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2035-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2035-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2035-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-10 Gregorian' );
Sterday 19 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190361600, 'utc_rd_as_seconds() on 2035-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742944,
  0,
  0
]
, 'utc_rd_values() on 2035-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2035-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2035-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-11 Gregorian' );
Sunday 20 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190448000, 'utc_rd_as_seconds() on 2035-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742945,
  0,
  0
]
, 'utc_rd_values() on 2035-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2035-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2035-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-12 Gregorian' );
Monday 21 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190534400, 'utc_rd_as_seconds() on 2035-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742946,
  0,
  0
]
, 'utc_rd_values() on 2035-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2035-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2035-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-13 Gregorian' );
Trewsday 22 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190620800, 'utc_rd_as_seconds() on 2035-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742947,
  0,
  0
]
, 'utc_rd_values() on 2035-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2035-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2035-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-14 Gregorian' );
Hevensday 23 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190707200, 'utc_rd_as_seconds() on 2035-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742948,
  0,
  0
]
, 'utc_rd_values() on 2035-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2035-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2035-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-15 Gregorian' );
Mersday 24 Solmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190793600, 'utc_rd_as_seconds() on 2035-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742949,
  0,
  0
]
, 'utc_rd_values() on 2035-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2035-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2035-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-16 Gregorian' );
Highday 25 Solmath 7499

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190880000, 'utc_rd_as_seconds() on 2035-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742950,
  0,
  0
]
, 'utc_rd_values() on 2035-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  8
]
, 'week() on 2035-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2035-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2035-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2035-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-17 Gregorian' );
Sterday 26 Solmath 7499

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64190966400, 'utc_rd_as_seconds() on 2035-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742951,
  0,
  0
]
, 'utc_rd_values() on 2035-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2035-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2035-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-18 Gregorian' );
Sunday 27 Solmath 7499

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191052800, 'utc_rd_as_seconds() on 2035-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742952,
  0,
  0
]
, 'utc_rd_values() on 2035-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2035-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2035-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-19 Gregorian' );
Monday 28 Solmath 7499

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191139200, 'utc_rd_as_seconds() on 2035-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742953,
  0,
  0
]
, 'utc_rd_values() on 2035-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2035-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2035-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-20 Gregorian' );
Trewsday 29 Solmath 7499

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191225600, 'utc_rd_as_seconds() on 2035-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742954,
  0,
  0
]
, 'utc_rd_values() on 2035-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2035-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2035-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2035-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2035-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-21 Gregorian' );
Hevensday 30 Solmath 7499

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191312000, 'utc_rd_as_seconds() on 2035-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742955,
  0,
  0
]
, 'utc_rd_values() on 2035-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2035-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2035-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-22 Gregorian' );
Mersday 1 Rethe 7499

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191398400, 'utc_rd_as_seconds() on 2035-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742956,
  0,
  0
]
, 'utc_rd_values() on 2035-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2035-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2035-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-23 Gregorian' );
Highday 2 Rethe 7499

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191484800, 'utc_rd_as_seconds() on 2035-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742957,
  0,
  0
]
, 'utc_rd_values() on 2035-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  9
]
, 'week() on 2035-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2035-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2035-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2035-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-24 Gregorian' );
Sterday 3 Rethe 7499

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191571200, 'utc_rd_as_seconds() on 2035-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742958,
  0,
  0
]
, 'utc_rd_values() on 2035-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2035-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2035-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-25 Gregorian' );
Sunday 4 Rethe 7499

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191657600, 'utc_rd_as_seconds() on 2035-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742959,
  0,
  0
]
, 'utc_rd_values() on 2035-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2035-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2035-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-26 Gregorian' );
Monday 5 Rethe 7499

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191744000, 'utc_rd_as_seconds() on 2035-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742960,
  0,
  0
]
, 'utc_rd_values() on 2035-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2035-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2035-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-27 Gregorian' );
Trewsday 6 Rethe 7499

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191830400, 'utc_rd_as_seconds() on 2035-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742961,
  0,
  0
]
, 'utc_rd_values() on 2035-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2035-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2035-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-02-28 Gregorian' );
Hevensday 7 Rethe 7499

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64191916800, 'utc_rd_as_seconds() on 2035-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742962,
  0,
  0
]
, 'utc_rd_values() on 2035-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2035-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2035-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-01 Gregorian' );
Mersday 8 Rethe 7499

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192003200, 'utc_rd_as_seconds() on 2035-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742963,
  0,
  0
]
, 'utc_rd_values() on 2035-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2035-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2035-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-02 Gregorian' );
Highday 9 Rethe 7499

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192089600, 'utc_rd_as_seconds() on 2035-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742964,
  0,
  0
]
, 'utc_rd_values() on 2035-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  10
]
, 'week() on 2035-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2035-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2035-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2035-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-03 Gregorian' );
Sterday 10 Rethe 7499

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192176000, 'utc_rd_as_seconds() on 2035-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742965,
  0,
  0
]
, 'utc_rd_values() on 2035-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2035-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2035-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-04 Gregorian' );
Sunday 11 Rethe 7499

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192262400, 'utc_rd_as_seconds() on 2035-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742966,
  0,
  0
]
, 'utc_rd_values() on 2035-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2035-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2035-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-05 Gregorian' );
Monday 12 Rethe 7499

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192348800, 'utc_rd_as_seconds() on 2035-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742967,
  0,
  0
]
, 'utc_rd_values() on 2035-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2035-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2035-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-06 Gregorian' );
Trewsday 13 Rethe 7499

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192435200, 'utc_rd_as_seconds() on 2035-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742968,
  0,
  0
]
, 'utc_rd_values() on 2035-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2035-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2035-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-07 Gregorian' );
Hevensday 14 Rethe 7499

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192521600, 'utc_rd_as_seconds() on 2035-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742969,
  0,
  0
]
, 'utc_rd_values() on 2035-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2035-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2035-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-08 Gregorian' );
Mersday 15 Rethe 7499

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192608000, 'utc_rd_as_seconds() on 2035-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742970,
  0,
  0
]
, 'utc_rd_values() on 2035-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2035-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2035-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-09 Gregorian' );
Highday 16 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192694400, 'utc_rd_as_seconds() on 2035-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742971,
  0,
  0
]
, 'utc_rd_values() on 2035-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  11
]
, 'week() on 2035-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2035-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2035-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2035-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-10 Gregorian' );
Sterday 17 Rethe 7499

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192780800, 'utc_rd_as_seconds() on 2035-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742972,
  0,
  0
]
, 'utc_rd_values() on 2035-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2035-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2035-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-11 Gregorian' );
Sunday 18 Rethe 7499

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192867200, 'utc_rd_as_seconds() on 2035-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742973,
  0,
  0
]
, 'utc_rd_values() on 2035-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2035-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2035-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-12 Gregorian' );
Monday 19 Rethe 7499

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64192953600, 'utc_rd_as_seconds() on 2035-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742974,
  0,
  0
]
, 'utc_rd_values() on 2035-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2035-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2035-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-13 Gregorian' );
Trewsday 20 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193040000, 'utc_rd_as_seconds() on 2035-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742975,
  0,
  0
]
, 'utc_rd_values() on 2035-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2035-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2035-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-14 Gregorian' );
Hevensday 21 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193126400, 'utc_rd_as_seconds() on 2035-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742976,
  0,
  0
]
, 'utc_rd_values() on 2035-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2035-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2035-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-15 Gregorian' );
Mersday 22 Rethe 7499

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193212800, 'utc_rd_as_seconds() on 2035-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742977,
  0,
  0
]
, 'utc_rd_values() on 2035-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2035-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2035-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-16 Gregorian' );
Highday 23 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193299200, 'utc_rd_as_seconds() on 2035-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742978,
  0,
  0
]
, 'utc_rd_values() on 2035-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  12
]
, 'week() on 2035-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2035-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2035-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2035-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-17 Gregorian' );
Sterday 24 Rethe 7499

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193385600, 'utc_rd_as_seconds() on 2035-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742979,
  0,
  0
]
, 'utc_rd_values() on 2035-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2035-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2035-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-18 Gregorian' );
Sunday 25 Rethe 7499

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193472000, 'utc_rd_as_seconds() on 2035-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742980,
  0,
  0
]
, 'utc_rd_values() on 2035-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2035-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2035-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-19 Gregorian' );
Monday 26 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193558400, 'utc_rd_as_seconds() on 2035-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742981,
  0,
  0
]
, 'utc_rd_values() on 2035-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2035-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2035-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-20 Gregorian' );
Trewsday 27 Rethe 7499

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193644800, 'utc_rd_as_seconds() on 2035-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742982,
  0,
  0
]
, 'utc_rd_values() on 2035-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2035-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2035-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-21 Gregorian' );
Hevensday 28 Rethe 7499

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193731200, 'utc_rd_as_seconds() on 2035-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742983,
  0,
  0
]
, 'utc_rd_values() on 2035-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2035-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2035-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-22 Gregorian' );
Mersday 29 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193817600, 'utc_rd_as_seconds() on 2035-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742984,
  0,
  0
]
, 'utc_rd_values() on 2035-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2035-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2035-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2035-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2035-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-23 Gregorian' );
Highday 30 Rethe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193904000, 'utc_rd_as_seconds() on 2035-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742985,
  0,
  0
]
, 'utc_rd_values() on 2035-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  13
]
, 'week() on 2035-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2035-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2035-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2035-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-24 Gregorian' );
Sterday 1 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64193990400, 'utc_rd_as_seconds() on 2035-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742986,
  0,
  0
]
, 'utc_rd_values() on 2035-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2035-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2035-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-25 Gregorian' );
Sunday 2 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194076800, 'utc_rd_as_seconds() on 2035-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742987,
  0,
  0
]
, 'utc_rd_values() on 2035-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2035-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2035-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-26 Gregorian' );
Monday 3 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194163200, 'utc_rd_as_seconds() on 2035-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742988,
  0,
  0
]
, 'utc_rd_values() on 2035-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2035-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2035-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-27 Gregorian' );
Trewsday 4 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194249600, 'utc_rd_as_seconds() on 2035-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742989,
  0,
  0
]
, 'utc_rd_values() on 2035-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2035-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2035-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-28 Gregorian' );
Hevensday 5 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194336000, 'utc_rd_as_seconds() on 2035-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742990,
  0,
  0
]
, 'utc_rd_values() on 2035-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2035-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2035-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-29 Gregorian' );
Mersday 6 Astron 7499

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194422400, 'utc_rd_as_seconds() on 2035-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742991,
  0,
  0
]
, 'utc_rd_values() on 2035-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2035-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2035-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-30 Gregorian' );
Highday 7 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194508800, 'utc_rd_as_seconds() on 2035-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742992,
  0,
  0
]
, 'utc_rd_values() on 2035-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  14
]
, 'week() on 2035-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2035-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2035-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2035-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-03-31 Gregorian' );
Sterday 8 Astron 7499

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194595200, 'utc_rd_as_seconds() on 2035-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742993,
  0,
  0
]
, 'utc_rd_values() on 2035-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2035-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2035-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-01 Gregorian' );
Sunday 9 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194681600, 'utc_rd_as_seconds() on 2035-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742994,
  0,
  0
]
, 'utc_rd_values() on 2035-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2035-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2035-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-02 Gregorian' );
Monday 10 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194768000, 'utc_rd_as_seconds() on 2035-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742995,
  0,
  0
]
, 'utc_rd_values() on 2035-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2035-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2035-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-03 Gregorian' );
Trewsday 11 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194854400, 'utc_rd_as_seconds() on 2035-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742996,
  0,
  0
]
, 'utc_rd_values() on 2035-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2035-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2035-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-04 Gregorian' );
Hevensday 12 Astron 7499

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64194940800, 'utc_rd_as_seconds() on 2035-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742997,
  0,
  0
]
, 'utc_rd_values() on 2035-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2035-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2035-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-05 Gregorian' );
Mersday 13 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195027200, 'utc_rd_as_seconds() on 2035-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742998,
  0,
  0
]
, 'utc_rd_values() on 2035-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2035-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2035-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-06 Gregorian' );
Highday 14 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195113600, 'utc_rd_as_seconds() on 2035-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  742999,
  0,
  0
]
, 'utc_rd_values() on 2035-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  15
]
, 'week() on 2035-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2035-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2035-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2035-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-07 Gregorian' );
Sterday 15 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195200000, 'utc_rd_as_seconds() on 2035-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743000,
  0,
  0
]
, 'utc_rd_values() on 2035-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2035-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2035-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-08 Gregorian' );
Sunday 16 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195286400, 'utc_rd_as_seconds() on 2035-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743001,
  0,
  0
]
, 'utc_rd_values() on 2035-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2035-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2035-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-09 Gregorian' );
Monday 17 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195372800, 'utc_rd_as_seconds() on 2035-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743002,
  0,
  0
]
, 'utc_rd_values() on 2035-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2035-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2035-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-10 Gregorian' );
Trewsday 18 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195459200, 'utc_rd_as_seconds() on 2035-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743003,
  0,
  0
]
, 'utc_rd_values() on 2035-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2035-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2035-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-11 Gregorian' );
Hevensday 19 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195545600, 'utc_rd_as_seconds() on 2035-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743004,
  0,
  0
]
, 'utc_rd_values() on 2035-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2035-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2035-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-12 Gregorian' );
Mersday 20 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195632000, 'utc_rd_as_seconds() on 2035-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743005,
  0,
  0
]
, 'utc_rd_values() on 2035-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2035-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2035-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-13 Gregorian' );
Highday 21 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195718400, 'utc_rd_as_seconds() on 2035-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743006,
  0,
  0
]
, 'utc_rd_values() on 2035-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  16
]
, 'week() on 2035-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2035-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2035-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2035-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-14 Gregorian' );
Sterday 22 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195804800, 'utc_rd_as_seconds() on 2035-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743007,
  0,
  0
]
, 'utc_rd_values() on 2035-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2035-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2035-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-15 Gregorian' );
Sunday 23 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195891200, 'utc_rd_as_seconds() on 2035-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743008,
  0,
  0
]
, 'utc_rd_values() on 2035-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2035-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2035-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-16 Gregorian' );
Monday 24 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64195977600, 'utc_rd_as_seconds() on 2035-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743009,
  0,
  0
]
, 'utc_rd_values() on 2035-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2035-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2035-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-17 Gregorian' );
Trewsday 25 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196064000, 'utc_rd_as_seconds() on 2035-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743010,
  0,
  0
]
, 'utc_rd_values() on 2035-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2035-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2035-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-18 Gregorian' );
Hevensday 26 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196150400, 'utc_rd_as_seconds() on 2035-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743011,
  0,
  0
]
, 'utc_rd_values() on 2035-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2035-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2035-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-19 Gregorian' );
Mersday 27 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196236800, 'utc_rd_as_seconds() on 2035-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743012,
  0,
  0
]
, 'utc_rd_values() on 2035-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2035-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2035-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-20 Gregorian' );
Highday 28 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196323200, 'utc_rd_as_seconds() on 2035-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743013,
  0,
  0
]
, 'utc_rd_values() on 2035-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  17
]
, 'week() on 2035-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2035-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2035-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2035-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-21 Gregorian' );
Sterday 29 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196409600, 'utc_rd_as_seconds() on 2035-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743014,
  0,
  0
]
, 'utc_rd_values() on 2035-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2035-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2035-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2035-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2035-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-22 Gregorian' );
Sunday 30 Astron 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196496000, 'utc_rd_as_seconds() on 2035-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743015,
  0,
  0
]
, 'utc_rd_values() on 2035-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2035-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2035-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-23 Gregorian' );
Monday 1 Thrimidge 7499

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196582400, 'utc_rd_as_seconds() on 2035-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743016,
  0,
  0
]
, 'utc_rd_values() on 2035-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2035-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2035-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-24 Gregorian' );
Trewsday 2 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196668800, 'utc_rd_as_seconds() on 2035-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743017,
  0,
  0
]
, 'utc_rd_values() on 2035-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2035-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2035-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-25 Gregorian' );
Hevensday 3 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196755200, 'utc_rd_as_seconds() on 2035-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743018,
  0,
  0
]
, 'utc_rd_values() on 2035-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2035-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2035-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-26 Gregorian' );
Mersday 4 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196841600, 'utc_rd_as_seconds() on 2035-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743019,
  0,
  0
]
, 'utc_rd_values() on 2035-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2035-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2035-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-27 Gregorian' );
Highday 5 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64196928000, 'utc_rd_as_seconds() on 2035-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743020,
  0,
  0
]
, 'utc_rd_values() on 2035-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  18
]
, 'week() on 2035-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2035-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2035-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2035-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-28 Gregorian' );
Sterday 6 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197014400, 'utc_rd_as_seconds() on 2035-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743021,
  0,
  0
]
, 'utc_rd_values() on 2035-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2035-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2035-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-29 Gregorian' );
Sunday 7 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197100800, 'utc_rd_as_seconds() on 2035-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743022,
  0,
  0
]
, 'utc_rd_values() on 2035-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2035-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2035-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-04-30 Gregorian' );
Monday 8 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197187200, 'utc_rd_as_seconds() on 2035-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743023,
  0,
  0
]
, 'utc_rd_values() on 2035-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2035-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2035-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-01 Gregorian' );
Trewsday 9 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197273600, 'utc_rd_as_seconds() on 2035-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743024,
  0,
  0
]
, 'utc_rd_values() on 2035-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2035-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2035-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-02 Gregorian' );
Hevensday 10 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197360000, 'utc_rd_as_seconds() on 2035-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743025,
  0,
  0
]
, 'utc_rd_values() on 2035-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2035-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2035-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-03 Gregorian' );
Mersday 11 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197446400, 'utc_rd_as_seconds() on 2035-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743026,
  0,
  0
]
, 'utc_rd_values() on 2035-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2035-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2035-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-04 Gregorian' );
Highday 12 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197532800, 'utc_rd_as_seconds() on 2035-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743027,
  0,
  0
]
, 'utc_rd_values() on 2035-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  19
]
, 'week() on 2035-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2035-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2035-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2035-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-05 Gregorian' );
Sterday 13 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197619200, 'utc_rd_as_seconds() on 2035-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743028,
  0,
  0
]
, 'utc_rd_values() on 2035-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2035-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2035-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-06 Gregorian' );
Sunday 14 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197705600, 'utc_rd_as_seconds() on 2035-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743029,
  0,
  0
]
, 'utc_rd_values() on 2035-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2035-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2035-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-07 Gregorian' );
Monday 15 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197792000, 'utc_rd_as_seconds() on 2035-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743030,
  0,
  0
]
, 'utc_rd_values() on 2035-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2035-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2035-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-08 Gregorian' );
Trewsday 16 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197878400, 'utc_rd_as_seconds() on 2035-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743031,
  0,
  0
]
, 'utc_rd_values() on 2035-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2035-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2035-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-09 Gregorian' );
Hevensday 17 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64197964800, 'utc_rd_as_seconds() on 2035-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743032,
  0,
  0
]
, 'utc_rd_values() on 2035-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2035-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2035-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-10 Gregorian' );
Mersday 18 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198051200, 'utc_rd_as_seconds() on 2035-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743033,
  0,
  0
]
, 'utc_rd_values() on 2035-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2035-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2035-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-11 Gregorian' );
Highday 19 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198137600, 'utc_rd_as_seconds() on 2035-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743034,
  0,
  0
]
, 'utc_rd_values() on 2035-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  20
]
, 'week() on 2035-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2035-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2035-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2035-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-12 Gregorian' );
Sterday 20 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198224000, 'utc_rd_as_seconds() on 2035-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743035,
  0,
  0
]
, 'utc_rd_values() on 2035-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2035-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2035-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-13 Gregorian' );
Sunday 21 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198310400, 'utc_rd_as_seconds() on 2035-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743036,
  0,
  0
]
, 'utc_rd_values() on 2035-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2035-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2035-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-14 Gregorian' );
Monday 22 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198396800, 'utc_rd_as_seconds() on 2035-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743037,
  0,
  0
]
, 'utc_rd_values() on 2035-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2035-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2035-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-15 Gregorian' );
Trewsday 23 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198483200, 'utc_rd_as_seconds() on 2035-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743038,
  0,
  0
]
, 'utc_rd_values() on 2035-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2035-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2035-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-16 Gregorian' );
Hevensday 24 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198569600, 'utc_rd_as_seconds() on 2035-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743039,
  0,
  0
]
, 'utc_rd_values() on 2035-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2035-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2035-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-17 Gregorian' );
Mersday 25 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198656000, 'utc_rd_as_seconds() on 2035-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743040,
  0,
  0
]
, 'utc_rd_values() on 2035-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2035-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2035-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-18 Gregorian' );
Highday 26 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198742400, 'utc_rd_as_seconds() on 2035-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743041,
  0,
  0
]
, 'utc_rd_values() on 2035-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  21
]
, 'week() on 2035-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2035-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2035-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2035-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-19 Gregorian' );
Sterday 27 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198828800, 'utc_rd_as_seconds() on 2035-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743042,
  0,
  0
]
, 'utc_rd_values() on 2035-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2035-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2035-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-20 Gregorian' );
Sunday 28 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64198915200, 'utc_rd_as_seconds() on 2035-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743043,
  0,
  0
]
, 'utc_rd_values() on 2035-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2035-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2035-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-21 Gregorian' );
Monday 29 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199001600, 'utc_rd_as_seconds() on 2035-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743044,
  0,
  0
]
, 'utc_rd_values() on 2035-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2035-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2035-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2035-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2035-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-22 Gregorian' );
Trewsday 30 Thrimidge 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199088000, 'utc_rd_as_seconds() on 2035-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743045,
  0,
  0
]
, 'utc_rd_values() on 2035-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2035-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2035-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-23 Gregorian' );
Hevensday 1 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199174400, 'utc_rd_as_seconds() on 2035-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743046,
  0,
  0
]
, 'utc_rd_values() on 2035-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2035-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2035-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-24 Gregorian' );
Mersday 2 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199260800, 'utc_rd_as_seconds() on 2035-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743047,
  0,
  0
]
, 'utc_rd_values() on 2035-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2035-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2035-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-25 Gregorian' );
Highday 3 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199347200, 'utc_rd_as_seconds() on 2035-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743048,
  0,
  0
]
, 'utc_rd_values() on 2035-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  22
]
, 'week() on 2035-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2035-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2035-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2035-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-26 Gregorian' );
Sterday 4 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199433600, 'utc_rd_as_seconds() on 2035-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743049,
  0,
  0
]
, 'utc_rd_values() on 2035-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2035-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2035-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-27 Gregorian' );
Sunday 5 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199520000, 'utc_rd_as_seconds() on 2035-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743050,
  0,
  0
]
, 'utc_rd_values() on 2035-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2035-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2035-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-28 Gregorian' );
Monday 6 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199606400, 'utc_rd_as_seconds() on 2035-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743051,
  0,
  0
]
, 'utc_rd_values() on 2035-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2035-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2035-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-29 Gregorian' );
Trewsday 7 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199692800, 'utc_rd_as_seconds() on 2035-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743052,
  0,
  0
]
, 'utc_rd_values() on 2035-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2035-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2035-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-30 Gregorian' );
Hevensday 8 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199779200, 'utc_rd_as_seconds() on 2035-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743053,
  0,
  0
]
, 'utc_rd_values() on 2035-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2035-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2035-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-05-31 Gregorian' );
Mersday 9 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199865600, 'utc_rd_as_seconds() on 2035-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743054,
  0,
  0
]
, 'utc_rd_values() on 2035-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2035-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2035-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-01 Gregorian' );
Highday 10 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64199952000, 'utc_rd_as_seconds() on 2035-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743055,
  0,
  0
]
, 'utc_rd_values() on 2035-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  23
]
, 'week() on 2035-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2035-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2035-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2035-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-02 Gregorian' );
Sterday 11 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200038400, 'utc_rd_as_seconds() on 2035-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743056,
  0,
  0
]
, 'utc_rd_values() on 2035-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2035-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2035-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-03 Gregorian' );
Sunday 12 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200124800, 'utc_rd_as_seconds() on 2035-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743057,
  0,
  0
]
, 'utc_rd_values() on 2035-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2035-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2035-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-04 Gregorian' );
Monday 13 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200211200, 'utc_rd_as_seconds() on 2035-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743058,
  0,
  0
]
, 'utc_rd_values() on 2035-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2035-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2035-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-05 Gregorian' );
Trewsday 14 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200297600, 'utc_rd_as_seconds() on 2035-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743059,
  0,
  0
]
, 'utc_rd_values() on 2035-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2035-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2035-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-06 Gregorian' );
Hevensday 15 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200384000, 'utc_rd_as_seconds() on 2035-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743060,
  0,
  0
]
, 'utc_rd_values() on 2035-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2035-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2035-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-07 Gregorian' );
Mersday 16 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200470400, 'utc_rd_as_seconds() on 2035-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743061,
  0,
  0
]
, 'utc_rd_values() on 2035-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2035-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2035-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-08 Gregorian' );
Highday 17 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200556800, 'utc_rd_as_seconds() on 2035-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743062,
  0,
  0
]
, 'utc_rd_values() on 2035-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  24
]
, 'week() on 2035-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2035-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2035-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2035-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-09 Gregorian' );
Sterday 18 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200643200, 'utc_rd_as_seconds() on 2035-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743063,
  0,
  0
]
, 'utc_rd_values() on 2035-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2035-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2035-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-10 Gregorian' );
Sunday 19 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200729600, 'utc_rd_as_seconds() on 2035-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743064,
  0,
  0
]
, 'utc_rd_values() on 2035-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2035-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2035-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-11 Gregorian' );
Monday 20 Forelithe 7499

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200816000, 'utc_rd_as_seconds() on 2035-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743065,
  0,
  0
]
, 'utc_rd_values() on 2035-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2035-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2035-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-12 Gregorian' );
Trewsday 21 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200902400, 'utc_rd_as_seconds() on 2035-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743066,
  0,
  0
]
, 'utc_rd_values() on 2035-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2035-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2035-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-13 Gregorian' );
Hevensday 22 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64200988800, 'utc_rd_as_seconds() on 2035-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743067,
  0,
  0
]
, 'utc_rd_values() on 2035-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2035-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2035-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-14 Gregorian' );
Mersday 23 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201075200, 'utc_rd_as_seconds() on 2035-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743068,
  0,
  0
]
, 'utc_rd_values() on 2035-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2035-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2035-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-15 Gregorian' );
Highday 24 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201161600, 'utc_rd_as_seconds() on 2035-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743069,
  0,
  0
]
, 'utc_rd_values() on 2035-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  25
]
, 'week() on 2035-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2035-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2035-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2035-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-16 Gregorian' );
Sterday 25 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201248000, 'utc_rd_as_seconds() on 2035-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743070,
  0,
  0
]
, 'utc_rd_values() on 2035-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2035-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2035-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-17 Gregorian' );
Sunday 26 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201334400, 'utc_rd_as_seconds() on 2035-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743071,
  0,
  0
]
, 'utc_rd_values() on 2035-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2035-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2035-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-18 Gregorian' );
Monday 27 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201420800, 'utc_rd_as_seconds() on 2035-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743072,
  0,
  0
]
, 'utc_rd_values() on 2035-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2035-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2035-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-19 Gregorian' );
Trewsday 28 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201507200, 'utc_rd_as_seconds() on 2035-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743073,
  0,
  0
]
, 'utc_rd_values() on 2035-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2035-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2035-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-20 Gregorian' );
Hevensday 29 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201593600, 'utc_rd_as_seconds() on 2035-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743074,
  0,
  0
]
, 'utc_rd_values() on 2035-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2035-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2035-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2035-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2035-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-21 Gregorian' );
Mersday 30 Forelithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201680000, 'utc_rd_as_seconds() on 2035-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743075,
  0,
  0
]
, 'utc_rd_values() on 2035-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2035-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2035-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2035-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2035-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2035-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2035-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2035-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2035-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2035-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-22 Gregorian' );
Highday 1 Lithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201766400, 'utc_rd_as_seconds() on 2035-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743076,
  0,
  0
]
, 'utc_rd_values() on 2035-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  26
]
, 'week() on 2035-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2035-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2035-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2035-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2035-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2035-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2035-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2035-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2035-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2035-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2035-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2035-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2035-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2035-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2035-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-23 Gregorian' );
Midyear's day 7499

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201852800, 'utc_rd_as_seconds() on 2035-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743077,
  0,
  0
]
, 'utc_rd_values() on 2035-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2035-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  0
]
, 'week() on 2035-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2035-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2035-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2035-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2035-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2035-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2035-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2035-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2035-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2035-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2035-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-24 Gregorian' );
Sterday 2 Lithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64201939200, 'utc_rd_as_seconds() on 2035-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743078,
  0,
  0
]
, 'utc_rd_values() on 2035-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2035-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2035-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-25 Gregorian' );
Sunday 1 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202025600, 'utc_rd_as_seconds() on 2035-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743079,
  0,
  0
]
, 'utc_rd_values() on 2035-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2035-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2035-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-26 Gregorian' );
Monday 2 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202112000, 'utc_rd_as_seconds() on 2035-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743080,
  0,
  0
]
, 'utc_rd_values() on 2035-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2035-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2035-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-27 Gregorian' );
Trewsday 3 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202198400, 'utc_rd_as_seconds() on 2035-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743081,
  0,
  0
]
, 'utc_rd_values() on 2035-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2035-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2035-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-28 Gregorian' );
Hevensday 4 Afterlithe 7499

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202284800, 'utc_rd_as_seconds() on 2035-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743082,
  0,
  0
]
, 'utc_rd_values() on 2035-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2035-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2035-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-29 Gregorian' );
Mersday 5 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202371200, 'utc_rd_as_seconds() on 2035-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743083,
  0,
  0
]
, 'utc_rd_values() on 2035-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2035-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2035-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-06-30 Gregorian' );
Highday 6 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202457600, 'utc_rd_as_seconds() on 2035-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743084,
  0,
  0
]
, 'utc_rd_values() on 2035-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  27
]
, 'week() on 2035-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2035-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2035-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2035-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-01 Gregorian' );
Sterday 7 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202544000, 'utc_rd_as_seconds() on 2035-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743085,
  0,
  0
]
, 'utc_rd_values() on 2035-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2035-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2035-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-02 Gregorian' );
Sunday 8 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202630400, 'utc_rd_as_seconds() on 2035-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743086,
  0,
  0
]
, 'utc_rd_values() on 2035-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2035-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2035-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-03 Gregorian' );
Monday 9 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202716800, 'utc_rd_as_seconds() on 2035-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743087,
  0,
  0
]
, 'utc_rd_values() on 2035-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2035-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2035-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-04 Gregorian' );
Trewsday 10 Afterlithe 7499

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202803200, 'utc_rd_as_seconds() on 2035-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743088,
  0,
  0
]
, 'utc_rd_values() on 2035-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2035-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2035-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-05 Gregorian' );
Hevensday 11 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202889600, 'utc_rd_as_seconds() on 2035-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743089,
  0,
  0
]
, 'utc_rd_values() on 2035-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2035-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2035-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-06 Gregorian' );
Mersday 12 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64202976000, 'utc_rd_as_seconds() on 2035-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743090,
  0,
  0
]
, 'utc_rd_values() on 2035-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2035-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2035-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-07 Gregorian' );
Highday 13 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203062400, 'utc_rd_as_seconds() on 2035-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743091,
  0,
  0
]
, 'utc_rd_values() on 2035-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  28
]
, 'week() on 2035-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2035-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2035-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2035-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-08 Gregorian' );
Sterday 14 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203148800, 'utc_rd_as_seconds() on 2035-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743092,
  0,
  0
]
, 'utc_rd_values() on 2035-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2035-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2035-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-09 Gregorian' );
Sunday 15 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203235200, 'utc_rd_as_seconds() on 2035-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743093,
  0,
  0
]
, 'utc_rd_values() on 2035-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2035-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2035-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-10 Gregorian' );
Monday 16 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203321600, 'utc_rd_as_seconds() on 2035-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743094,
  0,
  0
]
, 'utc_rd_values() on 2035-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2035-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2035-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-11 Gregorian' );
Trewsday 17 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203408000, 'utc_rd_as_seconds() on 2035-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743095,
  0,
  0
]
, 'utc_rd_values() on 2035-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2035-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2035-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-12 Gregorian' );
Hevensday 18 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203494400, 'utc_rd_as_seconds() on 2035-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743096,
  0,
  0
]
, 'utc_rd_values() on 2035-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2035-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2035-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-13 Gregorian' );
Mersday 19 Afterlithe 7499

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203580800, 'utc_rd_as_seconds() on 2035-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743097,
  0,
  0
]
, 'utc_rd_values() on 2035-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2035-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2035-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-14 Gregorian' );
Highday 20 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203667200, 'utc_rd_as_seconds() on 2035-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743098,
  0,
  0
]
, 'utc_rd_values() on 2035-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  29
]
, 'week() on 2035-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2035-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2035-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2035-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-15 Gregorian' );
Sterday 21 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203753600, 'utc_rd_as_seconds() on 2035-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743099,
  0,
  0
]
, 'utc_rd_values() on 2035-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2035-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2035-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-16 Gregorian' );
Sunday 22 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203840000, 'utc_rd_as_seconds() on 2035-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743100,
  0,
  0
]
, 'utc_rd_values() on 2035-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2035-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2035-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-17 Gregorian' );
Monday 23 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64203926400, 'utc_rd_as_seconds() on 2035-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743101,
  0,
  0
]
, 'utc_rd_values() on 2035-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2035-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2035-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-18 Gregorian' );
Trewsday 24 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204012800, 'utc_rd_as_seconds() on 2035-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743102,
  0,
  0
]
, 'utc_rd_values() on 2035-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2035-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2035-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-19 Gregorian' );
Hevensday 25 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204099200, 'utc_rd_as_seconds() on 2035-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743103,
  0,
  0
]
, 'utc_rd_values() on 2035-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2035-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2035-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-20 Gregorian' );
Mersday 26 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204185600, 'utc_rd_as_seconds() on 2035-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743104,
  0,
  0
]
, 'utc_rd_values() on 2035-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2035-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2035-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-21 Gregorian' );
Highday 27 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204272000, 'utc_rd_as_seconds() on 2035-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743105,
  0,
  0
]
, 'utc_rd_values() on 2035-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  30
]
, 'week() on 2035-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2035-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2035-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2035-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-22 Gregorian' );
Sterday 28 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204358400, 'utc_rd_as_seconds() on 2035-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743106,
  0,
  0
]
, 'utc_rd_values() on 2035-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2035-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2035-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-23 Gregorian' );
Sunday 29 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204444800, 'utc_rd_as_seconds() on 2035-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743107,
  0,
  0
]
, 'utc_rd_values() on 2035-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2035-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2035-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2035-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2035-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-24 Gregorian' );
Monday 30 Afterlithe 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204531200, 'utc_rd_as_seconds() on 2035-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743108,
  0,
  0
]
, 'utc_rd_values() on 2035-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2035-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2035-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-25 Gregorian' );
Trewsday 1 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204617600, 'utc_rd_as_seconds() on 2035-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743109,
  0,
  0
]
, 'utc_rd_values() on 2035-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2035-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2035-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-26 Gregorian' );
Hevensday 2 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204704000, 'utc_rd_as_seconds() on 2035-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743110,
  0,
  0
]
, 'utc_rd_values() on 2035-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2035-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2035-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-27 Gregorian' );
Mersday 3 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204790400, 'utc_rd_as_seconds() on 2035-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743111,
  0,
  0
]
, 'utc_rd_values() on 2035-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2035-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2035-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-28 Gregorian' );
Highday 4 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204876800, 'utc_rd_as_seconds() on 2035-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743112,
  0,
  0
]
, 'utc_rd_values() on 2035-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  31
]
, 'week() on 2035-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2035-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2035-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2035-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-29 Gregorian' );
Sterday 5 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64204963200, 'utc_rd_as_seconds() on 2035-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743113,
  0,
  0
]
, 'utc_rd_values() on 2035-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2035-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2035-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-30 Gregorian' );
Sunday 6 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205049600, 'utc_rd_as_seconds() on 2035-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743114,
  0,
  0
]
, 'utc_rd_values() on 2035-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2035-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2035-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-07-31 Gregorian' );
Monday 7 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205136000, 'utc_rd_as_seconds() on 2035-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743115,
  0,
  0
]
, 'utc_rd_values() on 2035-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2035-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2035-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-01 Gregorian' );
Trewsday 8 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205222400, 'utc_rd_as_seconds() on 2035-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743116,
  0,
  0
]
, 'utc_rd_values() on 2035-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2035-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2035-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-02 Gregorian' );
Hevensday 9 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205308800, 'utc_rd_as_seconds() on 2035-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743117,
  0,
  0
]
, 'utc_rd_values() on 2035-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2035-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2035-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-03 Gregorian' );
Mersday 10 Wedmath 7499

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205395200, 'utc_rd_as_seconds() on 2035-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743118,
  0,
  0
]
, 'utc_rd_values() on 2035-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2035-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2035-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-04 Gregorian' );
Highday 11 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205481600, 'utc_rd_as_seconds() on 2035-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743119,
  0,
  0
]
, 'utc_rd_values() on 2035-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  32
]
, 'week() on 2035-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2035-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2035-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2035-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-05 Gregorian' );
Sterday 12 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205568000, 'utc_rd_as_seconds() on 2035-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743120,
  0,
  0
]
, 'utc_rd_values() on 2035-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2035-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2035-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-06 Gregorian' );
Sunday 13 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205654400, 'utc_rd_as_seconds() on 2035-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743121,
  0,
  0
]
, 'utc_rd_values() on 2035-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2035-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2035-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-07 Gregorian' );
Monday 14 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205740800, 'utc_rd_as_seconds() on 2035-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743122,
  0,
  0
]
, 'utc_rd_values() on 2035-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2035-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2035-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-08 Gregorian' );
Trewsday 15 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205827200, 'utc_rd_as_seconds() on 2035-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743123,
  0,
  0
]
, 'utc_rd_values() on 2035-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2035-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2035-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-09 Gregorian' );
Hevensday 16 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64205913600, 'utc_rd_as_seconds() on 2035-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743124,
  0,
  0
]
, 'utc_rd_values() on 2035-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2035-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2035-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-10 Gregorian' );
Mersday 17 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206000000, 'utc_rd_as_seconds() on 2035-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743125,
  0,
  0
]
, 'utc_rd_values() on 2035-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2035-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2035-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-11 Gregorian' );
Highday 18 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206086400, 'utc_rd_as_seconds() on 2035-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743126,
  0,
  0
]
, 'utc_rd_values() on 2035-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  33
]
, 'week() on 2035-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2035-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2035-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2035-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-12 Gregorian' );
Sterday 19 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206172800, 'utc_rd_as_seconds() on 2035-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743127,
  0,
  0
]
, 'utc_rd_values() on 2035-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2035-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2035-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-13 Gregorian' );
Sunday 20 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206259200, 'utc_rd_as_seconds() on 2035-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743128,
  0,
  0
]
, 'utc_rd_values() on 2035-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2035-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2035-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-14 Gregorian' );
Monday 21 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206345600, 'utc_rd_as_seconds() on 2035-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743129,
  0,
  0
]
, 'utc_rd_values() on 2035-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2035-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2035-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-15 Gregorian' );
Trewsday 22 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206432000, 'utc_rd_as_seconds() on 2035-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743130,
  0,
  0
]
, 'utc_rd_values() on 2035-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2035-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2035-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-16 Gregorian' );
Hevensday 23 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206518400, 'utc_rd_as_seconds() on 2035-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743131,
  0,
  0
]
, 'utc_rd_values() on 2035-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2035-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2035-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-17 Gregorian' );
Mersday 24 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206604800, 'utc_rd_as_seconds() on 2035-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743132,
  0,
  0
]
, 'utc_rd_values() on 2035-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2035-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2035-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-18 Gregorian' );
Highday 25 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206691200, 'utc_rd_as_seconds() on 2035-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743133,
  0,
  0
]
, 'utc_rd_values() on 2035-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  34
]
, 'week() on 2035-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2035-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2035-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2035-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-19 Gregorian' );
Sterday 26 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206777600, 'utc_rd_as_seconds() on 2035-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743134,
  0,
  0
]
, 'utc_rd_values() on 2035-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2035-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2035-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-20 Gregorian' );
Sunday 27 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206864000, 'utc_rd_as_seconds() on 2035-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743135,
  0,
  0
]
, 'utc_rd_values() on 2035-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2035-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2035-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-21 Gregorian' );
Monday 28 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64206950400, 'utc_rd_as_seconds() on 2035-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743136,
  0,
  0
]
, 'utc_rd_values() on 2035-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2035-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2035-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-22 Gregorian' );
Trewsday 29 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207036800, 'utc_rd_as_seconds() on 2035-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743137,
  0,
  0
]
, 'utc_rd_values() on 2035-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2035-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2035-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2035-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2035-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-23 Gregorian' );
Hevensday 30 Wedmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207123200, 'utc_rd_as_seconds() on 2035-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743138,
  0,
  0
]
, 'utc_rd_values() on 2035-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2035-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2035-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-24 Gregorian' );
Mersday 1 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207209600, 'utc_rd_as_seconds() on 2035-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743139,
  0,
  0
]
, 'utc_rd_values() on 2035-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2035-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2035-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-25 Gregorian' );
Highday 2 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207296000, 'utc_rd_as_seconds() on 2035-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743140,
  0,
  0
]
, 'utc_rd_values() on 2035-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  35
]
, 'week() on 2035-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2035-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2035-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2035-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-26 Gregorian' );
Sterday 3 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207382400, 'utc_rd_as_seconds() on 2035-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743141,
  0,
  0
]
, 'utc_rd_values() on 2035-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2035-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2035-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-27 Gregorian' );
Sunday 4 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207468800, 'utc_rd_as_seconds() on 2035-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743142,
  0,
  0
]
, 'utc_rd_values() on 2035-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2035-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2035-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-28 Gregorian' );
Monday 5 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207555200, 'utc_rd_as_seconds() on 2035-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743143,
  0,
  0
]
, 'utc_rd_values() on 2035-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2035-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2035-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-29 Gregorian' );
Trewsday 6 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207641600, 'utc_rd_as_seconds() on 2035-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743144,
  0,
  0
]
, 'utc_rd_values() on 2035-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2035-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2035-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-30 Gregorian' );
Hevensday 7 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207728000, 'utc_rd_as_seconds() on 2035-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743145,
  0,
  0
]
, 'utc_rd_values() on 2035-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2035-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2035-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-08-31 Gregorian' );
Mersday 8 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207814400, 'utc_rd_as_seconds() on 2035-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743146,
  0,
  0
]
, 'utc_rd_values() on 2035-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2035-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2035-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-01 Gregorian' );
Highday 9 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207900800, 'utc_rd_as_seconds() on 2035-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743147,
  0,
  0
]
, 'utc_rd_values() on 2035-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  36
]
, 'week() on 2035-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2035-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2035-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2035-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-02 Gregorian' );
Sterday 10 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64207987200, 'utc_rd_as_seconds() on 2035-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743148,
  0,
  0
]
, 'utc_rd_values() on 2035-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2035-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2035-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-03 Gregorian' );
Sunday 11 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208073600, 'utc_rd_as_seconds() on 2035-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743149,
  0,
  0
]
, 'utc_rd_values() on 2035-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2035-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2035-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-04 Gregorian' );
Monday 12 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208160000, 'utc_rd_as_seconds() on 2035-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743150,
  0,
  0
]
, 'utc_rd_values() on 2035-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2035-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2035-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-05 Gregorian' );
Trewsday 13 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208246400, 'utc_rd_as_seconds() on 2035-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743151,
  0,
  0
]
, 'utc_rd_values() on 2035-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2035-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2035-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-06 Gregorian' );
Hevensday 14 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208332800, 'utc_rd_as_seconds() on 2035-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743152,
  0,
  0
]
, 'utc_rd_values() on 2035-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2035-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2035-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-07 Gregorian' );
Mersday 15 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208419200, 'utc_rd_as_seconds() on 2035-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743153,
  0,
  0
]
, 'utc_rd_values() on 2035-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2035-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2035-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-08 Gregorian' );
Highday 16 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208505600, 'utc_rd_as_seconds() on 2035-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743154,
  0,
  0
]
, 'utc_rd_values() on 2035-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  37
]
, 'week() on 2035-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2035-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2035-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2035-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-09 Gregorian' );
Sterday 17 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208592000, 'utc_rd_as_seconds() on 2035-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743155,
  0,
  0
]
, 'utc_rd_values() on 2035-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2035-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2035-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-10 Gregorian' );
Sunday 18 Halimath 7499

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208678400, 'utc_rd_as_seconds() on 2035-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743156,
  0,
  0
]
, 'utc_rd_values() on 2035-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2035-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2035-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-11 Gregorian' );
Monday 19 Halimath 7499

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208764800, 'utc_rd_as_seconds() on 2035-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743157,
  0,
  0
]
, 'utc_rd_values() on 2035-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2035-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2035-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-12 Gregorian' );
Trewsday 20 Halimath 7499

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208851200, 'utc_rd_as_seconds() on 2035-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743158,
  0,
  0
]
, 'utc_rd_values() on 2035-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2035-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2035-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-13 Gregorian' );
Hevensday 21 Halimath 7499

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64208937600, 'utc_rd_as_seconds() on 2035-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743159,
  0,
  0
]
, 'utc_rd_values() on 2035-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2035-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2035-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-14 Gregorian' );
Mersday 22 Halimath 7499

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209024000, 'utc_rd_as_seconds() on 2035-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743160,
  0,
  0
]
, 'utc_rd_values() on 2035-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2035-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2035-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-15 Gregorian' );
Highday 23 Halimath 7499

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209110400, 'utc_rd_as_seconds() on 2035-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743161,
  0,
  0
]
, 'utc_rd_values() on 2035-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  38
]
, 'week() on 2035-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2035-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2035-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2035-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-16 Gregorian' );
Sterday 24 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209196800, 'utc_rd_as_seconds() on 2035-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743162,
  0,
  0
]
, 'utc_rd_values() on 2035-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2035-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2035-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-17 Gregorian' );
Sunday 25 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209283200, 'utc_rd_as_seconds() on 2035-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743163,
  0,
  0
]
, 'utc_rd_values() on 2035-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2035-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2035-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-18 Gregorian' );
Monday 26 Halimath 7499

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209369600, 'utc_rd_as_seconds() on 2035-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743164,
  0,
  0
]
, 'utc_rd_values() on 2035-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2035-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2035-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-19 Gregorian' );
Trewsday 27 Halimath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209456000, 'utc_rd_as_seconds() on 2035-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743165,
  0,
  0
]
, 'utc_rd_values() on 2035-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2035-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2035-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-20 Gregorian' );
Hevensday 28 Halimath 7499

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209542400, 'utc_rd_as_seconds() on 2035-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743166,
  0,
  0
]
, 'utc_rd_values() on 2035-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2035-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2035-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-21 Gregorian' );
Mersday 29 Halimath 7499

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209628800, 'utc_rd_as_seconds() on 2035-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743167,
  0,
  0
]
, 'utc_rd_values() on 2035-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2035-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2035-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2035-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2035-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-22 Gregorian' );
Highday 30 Halimath 7499

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209715200, 'utc_rd_as_seconds() on 2035-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743168,
  0,
  0
]
, 'utc_rd_values() on 2035-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  39
]
, 'week() on 2035-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2035-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2035-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2035-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-23 Gregorian' );
Sterday 1 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209801600, 'utc_rd_as_seconds() on 2035-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743169,
  0,
  0
]
, 'utc_rd_values() on 2035-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2035-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2035-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-24 Gregorian' );
Sunday 2 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209888000, 'utc_rd_as_seconds() on 2035-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743170,
  0,
  0
]
, 'utc_rd_values() on 2035-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2035-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2035-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-25 Gregorian' );
Monday 3 Winterfilth 7499

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64209974400, 'utc_rd_as_seconds() on 2035-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743171,
  0,
  0
]
, 'utc_rd_values() on 2035-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2035-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2035-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-26 Gregorian' );
Trewsday 4 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210060800, 'utc_rd_as_seconds() on 2035-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743172,
  0,
  0
]
, 'utc_rd_values() on 2035-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2035-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2035-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-27 Gregorian' );
Hevensday 5 Winterfilth 7499

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210147200, 'utc_rd_as_seconds() on 2035-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743173,
  0,
  0
]
, 'utc_rd_values() on 2035-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2035-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2035-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-28 Gregorian' );
Mersday 6 Winterfilth 7499

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210233600, 'utc_rd_as_seconds() on 2035-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743174,
  0,
  0
]
, 'utc_rd_values() on 2035-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2035-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2035-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-29 Gregorian' );
Highday 7 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210320000, 'utc_rd_as_seconds() on 2035-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743175,
  0,
  0
]
, 'utc_rd_values() on 2035-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  40
]
, 'week() on 2035-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2035-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2035-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2035-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-09-30 Gregorian' );
Sterday 8 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210406400, 'utc_rd_as_seconds() on 2035-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743176,
  0,
  0
]
, 'utc_rd_values() on 2035-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2035-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2035-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-01 Gregorian' );
Sunday 9 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210492800, 'utc_rd_as_seconds() on 2035-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743177,
  0,
  0
]
, 'utc_rd_values() on 2035-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2035-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2035-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-02 Gregorian' );
Monday 10 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210579200, 'utc_rd_as_seconds() on 2035-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743178,
  0,
  0
]
, 'utc_rd_values() on 2035-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2035-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2035-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-03 Gregorian' );
Trewsday 11 Winterfilth 7499

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210665600, 'utc_rd_as_seconds() on 2035-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743179,
  0,
  0
]
, 'utc_rd_values() on 2035-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2035-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2035-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-04 Gregorian' );
Hevensday 12 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210752000, 'utc_rd_as_seconds() on 2035-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743180,
  0,
  0
]
, 'utc_rd_values() on 2035-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2035-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2035-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-05 Gregorian' );
Mersday 13 Winterfilth 7499

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210838400, 'utc_rd_as_seconds() on 2035-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743181,
  0,
  0
]
, 'utc_rd_values() on 2035-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2035-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2035-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-06 Gregorian' );
Highday 14 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64210924800, 'utc_rd_as_seconds() on 2035-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743182,
  0,
  0
]
, 'utc_rd_values() on 2035-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  41
]
, 'week() on 2035-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2035-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2035-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2035-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-07 Gregorian' );
Sterday 15 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211011200, 'utc_rd_as_seconds() on 2035-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743183,
  0,
  0
]
, 'utc_rd_values() on 2035-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2035-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2035-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-08 Gregorian' );
Sunday 16 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211097600, 'utc_rd_as_seconds() on 2035-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743184,
  0,
  0
]
, 'utc_rd_values() on 2035-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2035-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2035-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-09 Gregorian' );
Monday 17 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211184000, 'utc_rd_as_seconds() on 2035-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743185,
  0,
  0
]
, 'utc_rd_values() on 2035-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2035-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2035-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-10 Gregorian' );
Trewsday 18 Winterfilth 7499

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211270400, 'utc_rd_as_seconds() on 2035-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743186,
  0,
  0
]
, 'utc_rd_values() on 2035-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2035-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2035-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-11 Gregorian' );
Hevensday 19 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211356800, 'utc_rd_as_seconds() on 2035-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743187,
  0,
  0
]
, 'utc_rd_values() on 2035-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2035-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2035-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-12 Gregorian' );
Mersday 20 Winterfilth 7499

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211443200, 'utc_rd_as_seconds() on 2035-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743188,
  0,
  0
]
, 'utc_rd_values() on 2035-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2035-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2035-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-13 Gregorian' );
Highday 21 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211529600, 'utc_rd_as_seconds() on 2035-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743189,
  0,
  0
]
, 'utc_rd_values() on 2035-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  42
]
, 'week() on 2035-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2035-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2035-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2035-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-14 Gregorian' );
Sterday 22 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211616000, 'utc_rd_as_seconds() on 2035-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743190,
  0,
  0
]
, 'utc_rd_values() on 2035-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2035-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2035-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-15 Gregorian' );
Sunday 23 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211702400, 'utc_rd_as_seconds() on 2035-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743191,
  0,
  0
]
, 'utc_rd_values() on 2035-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2035-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2035-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-16 Gregorian' );
Monday 24 Winterfilth 7499

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211788800, 'utc_rd_as_seconds() on 2035-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743192,
  0,
  0
]
, 'utc_rd_values() on 2035-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2035-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2035-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-17 Gregorian' );
Trewsday 25 Winterfilth 7499

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211875200, 'utc_rd_as_seconds() on 2035-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743193,
  0,
  0
]
, 'utc_rd_values() on 2035-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2035-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2035-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-18 Gregorian' );
Hevensday 26 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64211961600, 'utc_rd_as_seconds() on 2035-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743194,
  0,
  0
]
, 'utc_rd_values() on 2035-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2035-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2035-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-19 Gregorian' );
Mersday 27 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212048000, 'utc_rd_as_seconds() on 2035-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743195,
  0,
  0
]
, 'utc_rd_values() on 2035-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2035-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2035-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-20 Gregorian' );
Highday 28 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212134400, 'utc_rd_as_seconds() on 2035-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743196,
  0,
  0
]
, 'utc_rd_values() on 2035-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  43
]
, 'week() on 2035-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2035-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2035-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2035-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-21 Gregorian' );
Sterday 29 Winterfilth 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212220800, 'utc_rd_as_seconds() on 2035-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743197,
  0,
  0
]
, 'utc_rd_values() on 2035-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2035-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2035-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2035-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2035-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-22 Gregorian' );
Sunday 30 Winterfilth 7499

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212307200, 'utc_rd_as_seconds() on 2035-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743198,
  0,
  0
]
, 'utc_rd_values() on 2035-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2035-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2035-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-23 Gregorian' );
Monday 1 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212393600, 'utc_rd_as_seconds() on 2035-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743199,
  0,
  0
]
, 'utc_rd_values() on 2035-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2035-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2035-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-24 Gregorian' );
Trewsday 2 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212480000, 'utc_rd_as_seconds() on 2035-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743200,
  0,
  0
]
, 'utc_rd_values() on 2035-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2035-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2035-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-25 Gregorian' );
Hevensday 3 Blotmath 7499

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212566400, 'utc_rd_as_seconds() on 2035-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743201,
  0,
  0
]
, 'utc_rd_values() on 2035-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2035-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2035-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-26 Gregorian' );
Mersday 4 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212652800, 'utc_rd_as_seconds() on 2035-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743202,
  0,
  0
]
, 'utc_rd_values() on 2035-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2035-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2035-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-27 Gregorian' );
Highday 5 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212739200, 'utc_rd_as_seconds() on 2035-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743203,
  0,
  0
]
, 'utc_rd_values() on 2035-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  44
]
, 'week() on 2035-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2035-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2035-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2035-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-28 Gregorian' );
Sterday 6 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212825600, 'utc_rd_as_seconds() on 2035-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743204,
  0,
  0
]
, 'utc_rd_values() on 2035-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2035-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2035-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-29 Gregorian' );
Sunday 7 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212912000, 'utc_rd_as_seconds() on 2035-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743205,
  0,
  0
]
, 'utc_rd_values() on 2035-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2035-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2035-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-30 Gregorian' );
Monday 8 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64212998400, 'utc_rd_as_seconds() on 2035-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743206,
  0,
  0
]
, 'utc_rd_values() on 2035-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2035-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2035-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-10-31 Gregorian' );
Trewsday 9 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213084800, 'utc_rd_as_seconds() on 2035-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743207,
  0,
  0
]
, 'utc_rd_values() on 2035-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2035-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2035-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-01 Gregorian' );
Hevensday 10 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213171200, 'utc_rd_as_seconds() on 2035-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743208,
  0,
  0
]
, 'utc_rd_values() on 2035-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2035-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2035-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-02 Gregorian' );
Mersday 11 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213257600, 'utc_rd_as_seconds() on 2035-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743209,
  0,
  0
]
, 'utc_rd_values() on 2035-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2035-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2035-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-03 Gregorian' );
Highday 12 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213344000, 'utc_rd_as_seconds() on 2035-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743210,
  0,
  0
]
, 'utc_rd_values() on 2035-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  45
]
, 'week() on 2035-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2035-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2035-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2035-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-04 Gregorian' );
Sterday 13 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213430400, 'utc_rd_as_seconds() on 2035-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743211,
  0,
  0
]
, 'utc_rd_values() on 2035-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2035-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2035-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-05 Gregorian' );
Sunday 14 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213516800, 'utc_rd_as_seconds() on 2035-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743212,
  0,
  0
]
, 'utc_rd_values() on 2035-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2035-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2035-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-06 Gregorian' );
Monday 15 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213603200, 'utc_rd_as_seconds() on 2035-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743213,
  0,
  0
]
, 'utc_rd_values() on 2035-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2035-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2035-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-07 Gregorian' );
Trewsday 16 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213689600, 'utc_rd_as_seconds() on 2035-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743214,
  0,
  0
]
, 'utc_rd_values() on 2035-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2035-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2035-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-08 Gregorian' );
Hevensday 17 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213776000, 'utc_rd_as_seconds() on 2035-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743215,
  0,
  0
]
, 'utc_rd_values() on 2035-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2035-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2035-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-09 Gregorian' );
Mersday 18 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213862400, 'utc_rd_as_seconds() on 2035-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743216,
  0,
  0
]
, 'utc_rd_values() on 2035-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2035-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2035-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-10 Gregorian' );
Highday 19 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64213948800, 'utc_rd_as_seconds() on 2035-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743217,
  0,
  0
]
, 'utc_rd_values() on 2035-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  46
]
, 'week() on 2035-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2035-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2035-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2035-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-11 Gregorian' );
Sterday 20 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214035200, 'utc_rd_as_seconds() on 2035-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743218,
  0,
  0
]
, 'utc_rd_values() on 2035-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2035-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2035-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-12 Gregorian' );
Sunday 21 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214121600, 'utc_rd_as_seconds() on 2035-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743219,
  0,
  0
]
, 'utc_rd_values() on 2035-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2035-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2035-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-13 Gregorian' );
Monday 22 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214208000, 'utc_rd_as_seconds() on 2035-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743220,
  0,
  0
]
, 'utc_rd_values() on 2035-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2035-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2035-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-14 Gregorian' );
Trewsday 23 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214294400, 'utc_rd_as_seconds() on 2035-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743221,
  0,
  0
]
, 'utc_rd_values() on 2035-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2035-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2035-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-15 Gregorian' );
Hevensday 24 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214380800, 'utc_rd_as_seconds() on 2035-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743222,
  0,
  0
]
, 'utc_rd_values() on 2035-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2035-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2035-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-16 Gregorian' );
Mersday 25 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214467200, 'utc_rd_as_seconds() on 2035-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743223,
  0,
  0
]
, 'utc_rd_values() on 2035-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2035-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2035-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-17 Gregorian' );
Highday 26 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214553600, 'utc_rd_as_seconds() on 2035-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743224,
  0,
  0
]
, 'utc_rd_values() on 2035-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  47
]
, 'week() on 2035-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2035-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2035-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2035-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-18 Gregorian' );
Sterday 27 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214640000, 'utc_rd_as_seconds() on 2035-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743225,
  0,
  0
]
, 'utc_rd_values() on 2035-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2035-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2035-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-19 Gregorian' );
Sunday 28 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214726400, 'utc_rd_as_seconds() on 2035-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743226,
  0,
  0
]
, 'utc_rd_values() on 2035-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2035-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2035-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-20 Gregorian' );
Monday 29 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214812800, 'utc_rd_as_seconds() on 2035-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743227,
  0,
  0
]
, 'utc_rd_values() on 2035-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2035-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2035-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2035-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2035-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-21 Gregorian' );
Trewsday 30 Blotmath 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214899200, 'utc_rd_as_seconds() on 2035-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743228,
  0,
  0
]
, 'utc_rd_values() on 2035-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2035-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2035-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-22 Gregorian' );
Hevensday 1 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64214985600, 'utc_rd_as_seconds() on 2035-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743229,
  0,
  0
]
, 'utc_rd_values() on 2035-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2035-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2035-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-23 Gregorian' );
Mersday 2 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215072000, 'utc_rd_as_seconds() on 2035-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743230,
  0,
  0
]
, 'utc_rd_values() on 2035-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2035-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2035-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-24 Gregorian' );
Highday 3 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215158400, 'utc_rd_as_seconds() on 2035-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743231,
  0,
  0
]
, 'utc_rd_values() on 2035-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  48
]
, 'week() on 2035-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2035-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2035-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2035-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-25 Gregorian' );
Sterday 4 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215244800, 'utc_rd_as_seconds() on 2035-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743232,
  0,
  0
]
, 'utc_rd_values() on 2035-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2035-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2035-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-26 Gregorian' );
Sunday 5 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215331200, 'utc_rd_as_seconds() on 2035-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743233,
  0,
  0
]
, 'utc_rd_values() on 2035-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2035-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2035-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-27 Gregorian' );
Monday 6 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215417600, 'utc_rd_as_seconds() on 2035-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743234,
  0,
  0
]
, 'utc_rd_values() on 2035-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2035-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2035-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-28 Gregorian' );
Trewsday 7 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215504000, 'utc_rd_as_seconds() on 2035-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743235,
  0,
  0
]
, 'utc_rd_values() on 2035-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2035-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2035-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-29 Gregorian' );
Hevensday 8 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215590400, 'utc_rd_as_seconds() on 2035-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743236,
  0,
  0
]
, 'utc_rd_values() on 2035-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2035-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2035-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2035-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2035-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2035-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-11-30 Gregorian' );
Mersday 9 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215676800, 'utc_rd_as_seconds() on 2035-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743237,
  0,
  0
]
, 'utc_rd_values() on 2035-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2035-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2035-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2035-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2035-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2035-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-01 Gregorian' );
Highday 10 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215763200, 'utc_rd_as_seconds() on 2035-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743238,
  0,
  0
]
, 'utc_rd_values() on 2035-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  49
]
, 'week() on 2035-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2035-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2035-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2035-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2035-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2035-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2035-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-02 Gregorian' );
Sterday 11 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215849600, 'utc_rd_as_seconds() on 2035-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743239,
  0,
  0
]
, 'utc_rd_values() on 2035-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2035-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2035-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2035-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2035-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2035-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-03 Gregorian' );
Sunday 12 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64215936000, 'utc_rd_as_seconds() on 2035-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743240,
  0,
  0
]
, 'utc_rd_values() on 2035-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2035-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2035-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2035-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2035-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2035-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-04 Gregorian' );
Monday 13 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216022400, 'utc_rd_as_seconds() on 2035-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743241,
  0,
  0
]
, 'utc_rd_values() on 2035-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2035-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2035-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2035-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2035-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2035-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-05 Gregorian' );
Trewsday 14 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216108800, 'utc_rd_as_seconds() on 2035-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743242,
  0,
  0
]
, 'utc_rd_values() on 2035-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2035-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2035-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2035-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2035-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2035-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-06 Gregorian' );
Hevensday 15 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216195200, 'utc_rd_as_seconds() on 2035-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743243,
  0,
  0
]
, 'utc_rd_values() on 2035-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2035-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2035-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2035-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2035-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2035-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-07 Gregorian' );
Mersday 16 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216281600, 'utc_rd_as_seconds() on 2035-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743244,
  0,
  0
]
, 'utc_rd_values() on 2035-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2035-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2035-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2035-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2035-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2035-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-08 Gregorian' );
Highday 17 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216368000, 'utc_rd_as_seconds() on 2035-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743245,
  0,
  0
]
, 'utc_rd_values() on 2035-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  50
]
, 'week() on 2035-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2035-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2035-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2035-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2035-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2035-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2035-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-09 Gregorian' );
Sterday 18 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216454400, 'utc_rd_as_seconds() on 2035-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743246,
  0,
  0
]
, 'utc_rd_values() on 2035-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2035-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2035-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2035-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2035-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2035-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-10 Gregorian' );
Sunday 19 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216540800, 'utc_rd_as_seconds() on 2035-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743247,
  0,
  0
]
, 'utc_rd_values() on 2035-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2035-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2035-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2035-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2035-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2035-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-11 Gregorian' );
Monday 20 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216627200, 'utc_rd_as_seconds() on 2035-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743248,
  0,
  0
]
, 'utc_rd_values() on 2035-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2035-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2035-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2035-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2035-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2035-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-12 Gregorian' );
Trewsday 21 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216713600, 'utc_rd_as_seconds() on 2035-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743249,
  0,
  0
]
, 'utc_rd_values() on 2035-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2035-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2035-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2035-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2035-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2035-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-13 Gregorian' );
Hevensday 22 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216800000, 'utc_rd_as_seconds() on 2035-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743250,
  0,
  0
]
, 'utc_rd_values() on 2035-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2035-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2035-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2035-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2035-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2035-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-14 Gregorian' );
Mersday 23 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216886400, 'utc_rd_as_seconds() on 2035-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743251,
  0,
  0
]
, 'utc_rd_values() on 2035-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2035-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2035-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2035-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2035-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2035-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-15 Gregorian' );
Highday 24 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64216972800, 'utc_rd_as_seconds() on 2035-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743252,
  0,
  0
]
, 'utc_rd_values() on 2035-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  51
]
, 'week() on 2035-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2035-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2035-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2035-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2035-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2035-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2035-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-16 Gregorian' );
Sterday 25 Foreyule 7499

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217059200, 'utc_rd_as_seconds() on 2035-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743253,
  0,
  0
]
, 'utc_rd_values() on 2035-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2035-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2035-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2035-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2035-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2035-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-17 Gregorian' );
Sunday 26 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217145600, 'utc_rd_as_seconds() on 2035-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743254,
  0,
  0
]
, 'utc_rd_values() on 2035-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2035-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2035-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2035-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2035-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2035-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-18 Gregorian' );
Monday 27 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217232000, 'utc_rd_as_seconds() on 2035-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743255,
  0,
  0
]
, 'utc_rd_values() on 2035-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2035-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2035-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2035-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2035-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2035-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-19 Gregorian' );
Trewsday 28 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217318400, 'utc_rd_as_seconds() on 2035-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743256,
  0,
  0
]
, 'utc_rd_values() on 2035-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2035-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2035-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2035-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2035-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2035-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-20 Gregorian' );
Hevensday 29 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217404800, 'utc_rd_as_seconds() on 2035-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743257,
  0,
  0
]
, 'utc_rd_values() on 2035-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2035-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2035-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2035-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2035-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2035-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2035-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2035-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-21 Gregorian' );
Mersday 30 Foreyule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217491200, 'utc_rd_as_seconds() on 2035-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743258,
  0,
  0
]
, 'utc_rd_values() on 2035-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2035-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2035-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2035-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2035-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2035-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2035-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2035-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2035-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2035-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-22 Gregorian' );
Highday 1 Yule 7499
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217577600, 'utc_rd_as_seconds() on 2035-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743259,
  0,
  0
]
, 'utc_rd_values() on 2035-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7499,
  52
]
, 'week() on 2035-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2035-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7499, 'week_year() on 2035-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7499, 'year() on 2035-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2035-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2035-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2035-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2035-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2035-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2035-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2035-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2035-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2035-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-23 Gregorian' );
Sterday 2 Yule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217664000, 'utc_rd_as_seconds() on 2035-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743260,
  0,
  0
]
, 'utc_rd_values() on 2035-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2035-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2035-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2035-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2035-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2035-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-24 Gregorian' );
Sunday 1 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217750400, 'utc_rd_as_seconds() on 2035-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743261,
  0,
  0
]
, 'utc_rd_values() on 2035-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2035-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2035-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2035-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2035-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2035-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2035-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2035-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2035-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2035-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-25 Gregorian' );
Monday 2 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217836800, 'utc_rd_as_seconds() on 2035-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743262,
  0,
  0
]
, 'utc_rd_values() on 2035-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2035-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2035-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2035-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2035-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2035-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2035-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2035-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2035-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2035-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2035-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-26 Gregorian' );
Trewsday 3 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64217923200, 'utc_rd_as_seconds() on 2035-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743263,
  0,
  0
]
, 'utc_rd_values() on 2035-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2035-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2035-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2035-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2035-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2035-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2035-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2035-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2035-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2035-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2035-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-27 Gregorian' );
Hevensday 4 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218009600, 'utc_rd_as_seconds() on 2035-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743264,
  0,
  0
]
, 'utc_rd_values() on 2035-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2035-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2035-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2035-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2035-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2035-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2035-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2035-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2035-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2035-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2035-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-28 Gregorian' );
Mersday 5 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218096000, 'utc_rd_as_seconds() on 2035-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743265,
  0,
  0
]
, 'utc_rd_values() on 2035-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2035-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2035-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2035-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2035-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2035-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2035-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2035-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2035-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2035-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2035-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-29 Gregorian' );
Highday 6 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218182400, 'utc_rd_as_seconds() on 2035-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743266,
  0,
  0
]
, 'utc_rd_values() on 2035-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2035-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  1
]
, 'week() on 2035-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2035-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2035-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2035-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2035-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2035-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2035-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2035-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2035-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2035-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2035-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-30 Gregorian' );
Sterday 7 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218268800, 'utc_rd_as_seconds() on 2035-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743267,
  0,
  0
]
, 'utc_rd_values() on 2035-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2035-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2035-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2035 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2035,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2035-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2035-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2035-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2035-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2035-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2035-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2035-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2035-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2035-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2035-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2035-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2035-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2035-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2035-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2035-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2035-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2035-12-31 Gregorian' );
Sunday 8 Afteryule 7500

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218355200, 'utc_rd_as_seconds() on 2035-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743268,
  0,
  0
]
, 'utc_rd_values() on 2035-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2035-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2035-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2035-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2035-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2035-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2036-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2036-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-01 Gregorian' );
Monday 9 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218441600, 'utc_rd_as_seconds() on 2036-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743269,
  0,
  0
]
, 'utc_rd_values() on 2036-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2036-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2036-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2036-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-02 Gregorian' );
Trewsday 10 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218528000, 'utc_rd_as_seconds() on 2036-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743270,
  0,
  0
]
, 'utc_rd_values() on 2036-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2036-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2036-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2036-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-03 Gregorian' );
Hevensday 11 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218614400, 'utc_rd_as_seconds() on 2036-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743271,
  0,
  0
]
, 'utc_rd_values() on 2036-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2036-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2036-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2036-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-04 Gregorian' );
Mersday 12 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218700800, 'utc_rd_as_seconds() on 2036-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743272,
  0,
  0
]
, 'utc_rd_values() on 2036-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2036-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2036-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2036-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-05 Gregorian' );
Highday 13 Afteryule 7500

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218787200, 'utc_rd_as_seconds() on 2036-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743273,
  0,
  0
]
, 'utc_rd_values() on 2036-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  2
]
, 'week() on 2036-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2036-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2036-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-06 Gregorian' );
Sterday 14 Afteryule 7500

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218873600, 'utc_rd_as_seconds() on 2036-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743274,
  0,
  0
]
, 'utc_rd_values() on 2036-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2036-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2036-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-07 Gregorian' );
Sunday 15 Afteryule 7500

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64218960000, 'utc_rd_as_seconds() on 2036-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743275,
  0,
  0
]
, 'utc_rd_values() on 2036-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2036-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2036-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-08 Gregorian' );
Monday 16 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219046400, 'utc_rd_as_seconds() on 2036-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743276,
  0,
  0
]
, 'utc_rd_values() on 2036-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2036-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2036-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-09 Gregorian' );
Trewsday 17 Afteryule 7500

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219132800, 'utc_rd_as_seconds() on 2036-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743277,
  0,
  0
]
, 'utc_rd_values() on 2036-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2036-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2036-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-10 Gregorian' );
Hevensday 18 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219219200, 'utc_rd_as_seconds() on 2036-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743278,
  0,
  0
]
, 'utc_rd_values() on 2036-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2036-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2036-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-11 Gregorian' );
Mersday 19 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219305600, 'utc_rd_as_seconds() on 2036-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743279,
  0,
  0
]
, 'utc_rd_values() on 2036-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2036-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2036-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-12 Gregorian' );
Highday 20 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219392000, 'utc_rd_as_seconds() on 2036-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743280,
  0,
  0
]
, 'utc_rd_values() on 2036-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  3
]
, 'week() on 2036-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2036-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2036-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2036-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-13 Gregorian' );
Sterday 21 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219478400, 'utc_rd_as_seconds() on 2036-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743281,
  0,
  0
]
, 'utc_rd_values() on 2036-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2036-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2036-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-14 Gregorian' );
Sunday 22 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219564800, 'utc_rd_as_seconds() on 2036-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743282,
  0,
  0
]
, 'utc_rd_values() on 2036-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2036-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2036-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-15 Gregorian' );
Monday 23 Afteryule 7500

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219651200, 'utc_rd_as_seconds() on 2036-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743283,
  0,
  0
]
, 'utc_rd_values() on 2036-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2036-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2036-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-16 Gregorian' );
Trewsday 24 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219737600, 'utc_rd_as_seconds() on 2036-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743284,
  0,
  0
]
, 'utc_rd_values() on 2036-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2036-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2036-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-17 Gregorian' );
Hevensday 25 Afteryule 7500

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219824000, 'utc_rd_as_seconds() on 2036-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743285,
  0,
  0
]
, 'utc_rd_values() on 2036-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2036-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2036-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-18 Gregorian' );
Mersday 26 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219910400, 'utc_rd_as_seconds() on 2036-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743286,
  0,
  0
]
, 'utc_rd_values() on 2036-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2036-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2036-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-19 Gregorian' );
Highday 27 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64219996800, 'utc_rd_as_seconds() on 2036-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743287,
  0,
  0
]
, 'utc_rd_values() on 2036-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  4
]
, 'week() on 2036-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2036-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2036-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2036-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-20 Gregorian' );
Sterday 28 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220083200, 'utc_rd_as_seconds() on 2036-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743288,
  0,
  0
]
, 'utc_rd_values() on 2036-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2036-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2036-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-21 Gregorian' );
Sunday 29 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220169600, 'utc_rd_as_seconds() on 2036-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743289,
  0,
  0
]
, 'utc_rd_values() on 2036-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2036-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2036-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-22 Gregorian' );
Monday 30 Afteryule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220256000, 'utc_rd_as_seconds() on 2036-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743290,
  0,
  0
]
, 'utc_rd_values() on 2036-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2036-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2036-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-23 Gregorian' );
Trewsday 1 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220342400, 'utc_rd_as_seconds() on 2036-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743291,
  0,
  0
]
, 'utc_rd_values() on 2036-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2036-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2036-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-24 Gregorian' );
Hevensday 2 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220428800, 'utc_rd_as_seconds() on 2036-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743292,
  0,
  0
]
, 'utc_rd_values() on 2036-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2036-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2036-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-25 Gregorian' );
Mersday 3 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220515200, 'utc_rd_as_seconds() on 2036-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743293,
  0,
  0
]
, 'utc_rd_values() on 2036-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2036-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2036-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-26 Gregorian' );
Highday 4 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220601600, 'utc_rd_as_seconds() on 2036-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743294,
  0,
  0
]
, 'utc_rd_values() on 2036-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  5
]
, 'week() on 2036-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2036-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2036-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2036-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-27 Gregorian' );
Sterday 5 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220688000, 'utc_rd_as_seconds() on 2036-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743295,
  0,
  0
]
, 'utc_rd_values() on 2036-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2036-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2036-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-28 Gregorian' );
Sunday 6 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220774400, 'utc_rd_as_seconds() on 2036-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743296,
  0,
  0
]
, 'utc_rd_values() on 2036-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2036-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2036-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-29 Gregorian' );
Monday 7 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220860800, 'utc_rd_as_seconds() on 2036-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743297,
  0,
  0
]
, 'utc_rd_values() on 2036-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2036-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2036-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-30 Gregorian' );
Trewsday 8 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64220947200, 'utc_rd_as_seconds() on 2036-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743298,
  0,
  0
]
, 'utc_rd_values() on 2036-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2036-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2036-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-01-31 Gregorian' );
Hevensday 9 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221033600, 'utc_rd_as_seconds() on 2036-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743299,
  0,
  0
]
, 'utc_rd_values() on 2036-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2036-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2036-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-01 Gregorian' );
Mersday 10 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221120000, 'utc_rd_as_seconds() on 2036-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743300,
  0,
  0
]
, 'utc_rd_values() on 2036-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2036-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2036-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-02 Gregorian' );
Highday 11 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221206400, 'utc_rd_as_seconds() on 2036-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743301,
  0,
  0
]
, 'utc_rd_values() on 2036-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  6
]
, 'week() on 2036-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2036-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2036-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2036-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-03 Gregorian' );
Sterday 12 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221292800, 'utc_rd_as_seconds() on 2036-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743302,
  0,
  0
]
, 'utc_rd_values() on 2036-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2036-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2036-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-04 Gregorian' );
Sunday 13 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221379200, 'utc_rd_as_seconds() on 2036-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743303,
  0,
  0
]
, 'utc_rd_values() on 2036-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2036-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2036-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-05 Gregorian' );
Monday 14 Solmath 7500

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221465600, 'utc_rd_as_seconds() on 2036-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743304,
  0,
  0
]
, 'utc_rd_values() on 2036-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2036-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2036-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-06 Gregorian' );
Trewsday 15 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221552000, 'utc_rd_as_seconds() on 2036-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743305,
  0,
  0
]
, 'utc_rd_values() on 2036-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2036-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2036-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-07 Gregorian' );
Hevensday 16 Solmath 7500

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221638400, 'utc_rd_as_seconds() on 2036-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743306,
  0,
  0
]
, 'utc_rd_values() on 2036-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2036-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2036-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-08 Gregorian' );
Mersday 17 Solmath 7500

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221724800, 'utc_rd_as_seconds() on 2036-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743307,
  0,
  0
]
, 'utc_rd_values() on 2036-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2036-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2036-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-09 Gregorian' );
Highday 18 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221811200, 'utc_rd_as_seconds() on 2036-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743308,
  0,
  0
]
, 'utc_rd_values() on 2036-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  7
]
, 'week() on 2036-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2036-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2036-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2036-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-10 Gregorian' );
Sterday 19 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221897600, 'utc_rd_as_seconds() on 2036-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743309,
  0,
  0
]
, 'utc_rd_values() on 2036-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2036-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2036-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-11 Gregorian' );
Sunday 20 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64221984000, 'utc_rd_as_seconds() on 2036-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743310,
  0,
  0
]
, 'utc_rd_values() on 2036-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2036-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2036-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-12 Gregorian' );
Monday 21 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222070400, 'utc_rd_as_seconds() on 2036-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743311,
  0,
  0
]
, 'utc_rd_values() on 2036-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2036-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2036-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-13 Gregorian' );
Trewsday 22 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222156800, 'utc_rd_as_seconds() on 2036-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743312,
  0,
  0
]
, 'utc_rd_values() on 2036-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2036-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2036-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-14 Gregorian' );
Hevensday 23 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222243200, 'utc_rd_as_seconds() on 2036-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743313,
  0,
  0
]
, 'utc_rd_values() on 2036-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2036-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2036-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-15 Gregorian' );
Mersday 24 Solmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222329600, 'utc_rd_as_seconds() on 2036-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743314,
  0,
  0
]
, 'utc_rd_values() on 2036-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2036-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2036-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-16 Gregorian' );
Highday 25 Solmath 7500

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222416000, 'utc_rd_as_seconds() on 2036-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743315,
  0,
  0
]
, 'utc_rd_values() on 2036-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  8
]
, 'week() on 2036-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2036-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2036-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2036-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-17 Gregorian' );
Sterday 26 Solmath 7500

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222502400, 'utc_rd_as_seconds() on 2036-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743316,
  0,
  0
]
, 'utc_rd_values() on 2036-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2036-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2036-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-18 Gregorian' );
Sunday 27 Solmath 7500

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222588800, 'utc_rd_as_seconds() on 2036-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743317,
  0,
  0
]
, 'utc_rd_values() on 2036-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2036-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2036-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-19 Gregorian' );
Monday 28 Solmath 7500

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222675200, 'utc_rd_as_seconds() on 2036-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743318,
  0,
  0
]
, 'utc_rd_values() on 2036-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2036-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2036-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-20 Gregorian' );
Trewsday 29 Solmath 7500

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222761600, 'utc_rd_as_seconds() on 2036-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743319,
  0,
  0
]
, 'utc_rd_values() on 2036-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2036-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2036-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2036-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2036-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-21 Gregorian' );
Hevensday 30 Solmath 7500

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222848000, 'utc_rd_as_seconds() on 2036-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743320,
  0,
  0
]
, 'utc_rd_values() on 2036-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2036-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2036-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-22 Gregorian' );
Mersday 1 Rethe 7500

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64222934400, 'utc_rd_as_seconds() on 2036-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743321,
  0,
  0
]
, 'utc_rd_values() on 2036-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2036-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2036-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-23 Gregorian' );
Highday 2 Rethe 7500

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223020800, 'utc_rd_as_seconds() on 2036-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743322,
  0,
  0
]
, 'utc_rd_values() on 2036-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  9
]
, 'week() on 2036-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2036-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2036-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2036-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-24 Gregorian' );
Sterday 3 Rethe 7500

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223107200, 'utc_rd_as_seconds() on 2036-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743323,
  0,
  0
]
, 'utc_rd_values() on 2036-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2036-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2036-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-25 Gregorian' );
Sunday 4 Rethe 7500

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223193600, 'utc_rd_as_seconds() on 2036-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743324,
  0,
  0
]
, 'utc_rd_values() on 2036-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2036-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2036-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-26 Gregorian' );
Monday 5 Rethe 7500

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223280000, 'utc_rd_as_seconds() on 2036-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743325,
  0,
  0
]
, 'utc_rd_values() on 2036-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2036-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2036-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-27 Gregorian' );
Trewsday 6 Rethe 7500

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223366400, 'utc_rd_as_seconds() on 2036-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743326,
  0,
  0
]
, 'utc_rd_values() on 2036-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2036-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2036-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-28 Gregorian' );
Hevensday 7 Rethe 7500

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223452800, 'utc_rd_as_seconds() on 2036-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743327,
  0,
  0
]
, 'utc_rd_values() on 2036-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 2 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 2,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-02-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-02-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-02-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-02-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-02-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2036-02-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-02-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2036-02-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-02-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-02-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-02-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-02-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-02-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-02-29 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-02-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-02-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-02-29 Gregorian' );
Mersday 8 Rethe 7500

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223539200, 'utc_rd_as_seconds() on 2036-02-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743328,
  0,
  0
]
, 'utc_rd_values() on 2036-02-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-02-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-02-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-02-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-02-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-02-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2036-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2036-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-01 Gregorian' );
Highday 9 Rethe 7500

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223625600, 'utc_rd_as_seconds() on 2036-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743329,
  0,
  0
]
, 'utc_rd_values() on 2036-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  10
]
, 'week() on 2036-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2036-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2036-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2036-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-02 Gregorian' );
Sterday 10 Rethe 7500

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223712000, 'utc_rd_as_seconds() on 2036-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743330,
  0,
  0
]
, 'utc_rd_values() on 2036-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2036-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2036-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-03 Gregorian' );
Sunday 11 Rethe 7500

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223798400, 'utc_rd_as_seconds() on 2036-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743331,
  0,
  0
]
, 'utc_rd_values() on 2036-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2036-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2036-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-04 Gregorian' );
Monday 12 Rethe 7500

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223884800, 'utc_rd_as_seconds() on 2036-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743332,
  0,
  0
]
, 'utc_rd_values() on 2036-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2036-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2036-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-05 Gregorian' );
Trewsday 13 Rethe 7500

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64223971200, 'utc_rd_as_seconds() on 2036-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743333,
  0,
  0
]
, 'utc_rd_values() on 2036-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2036-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2036-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-06 Gregorian' );
Hevensday 14 Rethe 7500

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224057600, 'utc_rd_as_seconds() on 2036-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743334,
  0,
  0
]
, 'utc_rd_values() on 2036-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2036-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2036-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-07 Gregorian' );
Mersday 15 Rethe 7500

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224144000, 'utc_rd_as_seconds() on 2036-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743335,
  0,
  0
]
, 'utc_rd_values() on 2036-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2036-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2036-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-08 Gregorian' );
Highday 16 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224230400, 'utc_rd_as_seconds() on 2036-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743336,
  0,
  0
]
, 'utc_rd_values() on 2036-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  11
]
, 'week() on 2036-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2036-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2036-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2036-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-09 Gregorian' );
Sterday 17 Rethe 7500

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224316800, 'utc_rd_as_seconds() on 2036-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743337,
  0,
  0
]
, 'utc_rd_values() on 2036-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2036-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2036-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-10 Gregorian' );
Sunday 18 Rethe 7500

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224403200, 'utc_rd_as_seconds() on 2036-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743338,
  0,
  0
]
, 'utc_rd_values() on 2036-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2036-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2036-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-11 Gregorian' );
Monday 19 Rethe 7500

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224489600, 'utc_rd_as_seconds() on 2036-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743339,
  0,
  0
]
, 'utc_rd_values() on 2036-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2036-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2036-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-12 Gregorian' );
Trewsday 20 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224576000, 'utc_rd_as_seconds() on 2036-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743340,
  0,
  0
]
, 'utc_rd_values() on 2036-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2036-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2036-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-13 Gregorian' );
Hevensday 21 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224662400, 'utc_rd_as_seconds() on 2036-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743341,
  0,
  0
]
, 'utc_rd_values() on 2036-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2036-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2036-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-14 Gregorian' );
Mersday 22 Rethe 7500

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224748800, 'utc_rd_as_seconds() on 2036-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743342,
  0,
  0
]
, 'utc_rd_values() on 2036-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2036-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2036-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-15 Gregorian' );
Highday 23 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224835200, 'utc_rd_as_seconds() on 2036-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743343,
  0,
  0
]
, 'utc_rd_values() on 2036-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  12
]
, 'week() on 2036-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2036-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2036-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2036-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-16 Gregorian' );
Sterday 24 Rethe 7500

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64224921600, 'utc_rd_as_seconds() on 2036-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743344,
  0,
  0
]
, 'utc_rd_values() on 2036-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2036-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2036-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-17 Gregorian' );
Sunday 25 Rethe 7500

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225008000, 'utc_rd_as_seconds() on 2036-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743345,
  0,
  0
]
, 'utc_rd_values() on 2036-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2036-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2036-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-18 Gregorian' );
Monday 26 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225094400, 'utc_rd_as_seconds() on 2036-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743346,
  0,
  0
]
, 'utc_rd_values() on 2036-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2036-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2036-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-19 Gregorian' );
Trewsday 27 Rethe 7500

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225180800, 'utc_rd_as_seconds() on 2036-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743347,
  0,
  0
]
, 'utc_rd_values() on 2036-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2036-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2036-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-20 Gregorian' );
Hevensday 28 Rethe 7500

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225267200, 'utc_rd_as_seconds() on 2036-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743348,
  0,
  0
]
, 'utc_rd_values() on 2036-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2036-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2036-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-21 Gregorian' );
Mersday 29 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225353600, 'utc_rd_as_seconds() on 2036-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743349,
  0,
  0
]
, 'utc_rd_values() on 2036-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2036-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2036-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2036-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2036-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-22 Gregorian' );
Highday 30 Rethe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225440000, 'utc_rd_as_seconds() on 2036-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743350,
  0,
  0
]
, 'utc_rd_values() on 2036-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  13
]
, 'week() on 2036-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2036-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2036-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2036-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-23 Gregorian' );
Sterday 1 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225526400, 'utc_rd_as_seconds() on 2036-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743351,
  0,
  0
]
, 'utc_rd_values() on 2036-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2036-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2036-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-24 Gregorian' );
Sunday 2 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225612800, 'utc_rd_as_seconds() on 2036-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743352,
  0,
  0
]
, 'utc_rd_values() on 2036-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2036-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2036-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-25 Gregorian' );
Monday 3 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225699200, 'utc_rd_as_seconds() on 2036-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743353,
  0,
  0
]
, 'utc_rd_values() on 2036-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2036-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2036-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-26 Gregorian' );
Trewsday 4 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225785600, 'utc_rd_as_seconds() on 2036-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743354,
  0,
  0
]
, 'utc_rd_values() on 2036-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2036-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2036-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-27 Gregorian' );
Hevensday 5 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225872000, 'utc_rd_as_seconds() on 2036-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743355,
  0,
  0
]
, 'utc_rd_values() on 2036-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2036-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2036-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-28 Gregorian' );
Mersday 6 Astron 7500

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64225958400, 'utc_rd_as_seconds() on 2036-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743356,
  0,
  0
]
, 'utc_rd_values() on 2036-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2036-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2036-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-29 Gregorian' );
Highday 7 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226044800, 'utc_rd_as_seconds() on 2036-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743357,
  0,
  0
]
, 'utc_rd_values() on 2036-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  14
]
, 'week() on 2036-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2036-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2036-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2036-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-30 Gregorian' );
Sterday 8 Astron 7500

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226131200, 'utc_rd_as_seconds() on 2036-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743358,
  0,
  0
]
, 'utc_rd_values() on 2036-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2036-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2036-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-03-31 Gregorian' );
Sunday 9 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226217600, 'utc_rd_as_seconds() on 2036-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743359,
  0,
  0
]
, 'utc_rd_values() on 2036-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2036-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2036-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-01 Gregorian' );
Monday 10 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226304000, 'utc_rd_as_seconds() on 2036-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743360,
  0,
  0
]
, 'utc_rd_values() on 2036-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2036-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2036-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-02 Gregorian' );
Trewsday 11 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226390400, 'utc_rd_as_seconds() on 2036-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743361,
  0,
  0
]
, 'utc_rd_values() on 2036-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2036-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2036-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-03 Gregorian' );
Hevensday 12 Astron 7500

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226476800, 'utc_rd_as_seconds() on 2036-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743362,
  0,
  0
]
, 'utc_rd_values() on 2036-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2036-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2036-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-04 Gregorian' );
Mersday 13 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226563200, 'utc_rd_as_seconds() on 2036-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743363,
  0,
  0
]
, 'utc_rd_values() on 2036-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2036-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2036-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-05 Gregorian' );
Highday 14 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226649600, 'utc_rd_as_seconds() on 2036-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743364,
  0,
  0
]
, 'utc_rd_values() on 2036-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  15
]
, 'week() on 2036-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2036-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2036-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2036-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-06 Gregorian' );
Sterday 15 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226736000, 'utc_rd_as_seconds() on 2036-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743365,
  0,
  0
]
, 'utc_rd_values() on 2036-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2036-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2036-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-07 Gregorian' );
Sunday 16 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226822400, 'utc_rd_as_seconds() on 2036-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743366,
  0,
  0
]
, 'utc_rd_values() on 2036-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2036-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2036-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-08 Gregorian' );
Monday 17 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226908800, 'utc_rd_as_seconds() on 2036-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743367,
  0,
  0
]
, 'utc_rd_values() on 2036-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2036-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2036-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-09 Gregorian' );
Trewsday 18 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64226995200, 'utc_rd_as_seconds() on 2036-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743368,
  0,
  0
]
, 'utc_rd_values() on 2036-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2036-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2036-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-10 Gregorian' );
Hevensday 19 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227081600, 'utc_rd_as_seconds() on 2036-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743369,
  0,
  0
]
, 'utc_rd_values() on 2036-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2036-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2036-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-11 Gregorian' );
Mersday 20 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227168000, 'utc_rd_as_seconds() on 2036-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743370,
  0,
  0
]
, 'utc_rd_values() on 2036-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2036-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2036-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-12 Gregorian' );
Highday 21 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227254400, 'utc_rd_as_seconds() on 2036-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743371,
  0,
  0
]
, 'utc_rd_values() on 2036-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  16
]
, 'week() on 2036-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2036-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2036-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2036-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-13 Gregorian' );
Sterday 22 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227340800, 'utc_rd_as_seconds() on 2036-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743372,
  0,
  0
]
, 'utc_rd_values() on 2036-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2036-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2036-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-14 Gregorian' );
Sunday 23 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227427200, 'utc_rd_as_seconds() on 2036-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743373,
  0,
  0
]
, 'utc_rd_values() on 2036-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2036-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2036-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-15 Gregorian' );
Monday 24 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227513600, 'utc_rd_as_seconds() on 2036-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743374,
  0,
  0
]
, 'utc_rd_values() on 2036-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2036-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2036-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-16 Gregorian' );
Trewsday 25 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227600000, 'utc_rd_as_seconds() on 2036-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743375,
  0,
  0
]
, 'utc_rd_values() on 2036-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2036-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2036-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-17 Gregorian' );
Hevensday 26 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227686400, 'utc_rd_as_seconds() on 2036-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743376,
  0,
  0
]
, 'utc_rd_values() on 2036-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2036-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2036-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-18 Gregorian' );
Mersday 27 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227772800, 'utc_rd_as_seconds() on 2036-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743377,
  0,
  0
]
, 'utc_rd_values() on 2036-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2036-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2036-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-19 Gregorian' );
Highday 28 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227859200, 'utc_rd_as_seconds() on 2036-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743378,
  0,
  0
]
, 'utc_rd_values() on 2036-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  17
]
, 'week() on 2036-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2036-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2036-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2036-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-20 Gregorian' );
Sterday 29 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64227945600, 'utc_rd_as_seconds() on 2036-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743379,
  0,
  0
]
, 'utc_rd_values() on 2036-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2036-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2036-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2036-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2036-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-21 Gregorian' );
Sunday 30 Astron 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228032000, 'utc_rd_as_seconds() on 2036-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743380,
  0,
  0
]
, 'utc_rd_values() on 2036-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2036-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2036-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-22 Gregorian' );
Monday 1 Thrimidge 7500

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228118400, 'utc_rd_as_seconds() on 2036-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743381,
  0,
  0
]
, 'utc_rd_values() on 2036-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2036-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2036-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-23 Gregorian' );
Trewsday 2 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228204800, 'utc_rd_as_seconds() on 2036-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743382,
  0,
  0
]
, 'utc_rd_values() on 2036-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2036-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2036-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-24 Gregorian' );
Hevensday 3 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228291200, 'utc_rd_as_seconds() on 2036-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743383,
  0,
  0
]
, 'utc_rd_values() on 2036-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2036-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2036-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-25 Gregorian' );
Mersday 4 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228377600, 'utc_rd_as_seconds() on 2036-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743384,
  0,
  0
]
, 'utc_rd_values() on 2036-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2036-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2036-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-26 Gregorian' );
Highday 5 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228464000, 'utc_rd_as_seconds() on 2036-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743385,
  0,
  0
]
, 'utc_rd_values() on 2036-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  18
]
, 'week() on 2036-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2036-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2036-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2036-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-27 Gregorian' );
Sterday 6 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228550400, 'utc_rd_as_seconds() on 2036-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743386,
  0,
  0
]
, 'utc_rd_values() on 2036-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2036-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2036-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-28 Gregorian' );
Sunday 7 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228636800, 'utc_rd_as_seconds() on 2036-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743387,
  0,
  0
]
, 'utc_rd_values() on 2036-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2036-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2036-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-29 Gregorian' );
Monday 8 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228723200, 'utc_rd_as_seconds() on 2036-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743388,
  0,
  0
]
, 'utc_rd_values() on 2036-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2036-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2036-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-04-30 Gregorian' );
Trewsday 9 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228809600, 'utc_rd_as_seconds() on 2036-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743389,
  0,
  0
]
, 'utc_rd_values() on 2036-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2036-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2036-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-01 Gregorian' );
Hevensday 10 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228896000, 'utc_rd_as_seconds() on 2036-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743390,
  0,
  0
]
, 'utc_rd_values() on 2036-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2036-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2036-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-02 Gregorian' );
Mersday 11 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64228982400, 'utc_rd_as_seconds() on 2036-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743391,
  0,
  0
]
, 'utc_rd_values() on 2036-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2036-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2036-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-03 Gregorian' );
Highday 12 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229068800, 'utc_rd_as_seconds() on 2036-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743392,
  0,
  0
]
, 'utc_rd_values() on 2036-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  19
]
, 'week() on 2036-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2036-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2036-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2036-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-04 Gregorian' );
Sterday 13 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229155200, 'utc_rd_as_seconds() on 2036-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743393,
  0,
  0
]
, 'utc_rd_values() on 2036-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2036-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2036-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-05 Gregorian' );
Sunday 14 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229241600, 'utc_rd_as_seconds() on 2036-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743394,
  0,
  0
]
, 'utc_rd_values() on 2036-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2036-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2036-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-06 Gregorian' );
Monday 15 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229328000, 'utc_rd_as_seconds() on 2036-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743395,
  0,
  0
]
, 'utc_rd_values() on 2036-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2036-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2036-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-07 Gregorian' );
Trewsday 16 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229414400, 'utc_rd_as_seconds() on 2036-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743396,
  0,
  0
]
, 'utc_rd_values() on 2036-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2036-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2036-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-08 Gregorian' );
Hevensday 17 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229500800, 'utc_rd_as_seconds() on 2036-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743397,
  0,
  0
]
, 'utc_rd_values() on 2036-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2036-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2036-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-09 Gregorian' );
Mersday 18 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229587200, 'utc_rd_as_seconds() on 2036-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743398,
  0,
  0
]
, 'utc_rd_values() on 2036-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2036-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2036-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-10 Gregorian' );
Highday 19 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229673600, 'utc_rd_as_seconds() on 2036-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743399,
  0,
  0
]
, 'utc_rd_values() on 2036-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  20
]
, 'week() on 2036-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2036-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2036-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2036-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-11 Gregorian' );
Sterday 20 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229760000, 'utc_rd_as_seconds() on 2036-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743400,
  0,
  0
]
, 'utc_rd_values() on 2036-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2036-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2036-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-12 Gregorian' );
Sunday 21 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229846400, 'utc_rd_as_seconds() on 2036-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743401,
  0,
  0
]
, 'utc_rd_values() on 2036-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2036-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2036-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-13 Gregorian' );
Monday 22 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64229932800, 'utc_rd_as_seconds() on 2036-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743402,
  0,
  0
]
, 'utc_rd_values() on 2036-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2036-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2036-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-14 Gregorian' );
Trewsday 23 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230019200, 'utc_rd_as_seconds() on 2036-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743403,
  0,
  0
]
, 'utc_rd_values() on 2036-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2036-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2036-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-15 Gregorian' );
Hevensday 24 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230105600, 'utc_rd_as_seconds() on 2036-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743404,
  0,
  0
]
, 'utc_rd_values() on 2036-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2036-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2036-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-16 Gregorian' );
Mersday 25 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230192000, 'utc_rd_as_seconds() on 2036-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743405,
  0,
  0
]
, 'utc_rd_values() on 2036-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2036-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2036-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-17 Gregorian' );
Highday 26 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230278400, 'utc_rd_as_seconds() on 2036-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743406,
  0,
  0
]
, 'utc_rd_values() on 2036-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  21
]
, 'week() on 2036-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2036-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2036-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2036-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-18 Gregorian' );
Sterday 27 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230364800, 'utc_rd_as_seconds() on 2036-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743407,
  0,
  0
]
, 'utc_rd_values() on 2036-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2036-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2036-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-19 Gregorian' );
Sunday 28 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230451200, 'utc_rd_as_seconds() on 2036-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743408,
  0,
  0
]
, 'utc_rd_values() on 2036-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2036-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2036-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-20 Gregorian' );
Monday 29 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230537600, 'utc_rd_as_seconds() on 2036-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743409,
  0,
  0
]
, 'utc_rd_values() on 2036-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2036-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2036-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2036-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2036-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-21 Gregorian' );
Trewsday 30 Thrimidge 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230624000, 'utc_rd_as_seconds() on 2036-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743410,
  0,
  0
]
, 'utc_rd_values() on 2036-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2036-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2036-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-22 Gregorian' );
Hevensday 1 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230710400, 'utc_rd_as_seconds() on 2036-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743411,
  0,
  0
]
, 'utc_rd_values() on 2036-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2036-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2036-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-23 Gregorian' );
Mersday 2 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230796800, 'utc_rd_as_seconds() on 2036-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743412,
  0,
  0
]
, 'utc_rd_values() on 2036-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2036-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2036-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-24 Gregorian' );
Highday 3 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230883200, 'utc_rd_as_seconds() on 2036-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743413,
  0,
  0
]
, 'utc_rd_values() on 2036-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  22
]
, 'week() on 2036-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2036-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2036-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2036-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-25 Gregorian' );
Sterday 4 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64230969600, 'utc_rd_as_seconds() on 2036-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743414,
  0,
  0
]
, 'utc_rd_values() on 2036-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2036-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2036-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-26 Gregorian' );
Sunday 5 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231056000, 'utc_rd_as_seconds() on 2036-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743415,
  0,
  0
]
, 'utc_rd_values() on 2036-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2036-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2036-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-27 Gregorian' );
Monday 6 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231142400, 'utc_rd_as_seconds() on 2036-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743416,
  0,
  0
]
, 'utc_rd_values() on 2036-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2036-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2036-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-28 Gregorian' );
Trewsday 7 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231228800, 'utc_rd_as_seconds() on 2036-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743417,
  0,
  0
]
, 'utc_rd_values() on 2036-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2036-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2036-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-29 Gregorian' );
Hevensday 8 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231315200, 'utc_rd_as_seconds() on 2036-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743418,
  0,
  0
]
, 'utc_rd_values() on 2036-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2036-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2036-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-30 Gregorian' );
Mersday 9 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231401600, 'utc_rd_as_seconds() on 2036-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743419,
  0,
  0
]
, 'utc_rd_values() on 2036-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2036-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2036-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-05-31 Gregorian' );
Highday 10 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231488000, 'utc_rd_as_seconds() on 2036-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743420,
  0,
  0
]
, 'utc_rd_values() on 2036-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  23
]
, 'week() on 2036-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2036-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2036-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2036-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-01 Gregorian' );
Sterday 11 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231574400, 'utc_rd_as_seconds() on 2036-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743421,
  0,
  0
]
, 'utc_rd_values() on 2036-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2036-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2036-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-02 Gregorian' );
Sunday 12 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231660800, 'utc_rd_as_seconds() on 2036-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743422,
  0,
  0
]
, 'utc_rd_values() on 2036-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2036-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2036-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-03 Gregorian' );
Monday 13 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231747200, 'utc_rd_as_seconds() on 2036-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743423,
  0,
  0
]
, 'utc_rd_values() on 2036-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2036-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2036-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-04 Gregorian' );
Trewsday 14 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231833600, 'utc_rd_as_seconds() on 2036-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743424,
  0,
  0
]
, 'utc_rd_values() on 2036-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2036-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2036-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-05 Gregorian' );
Hevensday 15 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64231920000, 'utc_rd_as_seconds() on 2036-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743425,
  0,
  0
]
, 'utc_rd_values() on 2036-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2036-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2036-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-06 Gregorian' );
Mersday 16 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232006400, 'utc_rd_as_seconds() on 2036-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743426,
  0,
  0
]
, 'utc_rd_values() on 2036-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2036-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2036-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-07 Gregorian' );
Highday 17 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232092800, 'utc_rd_as_seconds() on 2036-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743427,
  0,
  0
]
, 'utc_rd_values() on 2036-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  24
]
, 'week() on 2036-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2036-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2036-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2036-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-08 Gregorian' );
Sterday 18 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232179200, 'utc_rd_as_seconds() on 2036-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743428,
  0,
  0
]
, 'utc_rd_values() on 2036-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2036-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2036-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-09 Gregorian' );
Sunday 19 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232265600, 'utc_rd_as_seconds() on 2036-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743429,
  0,
  0
]
, 'utc_rd_values() on 2036-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2036-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2036-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-10 Gregorian' );
Monday 20 Forelithe 7500

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232352000, 'utc_rd_as_seconds() on 2036-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743430,
  0,
  0
]
, 'utc_rd_values() on 2036-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2036-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2036-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-11 Gregorian' );
Trewsday 21 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232438400, 'utc_rd_as_seconds() on 2036-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743431,
  0,
  0
]
, 'utc_rd_values() on 2036-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2036-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2036-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-12 Gregorian' );
Hevensday 22 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232524800, 'utc_rd_as_seconds() on 2036-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743432,
  0,
  0
]
, 'utc_rd_values() on 2036-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2036-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2036-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-13 Gregorian' );
Mersday 23 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232611200, 'utc_rd_as_seconds() on 2036-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743433,
  0,
  0
]
, 'utc_rd_values() on 2036-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2036-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2036-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-14 Gregorian' );
Highday 24 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232697600, 'utc_rd_as_seconds() on 2036-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743434,
  0,
  0
]
, 'utc_rd_values() on 2036-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  25
]
, 'week() on 2036-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2036-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2036-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2036-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-15 Gregorian' );
Sterday 25 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232784000, 'utc_rd_as_seconds() on 2036-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743435,
  0,
  0
]
, 'utc_rd_values() on 2036-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2036-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2036-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-16 Gregorian' );
Sunday 26 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232870400, 'utc_rd_as_seconds() on 2036-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743436,
  0,
  0
]
, 'utc_rd_values() on 2036-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2036-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2036-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-17 Gregorian' );
Monday 27 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64232956800, 'utc_rd_as_seconds() on 2036-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743437,
  0,
  0
]
, 'utc_rd_values() on 2036-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2036-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2036-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-18 Gregorian' );
Trewsday 28 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233043200, 'utc_rd_as_seconds() on 2036-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743438,
  0,
  0
]
, 'utc_rd_values() on 2036-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2036-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2036-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-19 Gregorian' );
Hevensday 29 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233129600, 'utc_rd_as_seconds() on 2036-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743439,
  0,
  0
]
, 'utc_rd_values() on 2036-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2036-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2036-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2036-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2036-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-20 Gregorian' );
Mersday 30 Forelithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233216000, 'utc_rd_as_seconds() on 2036-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743440,
  0,
  0
]
, 'utc_rd_values() on 2036-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2036-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2036-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2036-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2036-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2036-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2036-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2036-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2036-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2036-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-21 Gregorian' );
Highday 1 Lithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233302400, 'utc_rd_as_seconds() on 2036-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743441,
  0,
  0
]
, 'utc_rd_values() on 2036-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  26
]
, 'week() on 2036-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2036-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2036-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2036-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2036-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2036-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2036-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2036-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2036-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2036-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2036-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2036-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2036-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2036-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2036-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-22 Gregorian' );
Midyear's day 7500

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233388800, 'utc_rd_as_seconds() on 2036-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743442,
  0,
  0
]
, 'utc_rd_values() on 2036-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2036-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  0
]
, 'week() on 2036-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2036-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2036-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2036-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2036-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2036-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2036-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2036-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2036-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2036-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2036-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-23 Gregorian' );
Sterday 2 Lithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233475200, 'utc_rd_as_seconds() on 2036-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743443,
  0,
  0
]
, 'utc_rd_values() on 2036-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2036-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2036-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-24 Gregorian' );
Sunday 1 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233561600, 'utc_rd_as_seconds() on 2036-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743444,
  0,
  0
]
, 'utc_rd_values() on 2036-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2036-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2036-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-25 Gregorian' );
Monday 2 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233648000, 'utc_rd_as_seconds() on 2036-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743445,
  0,
  0
]
, 'utc_rd_values() on 2036-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2036-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2036-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-26 Gregorian' );
Trewsday 3 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233734400, 'utc_rd_as_seconds() on 2036-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743446,
  0,
  0
]
, 'utc_rd_values() on 2036-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2036-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2036-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-27 Gregorian' );
Hevensday 4 Afterlithe 7500

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233820800, 'utc_rd_as_seconds() on 2036-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743447,
  0,
  0
]
, 'utc_rd_values() on 2036-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2036-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2036-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-28 Gregorian' );
Mersday 5 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233907200, 'utc_rd_as_seconds() on 2036-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743448,
  0,
  0
]
, 'utc_rd_values() on 2036-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2036-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2036-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-29 Gregorian' );
Highday 6 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64233993600, 'utc_rd_as_seconds() on 2036-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743449,
  0,
  0
]
, 'utc_rd_values() on 2036-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  27
]
, 'week() on 2036-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2036-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2036-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2036-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-06-30 Gregorian' );
Sterday 7 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234080000, 'utc_rd_as_seconds() on 2036-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743450,
  0,
  0
]
, 'utc_rd_values() on 2036-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2036-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2036-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-01 Gregorian' );
Sunday 8 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234166400, 'utc_rd_as_seconds() on 2036-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743451,
  0,
  0
]
, 'utc_rd_values() on 2036-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2036-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2036-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-02 Gregorian' );
Monday 9 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234252800, 'utc_rd_as_seconds() on 2036-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743452,
  0,
  0
]
, 'utc_rd_values() on 2036-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2036-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2036-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-03 Gregorian' );
Trewsday 10 Afterlithe 7500

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234339200, 'utc_rd_as_seconds() on 2036-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743453,
  0,
  0
]
, 'utc_rd_values() on 2036-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2036-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2036-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-04 Gregorian' );
Hevensday 11 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234425600, 'utc_rd_as_seconds() on 2036-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743454,
  0,
  0
]
, 'utc_rd_values() on 2036-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2036-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2036-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-05 Gregorian' );
Mersday 12 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234512000, 'utc_rd_as_seconds() on 2036-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743455,
  0,
  0
]
, 'utc_rd_values() on 2036-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2036-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2036-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-06 Gregorian' );
Highday 13 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234598400, 'utc_rd_as_seconds() on 2036-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743456,
  0,
  0
]
, 'utc_rd_values() on 2036-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  28
]
, 'week() on 2036-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2036-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2036-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2036-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-07 Gregorian' );
Sterday 14 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234684800, 'utc_rd_as_seconds() on 2036-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743457,
  0,
  0
]
, 'utc_rd_values() on 2036-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2036-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2036-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-08 Gregorian' );
Sunday 15 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234771200, 'utc_rd_as_seconds() on 2036-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743458,
  0,
  0
]
, 'utc_rd_values() on 2036-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2036-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2036-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-09 Gregorian' );
Monday 16 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234857600, 'utc_rd_as_seconds() on 2036-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743459,
  0,
  0
]
, 'utc_rd_values() on 2036-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2036-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2036-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-10 Gregorian' );
Trewsday 17 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64234944000, 'utc_rd_as_seconds() on 2036-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743460,
  0,
  0
]
, 'utc_rd_values() on 2036-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2036-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2036-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-11 Gregorian' );
Hevensday 18 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235030400, 'utc_rd_as_seconds() on 2036-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743461,
  0,
  0
]
, 'utc_rd_values() on 2036-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2036-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2036-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-12 Gregorian' );
Mersday 19 Afterlithe 7500

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235116800, 'utc_rd_as_seconds() on 2036-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743462,
  0,
  0
]
, 'utc_rd_values() on 2036-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2036-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2036-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-13 Gregorian' );
Highday 20 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235203200, 'utc_rd_as_seconds() on 2036-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743463,
  0,
  0
]
, 'utc_rd_values() on 2036-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  29
]
, 'week() on 2036-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2036-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2036-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2036-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-14 Gregorian' );
Sterday 21 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235289600, 'utc_rd_as_seconds() on 2036-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743464,
  0,
  0
]
, 'utc_rd_values() on 2036-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2036-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2036-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-15 Gregorian' );
Sunday 22 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235376000, 'utc_rd_as_seconds() on 2036-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743465,
  0,
  0
]
, 'utc_rd_values() on 2036-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2036-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2036-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-16 Gregorian' );
Monday 23 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235462400, 'utc_rd_as_seconds() on 2036-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743466,
  0,
  0
]
, 'utc_rd_values() on 2036-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2036-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2036-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-17 Gregorian' );
Trewsday 24 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235548800, 'utc_rd_as_seconds() on 2036-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743467,
  0,
  0
]
, 'utc_rd_values() on 2036-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2036-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2036-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-18 Gregorian' );
Hevensday 25 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235635200, 'utc_rd_as_seconds() on 2036-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743468,
  0,
  0
]
, 'utc_rd_values() on 2036-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2036-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2036-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-19 Gregorian' );
Mersday 26 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235721600, 'utc_rd_as_seconds() on 2036-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743469,
  0,
  0
]
, 'utc_rd_values() on 2036-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2036-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2036-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-20 Gregorian' );
Highday 27 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235808000, 'utc_rd_as_seconds() on 2036-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743470,
  0,
  0
]
, 'utc_rd_values() on 2036-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  30
]
, 'week() on 2036-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2036-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2036-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2036-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-21 Gregorian' );
Sterday 28 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235894400, 'utc_rd_as_seconds() on 2036-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743471,
  0,
  0
]
, 'utc_rd_values() on 2036-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2036-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2036-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-22 Gregorian' );
Sunday 29 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64235980800, 'utc_rd_as_seconds() on 2036-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743472,
  0,
  0
]
, 'utc_rd_values() on 2036-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2036-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2036-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2036-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2036-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-23 Gregorian' );
Monday 30 Afterlithe 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236067200, 'utc_rd_as_seconds() on 2036-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743473,
  0,
  0
]
, 'utc_rd_values() on 2036-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2036-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2036-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-24 Gregorian' );
Trewsday 1 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236153600, 'utc_rd_as_seconds() on 2036-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743474,
  0,
  0
]
, 'utc_rd_values() on 2036-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2036-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2036-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-25 Gregorian' );
Hevensday 2 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236240000, 'utc_rd_as_seconds() on 2036-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743475,
  0,
  0
]
, 'utc_rd_values() on 2036-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2036-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2036-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-26 Gregorian' );
Mersday 3 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236326400, 'utc_rd_as_seconds() on 2036-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743476,
  0,
  0
]
, 'utc_rd_values() on 2036-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2036-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2036-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-27 Gregorian' );
Highday 4 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236412800, 'utc_rd_as_seconds() on 2036-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743477,
  0,
  0
]
, 'utc_rd_values() on 2036-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  31
]
, 'week() on 2036-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2036-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2036-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2036-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-28 Gregorian' );
Sterday 5 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236499200, 'utc_rd_as_seconds() on 2036-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743478,
  0,
  0
]
, 'utc_rd_values() on 2036-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2036-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2036-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-29 Gregorian' );
Sunday 6 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236585600, 'utc_rd_as_seconds() on 2036-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743479,
  0,
  0
]
, 'utc_rd_values() on 2036-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2036-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2036-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-30 Gregorian' );
Monday 7 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236672000, 'utc_rd_as_seconds() on 2036-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743480,
  0,
  0
]
, 'utc_rd_values() on 2036-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2036-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2036-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-07-31 Gregorian' );
Trewsday 8 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236758400, 'utc_rd_as_seconds() on 2036-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743481,
  0,
  0
]
, 'utc_rd_values() on 2036-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2036-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2036-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-01 Gregorian' );
Hevensday 9 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236844800, 'utc_rd_as_seconds() on 2036-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743482,
  0,
  0
]
, 'utc_rd_values() on 2036-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2036-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2036-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-02 Gregorian' );
Mersday 10 Wedmath 7500

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64236931200, 'utc_rd_as_seconds() on 2036-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743483,
  0,
  0
]
, 'utc_rd_values() on 2036-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2036-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2036-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-03 Gregorian' );
Highday 11 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237017600, 'utc_rd_as_seconds() on 2036-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743484,
  0,
  0
]
, 'utc_rd_values() on 2036-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  32
]
, 'week() on 2036-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2036-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2036-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2036-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-04 Gregorian' );
Sterday 12 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237104000, 'utc_rd_as_seconds() on 2036-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743485,
  0,
  0
]
, 'utc_rd_values() on 2036-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2036-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2036-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-05 Gregorian' );
Sunday 13 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237190400, 'utc_rd_as_seconds() on 2036-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743486,
  0,
  0
]
, 'utc_rd_values() on 2036-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2036-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2036-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-06 Gregorian' );
Monday 14 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237276800, 'utc_rd_as_seconds() on 2036-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743487,
  0,
  0
]
, 'utc_rd_values() on 2036-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2036-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2036-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-07 Gregorian' );
Trewsday 15 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237363200, 'utc_rd_as_seconds() on 2036-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743488,
  0,
  0
]
, 'utc_rd_values() on 2036-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2036-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2036-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-08 Gregorian' );
Hevensday 16 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237449600, 'utc_rd_as_seconds() on 2036-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743489,
  0,
  0
]
, 'utc_rd_values() on 2036-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2036-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2036-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-09 Gregorian' );
Mersday 17 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237536000, 'utc_rd_as_seconds() on 2036-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743490,
  0,
  0
]
, 'utc_rd_values() on 2036-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2036-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2036-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-10 Gregorian' );
Highday 18 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237622400, 'utc_rd_as_seconds() on 2036-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743491,
  0,
  0
]
, 'utc_rd_values() on 2036-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  33
]
, 'week() on 2036-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2036-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2036-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2036-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-11 Gregorian' );
Sterday 19 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237708800, 'utc_rd_as_seconds() on 2036-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743492,
  0,
  0
]
, 'utc_rd_values() on 2036-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2036-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2036-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-12 Gregorian' );
Sunday 20 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237795200, 'utc_rd_as_seconds() on 2036-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743493,
  0,
  0
]
, 'utc_rd_values() on 2036-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2036-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2036-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-13 Gregorian' );
Monday 21 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237881600, 'utc_rd_as_seconds() on 2036-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743494,
  0,
  0
]
, 'utc_rd_values() on 2036-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2036-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2036-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-14 Gregorian' );
Trewsday 22 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64237968000, 'utc_rd_as_seconds() on 2036-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743495,
  0,
  0
]
, 'utc_rd_values() on 2036-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2036-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2036-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-15 Gregorian' );
Hevensday 23 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238054400, 'utc_rd_as_seconds() on 2036-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743496,
  0,
  0
]
, 'utc_rd_values() on 2036-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2036-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2036-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-16 Gregorian' );
Mersday 24 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238140800, 'utc_rd_as_seconds() on 2036-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743497,
  0,
  0
]
, 'utc_rd_values() on 2036-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2036-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2036-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-17 Gregorian' );
Highday 25 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238227200, 'utc_rd_as_seconds() on 2036-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743498,
  0,
  0
]
, 'utc_rd_values() on 2036-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  34
]
, 'week() on 2036-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2036-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2036-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2036-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-18 Gregorian' );
Sterday 26 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238313600, 'utc_rd_as_seconds() on 2036-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743499,
  0,
  0
]
, 'utc_rd_values() on 2036-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2036-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2036-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-19 Gregorian' );
Sunday 27 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238400000, 'utc_rd_as_seconds() on 2036-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743500,
  0,
  0
]
, 'utc_rd_values() on 2036-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2036-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2036-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-20 Gregorian' );
Monday 28 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238486400, 'utc_rd_as_seconds() on 2036-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743501,
  0,
  0
]
, 'utc_rd_values() on 2036-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2036-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2036-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-21 Gregorian' );
Trewsday 29 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238572800, 'utc_rd_as_seconds() on 2036-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743502,
  0,
  0
]
, 'utc_rd_values() on 2036-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2036-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2036-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2036-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2036-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-22 Gregorian' );
Hevensday 30 Wedmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238659200, 'utc_rd_as_seconds() on 2036-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743503,
  0,
  0
]
, 'utc_rd_values() on 2036-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2036-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2036-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-23 Gregorian' );
Mersday 1 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238745600, 'utc_rd_as_seconds() on 2036-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743504,
  0,
  0
]
, 'utc_rd_values() on 2036-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2036-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2036-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-24 Gregorian' );
Highday 2 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238832000, 'utc_rd_as_seconds() on 2036-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743505,
  0,
  0
]
, 'utc_rd_values() on 2036-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  35
]
, 'week() on 2036-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2036-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2036-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2036-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-25 Gregorian' );
Sterday 3 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64238918400, 'utc_rd_as_seconds() on 2036-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743506,
  0,
  0
]
, 'utc_rd_values() on 2036-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2036-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2036-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-26 Gregorian' );
Sunday 4 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239004800, 'utc_rd_as_seconds() on 2036-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743507,
  0,
  0
]
, 'utc_rd_values() on 2036-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2036-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2036-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-27 Gregorian' );
Monday 5 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239091200, 'utc_rd_as_seconds() on 2036-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743508,
  0,
  0
]
, 'utc_rd_values() on 2036-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2036-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2036-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-28 Gregorian' );
Trewsday 6 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239177600, 'utc_rd_as_seconds() on 2036-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743509,
  0,
  0
]
, 'utc_rd_values() on 2036-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2036-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2036-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-29 Gregorian' );
Hevensday 7 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239264000, 'utc_rd_as_seconds() on 2036-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743510,
  0,
  0
]
, 'utc_rd_values() on 2036-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2036-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2036-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-30 Gregorian' );
Mersday 8 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239350400, 'utc_rd_as_seconds() on 2036-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743511,
  0,
  0
]
, 'utc_rd_values() on 2036-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2036-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2036-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-08-31 Gregorian' );
Highday 9 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239436800, 'utc_rd_as_seconds() on 2036-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743512,
  0,
  0
]
, 'utc_rd_values() on 2036-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  36
]
, 'week() on 2036-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2036-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2036-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2036-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-01 Gregorian' );
Sterday 10 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239523200, 'utc_rd_as_seconds() on 2036-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743513,
  0,
  0
]
, 'utc_rd_values() on 2036-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2036-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2036-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-02 Gregorian' );
Sunday 11 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239609600, 'utc_rd_as_seconds() on 2036-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743514,
  0,
  0
]
, 'utc_rd_values() on 2036-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2036-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2036-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-03 Gregorian' );
Monday 12 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239696000, 'utc_rd_as_seconds() on 2036-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743515,
  0,
  0
]
, 'utc_rd_values() on 2036-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2036-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2036-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-04 Gregorian' );
Trewsday 13 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239782400, 'utc_rd_as_seconds() on 2036-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743516,
  0,
  0
]
, 'utc_rd_values() on 2036-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2036-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2036-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-05 Gregorian' );
Hevensday 14 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239868800, 'utc_rd_as_seconds() on 2036-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743517,
  0,
  0
]
, 'utc_rd_values() on 2036-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2036-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2036-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-06 Gregorian' );
Mersday 15 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64239955200, 'utc_rd_as_seconds() on 2036-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743518,
  0,
  0
]
, 'utc_rd_values() on 2036-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2036-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2036-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-07 Gregorian' );
Highday 16 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240041600, 'utc_rd_as_seconds() on 2036-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743519,
  0,
  0
]
, 'utc_rd_values() on 2036-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  37
]
, 'week() on 2036-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2036-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2036-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2036-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-08 Gregorian' );
Sterday 17 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240128000, 'utc_rd_as_seconds() on 2036-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743520,
  0,
  0
]
, 'utc_rd_values() on 2036-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2036-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2036-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-09 Gregorian' );
Sunday 18 Halimath 7500

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240214400, 'utc_rd_as_seconds() on 2036-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743521,
  0,
  0
]
, 'utc_rd_values() on 2036-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2036-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2036-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-10 Gregorian' );
Monday 19 Halimath 7500

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240300800, 'utc_rd_as_seconds() on 2036-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743522,
  0,
  0
]
, 'utc_rd_values() on 2036-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2036-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2036-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-11 Gregorian' );
Trewsday 20 Halimath 7500

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240387200, 'utc_rd_as_seconds() on 2036-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743523,
  0,
  0
]
, 'utc_rd_values() on 2036-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2036-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2036-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-12 Gregorian' );
Hevensday 21 Halimath 7500

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240473600, 'utc_rd_as_seconds() on 2036-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743524,
  0,
  0
]
, 'utc_rd_values() on 2036-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2036-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2036-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-13 Gregorian' );
Mersday 22 Halimath 7500

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240560000, 'utc_rd_as_seconds() on 2036-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743525,
  0,
  0
]
, 'utc_rd_values() on 2036-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2036-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2036-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-14 Gregorian' );
Highday 23 Halimath 7500

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240646400, 'utc_rd_as_seconds() on 2036-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743526,
  0,
  0
]
, 'utc_rd_values() on 2036-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  38
]
, 'week() on 2036-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2036-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2036-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2036-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-15 Gregorian' );
Sterday 24 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240732800, 'utc_rd_as_seconds() on 2036-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743527,
  0,
  0
]
, 'utc_rd_values() on 2036-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2036-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2036-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-16 Gregorian' );
Sunday 25 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240819200, 'utc_rd_as_seconds() on 2036-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743528,
  0,
  0
]
, 'utc_rd_values() on 2036-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2036-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2036-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-17 Gregorian' );
Monday 26 Halimath 7500

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240905600, 'utc_rd_as_seconds() on 2036-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743529,
  0,
  0
]
, 'utc_rd_values() on 2036-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2036-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2036-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-18 Gregorian' );
Trewsday 27 Halimath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64240992000, 'utc_rd_as_seconds() on 2036-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743530,
  0,
  0
]
, 'utc_rd_values() on 2036-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2036-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2036-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-19 Gregorian' );
Hevensday 28 Halimath 7500

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241078400, 'utc_rd_as_seconds() on 2036-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743531,
  0,
  0
]
, 'utc_rd_values() on 2036-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2036-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2036-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-20 Gregorian' );
Mersday 29 Halimath 7500

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241164800, 'utc_rd_as_seconds() on 2036-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743532,
  0,
  0
]
, 'utc_rd_values() on 2036-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2036-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2036-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2036-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2036-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-21 Gregorian' );
Highday 30 Halimath 7500

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241251200, 'utc_rd_as_seconds() on 2036-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743533,
  0,
  0
]
, 'utc_rd_values() on 2036-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  39
]
, 'week() on 2036-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2036-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2036-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2036-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-22 Gregorian' );
Sterday 1 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241337600, 'utc_rd_as_seconds() on 2036-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743534,
  0,
  0
]
, 'utc_rd_values() on 2036-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2036-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2036-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-23 Gregorian' );
Sunday 2 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241424000, 'utc_rd_as_seconds() on 2036-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743535,
  0,
  0
]
, 'utc_rd_values() on 2036-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2036-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2036-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-24 Gregorian' );
Monday 3 Winterfilth 7500

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241510400, 'utc_rd_as_seconds() on 2036-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743536,
  0,
  0
]
, 'utc_rd_values() on 2036-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2036-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2036-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-25 Gregorian' );
Trewsday 4 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241596800, 'utc_rd_as_seconds() on 2036-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743537,
  0,
  0
]
, 'utc_rd_values() on 2036-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2036-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2036-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-26 Gregorian' );
Hevensday 5 Winterfilth 7500

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241683200, 'utc_rd_as_seconds() on 2036-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743538,
  0,
  0
]
, 'utc_rd_values() on 2036-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2036-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2036-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-27 Gregorian' );
Mersday 6 Winterfilth 7500

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241769600, 'utc_rd_as_seconds() on 2036-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743539,
  0,
  0
]
, 'utc_rd_values() on 2036-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2036-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2036-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-28 Gregorian' );
Highday 7 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241856000, 'utc_rd_as_seconds() on 2036-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743540,
  0,
  0
]
, 'utc_rd_values() on 2036-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  40
]
, 'week() on 2036-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2036-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2036-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2036-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-29 Gregorian' );
Sterday 8 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64241942400, 'utc_rd_as_seconds() on 2036-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743541,
  0,
  0
]
, 'utc_rd_values() on 2036-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2036-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2036-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-09-30 Gregorian' );
Sunday 9 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242028800, 'utc_rd_as_seconds() on 2036-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743542,
  0,
  0
]
, 'utc_rd_values() on 2036-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2036-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2036-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-01 Gregorian' );
Monday 10 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242115200, 'utc_rd_as_seconds() on 2036-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743543,
  0,
  0
]
, 'utc_rd_values() on 2036-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2036-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2036-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-02 Gregorian' );
Trewsday 11 Winterfilth 7500

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242201600, 'utc_rd_as_seconds() on 2036-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743544,
  0,
  0
]
, 'utc_rd_values() on 2036-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2036-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2036-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-03 Gregorian' );
Hevensday 12 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242288000, 'utc_rd_as_seconds() on 2036-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743545,
  0,
  0
]
, 'utc_rd_values() on 2036-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2036-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2036-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-04 Gregorian' );
Mersday 13 Winterfilth 7500

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242374400, 'utc_rd_as_seconds() on 2036-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743546,
  0,
  0
]
, 'utc_rd_values() on 2036-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2036-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2036-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-05 Gregorian' );
Highday 14 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242460800, 'utc_rd_as_seconds() on 2036-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743547,
  0,
  0
]
, 'utc_rd_values() on 2036-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  41
]
, 'week() on 2036-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2036-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2036-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2036-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-06 Gregorian' );
Sterday 15 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242547200, 'utc_rd_as_seconds() on 2036-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743548,
  0,
  0
]
, 'utc_rd_values() on 2036-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2036-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2036-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-07 Gregorian' );
Sunday 16 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242633600, 'utc_rd_as_seconds() on 2036-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743549,
  0,
  0
]
, 'utc_rd_values() on 2036-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2036-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2036-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-08 Gregorian' );
Monday 17 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242720000, 'utc_rd_as_seconds() on 2036-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743550,
  0,
  0
]
, 'utc_rd_values() on 2036-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2036-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2036-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-09 Gregorian' );
Trewsday 18 Winterfilth 7500

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242806400, 'utc_rd_as_seconds() on 2036-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743551,
  0,
  0
]
, 'utc_rd_values() on 2036-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2036-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2036-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-10 Gregorian' );
Hevensday 19 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242892800, 'utc_rd_as_seconds() on 2036-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743552,
  0,
  0
]
, 'utc_rd_values() on 2036-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2036-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2036-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-11 Gregorian' );
Mersday 20 Winterfilth 7500

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64242979200, 'utc_rd_as_seconds() on 2036-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743553,
  0,
  0
]
, 'utc_rd_values() on 2036-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2036-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2036-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-12 Gregorian' );
Highday 21 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243065600, 'utc_rd_as_seconds() on 2036-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743554,
  0,
  0
]
, 'utc_rd_values() on 2036-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  42
]
, 'week() on 2036-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2036-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2036-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2036-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-13 Gregorian' );
Sterday 22 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243152000, 'utc_rd_as_seconds() on 2036-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743555,
  0,
  0
]
, 'utc_rd_values() on 2036-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2036-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2036-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-14 Gregorian' );
Sunday 23 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243238400, 'utc_rd_as_seconds() on 2036-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743556,
  0,
  0
]
, 'utc_rd_values() on 2036-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2036-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2036-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-15 Gregorian' );
Monday 24 Winterfilth 7500

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243324800, 'utc_rd_as_seconds() on 2036-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743557,
  0,
  0
]
, 'utc_rd_values() on 2036-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2036-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2036-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-16 Gregorian' );
Trewsday 25 Winterfilth 7500

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243411200, 'utc_rd_as_seconds() on 2036-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743558,
  0,
  0
]
, 'utc_rd_values() on 2036-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2036-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2036-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-17 Gregorian' );
Hevensday 26 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243497600, 'utc_rd_as_seconds() on 2036-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743559,
  0,
  0
]
, 'utc_rd_values() on 2036-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2036-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2036-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-18 Gregorian' );
Mersday 27 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243584000, 'utc_rd_as_seconds() on 2036-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743560,
  0,
  0
]
, 'utc_rd_values() on 2036-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2036-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2036-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-19 Gregorian' );
Highday 28 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243670400, 'utc_rd_as_seconds() on 2036-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743561,
  0,
  0
]
, 'utc_rd_values() on 2036-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  43
]
, 'week() on 2036-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2036-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2036-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2036-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-20 Gregorian' );
Sterday 29 Winterfilth 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243756800, 'utc_rd_as_seconds() on 2036-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743562,
  0,
  0
]
, 'utc_rd_values() on 2036-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2036-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2036-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2036-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2036-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-21 Gregorian' );
Sunday 30 Winterfilth 7500

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243843200, 'utc_rd_as_seconds() on 2036-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743563,
  0,
  0
]
, 'utc_rd_values() on 2036-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2036-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2036-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-22 Gregorian' );
Monday 1 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64243929600, 'utc_rd_as_seconds() on 2036-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743564,
  0,
  0
]
, 'utc_rd_values() on 2036-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2036-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2036-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-23 Gregorian' );
Trewsday 2 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244016000, 'utc_rd_as_seconds() on 2036-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743565,
  0,
  0
]
, 'utc_rd_values() on 2036-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2036-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2036-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-24 Gregorian' );
Hevensday 3 Blotmath 7500

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244102400, 'utc_rd_as_seconds() on 2036-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743566,
  0,
  0
]
, 'utc_rd_values() on 2036-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2036-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2036-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-25 Gregorian' );
Mersday 4 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244188800, 'utc_rd_as_seconds() on 2036-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743567,
  0,
  0
]
, 'utc_rd_values() on 2036-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2036-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2036-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-26 Gregorian' );
Highday 5 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244275200, 'utc_rd_as_seconds() on 2036-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743568,
  0,
  0
]
, 'utc_rd_values() on 2036-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  44
]
, 'week() on 2036-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2036-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2036-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2036-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-27 Gregorian' );
Sterday 6 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244361600, 'utc_rd_as_seconds() on 2036-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743569,
  0,
  0
]
, 'utc_rd_values() on 2036-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2036-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2036-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-28 Gregorian' );
Sunday 7 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244448000, 'utc_rd_as_seconds() on 2036-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743570,
  0,
  0
]
, 'utc_rd_values() on 2036-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2036-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2036-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-29 Gregorian' );
Monday 8 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244534400, 'utc_rd_as_seconds() on 2036-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743571,
  0,
  0
]
, 'utc_rd_values() on 2036-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2036-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2036-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-30 Gregorian' );
Trewsday 9 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244620800, 'utc_rd_as_seconds() on 2036-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743572,
  0,
  0
]
, 'utc_rd_values() on 2036-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2036-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2036-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-10-31 Gregorian' );
Hevensday 10 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244707200, 'utc_rd_as_seconds() on 2036-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743573,
  0,
  0
]
, 'utc_rd_values() on 2036-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2036-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2036-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-01 Gregorian' );
Mersday 11 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244793600, 'utc_rd_as_seconds() on 2036-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743574,
  0,
  0
]
, 'utc_rd_values() on 2036-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2036-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2036-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-02 Gregorian' );
Highday 12 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244880000, 'utc_rd_as_seconds() on 2036-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743575,
  0,
  0
]
, 'utc_rd_values() on 2036-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  45
]
, 'week() on 2036-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2036-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2036-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2036-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-03 Gregorian' );
Sterday 13 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64244966400, 'utc_rd_as_seconds() on 2036-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743576,
  0,
  0
]
, 'utc_rd_values() on 2036-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2036-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2036-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-04 Gregorian' );
Sunday 14 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245052800, 'utc_rd_as_seconds() on 2036-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743577,
  0,
  0
]
, 'utc_rd_values() on 2036-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2036-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2036-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-05 Gregorian' );
Monday 15 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245139200, 'utc_rd_as_seconds() on 2036-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743578,
  0,
  0
]
, 'utc_rd_values() on 2036-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2036-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2036-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-06 Gregorian' );
Trewsday 16 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245225600, 'utc_rd_as_seconds() on 2036-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743579,
  0,
  0
]
, 'utc_rd_values() on 2036-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2036-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2036-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-07 Gregorian' );
Hevensday 17 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245312000, 'utc_rd_as_seconds() on 2036-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743580,
  0,
  0
]
, 'utc_rd_values() on 2036-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2036-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2036-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-08 Gregorian' );
Mersday 18 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245398400, 'utc_rd_as_seconds() on 2036-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743581,
  0,
  0
]
, 'utc_rd_values() on 2036-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2036-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2036-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-09 Gregorian' );
Highday 19 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245484800, 'utc_rd_as_seconds() on 2036-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743582,
  0,
  0
]
, 'utc_rd_values() on 2036-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  46
]
, 'week() on 2036-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2036-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2036-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2036-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-10 Gregorian' );
Sterday 20 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245571200, 'utc_rd_as_seconds() on 2036-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743583,
  0,
  0
]
, 'utc_rd_values() on 2036-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2036-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2036-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-11 Gregorian' );
Sunday 21 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245657600, 'utc_rd_as_seconds() on 2036-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743584,
  0,
  0
]
, 'utc_rd_values() on 2036-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2036-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2036-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-12 Gregorian' );
Monday 22 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245744000, 'utc_rd_as_seconds() on 2036-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743585,
  0,
  0
]
, 'utc_rd_values() on 2036-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2036-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2036-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-13 Gregorian' );
Trewsday 23 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245830400, 'utc_rd_as_seconds() on 2036-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743586,
  0,
  0
]
, 'utc_rd_values() on 2036-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2036-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2036-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-14 Gregorian' );
Hevensday 24 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64245916800, 'utc_rd_as_seconds() on 2036-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743587,
  0,
  0
]
, 'utc_rd_values() on 2036-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2036-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2036-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-15 Gregorian' );
Mersday 25 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246003200, 'utc_rd_as_seconds() on 2036-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743588,
  0,
  0
]
, 'utc_rd_values() on 2036-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2036-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2036-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-16 Gregorian' );
Highday 26 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246089600, 'utc_rd_as_seconds() on 2036-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743589,
  0,
  0
]
, 'utc_rd_values() on 2036-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  47
]
, 'week() on 2036-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2036-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2036-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2036-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-17 Gregorian' );
Sterday 27 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246176000, 'utc_rd_as_seconds() on 2036-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743590,
  0,
  0
]
, 'utc_rd_values() on 2036-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2036-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2036-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-18 Gregorian' );
Sunday 28 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246262400, 'utc_rd_as_seconds() on 2036-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743591,
  0,
  0
]
, 'utc_rd_values() on 2036-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2036-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2036-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-19 Gregorian' );
Monday 29 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246348800, 'utc_rd_as_seconds() on 2036-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743592,
  0,
  0
]
, 'utc_rd_values() on 2036-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2036-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2036-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2036-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2036-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-20 Gregorian' );
Trewsday 30 Blotmath 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246435200, 'utc_rd_as_seconds() on 2036-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743593,
  0,
  0
]
, 'utc_rd_values() on 2036-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2036-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2036-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-21 Gregorian' );
Hevensday 1 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246521600, 'utc_rd_as_seconds() on 2036-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743594,
  0,
  0
]
, 'utc_rd_values() on 2036-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2036-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2036-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-22 Gregorian' );
Mersday 2 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246608000, 'utc_rd_as_seconds() on 2036-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743595,
  0,
  0
]
, 'utc_rd_values() on 2036-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2036-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2036-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-23 Gregorian' );
Highday 3 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246694400, 'utc_rd_as_seconds() on 2036-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743596,
  0,
  0
]
, 'utc_rd_values() on 2036-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  48
]
, 'week() on 2036-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2036-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2036-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2036-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-24 Gregorian' );
Sterday 4 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246780800, 'utc_rd_as_seconds() on 2036-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743597,
  0,
  0
]
, 'utc_rd_values() on 2036-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2036-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2036-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-25 Gregorian' );
Sunday 5 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246867200, 'utc_rd_as_seconds() on 2036-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743598,
  0,
  0
]
, 'utc_rd_values() on 2036-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2036-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2036-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-26 Gregorian' );
Monday 6 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64246953600, 'utc_rd_as_seconds() on 2036-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743599,
  0,
  0
]
, 'utc_rd_values() on 2036-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2036-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2036-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-27 Gregorian' );
Trewsday 7 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247040000, 'utc_rd_as_seconds() on 2036-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743600,
  0,
  0
]
, 'utc_rd_values() on 2036-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2036-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2036-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-28 Gregorian' );
Hevensday 8 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247126400, 'utc_rd_as_seconds() on 2036-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743601,
  0,
  0
]
, 'utc_rd_values() on 2036-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2036-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2036-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-29 Gregorian' );
Mersday 9 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247212800, 'utc_rd_as_seconds() on 2036-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743602,
  0,
  0
]
, 'utc_rd_values() on 2036-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2036-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2036-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2036-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2036-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2036-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-11-30 Gregorian' );
Highday 10 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247299200, 'utc_rd_as_seconds() on 2036-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743603,
  0,
  0
]
, 'utc_rd_values() on 2036-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  49
]
, 'week() on 2036-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2036-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2036-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2036-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2036-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2036-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2036-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-01 Gregorian' );
Sterday 11 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247385600, 'utc_rd_as_seconds() on 2036-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743604,
  0,
  0
]
, 'utc_rd_values() on 2036-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2036-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2036-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2036-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2036-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2036-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-02 Gregorian' );
Sunday 12 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247472000, 'utc_rd_as_seconds() on 2036-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743605,
  0,
  0
]
, 'utc_rd_values() on 2036-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2036-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2036-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2036-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2036-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2036-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-03 Gregorian' );
Monday 13 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247558400, 'utc_rd_as_seconds() on 2036-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743606,
  0,
  0
]
, 'utc_rd_values() on 2036-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2036-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2036-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2036-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2036-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2036-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-04 Gregorian' );
Trewsday 14 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247644800, 'utc_rd_as_seconds() on 2036-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743607,
  0,
  0
]
, 'utc_rd_values() on 2036-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2036-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2036-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2036-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2036-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2036-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-05 Gregorian' );
Hevensday 15 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247731200, 'utc_rd_as_seconds() on 2036-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743608,
  0,
  0
]
, 'utc_rd_values() on 2036-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2036-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2036-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2036-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2036-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2036-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-06 Gregorian' );
Mersday 16 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247817600, 'utc_rd_as_seconds() on 2036-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743609,
  0,
  0
]
, 'utc_rd_values() on 2036-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2036-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2036-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2036-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2036-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2036-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-07 Gregorian' );
Highday 17 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247904000, 'utc_rd_as_seconds() on 2036-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743610,
  0,
  0
]
, 'utc_rd_values() on 2036-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  50
]
, 'week() on 2036-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2036-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2036-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2036-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2036-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2036-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2036-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-08 Gregorian' );
Sterday 18 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64247990400, 'utc_rd_as_seconds() on 2036-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743611,
  0,
  0
]
, 'utc_rd_values() on 2036-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2036-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2036-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2036-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2036-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2036-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-09 Gregorian' );
Sunday 19 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248076800, 'utc_rd_as_seconds() on 2036-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743612,
  0,
  0
]
, 'utc_rd_values() on 2036-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2036-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2036-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2036-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2036-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2036-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-10 Gregorian' );
Monday 20 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248163200, 'utc_rd_as_seconds() on 2036-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743613,
  0,
  0
]
, 'utc_rd_values() on 2036-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2036-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2036-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2036-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2036-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2036-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-11 Gregorian' );
Trewsday 21 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248249600, 'utc_rd_as_seconds() on 2036-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743614,
  0,
  0
]
, 'utc_rd_values() on 2036-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2036-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2036-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2036-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2036-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2036-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-12 Gregorian' );
Hevensday 22 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248336000, 'utc_rd_as_seconds() on 2036-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743615,
  0,
  0
]
, 'utc_rd_values() on 2036-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2036-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2036-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2036-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2036-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2036-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-13 Gregorian' );
Mersday 23 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248422400, 'utc_rd_as_seconds() on 2036-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743616,
  0,
  0
]
, 'utc_rd_values() on 2036-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2036-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2036-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2036-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2036-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2036-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-14 Gregorian' );
Highday 24 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248508800, 'utc_rd_as_seconds() on 2036-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743617,
  0,
  0
]
, 'utc_rd_values() on 2036-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  51
]
, 'week() on 2036-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2036-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2036-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2036-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2036-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2036-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2036-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-15 Gregorian' );
Sterday 25 Foreyule 7500

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248595200, 'utc_rd_as_seconds() on 2036-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743618,
  0,
  0
]
, 'utc_rd_values() on 2036-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2036-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2036-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2036-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2036-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2036-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-16 Gregorian' );
Sunday 26 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248681600, 'utc_rd_as_seconds() on 2036-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743619,
  0,
  0
]
, 'utc_rd_values() on 2036-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2036-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2036-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2036-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2036-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2036-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-17 Gregorian' );
Monday 27 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248768000, 'utc_rd_as_seconds() on 2036-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743620,
  0,
  0
]
, 'utc_rd_values() on 2036-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2036-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2036-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2036-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2036-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2036-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-18 Gregorian' );
Trewsday 28 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248854400, 'utc_rd_as_seconds() on 2036-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743621,
  0,
  0
]
, 'utc_rd_values() on 2036-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2036-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2036-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2036-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2036-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2036-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-19 Gregorian' );
Hevensday 29 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64248940800, 'utc_rd_as_seconds() on 2036-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743622,
  0,
  0
]
, 'utc_rd_values() on 2036-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2036-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2036-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2036-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2036-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2036-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2036-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2036-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-20 Gregorian' );
Mersday 30 Foreyule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249027200, 'utc_rd_as_seconds() on 2036-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743623,
  0,
  0
]
, 'utc_rd_values() on 2036-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2036-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2036-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2036-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2036-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2036-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2036-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2036-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2036-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2036-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-21 Gregorian' );
Highday 1 Yule 7500
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249113600, 'utc_rd_as_seconds() on 2036-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743624,
  0,
  0
]
, 'utc_rd_values() on 2036-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7500,
  52
]
, 'week() on 2036-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2036-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7500, 'week_year() on 2036-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7500, 'year() on 2036-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2036-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2036-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2036-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2036-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2036-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2036-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2036-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2036-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2036-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-22 Gregorian' );
Sterday 2 Yule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249200000, 'utc_rd_as_seconds() on 2036-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743625,
  0,
  0
]
, 'utc_rd_values() on 2036-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2036-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2036-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2036-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2036-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2036-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-23 Gregorian' );
Sunday 1 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249286400, 'utc_rd_as_seconds() on 2036-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743626,
  0,
  0
]
, 'utc_rd_values() on 2036-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2036-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2036-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2036-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2036-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2036-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-24 Gregorian' );
Monday 2 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249372800, 'utc_rd_as_seconds() on 2036-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743627,
  0,
  0
]
, 'utc_rd_values() on 2036-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2036-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2036-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2036-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2036-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2036-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2036-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2036-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2036-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2036-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-25 Gregorian' );
Trewsday 3 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249459200, 'utc_rd_as_seconds() on 2036-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743628,
  0,
  0
]
, 'utc_rd_values() on 2036-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2036-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2036-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2036-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2036-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2036-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2036-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2036-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2036-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2036-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2036-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-26 Gregorian' );
Hevensday 4 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249545600, 'utc_rd_as_seconds() on 2036-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743629,
  0,
  0
]
, 'utc_rd_values() on 2036-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2036-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2036-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2036-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2036-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2036-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2036-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2036-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2036-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2036-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2036-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-27 Gregorian' );
Mersday 5 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249632000, 'utc_rd_as_seconds() on 2036-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743630,
  0,
  0
]
, 'utc_rd_values() on 2036-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2036-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2036-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2036-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2036-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2036-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2036-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2036-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2036-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2036-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2036-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-28 Gregorian' );
Highday 6 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249718400, 'utc_rd_as_seconds() on 2036-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743631,
  0,
  0
]
, 'utc_rd_values() on 2036-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2036-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  1
]
, 'week() on 2036-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2036-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2036-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2036-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2036-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2036-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2036-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2036-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2036-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2036-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2036-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-29 Gregorian' );
Sterday 7 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249804800, 'utc_rd_as_seconds() on 2036-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743632,
  0,
  0
]
, 'utc_rd_values() on 2036-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2036-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2036-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2036-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2036-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2036-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2036-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2036-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2036-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2036-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2036-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2036-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-30 Gregorian' );
Sunday 8 Afteryule 7501

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249891200, 'utc_rd_as_seconds() on 2036-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743633,
  0,
  0
]
, 'utc_rd_values() on 2036-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2036-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2036-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2036 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2036,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2036-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2036-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2036-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2036-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2036-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2036-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2036-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2036-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2036-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2036-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2036-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2036-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2036-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2036-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2036-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2036-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2036-12-31 Gregorian' );
Monday 9 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64249977600, 'utc_rd_as_seconds() on 2036-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743634,
  0,
  0
]
, 'utc_rd_values() on 2036-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2036-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2036-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2036-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2036-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2036-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2037-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2037-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-01 Gregorian' );
Trewsday 10 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250064000, 'utc_rd_as_seconds() on 2037-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743635,
  0,
  0
]
, 'utc_rd_values() on 2037-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2037-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2037-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2037-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-02 Gregorian' );
Hevensday 11 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250150400, 'utc_rd_as_seconds() on 2037-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743636,
  0,
  0
]
, 'utc_rd_values() on 2037-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2037-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2037-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2037-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-03 Gregorian' );
Mersday 12 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250236800, 'utc_rd_as_seconds() on 2037-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743637,
  0,
  0
]
, 'utc_rd_values() on 2037-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2037-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2037-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2037-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-04 Gregorian' );
Highday 13 Afteryule 7501

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250323200, 'utc_rd_as_seconds() on 2037-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743638,
  0,
  0
]
, 'utc_rd_values() on 2037-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  2
]
, 'week() on 2037-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2037-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2037-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-05 Gregorian' );
Sterday 14 Afteryule 7501

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250409600, 'utc_rd_as_seconds() on 2037-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743639,
  0,
  0
]
, 'utc_rd_values() on 2037-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2037-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2037-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-06 Gregorian' );
Sunday 15 Afteryule 7501

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250496000, 'utc_rd_as_seconds() on 2037-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743640,
  0,
  0
]
, 'utc_rd_values() on 2037-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2037-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2037-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-07 Gregorian' );
Monday 16 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250582400, 'utc_rd_as_seconds() on 2037-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743641,
  0,
  0
]
, 'utc_rd_values() on 2037-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2037-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2037-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-08 Gregorian' );
Trewsday 17 Afteryule 7501

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250668800, 'utc_rd_as_seconds() on 2037-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743642,
  0,
  0
]
, 'utc_rd_values() on 2037-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2037-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2037-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-09 Gregorian' );
Hevensday 18 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250755200, 'utc_rd_as_seconds() on 2037-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743643,
  0,
  0
]
, 'utc_rd_values() on 2037-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2037-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2037-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-10 Gregorian' );
Mersday 19 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250841600, 'utc_rd_as_seconds() on 2037-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743644,
  0,
  0
]
, 'utc_rd_values() on 2037-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2037-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2037-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-11 Gregorian' );
Highday 20 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64250928000, 'utc_rd_as_seconds() on 2037-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743645,
  0,
  0
]
, 'utc_rd_values() on 2037-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  3
]
, 'week() on 2037-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2037-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2037-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2037-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-12 Gregorian' );
Sterday 21 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251014400, 'utc_rd_as_seconds() on 2037-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743646,
  0,
  0
]
, 'utc_rd_values() on 2037-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2037-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2037-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-13 Gregorian' );
Sunday 22 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251100800, 'utc_rd_as_seconds() on 2037-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743647,
  0,
  0
]
, 'utc_rd_values() on 2037-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2037-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2037-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-14 Gregorian' );
Monday 23 Afteryule 7501

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251187200, 'utc_rd_as_seconds() on 2037-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743648,
  0,
  0
]
, 'utc_rd_values() on 2037-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2037-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2037-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-15 Gregorian' );
Trewsday 24 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251273600, 'utc_rd_as_seconds() on 2037-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743649,
  0,
  0
]
, 'utc_rd_values() on 2037-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2037-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2037-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-16 Gregorian' );
Hevensday 25 Afteryule 7501

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251360000, 'utc_rd_as_seconds() on 2037-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743650,
  0,
  0
]
, 'utc_rd_values() on 2037-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2037-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2037-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-17 Gregorian' );
Mersday 26 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251446400, 'utc_rd_as_seconds() on 2037-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743651,
  0,
  0
]
, 'utc_rd_values() on 2037-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2037-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2037-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-18 Gregorian' );
Highday 27 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251532800, 'utc_rd_as_seconds() on 2037-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743652,
  0,
  0
]
, 'utc_rd_values() on 2037-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  4
]
, 'week() on 2037-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2037-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2037-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2037-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-19 Gregorian' );
Sterday 28 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251619200, 'utc_rd_as_seconds() on 2037-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743653,
  0,
  0
]
, 'utc_rd_values() on 2037-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2037-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2037-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-20 Gregorian' );
Sunday 29 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251705600, 'utc_rd_as_seconds() on 2037-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743654,
  0,
  0
]
, 'utc_rd_values() on 2037-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2037-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2037-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-21 Gregorian' );
Monday 30 Afteryule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251792000, 'utc_rd_as_seconds() on 2037-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743655,
  0,
  0
]
, 'utc_rd_values() on 2037-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2037-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2037-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-22 Gregorian' );
Trewsday 1 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251878400, 'utc_rd_as_seconds() on 2037-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743656,
  0,
  0
]
, 'utc_rd_values() on 2037-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2037-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2037-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-23 Gregorian' );
Hevensday 2 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64251964800, 'utc_rd_as_seconds() on 2037-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743657,
  0,
  0
]
, 'utc_rd_values() on 2037-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2037-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2037-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-24 Gregorian' );
Mersday 3 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252051200, 'utc_rd_as_seconds() on 2037-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743658,
  0,
  0
]
, 'utc_rd_values() on 2037-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2037-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2037-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-25 Gregorian' );
Highday 4 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252137600, 'utc_rd_as_seconds() on 2037-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743659,
  0,
  0
]
, 'utc_rd_values() on 2037-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  5
]
, 'week() on 2037-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2037-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2037-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2037-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-26 Gregorian' );
Sterday 5 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252224000, 'utc_rd_as_seconds() on 2037-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743660,
  0,
  0
]
, 'utc_rd_values() on 2037-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2037-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2037-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-27 Gregorian' );
Sunday 6 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252310400, 'utc_rd_as_seconds() on 2037-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743661,
  0,
  0
]
, 'utc_rd_values() on 2037-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2037-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2037-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-28 Gregorian' );
Monday 7 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252396800, 'utc_rd_as_seconds() on 2037-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743662,
  0,
  0
]
, 'utc_rd_values() on 2037-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2037-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2037-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-29 Gregorian' );
Trewsday 8 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252483200, 'utc_rd_as_seconds() on 2037-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743663,
  0,
  0
]
, 'utc_rd_values() on 2037-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2037-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2037-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-30 Gregorian' );
Hevensday 9 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252569600, 'utc_rd_as_seconds() on 2037-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743664,
  0,
  0
]
, 'utc_rd_values() on 2037-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2037-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2037-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-01-31 Gregorian' );
Mersday 10 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252656000, 'utc_rd_as_seconds() on 2037-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743665,
  0,
  0
]
, 'utc_rd_values() on 2037-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2037-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2037-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-01 Gregorian' );
Highday 11 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252742400, 'utc_rd_as_seconds() on 2037-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743666,
  0,
  0
]
, 'utc_rd_values() on 2037-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  6
]
, 'week() on 2037-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2037-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2037-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2037-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-02 Gregorian' );
Sterday 12 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252828800, 'utc_rd_as_seconds() on 2037-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743667,
  0,
  0
]
, 'utc_rd_values() on 2037-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2037-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2037-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-03 Gregorian' );
Sunday 13 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64252915200, 'utc_rd_as_seconds() on 2037-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743668,
  0,
  0
]
, 'utc_rd_values() on 2037-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2037-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2037-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-04 Gregorian' );
Monday 14 Solmath 7501

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253001600, 'utc_rd_as_seconds() on 2037-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743669,
  0,
  0
]
, 'utc_rd_values() on 2037-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2037-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2037-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-05 Gregorian' );
Trewsday 15 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253088000, 'utc_rd_as_seconds() on 2037-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743670,
  0,
  0
]
, 'utc_rd_values() on 2037-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2037-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2037-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-06 Gregorian' );
Hevensday 16 Solmath 7501

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253174400, 'utc_rd_as_seconds() on 2037-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743671,
  0,
  0
]
, 'utc_rd_values() on 2037-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2037-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2037-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-07 Gregorian' );
Mersday 17 Solmath 7501

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253260800, 'utc_rd_as_seconds() on 2037-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743672,
  0,
  0
]
, 'utc_rd_values() on 2037-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2037-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2037-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-08 Gregorian' );
Highday 18 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253347200, 'utc_rd_as_seconds() on 2037-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743673,
  0,
  0
]
, 'utc_rd_values() on 2037-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  7
]
, 'week() on 2037-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2037-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2037-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2037-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-09 Gregorian' );
Sterday 19 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253433600, 'utc_rd_as_seconds() on 2037-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743674,
  0,
  0
]
, 'utc_rd_values() on 2037-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2037-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2037-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-10 Gregorian' );
Sunday 20 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253520000, 'utc_rd_as_seconds() on 2037-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743675,
  0,
  0
]
, 'utc_rd_values() on 2037-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2037-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2037-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-11 Gregorian' );
Monday 21 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253606400, 'utc_rd_as_seconds() on 2037-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743676,
  0,
  0
]
, 'utc_rd_values() on 2037-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2037-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2037-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-12 Gregorian' );
Trewsday 22 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253692800, 'utc_rd_as_seconds() on 2037-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743677,
  0,
  0
]
, 'utc_rd_values() on 2037-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2037-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2037-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-13 Gregorian' );
Hevensday 23 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253779200, 'utc_rd_as_seconds() on 2037-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743678,
  0,
  0
]
, 'utc_rd_values() on 2037-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2037-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2037-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-14 Gregorian' );
Mersday 24 Solmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253865600, 'utc_rd_as_seconds() on 2037-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743679,
  0,
  0
]
, 'utc_rd_values() on 2037-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2037-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2037-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-15 Gregorian' );
Highday 25 Solmath 7501

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64253952000, 'utc_rd_as_seconds() on 2037-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743680,
  0,
  0
]
, 'utc_rd_values() on 2037-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  8
]
, 'week() on 2037-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2037-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2037-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2037-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-16 Gregorian' );
Sterday 26 Solmath 7501

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254038400, 'utc_rd_as_seconds() on 2037-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743681,
  0,
  0
]
, 'utc_rd_values() on 2037-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2037-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2037-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-17 Gregorian' );
Sunday 27 Solmath 7501

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254124800, 'utc_rd_as_seconds() on 2037-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743682,
  0,
  0
]
, 'utc_rd_values() on 2037-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2037-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2037-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-18 Gregorian' );
Monday 28 Solmath 7501

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254211200, 'utc_rd_as_seconds() on 2037-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743683,
  0,
  0
]
, 'utc_rd_values() on 2037-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2037-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2037-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-19 Gregorian' );
Trewsday 29 Solmath 7501

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254297600, 'utc_rd_as_seconds() on 2037-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743684,
  0,
  0
]
, 'utc_rd_values() on 2037-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2037-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2037-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2037-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2037-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-20 Gregorian' );
Hevensday 30 Solmath 7501

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254384000, 'utc_rd_as_seconds() on 2037-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743685,
  0,
  0
]
, 'utc_rd_values() on 2037-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2037-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2037-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-21 Gregorian' );
Mersday 1 Rethe 7501

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254470400, 'utc_rd_as_seconds() on 2037-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743686,
  0,
  0
]
, 'utc_rd_values() on 2037-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2037-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2037-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-22 Gregorian' );
Highday 2 Rethe 7501

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254556800, 'utc_rd_as_seconds() on 2037-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743687,
  0,
  0
]
, 'utc_rd_values() on 2037-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  9
]
, 'week() on 2037-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2037-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2037-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2037-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-23 Gregorian' );
Sterday 3 Rethe 7501

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254643200, 'utc_rd_as_seconds() on 2037-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743688,
  0,
  0
]
, 'utc_rd_values() on 2037-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2037-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2037-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-24 Gregorian' );
Sunday 4 Rethe 7501

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254729600, 'utc_rd_as_seconds() on 2037-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743689,
  0,
  0
]
, 'utc_rd_values() on 2037-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2037-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2037-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-25 Gregorian' );
Monday 5 Rethe 7501

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254816000, 'utc_rd_as_seconds() on 2037-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743690,
  0,
  0
]
, 'utc_rd_values() on 2037-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2037-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2037-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-26 Gregorian' );
Trewsday 6 Rethe 7501

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254902400, 'utc_rd_as_seconds() on 2037-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743691,
  0,
  0
]
, 'utc_rd_values() on 2037-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2037-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2037-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-27 Gregorian' );
Hevensday 7 Rethe 7501

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64254988800, 'utc_rd_as_seconds() on 2037-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743692,
  0,
  0
]
, 'utc_rd_values() on 2037-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2037-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2037-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-02-28 Gregorian' );
Mersday 8 Rethe 7501

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255075200, 'utc_rd_as_seconds() on 2037-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743693,
  0,
  0
]
, 'utc_rd_values() on 2037-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2037-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2037-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-01 Gregorian' );
Highday 9 Rethe 7501

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255161600, 'utc_rd_as_seconds() on 2037-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743694,
  0,
  0
]
, 'utc_rd_values() on 2037-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  10
]
, 'week() on 2037-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2037-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2037-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2037-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-02 Gregorian' );
Sterday 10 Rethe 7501

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255248000, 'utc_rd_as_seconds() on 2037-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743695,
  0,
  0
]
, 'utc_rd_values() on 2037-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2037-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2037-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-03 Gregorian' );
Sunday 11 Rethe 7501

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255334400, 'utc_rd_as_seconds() on 2037-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743696,
  0,
  0
]
, 'utc_rd_values() on 2037-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2037-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2037-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-04 Gregorian' );
Monday 12 Rethe 7501

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255420800, 'utc_rd_as_seconds() on 2037-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743697,
  0,
  0
]
, 'utc_rd_values() on 2037-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2037-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2037-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-05 Gregorian' );
Trewsday 13 Rethe 7501

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255507200, 'utc_rd_as_seconds() on 2037-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743698,
  0,
  0
]
, 'utc_rd_values() on 2037-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2037-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2037-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-06 Gregorian' );
Hevensday 14 Rethe 7501

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255593600, 'utc_rd_as_seconds() on 2037-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743699,
  0,
  0
]
, 'utc_rd_values() on 2037-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2037-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2037-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-07 Gregorian' );
Mersday 15 Rethe 7501

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255680000, 'utc_rd_as_seconds() on 2037-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743700,
  0,
  0
]
, 'utc_rd_values() on 2037-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2037-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2037-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-08 Gregorian' );
Highday 16 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255766400, 'utc_rd_as_seconds() on 2037-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743701,
  0,
  0
]
, 'utc_rd_values() on 2037-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  11
]
, 'week() on 2037-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2037-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2037-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2037-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-09 Gregorian' );
Sterday 17 Rethe 7501

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255852800, 'utc_rd_as_seconds() on 2037-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743702,
  0,
  0
]
, 'utc_rd_values() on 2037-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2037-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2037-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-10 Gregorian' );
Sunday 18 Rethe 7501

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64255939200, 'utc_rd_as_seconds() on 2037-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743703,
  0,
  0
]
, 'utc_rd_values() on 2037-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2037-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2037-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-11 Gregorian' );
Monday 19 Rethe 7501

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256025600, 'utc_rd_as_seconds() on 2037-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743704,
  0,
  0
]
, 'utc_rd_values() on 2037-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2037-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2037-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-12 Gregorian' );
Trewsday 20 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256112000, 'utc_rd_as_seconds() on 2037-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743705,
  0,
  0
]
, 'utc_rd_values() on 2037-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2037-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2037-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-13 Gregorian' );
Hevensday 21 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256198400, 'utc_rd_as_seconds() on 2037-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743706,
  0,
  0
]
, 'utc_rd_values() on 2037-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2037-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2037-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-14 Gregorian' );
Mersday 22 Rethe 7501

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256284800, 'utc_rd_as_seconds() on 2037-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743707,
  0,
  0
]
, 'utc_rd_values() on 2037-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2037-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2037-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-15 Gregorian' );
Highday 23 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256371200, 'utc_rd_as_seconds() on 2037-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743708,
  0,
  0
]
, 'utc_rd_values() on 2037-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  12
]
, 'week() on 2037-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2037-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2037-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2037-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-16 Gregorian' );
Sterday 24 Rethe 7501

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256457600, 'utc_rd_as_seconds() on 2037-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743709,
  0,
  0
]
, 'utc_rd_values() on 2037-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2037-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2037-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-17 Gregorian' );
Sunday 25 Rethe 7501

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256544000, 'utc_rd_as_seconds() on 2037-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743710,
  0,
  0
]
, 'utc_rd_values() on 2037-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2037-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2037-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-18 Gregorian' );
Monday 26 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256630400, 'utc_rd_as_seconds() on 2037-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743711,
  0,
  0
]
, 'utc_rd_values() on 2037-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2037-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2037-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-19 Gregorian' );
Trewsday 27 Rethe 7501

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256716800, 'utc_rd_as_seconds() on 2037-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743712,
  0,
  0
]
, 'utc_rd_values() on 2037-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2037-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2037-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-20 Gregorian' );
Hevensday 28 Rethe 7501

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256803200, 'utc_rd_as_seconds() on 2037-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743713,
  0,
  0
]
, 'utc_rd_values() on 2037-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2037-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2037-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-21 Gregorian' );
Mersday 29 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256889600, 'utc_rd_as_seconds() on 2037-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743714,
  0,
  0
]
, 'utc_rd_values() on 2037-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2037-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2037-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2037-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2037-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-22 Gregorian' );
Highday 30 Rethe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64256976000, 'utc_rd_as_seconds() on 2037-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743715,
  0,
  0
]
, 'utc_rd_values() on 2037-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  13
]
, 'week() on 2037-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2037-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2037-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2037-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-23 Gregorian' );
Sterday 1 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257062400, 'utc_rd_as_seconds() on 2037-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743716,
  0,
  0
]
, 'utc_rd_values() on 2037-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2037-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2037-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-24 Gregorian' );
Sunday 2 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257148800, 'utc_rd_as_seconds() on 2037-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743717,
  0,
  0
]
, 'utc_rd_values() on 2037-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2037-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2037-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-25 Gregorian' );
Monday 3 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257235200, 'utc_rd_as_seconds() on 2037-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743718,
  0,
  0
]
, 'utc_rd_values() on 2037-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2037-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2037-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-26 Gregorian' );
Trewsday 4 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257321600, 'utc_rd_as_seconds() on 2037-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743719,
  0,
  0
]
, 'utc_rd_values() on 2037-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2037-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2037-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-27 Gregorian' );
Hevensday 5 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257408000, 'utc_rd_as_seconds() on 2037-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743720,
  0,
  0
]
, 'utc_rd_values() on 2037-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2037-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2037-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-28 Gregorian' );
Mersday 6 Astron 7501

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257494400, 'utc_rd_as_seconds() on 2037-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743721,
  0,
  0
]
, 'utc_rd_values() on 2037-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2037-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2037-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-29 Gregorian' );
Highday 7 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257580800, 'utc_rd_as_seconds() on 2037-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743722,
  0,
  0
]
, 'utc_rd_values() on 2037-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  14
]
, 'week() on 2037-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2037-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2037-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2037-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-30 Gregorian' );
Sterday 8 Astron 7501

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257667200, 'utc_rd_as_seconds() on 2037-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743723,
  0,
  0
]
, 'utc_rd_values() on 2037-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2037-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2037-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-03-31 Gregorian' );
Sunday 9 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257753600, 'utc_rd_as_seconds() on 2037-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743724,
  0,
  0
]
, 'utc_rd_values() on 2037-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2037-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2037-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-01 Gregorian' );
Monday 10 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257840000, 'utc_rd_as_seconds() on 2037-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743725,
  0,
  0
]
, 'utc_rd_values() on 2037-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2037-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2037-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-02 Gregorian' );
Trewsday 11 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64257926400, 'utc_rd_as_seconds() on 2037-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743726,
  0,
  0
]
, 'utc_rd_values() on 2037-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2037-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2037-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-03 Gregorian' );
Hevensday 12 Astron 7501

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258012800, 'utc_rd_as_seconds() on 2037-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743727,
  0,
  0
]
, 'utc_rd_values() on 2037-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2037-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2037-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-04 Gregorian' );
Mersday 13 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258099200, 'utc_rd_as_seconds() on 2037-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743728,
  0,
  0
]
, 'utc_rd_values() on 2037-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2037-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2037-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-05 Gregorian' );
Highday 14 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258185600, 'utc_rd_as_seconds() on 2037-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743729,
  0,
  0
]
, 'utc_rd_values() on 2037-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  15
]
, 'week() on 2037-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2037-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2037-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2037-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-06 Gregorian' );
Sterday 15 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258272000, 'utc_rd_as_seconds() on 2037-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743730,
  0,
  0
]
, 'utc_rd_values() on 2037-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2037-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2037-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-07 Gregorian' );
Sunday 16 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258358400, 'utc_rd_as_seconds() on 2037-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743731,
  0,
  0
]
, 'utc_rd_values() on 2037-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2037-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2037-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-08 Gregorian' );
Monday 17 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258444800, 'utc_rd_as_seconds() on 2037-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743732,
  0,
  0
]
, 'utc_rd_values() on 2037-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2037-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2037-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-09 Gregorian' );
Trewsday 18 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258531200, 'utc_rd_as_seconds() on 2037-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743733,
  0,
  0
]
, 'utc_rd_values() on 2037-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2037-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2037-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-10 Gregorian' );
Hevensday 19 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258617600, 'utc_rd_as_seconds() on 2037-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743734,
  0,
  0
]
, 'utc_rd_values() on 2037-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2037-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2037-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-11 Gregorian' );
Mersday 20 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258704000, 'utc_rd_as_seconds() on 2037-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743735,
  0,
  0
]
, 'utc_rd_values() on 2037-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2037-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2037-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-12 Gregorian' );
Highday 21 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258790400, 'utc_rd_as_seconds() on 2037-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743736,
  0,
  0
]
, 'utc_rd_values() on 2037-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  16
]
, 'week() on 2037-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2037-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2037-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2037-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-13 Gregorian' );
Sterday 22 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258876800, 'utc_rd_as_seconds() on 2037-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743737,
  0,
  0
]
, 'utc_rd_values() on 2037-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2037-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2037-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-14 Gregorian' );
Sunday 23 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64258963200, 'utc_rd_as_seconds() on 2037-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743738,
  0,
  0
]
, 'utc_rd_values() on 2037-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2037-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2037-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-15 Gregorian' );
Monday 24 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259049600, 'utc_rd_as_seconds() on 2037-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743739,
  0,
  0
]
, 'utc_rd_values() on 2037-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2037-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2037-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-16 Gregorian' );
Trewsday 25 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259136000, 'utc_rd_as_seconds() on 2037-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743740,
  0,
  0
]
, 'utc_rd_values() on 2037-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2037-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2037-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-17 Gregorian' );
Hevensday 26 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259222400, 'utc_rd_as_seconds() on 2037-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743741,
  0,
  0
]
, 'utc_rd_values() on 2037-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2037-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2037-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-18 Gregorian' );
Mersday 27 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259308800, 'utc_rd_as_seconds() on 2037-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743742,
  0,
  0
]
, 'utc_rd_values() on 2037-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2037-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2037-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-19 Gregorian' );
Highday 28 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259395200, 'utc_rd_as_seconds() on 2037-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743743,
  0,
  0
]
, 'utc_rd_values() on 2037-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  17
]
, 'week() on 2037-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2037-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2037-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2037-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-20 Gregorian' );
Sterday 29 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259481600, 'utc_rd_as_seconds() on 2037-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743744,
  0,
  0
]
, 'utc_rd_values() on 2037-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2037-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2037-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2037-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2037-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-21 Gregorian' );
Sunday 30 Astron 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259568000, 'utc_rd_as_seconds() on 2037-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743745,
  0,
  0
]
, 'utc_rd_values() on 2037-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2037-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2037-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-22 Gregorian' );
Monday 1 Thrimidge 7501

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259654400, 'utc_rd_as_seconds() on 2037-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743746,
  0,
  0
]
, 'utc_rd_values() on 2037-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2037-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2037-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-23 Gregorian' );
Trewsday 2 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259740800, 'utc_rd_as_seconds() on 2037-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743747,
  0,
  0
]
, 'utc_rd_values() on 2037-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2037-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2037-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-24 Gregorian' );
Hevensday 3 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259827200, 'utc_rd_as_seconds() on 2037-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743748,
  0,
  0
]
, 'utc_rd_values() on 2037-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2037-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2037-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-25 Gregorian' );
Mersday 4 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64259913600, 'utc_rd_as_seconds() on 2037-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743749,
  0,
  0
]
, 'utc_rd_values() on 2037-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2037-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2037-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-26 Gregorian' );
Highday 5 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260000000, 'utc_rd_as_seconds() on 2037-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743750,
  0,
  0
]
, 'utc_rd_values() on 2037-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  18
]
, 'week() on 2037-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2037-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2037-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2037-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-27 Gregorian' );
Sterday 6 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260086400, 'utc_rd_as_seconds() on 2037-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743751,
  0,
  0
]
, 'utc_rd_values() on 2037-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2037-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2037-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-28 Gregorian' );
Sunday 7 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260172800, 'utc_rd_as_seconds() on 2037-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743752,
  0,
  0
]
, 'utc_rd_values() on 2037-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2037-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2037-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-29 Gregorian' );
Monday 8 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260259200, 'utc_rd_as_seconds() on 2037-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743753,
  0,
  0
]
, 'utc_rd_values() on 2037-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2037-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2037-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-04-30 Gregorian' );
Trewsday 9 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260345600, 'utc_rd_as_seconds() on 2037-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743754,
  0,
  0
]
, 'utc_rd_values() on 2037-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2037-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2037-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-01 Gregorian' );
Hevensday 10 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260432000, 'utc_rd_as_seconds() on 2037-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743755,
  0,
  0
]
, 'utc_rd_values() on 2037-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2037-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2037-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-02 Gregorian' );
Mersday 11 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260518400, 'utc_rd_as_seconds() on 2037-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743756,
  0,
  0
]
, 'utc_rd_values() on 2037-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2037-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2037-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-03 Gregorian' );
Highday 12 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260604800, 'utc_rd_as_seconds() on 2037-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743757,
  0,
  0
]
, 'utc_rd_values() on 2037-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  19
]
, 'week() on 2037-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2037-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2037-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2037-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-04 Gregorian' );
Sterday 13 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260691200, 'utc_rd_as_seconds() on 2037-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743758,
  0,
  0
]
, 'utc_rd_values() on 2037-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2037-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2037-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-05 Gregorian' );
Sunday 14 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260777600, 'utc_rd_as_seconds() on 2037-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743759,
  0,
  0
]
, 'utc_rd_values() on 2037-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2037-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2037-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-06 Gregorian' );
Monday 15 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260864000, 'utc_rd_as_seconds() on 2037-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743760,
  0,
  0
]
, 'utc_rd_values() on 2037-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2037-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2037-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-07 Gregorian' );
Trewsday 16 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64260950400, 'utc_rd_as_seconds() on 2037-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743761,
  0,
  0
]
, 'utc_rd_values() on 2037-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2037-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2037-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-08 Gregorian' );
Hevensday 17 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261036800, 'utc_rd_as_seconds() on 2037-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743762,
  0,
  0
]
, 'utc_rd_values() on 2037-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2037-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2037-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-09 Gregorian' );
Mersday 18 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261123200, 'utc_rd_as_seconds() on 2037-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743763,
  0,
  0
]
, 'utc_rd_values() on 2037-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2037-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2037-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-10 Gregorian' );
Highday 19 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261209600, 'utc_rd_as_seconds() on 2037-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743764,
  0,
  0
]
, 'utc_rd_values() on 2037-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  20
]
, 'week() on 2037-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2037-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2037-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2037-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-11 Gregorian' );
Sterday 20 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261296000, 'utc_rd_as_seconds() on 2037-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743765,
  0,
  0
]
, 'utc_rd_values() on 2037-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2037-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2037-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-12 Gregorian' );
Sunday 21 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261382400, 'utc_rd_as_seconds() on 2037-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743766,
  0,
  0
]
, 'utc_rd_values() on 2037-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2037-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2037-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-13 Gregorian' );
Monday 22 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261468800, 'utc_rd_as_seconds() on 2037-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743767,
  0,
  0
]
, 'utc_rd_values() on 2037-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2037-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2037-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-14 Gregorian' );
Trewsday 23 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261555200, 'utc_rd_as_seconds() on 2037-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743768,
  0,
  0
]
, 'utc_rd_values() on 2037-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2037-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2037-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-15 Gregorian' );
Hevensday 24 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261641600, 'utc_rd_as_seconds() on 2037-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743769,
  0,
  0
]
, 'utc_rd_values() on 2037-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2037-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2037-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-16 Gregorian' );
Mersday 25 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261728000, 'utc_rd_as_seconds() on 2037-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743770,
  0,
  0
]
, 'utc_rd_values() on 2037-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2037-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2037-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-17 Gregorian' );
Highday 26 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261814400, 'utc_rd_as_seconds() on 2037-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743771,
  0,
  0
]
, 'utc_rd_values() on 2037-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  21
]
, 'week() on 2037-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2037-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2037-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2037-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-18 Gregorian' );
Sterday 27 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261900800, 'utc_rd_as_seconds() on 2037-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743772,
  0,
  0
]
, 'utc_rd_values() on 2037-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2037-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2037-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-19 Gregorian' );
Sunday 28 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64261987200, 'utc_rd_as_seconds() on 2037-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743773,
  0,
  0
]
, 'utc_rd_values() on 2037-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2037-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2037-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-20 Gregorian' );
Monday 29 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262073600, 'utc_rd_as_seconds() on 2037-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743774,
  0,
  0
]
, 'utc_rd_values() on 2037-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2037-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2037-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2037-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2037-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-21 Gregorian' );
Trewsday 30 Thrimidge 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262160000, 'utc_rd_as_seconds() on 2037-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743775,
  0,
  0
]
, 'utc_rd_values() on 2037-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2037-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2037-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-22 Gregorian' );
Hevensday 1 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262246400, 'utc_rd_as_seconds() on 2037-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743776,
  0,
  0
]
, 'utc_rd_values() on 2037-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2037-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2037-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-23 Gregorian' );
Mersday 2 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262332800, 'utc_rd_as_seconds() on 2037-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743777,
  0,
  0
]
, 'utc_rd_values() on 2037-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2037-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2037-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-24 Gregorian' );
Highday 3 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262419200, 'utc_rd_as_seconds() on 2037-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743778,
  0,
  0
]
, 'utc_rd_values() on 2037-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  22
]
, 'week() on 2037-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2037-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2037-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2037-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-25 Gregorian' );
Sterday 4 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262505600, 'utc_rd_as_seconds() on 2037-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743779,
  0,
  0
]
, 'utc_rd_values() on 2037-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2037-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2037-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-26 Gregorian' );
Sunday 5 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262592000, 'utc_rd_as_seconds() on 2037-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743780,
  0,
  0
]
, 'utc_rd_values() on 2037-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2037-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2037-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-27 Gregorian' );
Monday 6 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262678400, 'utc_rd_as_seconds() on 2037-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743781,
  0,
  0
]
, 'utc_rd_values() on 2037-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2037-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2037-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-28 Gregorian' );
Trewsday 7 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262764800, 'utc_rd_as_seconds() on 2037-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743782,
  0,
  0
]
, 'utc_rd_values() on 2037-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2037-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2037-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-29 Gregorian' );
Hevensday 8 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262851200, 'utc_rd_as_seconds() on 2037-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743783,
  0,
  0
]
, 'utc_rd_values() on 2037-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2037-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2037-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-30 Gregorian' );
Mersday 9 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64262937600, 'utc_rd_as_seconds() on 2037-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743784,
  0,
  0
]
, 'utc_rd_values() on 2037-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2037-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2037-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-05-31 Gregorian' );
Highday 10 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263024000, 'utc_rd_as_seconds() on 2037-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743785,
  0,
  0
]
, 'utc_rd_values() on 2037-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  23
]
, 'week() on 2037-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2037-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2037-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2037-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-01 Gregorian' );
Sterday 11 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263110400, 'utc_rd_as_seconds() on 2037-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743786,
  0,
  0
]
, 'utc_rd_values() on 2037-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2037-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2037-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-02 Gregorian' );
Sunday 12 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263196800, 'utc_rd_as_seconds() on 2037-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743787,
  0,
  0
]
, 'utc_rd_values() on 2037-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2037-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2037-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-03 Gregorian' );
Monday 13 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263283200, 'utc_rd_as_seconds() on 2037-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743788,
  0,
  0
]
, 'utc_rd_values() on 2037-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2037-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2037-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-04 Gregorian' );
Trewsday 14 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263369600, 'utc_rd_as_seconds() on 2037-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743789,
  0,
  0
]
, 'utc_rd_values() on 2037-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2037-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2037-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-05 Gregorian' );
Hevensday 15 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263456000, 'utc_rd_as_seconds() on 2037-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743790,
  0,
  0
]
, 'utc_rd_values() on 2037-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2037-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2037-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-06 Gregorian' );
Mersday 16 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263542400, 'utc_rd_as_seconds() on 2037-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743791,
  0,
  0
]
, 'utc_rd_values() on 2037-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2037-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2037-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-07 Gregorian' );
Highday 17 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263628800, 'utc_rd_as_seconds() on 2037-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743792,
  0,
  0
]
, 'utc_rd_values() on 2037-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  24
]
, 'week() on 2037-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2037-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2037-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2037-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-08 Gregorian' );
Sterday 18 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263715200, 'utc_rd_as_seconds() on 2037-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743793,
  0,
  0
]
, 'utc_rd_values() on 2037-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2037-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2037-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-09 Gregorian' );
Sunday 19 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263801600, 'utc_rd_as_seconds() on 2037-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743794,
  0,
  0
]
, 'utc_rd_values() on 2037-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2037-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2037-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-10 Gregorian' );
Monday 20 Forelithe 7501

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263888000, 'utc_rd_as_seconds() on 2037-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743795,
  0,
  0
]
, 'utc_rd_values() on 2037-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2037-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2037-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-11 Gregorian' );
Trewsday 21 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64263974400, 'utc_rd_as_seconds() on 2037-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743796,
  0,
  0
]
, 'utc_rd_values() on 2037-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2037-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2037-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-12 Gregorian' );
Hevensday 22 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264060800, 'utc_rd_as_seconds() on 2037-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743797,
  0,
  0
]
, 'utc_rd_values() on 2037-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2037-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2037-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-13 Gregorian' );
Mersday 23 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264147200, 'utc_rd_as_seconds() on 2037-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743798,
  0,
  0
]
, 'utc_rd_values() on 2037-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2037-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2037-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-14 Gregorian' );
Highday 24 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264233600, 'utc_rd_as_seconds() on 2037-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743799,
  0,
  0
]
, 'utc_rd_values() on 2037-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  25
]
, 'week() on 2037-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2037-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2037-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2037-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-15 Gregorian' );
Sterday 25 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264320000, 'utc_rd_as_seconds() on 2037-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743800,
  0,
  0
]
, 'utc_rd_values() on 2037-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2037-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2037-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-16 Gregorian' );
Sunday 26 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264406400, 'utc_rd_as_seconds() on 2037-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743801,
  0,
  0
]
, 'utc_rd_values() on 2037-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2037-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2037-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-17 Gregorian' );
Monday 27 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264492800, 'utc_rd_as_seconds() on 2037-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743802,
  0,
  0
]
, 'utc_rd_values() on 2037-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2037-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2037-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-18 Gregorian' );
Trewsday 28 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264579200, 'utc_rd_as_seconds() on 2037-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743803,
  0,
  0
]
, 'utc_rd_values() on 2037-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2037-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2037-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-19 Gregorian' );
Hevensday 29 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264665600, 'utc_rd_as_seconds() on 2037-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743804,
  0,
  0
]
, 'utc_rd_values() on 2037-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2037-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2037-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2037-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2037-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-20 Gregorian' );
Mersday 30 Forelithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264752000, 'utc_rd_as_seconds() on 2037-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743805,
  0,
  0
]
, 'utc_rd_values() on 2037-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2037-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2037-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2037-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2037-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2037-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2037-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2037-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2037-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2037-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-21 Gregorian' );
Highday 1 Lithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264838400, 'utc_rd_as_seconds() on 2037-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743806,
  0,
  0
]
, 'utc_rd_values() on 2037-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  26
]
, 'week() on 2037-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2037-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2037-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2037-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2037-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2037-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2037-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2037-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2037-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2037-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2037-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2037-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2037-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2037-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2037-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-22 Gregorian' );
Midyear's day 7501

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64264924800, 'utc_rd_as_seconds() on 2037-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743807,
  0,
  0
]
, 'utc_rd_values() on 2037-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2037-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  0
]
, 'week() on 2037-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2037-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2037-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2037-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2037-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2037-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2037-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2037-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2037-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2037-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2037-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-23 Gregorian' );
Sterday 2 Lithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265011200, 'utc_rd_as_seconds() on 2037-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743808,
  0,
  0
]
, 'utc_rd_values() on 2037-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2037-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2037-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-24 Gregorian' );
Sunday 1 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265097600, 'utc_rd_as_seconds() on 2037-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743809,
  0,
  0
]
, 'utc_rd_values() on 2037-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2037-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2037-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-25 Gregorian' );
Monday 2 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265184000, 'utc_rd_as_seconds() on 2037-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743810,
  0,
  0
]
, 'utc_rd_values() on 2037-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2037-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2037-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-26 Gregorian' );
Trewsday 3 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265270400, 'utc_rd_as_seconds() on 2037-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743811,
  0,
  0
]
, 'utc_rd_values() on 2037-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2037-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2037-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-27 Gregorian' );
Hevensday 4 Afterlithe 7501

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265356800, 'utc_rd_as_seconds() on 2037-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743812,
  0,
  0
]
, 'utc_rd_values() on 2037-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2037-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2037-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-28 Gregorian' );
Mersday 5 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265443200, 'utc_rd_as_seconds() on 2037-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743813,
  0,
  0
]
, 'utc_rd_values() on 2037-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2037-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2037-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-29 Gregorian' );
Highday 6 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265529600, 'utc_rd_as_seconds() on 2037-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743814,
  0,
  0
]
, 'utc_rd_values() on 2037-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  27
]
, 'week() on 2037-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2037-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2037-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2037-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-06-30 Gregorian' );
Sterday 7 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265616000, 'utc_rd_as_seconds() on 2037-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743815,
  0,
  0
]
, 'utc_rd_values() on 2037-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2037-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2037-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-01 Gregorian' );
Sunday 8 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265702400, 'utc_rd_as_seconds() on 2037-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743816,
  0,
  0
]
, 'utc_rd_values() on 2037-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2037-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2037-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-02 Gregorian' );
Monday 9 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265788800, 'utc_rd_as_seconds() on 2037-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743817,
  0,
  0
]
, 'utc_rd_values() on 2037-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2037-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2037-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-03 Gregorian' );
Trewsday 10 Afterlithe 7501

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265875200, 'utc_rd_as_seconds() on 2037-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743818,
  0,
  0
]
, 'utc_rd_values() on 2037-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2037-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2037-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-04 Gregorian' );
Hevensday 11 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64265961600, 'utc_rd_as_seconds() on 2037-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743819,
  0,
  0
]
, 'utc_rd_values() on 2037-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2037-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2037-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-05 Gregorian' );
Mersday 12 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266048000, 'utc_rd_as_seconds() on 2037-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743820,
  0,
  0
]
, 'utc_rd_values() on 2037-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2037-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2037-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-06 Gregorian' );
Highday 13 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266134400, 'utc_rd_as_seconds() on 2037-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743821,
  0,
  0
]
, 'utc_rd_values() on 2037-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  28
]
, 'week() on 2037-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2037-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2037-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2037-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-07 Gregorian' );
Sterday 14 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266220800, 'utc_rd_as_seconds() on 2037-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743822,
  0,
  0
]
, 'utc_rd_values() on 2037-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2037-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2037-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-08 Gregorian' );
Sunday 15 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266307200, 'utc_rd_as_seconds() on 2037-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743823,
  0,
  0
]
, 'utc_rd_values() on 2037-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2037-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2037-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-09 Gregorian' );
Monday 16 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266393600, 'utc_rd_as_seconds() on 2037-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743824,
  0,
  0
]
, 'utc_rd_values() on 2037-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2037-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2037-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-10 Gregorian' );
Trewsday 17 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266480000, 'utc_rd_as_seconds() on 2037-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743825,
  0,
  0
]
, 'utc_rd_values() on 2037-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2037-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2037-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-11 Gregorian' );
Hevensday 18 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266566400, 'utc_rd_as_seconds() on 2037-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743826,
  0,
  0
]
, 'utc_rd_values() on 2037-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2037-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2037-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-12 Gregorian' );
Mersday 19 Afterlithe 7501

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266652800, 'utc_rd_as_seconds() on 2037-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743827,
  0,
  0
]
, 'utc_rd_values() on 2037-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2037-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2037-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-13 Gregorian' );
Highday 20 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266739200, 'utc_rd_as_seconds() on 2037-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743828,
  0,
  0
]
, 'utc_rd_values() on 2037-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  29
]
, 'week() on 2037-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2037-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2037-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2037-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-14 Gregorian' );
Sterday 21 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266825600, 'utc_rd_as_seconds() on 2037-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743829,
  0,
  0
]
, 'utc_rd_values() on 2037-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2037-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2037-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-15 Gregorian' );
Sunday 22 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266912000, 'utc_rd_as_seconds() on 2037-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743830,
  0,
  0
]
, 'utc_rd_values() on 2037-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2037-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2037-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-16 Gregorian' );
Monday 23 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64266998400, 'utc_rd_as_seconds() on 2037-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743831,
  0,
  0
]
, 'utc_rd_values() on 2037-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2037-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2037-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-17 Gregorian' );
Trewsday 24 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267084800, 'utc_rd_as_seconds() on 2037-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743832,
  0,
  0
]
, 'utc_rd_values() on 2037-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2037-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2037-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-18 Gregorian' );
Hevensday 25 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267171200, 'utc_rd_as_seconds() on 2037-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743833,
  0,
  0
]
, 'utc_rd_values() on 2037-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2037-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2037-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-19 Gregorian' );
Mersday 26 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267257600, 'utc_rd_as_seconds() on 2037-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743834,
  0,
  0
]
, 'utc_rd_values() on 2037-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2037-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2037-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-20 Gregorian' );
Highday 27 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267344000, 'utc_rd_as_seconds() on 2037-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743835,
  0,
  0
]
, 'utc_rd_values() on 2037-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  30
]
, 'week() on 2037-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2037-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2037-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2037-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-21 Gregorian' );
Sterday 28 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267430400, 'utc_rd_as_seconds() on 2037-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743836,
  0,
  0
]
, 'utc_rd_values() on 2037-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2037-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2037-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-22 Gregorian' );
Sunday 29 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267516800, 'utc_rd_as_seconds() on 2037-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743837,
  0,
  0
]
, 'utc_rd_values() on 2037-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2037-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2037-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2037-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2037-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-23 Gregorian' );
Monday 30 Afterlithe 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267603200, 'utc_rd_as_seconds() on 2037-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743838,
  0,
  0
]
, 'utc_rd_values() on 2037-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2037-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2037-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-24 Gregorian' );
Trewsday 1 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267689600, 'utc_rd_as_seconds() on 2037-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743839,
  0,
  0
]
, 'utc_rd_values() on 2037-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2037-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2037-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-25 Gregorian' );
Hevensday 2 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267776000, 'utc_rd_as_seconds() on 2037-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743840,
  0,
  0
]
, 'utc_rd_values() on 2037-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2037-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2037-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-26 Gregorian' );
Mersday 3 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267862400, 'utc_rd_as_seconds() on 2037-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743841,
  0,
  0
]
, 'utc_rd_values() on 2037-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2037-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2037-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-27 Gregorian' );
Highday 4 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64267948800, 'utc_rd_as_seconds() on 2037-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743842,
  0,
  0
]
, 'utc_rd_values() on 2037-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  31
]
, 'week() on 2037-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2037-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2037-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2037-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-28 Gregorian' );
Sterday 5 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268035200, 'utc_rd_as_seconds() on 2037-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743843,
  0,
  0
]
, 'utc_rd_values() on 2037-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2037-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2037-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-29 Gregorian' );
Sunday 6 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268121600, 'utc_rd_as_seconds() on 2037-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743844,
  0,
  0
]
, 'utc_rd_values() on 2037-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2037-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2037-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-30 Gregorian' );
Monday 7 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268208000, 'utc_rd_as_seconds() on 2037-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743845,
  0,
  0
]
, 'utc_rd_values() on 2037-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2037-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2037-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-07-31 Gregorian' );
Trewsday 8 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268294400, 'utc_rd_as_seconds() on 2037-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743846,
  0,
  0
]
, 'utc_rd_values() on 2037-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2037-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2037-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-01 Gregorian' );
Hevensday 9 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268380800, 'utc_rd_as_seconds() on 2037-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743847,
  0,
  0
]
, 'utc_rd_values() on 2037-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2037-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2037-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-02 Gregorian' );
Mersday 10 Wedmath 7501

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268467200, 'utc_rd_as_seconds() on 2037-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743848,
  0,
  0
]
, 'utc_rd_values() on 2037-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2037-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2037-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-03 Gregorian' );
Highday 11 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268553600, 'utc_rd_as_seconds() on 2037-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743849,
  0,
  0
]
, 'utc_rd_values() on 2037-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  32
]
, 'week() on 2037-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2037-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2037-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2037-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-04 Gregorian' );
Sterday 12 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268640000, 'utc_rd_as_seconds() on 2037-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743850,
  0,
  0
]
, 'utc_rd_values() on 2037-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2037-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2037-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-05 Gregorian' );
Sunday 13 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268726400, 'utc_rd_as_seconds() on 2037-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743851,
  0,
  0
]
, 'utc_rd_values() on 2037-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2037-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2037-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-06 Gregorian' );
Monday 14 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268812800, 'utc_rd_as_seconds() on 2037-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743852,
  0,
  0
]
, 'utc_rd_values() on 2037-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2037-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2037-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-07 Gregorian' );
Trewsday 15 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268899200, 'utc_rd_as_seconds() on 2037-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743853,
  0,
  0
]
, 'utc_rd_values() on 2037-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2037-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2037-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-08 Gregorian' );
Hevensday 16 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64268985600, 'utc_rd_as_seconds() on 2037-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743854,
  0,
  0
]
, 'utc_rd_values() on 2037-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2037-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2037-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-09 Gregorian' );
Mersday 17 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269072000, 'utc_rd_as_seconds() on 2037-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743855,
  0,
  0
]
, 'utc_rd_values() on 2037-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2037-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2037-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-10 Gregorian' );
Highday 18 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269158400, 'utc_rd_as_seconds() on 2037-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743856,
  0,
  0
]
, 'utc_rd_values() on 2037-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  33
]
, 'week() on 2037-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2037-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2037-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2037-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-11 Gregorian' );
Sterday 19 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269244800, 'utc_rd_as_seconds() on 2037-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743857,
  0,
  0
]
, 'utc_rd_values() on 2037-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2037-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2037-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-12 Gregorian' );
Sunday 20 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269331200, 'utc_rd_as_seconds() on 2037-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743858,
  0,
  0
]
, 'utc_rd_values() on 2037-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2037-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2037-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-13 Gregorian' );
Monday 21 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269417600, 'utc_rd_as_seconds() on 2037-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743859,
  0,
  0
]
, 'utc_rd_values() on 2037-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2037-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2037-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-14 Gregorian' );
Trewsday 22 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269504000, 'utc_rd_as_seconds() on 2037-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743860,
  0,
  0
]
, 'utc_rd_values() on 2037-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2037-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2037-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-15 Gregorian' );
Hevensday 23 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269590400, 'utc_rd_as_seconds() on 2037-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743861,
  0,
  0
]
, 'utc_rd_values() on 2037-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2037-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2037-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-16 Gregorian' );
Mersday 24 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269676800, 'utc_rd_as_seconds() on 2037-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743862,
  0,
  0
]
, 'utc_rd_values() on 2037-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2037-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2037-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-17 Gregorian' );
Highday 25 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269763200, 'utc_rd_as_seconds() on 2037-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743863,
  0,
  0
]
, 'utc_rd_values() on 2037-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  34
]
, 'week() on 2037-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2037-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2037-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2037-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-18 Gregorian' );
Sterday 26 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269849600, 'utc_rd_as_seconds() on 2037-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743864,
  0,
  0
]
, 'utc_rd_values() on 2037-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2037-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2037-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-19 Gregorian' );
Sunday 27 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64269936000, 'utc_rd_as_seconds() on 2037-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743865,
  0,
  0
]
, 'utc_rd_values() on 2037-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2037-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2037-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-20 Gregorian' );
Monday 28 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270022400, 'utc_rd_as_seconds() on 2037-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743866,
  0,
  0
]
, 'utc_rd_values() on 2037-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2037-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2037-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-21 Gregorian' );
Trewsday 29 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270108800, 'utc_rd_as_seconds() on 2037-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743867,
  0,
  0
]
, 'utc_rd_values() on 2037-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2037-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2037-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2037-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2037-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-22 Gregorian' );
Hevensday 30 Wedmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270195200, 'utc_rd_as_seconds() on 2037-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743868,
  0,
  0
]
, 'utc_rd_values() on 2037-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2037-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2037-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-23 Gregorian' );
Mersday 1 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270281600, 'utc_rd_as_seconds() on 2037-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743869,
  0,
  0
]
, 'utc_rd_values() on 2037-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2037-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2037-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-24 Gregorian' );
Highday 2 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270368000, 'utc_rd_as_seconds() on 2037-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743870,
  0,
  0
]
, 'utc_rd_values() on 2037-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  35
]
, 'week() on 2037-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2037-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2037-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2037-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-25 Gregorian' );
Sterday 3 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270454400, 'utc_rd_as_seconds() on 2037-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743871,
  0,
  0
]
, 'utc_rd_values() on 2037-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2037-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2037-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-26 Gregorian' );
Sunday 4 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270540800, 'utc_rd_as_seconds() on 2037-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743872,
  0,
  0
]
, 'utc_rd_values() on 2037-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2037-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2037-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-27 Gregorian' );
Monday 5 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270627200, 'utc_rd_as_seconds() on 2037-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743873,
  0,
  0
]
, 'utc_rd_values() on 2037-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2037-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2037-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-28 Gregorian' );
Trewsday 6 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270713600, 'utc_rd_as_seconds() on 2037-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743874,
  0,
  0
]
, 'utc_rd_values() on 2037-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2037-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2037-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-29 Gregorian' );
Hevensday 7 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270800000, 'utc_rd_as_seconds() on 2037-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743875,
  0,
  0
]
, 'utc_rd_values() on 2037-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2037-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2037-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-30 Gregorian' );
Mersday 8 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270886400, 'utc_rd_as_seconds() on 2037-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743876,
  0,
  0
]
, 'utc_rd_values() on 2037-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2037-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2037-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-08-31 Gregorian' );
Highday 9 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64270972800, 'utc_rd_as_seconds() on 2037-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743877,
  0,
  0
]
, 'utc_rd_values() on 2037-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  36
]
, 'week() on 2037-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2037-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2037-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2037-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-01 Gregorian' );
Sterday 10 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271059200, 'utc_rd_as_seconds() on 2037-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743878,
  0,
  0
]
, 'utc_rd_values() on 2037-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2037-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2037-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-02 Gregorian' );
Sunday 11 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271145600, 'utc_rd_as_seconds() on 2037-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743879,
  0,
  0
]
, 'utc_rd_values() on 2037-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2037-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2037-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-03 Gregorian' );
Monday 12 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271232000, 'utc_rd_as_seconds() on 2037-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743880,
  0,
  0
]
, 'utc_rd_values() on 2037-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2037-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2037-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-04 Gregorian' );
Trewsday 13 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271318400, 'utc_rd_as_seconds() on 2037-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743881,
  0,
  0
]
, 'utc_rd_values() on 2037-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2037-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2037-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-05 Gregorian' );
Hevensday 14 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271404800, 'utc_rd_as_seconds() on 2037-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743882,
  0,
  0
]
, 'utc_rd_values() on 2037-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2037-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2037-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-06 Gregorian' );
Mersday 15 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271491200, 'utc_rd_as_seconds() on 2037-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743883,
  0,
  0
]
, 'utc_rd_values() on 2037-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2037-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2037-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-07 Gregorian' );
Highday 16 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271577600, 'utc_rd_as_seconds() on 2037-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743884,
  0,
  0
]
, 'utc_rd_values() on 2037-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  37
]
, 'week() on 2037-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2037-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2037-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2037-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-08 Gregorian' );
Sterday 17 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271664000, 'utc_rd_as_seconds() on 2037-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743885,
  0,
  0
]
, 'utc_rd_values() on 2037-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2037-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2037-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-09 Gregorian' );
Sunday 18 Halimath 7501

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271750400, 'utc_rd_as_seconds() on 2037-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743886,
  0,
  0
]
, 'utc_rd_values() on 2037-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2037-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2037-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-10 Gregorian' );
Monday 19 Halimath 7501

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271836800, 'utc_rd_as_seconds() on 2037-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743887,
  0,
  0
]
, 'utc_rd_values() on 2037-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2037-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2037-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-11 Gregorian' );
Trewsday 20 Halimath 7501

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64271923200, 'utc_rd_as_seconds() on 2037-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743888,
  0,
  0
]
, 'utc_rd_values() on 2037-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2037-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2037-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-12 Gregorian' );
Hevensday 21 Halimath 7501

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272009600, 'utc_rd_as_seconds() on 2037-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743889,
  0,
  0
]
, 'utc_rd_values() on 2037-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2037-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2037-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-13 Gregorian' );
Mersday 22 Halimath 7501

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272096000, 'utc_rd_as_seconds() on 2037-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743890,
  0,
  0
]
, 'utc_rd_values() on 2037-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2037-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2037-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-14 Gregorian' );
Highday 23 Halimath 7501

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272182400, 'utc_rd_as_seconds() on 2037-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743891,
  0,
  0
]
, 'utc_rd_values() on 2037-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  38
]
, 'week() on 2037-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2037-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2037-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2037-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-15 Gregorian' );
Sterday 24 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272268800, 'utc_rd_as_seconds() on 2037-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743892,
  0,
  0
]
, 'utc_rd_values() on 2037-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2037-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2037-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-16 Gregorian' );
Sunday 25 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272355200, 'utc_rd_as_seconds() on 2037-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743893,
  0,
  0
]
, 'utc_rd_values() on 2037-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2037-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2037-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-17 Gregorian' );
Monday 26 Halimath 7501

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272441600, 'utc_rd_as_seconds() on 2037-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743894,
  0,
  0
]
, 'utc_rd_values() on 2037-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2037-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2037-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-18 Gregorian' );
Trewsday 27 Halimath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272528000, 'utc_rd_as_seconds() on 2037-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743895,
  0,
  0
]
, 'utc_rd_values() on 2037-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2037-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2037-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-19 Gregorian' );
Hevensday 28 Halimath 7501

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272614400, 'utc_rd_as_seconds() on 2037-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743896,
  0,
  0
]
, 'utc_rd_values() on 2037-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2037-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2037-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-20 Gregorian' );
Mersday 29 Halimath 7501

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272700800, 'utc_rd_as_seconds() on 2037-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743897,
  0,
  0
]
, 'utc_rd_values() on 2037-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2037-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2037-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2037-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2037-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-21 Gregorian' );
Highday 30 Halimath 7501

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272787200, 'utc_rd_as_seconds() on 2037-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743898,
  0,
  0
]
, 'utc_rd_values() on 2037-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  39
]
, 'week() on 2037-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2037-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2037-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2037-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-22 Gregorian' );
Sterday 1 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272873600, 'utc_rd_as_seconds() on 2037-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743899,
  0,
  0
]
, 'utc_rd_values() on 2037-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2037-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2037-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-23 Gregorian' );
Sunday 2 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64272960000, 'utc_rd_as_seconds() on 2037-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743900,
  0,
  0
]
, 'utc_rd_values() on 2037-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2037-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2037-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-24 Gregorian' );
Monday 3 Winterfilth 7501

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273046400, 'utc_rd_as_seconds() on 2037-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743901,
  0,
  0
]
, 'utc_rd_values() on 2037-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2037-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2037-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-25 Gregorian' );
Trewsday 4 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273132800, 'utc_rd_as_seconds() on 2037-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743902,
  0,
  0
]
, 'utc_rd_values() on 2037-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2037-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2037-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-26 Gregorian' );
Hevensday 5 Winterfilth 7501

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273219200, 'utc_rd_as_seconds() on 2037-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743903,
  0,
  0
]
, 'utc_rd_values() on 2037-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2037-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2037-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-27 Gregorian' );
Mersday 6 Winterfilth 7501

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273305600, 'utc_rd_as_seconds() on 2037-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743904,
  0,
  0
]
, 'utc_rd_values() on 2037-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2037-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2037-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-28 Gregorian' );
Highday 7 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273392000, 'utc_rd_as_seconds() on 2037-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743905,
  0,
  0
]
, 'utc_rd_values() on 2037-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  40
]
, 'week() on 2037-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2037-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2037-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2037-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-29 Gregorian' );
Sterday 8 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273478400, 'utc_rd_as_seconds() on 2037-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743906,
  0,
  0
]
, 'utc_rd_values() on 2037-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2037-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2037-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-09-30 Gregorian' );
Sunday 9 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273564800, 'utc_rd_as_seconds() on 2037-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743907,
  0,
  0
]
, 'utc_rd_values() on 2037-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2037-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2037-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-01 Gregorian' );
Monday 10 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273651200, 'utc_rd_as_seconds() on 2037-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743908,
  0,
  0
]
, 'utc_rd_values() on 2037-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2037-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2037-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-02 Gregorian' );
Trewsday 11 Winterfilth 7501

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273737600, 'utc_rd_as_seconds() on 2037-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743909,
  0,
  0
]
, 'utc_rd_values() on 2037-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2037-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2037-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-03 Gregorian' );
Hevensday 12 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273824000, 'utc_rd_as_seconds() on 2037-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743910,
  0,
  0
]
, 'utc_rd_values() on 2037-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2037-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2037-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-04 Gregorian' );
Mersday 13 Winterfilth 7501

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273910400, 'utc_rd_as_seconds() on 2037-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743911,
  0,
  0
]
, 'utc_rd_values() on 2037-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2037-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2037-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-05 Gregorian' );
Highday 14 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64273996800, 'utc_rd_as_seconds() on 2037-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743912,
  0,
  0
]
, 'utc_rd_values() on 2037-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  41
]
, 'week() on 2037-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2037-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2037-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2037-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-06 Gregorian' );
Sterday 15 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274083200, 'utc_rd_as_seconds() on 2037-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743913,
  0,
  0
]
, 'utc_rd_values() on 2037-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2037-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2037-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-07 Gregorian' );
Sunday 16 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274169600, 'utc_rd_as_seconds() on 2037-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743914,
  0,
  0
]
, 'utc_rd_values() on 2037-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2037-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2037-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-08 Gregorian' );
Monday 17 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274256000, 'utc_rd_as_seconds() on 2037-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743915,
  0,
  0
]
, 'utc_rd_values() on 2037-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2037-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2037-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-09 Gregorian' );
Trewsday 18 Winterfilth 7501

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274342400, 'utc_rd_as_seconds() on 2037-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743916,
  0,
  0
]
, 'utc_rd_values() on 2037-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2037-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2037-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-10 Gregorian' );
Hevensday 19 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274428800, 'utc_rd_as_seconds() on 2037-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743917,
  0,
  0
]
, 'utc_rd_values() on 2037-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2037-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2037-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-11 Gregorian' );
Mersday 20 Winterfilth 7501

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274515200, 'utc_rd_as_seconds() on 2037-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743918,
  0,
  0
]
, 'utc_rd_values() on 2037-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2037-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2037-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-12 Gregorian' );
Highday 21 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274601600, 'utc_rd_as_seconds() on 2037-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743919,
  0,
  0
]
, 'utc_rd_values() on 2037-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  42
]
, 'week() on 2037-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2037-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2037-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2037-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-13 Gregorian' );
Sterday 22 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274688000, 'utc_rd_as_seconds() on 2037-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743920,
  0,
  0
]
, 'utc_rd_values() on 2037-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2037-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2037-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-14 Gregorian' );
Sunday 23 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274774400, 'utc_rd_as_seconds() on 2037-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743921,
  0,
  0
]
, 'utc_rd_values() on 2037-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2037-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2037-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-15 Gregorian' );
Monday 24 Winterfilth 7501

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274860800, 'utc_rd_as_seconds() on 2037-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743922,
  0,
  0
]
, 'utc_rd_values() on 2037-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2037-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2037-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-16 Gregorian' );
Trewsday 25 Winterfilth 7501

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64274947200, 'utc_rd_as_seconds() on 2037-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743923,
  0,
  0
]
, 'utc_rd_values() on 2037-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2037-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2037-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-17 Gregorian' );
Hevensday 26 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275033600, 'utc_rd_as_seconds() on 2037-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743924,
  0,
  0
]
, 'utc_rd_values() on 2037-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2037-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2037-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-18 Gregorian' );
Mersday 27 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275120000, 'utc_rd_as_seconds() on 2037-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743925,
  0,
  0
]
, 'utc_rd_values() on 2037-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2037-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2037-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-19 Gregorian' );
Highday 28 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275206400, 'utc_rd_as_seconds() on 2037-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743926,
  0,
  0
]
, 'utc_rd_values() on 2037-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  43
]
, 'week() on 2037-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2037-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2037-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2037-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-20 Gregorian' );
Sterday 29 Winterfilth 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275292800, 'utc_rd_as_seconds() on 2037-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743927,
  0,
  0
]
, 'utc_rd_values() on 2037-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2037-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2037-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2037-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2037-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-21 Gregorian' );
Sunday 30 Winterfilth 7501

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275379200, 'utc_rd_as_seconds() on 2037-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743928,
  0,
  0
]
, 'utc_rd_values() on 2037-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2037-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2037-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-22 Gregorian' );
Monday 1 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275465600, 'utc_rd_as_seconds() on 2037-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743929,
  0,
  0
]
, 'utc_rd_values() on 2037-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2037-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2037-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-23 Gregorian' );
Trewsday 2 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275552000, 'utc_rd_as_seconds() on 2037-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743930,
  0,
  0
]
, 'utc_rd_values() on 2037-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2037-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2037-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-24 Gregorian' );
Hevensday 3 Blotmath 7501

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275638400, 'utc_rd_as_seconds() on 2037-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743931,
  0,
  0
]
, 'utc_rd_values() on 2037-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2037-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2037-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-25 Gregorian' );
Mersday 4 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275724800, 'utc_rd_as_seconds() on 2037-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743932,
  0,
  0
]
, 'utc_rd_values() on 2037-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2037-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2037-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-26 Gregorian' );
Highday 5 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275811200, 'utc_rd_as_seconds() on 2037-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743933,
  0,
  0
]
, 'utc_rd_values() on 2037-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  44
]
, 'week() on 2037-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2037-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2037-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2037-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-27 Gregorian' );
Sterday 6 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275897600, 'utc_rd_as_seconds() on 2037-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743934,
  0,
  0
]
, 'utc_rd_values() on 2037-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2037-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2037-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-28 Gregorian' );
Sunday 7 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64275984000, 'utc_rd_as_seconds() on 2037-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743935,
  0,
  0
]
, 'utc_rd_values() on 2037-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2037-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2037-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-29 Gregorian' );
Monday 8 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276070400, 'utc_rd_as_seconds() on 2037-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743936,
  0,
  0
]
, 'utc_rd_values() on 2037-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2037-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2037-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-30 Gregorian' );
Trewsday 9 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276156800, 'utc_rd_as_seconds() on 2037-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743937,
  0,
  0
]
, 'utc_rd_values() on 2037-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2037-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2037-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-10-31 Gregorian' );
Hevensday 10 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276243200, 'utc_rd_as_seconds() on 2037-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743938,
  0,
  0
]
, 'utc_rd_values() on 2037-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2037-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2037-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-01 Gregorian' );
Mersday 11 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276329600, 'utc_rd_as_seconds() on 2037-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743939,
  0,
  0
]
, 'utc_rd_values() on 2037-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2037-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2037-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-02 Gregorian' );
Highday 12 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276416000, 'utc_rd_as_seconds() on 2037-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743940,
  0,
  0
]
, 'utc_rd_values() on 2037-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  45
]
, 'week() on 2037-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2037-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2037-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2037-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-03 Gregorian' );
Sterday 13 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276502400, 'utc_rd_as_seconds() on 2037-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743941,
  0,
  0
]
, 'utc_rd_values() on 2037-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2037-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2037-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-04 Gregorian' );
Sunday 14 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276588800, 'utc_rd_as_seconds() on 2037-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743942,
  0,
  0
]
, 'utc_rd_values() on 2037-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2037-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2037-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-05 Gregorian' );
Monday 15 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276675200, 'utc_rd_as_seconds() on 2037-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743943,
  0,
  0
]
, 'utc_rd_values() on 2037-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2037-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2037-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-06 Gregorian' );
Trewsday 16 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276761600, 'utc_rd_as_seconds() on 2037-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743944,
  0,
  0
]
, 'utc_rd_values() on 2037-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2037-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2037-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-07 Gregorian' );
Hevensday 17 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276848000, 'utc_rd_as_seconds() on 2037-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743945,
  0,
  0
]
, 'utc_rd_values() on 2037-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2037-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2037-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-08 Gregorian' );
Mersday 18 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64276934400, 'utc_rd_as_seconds() on 2037-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743946,
  0,
  0
]
, 'utc_rd_values() on 2037-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2037-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2037-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-09 Gregorian' );
Highday 19 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277020800, 'utc_rd_as_seconds() on 2037-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743947,
  0,
  0
]
, 'utc_rd_values() on 2037-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  46
]
, 'week() on 2037-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2037-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2037-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2037-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-10 Gregorian' );
Sterday 20 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277107200, 'utc_rd_as_seconds() on 2037-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743948,
  0,
  0
]
, 'utc_rd_values() on 2037-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2037-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2037-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-11 Gregorian' );
Sunday 21 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277193600, 'utc_rd_as_seconds() on 2037-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743949,
  0,
  0
]
, 'utc_rd_values() on 2037-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2037-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2037-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-12 Gregorian' );
Monday 22 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277280000, 'utc_rd_as_seconds() on 2037-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743950,
  0,
  0
]
, 'utc_rd_values() on 2037-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2037-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2037-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-13 Gregorian' );
Trewsday 23 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277366400, 'utc_rd_as_seconds() on 2037-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743951,
  0,
  0
]
, 'utc_rd_values() on 2037-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2037-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2037-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-14 Gregorian' );
Hevensday 24 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277452800, 'utc_rd_as_seconds() on 2037-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743952,
  0,
  0
]
, 'utc_rd_values() on 2037-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2037-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2037-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-15 Gregorian' );
Mersday 25 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277539200, 'utc_rd_as_seconds() on 2037-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743953,
  0,
  0
]
, 'utc_rd_values() on 2037-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2037-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2037-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-16 Gregorian' );
Highday 26 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277625600, 'utc_rd_as_seconds() on 2037-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743954,
  0,
  0
]
, 'utc_rd_values() on 2037-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  47
]
, 'week() on 2037-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2037-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2037-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2037-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-17 Gregorian' );
Sterday 27 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277712000, 'utc_rd_as_seconds() on 2037-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743955,
  0,
  0
]
, 'utc_rd_values() on 2037-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2037-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2037-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-18 Gregorian' );
Sunday 28 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277798400, 'utc_rd_as_seconds() on 2037-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743956,
  0,
  0
]
, 'utc_rd_values() on 2037-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2037-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2037-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-19 Gregorian' );
Monday 29 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277884800, 'utc_rd_as_seconds() on 2037-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743957,
  0,
  0
]
, 'utc_rd_values() on 2037-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2037-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2037-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2037-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2037-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-20 Gregorian' );
Trewsday 30 Blotmath 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64277971200, 'utc_rd_as_seconds() on 2037-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743958,
  0,
  0
]
, 'utc_rd_values() on 2037-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2037-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2037-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-21 Gregorian' );
Hevensday 1 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278057600, 'utc_rd_as_seconds() on 2037-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743959,
  0,
  0
]
, 'utc_rd_values() on 2037-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2037-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2037-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-22 Gregorian' );
Mersday 2 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278144000, 'utc_rd_as_seconds() on 2037-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743960,
  0,
  0
]
, 'utc_rd_values() on 2037-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2037-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2037-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-23 Gregorian' );
Highday 3 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278230400, 'utc_rd_as_seconds() on 2037-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743961,
  0,
  0
]
, 'utc_rd_values() on 2037-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  48
]
, 'week() on 2037-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2037-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2037-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2037-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-24 Gregorian' );
Sterday 4 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278316800, 'utc_rd_as_seconds() on 2037-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743962,
  0,
  0
]
, 'utc_rd_values() on 2037-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2037-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2037-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-25 Gregorian' );
Sunday 5 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278403200, 'utc_rd_as_seconds() on 2037-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743963,
  0,
  0
]
, 'utc_rd_values() on 2037-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2037-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2037-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-26 Gregorian' );
Monday 6 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278489600, 'utc_rd_as_seconds() on 2037-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743964,
  0,
  0
]
, 'utc_rd_values() on 2037-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2037-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2037-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-27 Gregorian' );
Trewsday 7 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278576000, 'utc_rd_as_seconds() on 2037-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743965,
  0,
  0
]
, 'utc_rd_values() on 2037-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2037-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2037-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-28 Gregorian' );
Hevensday 8 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278662400, 'utc_rd_as_seconds() on 2037-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743966,
  0,
  0
]
, 'utc_rd_values() on 2037-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2037-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2037-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-29 Gregorian' );
Mersday 9 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278748800, 'utc_rd_as_seconds() on 2037-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743967,
  0,
  0
]
, 'utc_rd_values() on 2037-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2037-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2037-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2037-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2037-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2037-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-11-30 Gregorian' );
Highday 10 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278835200, 'utc_rd_as_seconds() on 2037-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743968,
  0,
  0
]
, 'utc_rd_values() on 2037-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  49
]
, 'week() on 2037-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2037-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2037-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2037-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2037-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2037-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2037-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-01 Gregorian' );
Sterday 11 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64278921600, 'utc_rd_as_seconds() on 2037-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743969,
  0,
  0
]
, 'utc_rd_values() on 2037-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2037-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2037-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2037-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2037-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2037-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-02 Gregorian' );
Sunday 12 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279008000, 'utc_rd_as_seconds() on 2037-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743970,
  0,
  0
]
, 'utc_rd_values() on 2037-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2037-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2037-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2037-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2037-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2037-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-03 Gregorian' );
Monday 13 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279094400, 'utc_rd_as_seconds() on 2037-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743971,
  0,
  0
]
, 'utc_rd_values() on 2037-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2037-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2037-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2037-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2037-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2037-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-04 Gregorian' );
Trewsday 14 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279180800, 'utc_rd_as_seconds() on 2037-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743972,
  0,
  0
]
, 'utc_rd_values() on 2037-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2037-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2037-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2037-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2037-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2037-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-05 Gregorian' );
Hevensday 15 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279267200, 'utc_rd_as_seconds() on 2037-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743973,
  0,
  0
]
, 'utc_rd_values() on 2037-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2037-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2037-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2037-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2037-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2037-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-06 Gregorian' );
Mersday 16 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279353600, 'utc_rd_as_seconds() on 2037-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743974,
  0,
  0
]
, 'utc_rd_values() on 2037-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2037-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2037-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2037-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2037-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2037-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-07 Gregorian' );
Highday 17 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279440000, 'utc_rd_as_seconds() on 2037-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743975,
  0,
  0
]
, 'utc_rd_values() on 2037-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  50
]
, 'week() on 2037-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2037-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2037-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2037-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2037-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2037-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2037-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-08 Gregorian' );
Sterday 18 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279526400, 'utc_rd_as_seconds() on 2037-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743976,
  0,
  0
]
, 'utc_rd_values() on 2037-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2037-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2037-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2037-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2037-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2037-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-09 Gregorian' );
Sunday 19 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279612800, 'utc_rd_as_seconds() on 2037-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743977,
  0,
  0
]
, 'utc_rd_values() on 2037-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2037-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2037-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2037-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2037-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2037-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-10 Gregorian' );
Monday 20 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279699200, 'utc_rd_as_seconds() on 2037-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743978,
  0,
  0
]
, 'utc_rd_values() on 2037-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2037-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2037-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2037-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2037-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2037-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-11 Gregorian' );
Trewsday 21 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279785600, 'utc_rd_as_seconds() on 2037-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743979,
  0,
  0
]
, 'utc_rd_values() on 2037-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2037-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2037-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2037-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2037-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2037-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-12 Gregorian' );
Hevensday 22 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279872000, 'utc_rd_as_seconds() on 2037-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743980,
  0,
  0
]
, 'utc_rd_values() on 2037-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2037-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2037-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2037-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2037-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2037-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-13 Gregorian' );
Mersday 23 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64279958400, 'utc_rd_as_seconds() on 2037-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743981,
  0,
  0
]
, 'utc_rd_values() on 2037-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2037-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2037-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2037-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2037-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2037-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-14 Gregorian' );
Highday 24 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280044800, 'utc_rd_as_seconds() on 2037-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743982,
  0,
  0
]
, 'utc_rd_values() on 2037-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  51
]
, 'week() on 2037-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2037-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2037-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2037-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2037-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2037-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2037-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-15 Gregorian' );
Sterday 25 Foreyule 7501

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280131200, 'utc_rd_as_seconds() on 2037-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743983,
  0,
  0
]
, 'utc_rd_values() on 2037-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2037-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2037-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2037-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2037-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2037-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-16 Gregorian' );
Sunday 26 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280217600, 'utc_rd_as_seconds() on 2037-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743984,
  0,
  0
]
, 'utc_rd_values() on 2037-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2037-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2037-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2037-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2037-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2037-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-17 Gregorian' );
Monday 27 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280304000, 'utc_rd_as_seconds() on 2037-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743985,
  0,
  0
]
, 'utc_rd_values() on 2037-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2037-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2037-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2037-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2037-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2037-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-18 Gregorian' );
Trewsday 28 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280390400, 'utc_rd_as_seconds() on 2037-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743986,
  0,
  0
]
, 'utc_rd_values() on 2037-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2037-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2037-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2037-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2037-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2037-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-19 Gregorian' );
Hevensday 29 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280476800, 'utc_rd_as_seconds() on 2037-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743987,
  0,
  0
]
, 'utc_rd_values() on 2037-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2037-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2037-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2037-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2037-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2037-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2037-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2037-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-20 Gregorian' );
Mersday 30 Foreyule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280563200, 'utc_rd_as_seconds() on 2037-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743988,
  0,
  0
]
, 'utc_rd_values() on 2037-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2037-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2037-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2037-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2037-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2037-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2037-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2037-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2037-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2037-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-21 Gregorian' );
Highday 1 Yule 7501
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280649600, 'utc_rd_as_seconds() on 2037-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743989,
  0,
  0
]
, 'utc_rd_values() on 2037-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7501,
  52
]
, 'week() on 2037-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2037-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7501, 'week_year() on 2037-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7501, 'year() on 2037-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2037-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2037-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2037-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2037-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2037-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2037-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2037-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2037-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2037-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-22 Gregorian' );
Sterday 2 Yule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280736000, 'utc_rd_as_seconds() on 2037-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743990,
  0,
  0
]
, 'utc_rd_values() on 2037-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2037-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2037-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2037-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2037-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2037-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-23 Gregorian' );
Sunday 1 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280822400, 'utc_rd_as_seconds() on 2037-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743991,
  0,
  0
]
, 'utc_rd_values() on 2037-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2037-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2037-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2037-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2037-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2037-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-24 Gregorian' );
Monday 2 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280908800, 'utc_rd_as_seconds() on 2037-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743992,
  0,
  0
]
, 'utc_rd_values() on 2037-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2037-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2037-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2037-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2037-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2037-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2037-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2037-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2037-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2037-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-25 Gregorian' );
Trewsday 3 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64280995200, 'utc_rd_as_seconds() on 2037-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743993,
  0,
  0
]
, 'utc_rd_values() on 2037-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2037-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2037-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2037-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2037-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2037-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2037-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2037-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2037-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2037-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2037-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-26 Gregorian' );
Hevensday 4 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281081600, 'utc_rd_as_seconds() on 2037-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743994,
  0,
  0
]
, 'utc_rd_values() on 2037-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2037-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2037-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2037-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2037-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2037-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2037-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2037-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2037-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2037-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2037-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-27 Gregorian' );
Mersday 5 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281168000, 'utc_rd_as_seconds() on 2037-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743995,
  0,
  0
]
, 'utc_rd_values() on 2037-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2037-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2037-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2037-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2037-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2037-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2037-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2037-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2037-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2037-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2037-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-28 Gregorian' );
Highday 6 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281254400, 'utc_rd_as_seconds() on 2037-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743996,
  0,
  0
]
, 'utc_rd_values() on 2037-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2037-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  1
]
, 'week() on 2037-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2037-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2037-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2037-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2037-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2037-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2037-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2037-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2037-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2037-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2037-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-29 Gregorian' );
Sterday 7 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281340800, 'utc_rd_as_seconds() on 2037-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743997,
  0,
  0
]
, 'utc_rd_values() on 2037-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2037-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2037-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2037-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2037-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2037-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2037-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2037-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2037-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2037-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2037-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2037-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-30 Gregorian' );
Sunday 8 Afteryule 7502

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281427200, 'utc_rd_as_seconds() on 2037-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743998,
  0,
  0
]
, 'utc_rd_values() on 2037-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2037-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2037-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2037 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2037,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2037-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2037-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2037-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2037-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2037-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2037-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2037-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2037-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2037-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2037-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2037-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2037-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2037-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2037-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2037-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2037-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2037-12-31 Gregorian' );
Monday 9 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281513600, 'utc_rd_as_seconds() on 2037-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  743999,
  0,
  0
]
, 'utc_rd_values() on 2037-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2037-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2037-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2037-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2037-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2037-12-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-01-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-01-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-01-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-01-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-01-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 11, 'day_of_year() on 2038-01-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-01-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 11, 'doy() on 2038-01-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-01-01 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-01 Gregorian' );
Trewsday 10 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281600000, 'utc_rd_as_seconds() on 2038-01-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744000,
  0,
  0
]
, 'utc_rd_values() on 2038-01-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-01-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2038-01-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-01-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-01-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-01-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-01-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-01-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-01-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 12, 'day_of_year() on 2038-01-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-01-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 12, 'doy() on 2038-01-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-01-02 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-02 Gregorian' );
Hevensday 11 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281686400, 'utc_rd_as_seconds() on 2038-01-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744001,
  0,
  0
]
, 'utc_rd_values() on 2038-01-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-01-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2038-01-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-01-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-01-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-01-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-01-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-01-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-01-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 13, 'day_of_year() on 2038-01-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-01-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 13, 'doy() on 2038-01-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-01-03 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-03 Gregorian' );
Mersday 12 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281772800, 'utc_rd_as_seconds() on 2038-01-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744002,
  0,
  0
]
, 'utc_rd_values() on 2038-01-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-01-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2038-01-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-01-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-01-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-01-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-01-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-01-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-01-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 14, 'day_of_year() on 2038-01-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-01-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 14, 'doy() on 2038-01-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-01-04 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-04 Gregorian' );
Highday 13 Afteryule 7502

The Company of the Ring reaches the West-gate of Moria at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281859200, 'utc_rd_as_seconds() on 2038-01-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744003,
  0,
  0
]
, 'utc_rd_values() on 2038-01-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-01-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  2
]
, 'week() on 2038-01-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-01-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-01-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-01-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-01-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-01-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-01-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 15, 'day_of_year() on 2038-01-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-01-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 15, 'doy() on 2038-01-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-01-05 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-05 Gregorian' );
Sterday 14 Afteryule 7502

The Company of the Ring spends the night in Moria hall 21, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64281945600, 'utc_rd_as_seconds() on 2038-01-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744004,
  0,
  0
]
, 'utc_rd_values() on 2038-01-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-01-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-01-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-01-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-01-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-01-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-01-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 16, 'day_of_year() on 2038-01-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-01-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 16, 'doy() on 2038-01-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-01-06 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-06 Gregorian' );
Sunday 15 Afteryule 7502

The Bridge of Khazad-dum, and the fall of Gandalf, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282032000, 'utc_rd_as_seconds() on 2038-01-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744005,
  0,
  0
]
, 'utc_rd_values() on 2038-01-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-01-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-01-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-01-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-01-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-01-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-01-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 17, 'day_of_year() on 2038-01-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-01-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 17, 'doy() on 2038-01-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-01-07 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-07 Gregorian' );
Monday 16 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282118400, 'utc_rd_as_seconds() on 2038-01-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744006,
  0,
  0
]
, 'utc_rd_values() on 2038-01-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-01-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-01-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-01-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-01-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-01-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-01-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 18, 'day_of_year() on 2038-01-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-01-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 18, 'doy() on 2038-01-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-01-08 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-08 Gregorian' );
Trewsday 17 Afteryule 7502

The Company of the Ring comes to Caras Galadhon at evening, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282204800, 'utc_rd_as_seconds() on 2038-01-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744007,
  0,
  0
]
, 'utc_rd_values() on 2038-01-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-01-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-01-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-01-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-01-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-01-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-01-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 19, 'day_of_year() on 2038-01-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-01-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 19, 'doy() on 2038-01-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-01-09 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-09 Gregorian' );
Hevensday 18 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282291200, 'utc_rd_as_seconds() on 2038-01-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744008,
  0,
  0
]
, 'utc_rd_values() on 2038-01-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-01-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-01-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-01-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-01-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-01-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-01-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 20, 'day_of_year() on 2038-01-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-01-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 20, 'doy() on 2038-01-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-01-10 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-10 Gregorian' );
Mersday 19 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282377600, 'utc_rd_as_seconds() on 2038-01-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744009,
  0,
  0
]
, 'utc_rd_values() on 2038-01-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-01-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-01-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-01-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-01-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-01-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-01-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 21, 'day_of_year() on 2038-01-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-01-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 21, 'doy() on 2038-01-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-01-11 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-11 Gregorian' );
Highday 20 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282464000, 'utc_rd_as_seconds() on 2038-01-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744010,
  0,
  0
]
, 'utc_rd_values() on 2038-01-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-01-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  3
]
, 'week() on 2038-01-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 3, 'week_number() on 2038-01-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-01-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-01-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-01-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-01-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-01-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 22, 'day_of_year() on 2038-01-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-01-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 22, 'doy() on 2038-01-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-01-12 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-12 Gregorian' );
Sterday 21 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282550400, 'utc_rd_as_seconds() on 2038-01-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744011,
  0,
  0
]
, 'utc_rd_values() on 2038-01-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-01-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-01-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-01-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-01-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-01-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-01-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 23, 'day_of_year() on 2038-01-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-01-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 23, 'doy() on 2038-01-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-01-13 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-13 Gregorian' );
Sunday 22 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282636800, 'utc_rd_as_seconds() on 2038-01-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744012,
  0,
  0
]
, 'utc_rd_values() on 2038-01-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-01-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-01-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-01-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-01-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-01-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-01-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 24, 'day_of_year() on 2038-01-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-01-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 24, 'doy() on 2038-01-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-01-14 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-14 Gregorian' );
Monday 23 Afteryule 7502

Gandalf pursues the Balrog to the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282723200, 'utc_rd_as_seconds() on 2038-01-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744013,
  0,
  0
]
, 'utc_rd_values() on 2038-01-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-01-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-01-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-01-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-01-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-01-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-01-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 25, 'day_of_year() on 2038-01-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-01-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 25, 'doy() on 2038-01-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-01-15 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-15 Gregorian' );
Trewsday 24 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282809600, 'utc_rd_as_seconds() on 2038-01-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744014,
  0,
  0
]
, 'utc_rd_values() on 2038-01-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-01-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-01-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-01-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-01-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-01-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-01-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 26, 'day_of_year() on 2038-01-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-01-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 26, 'doy() on 2038-01-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-01-16 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-16 Gregorian' );
Hevensday 25 Afteryule 7502

Gandalf casts down the Balrog, and passes away.
His body lies on the peak of Zirakzigil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282896000, 'utc_rd_as_seconds() on 2038-01-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744015,
  0,
  0
]
, 'utc_rd_values() on 2038-01-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-01-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-01-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-01-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-01-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-01-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-01-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 27, 'day_of_year() on 2038-01-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-01-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 27, 'doy() on 2038-01-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-01-17 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-17 Gregorian' );
Mersday 26 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64282982400, 'utc_rd_as_seconds() on 2038-01-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744016,
  0,
  0
]
, 'utc_rd_values() on 2038-01-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-01-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-01-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-01-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-01-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-01-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-01-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 28, 'day_of_year() on 2038-01-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-01-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 28, 'doy() on 2038-01-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-01-18 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-18 Gregorian' );
Highday 27 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283068800, 'utc_rd_as_seconds() on 2038-01-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744017,
  0,
  0
]
, 'utc_rd_values() on 2038-01-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-01-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  4
]
, 'week() on 2038-01-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 4, 'week_number() on 2038-01-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-01-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-01-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-01-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-01-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-01-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 29, 'day_of_year() on 2038-01-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-01-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 29, 'doy() on 2038-01-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-01-19 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-19 Gregorian' );
Sterday 28 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283155200, 'utc_rd_as_seconds() on 2038-01-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744018,
  0,
  0
]
, 'utc_rd_values() on 2038-01-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-01-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-01-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-01-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-01-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-01-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-01-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 30, 'day_of_year() on 2038-01-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-01-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 30, 'doy() on 2038-01-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-01-20 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-20 Gregorian' );
Sunday 29 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283241600, 'utc_rd_as_seconds() on 2038-01-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744019,
  0,
  0
]
, 'utc_rd_values() on 2038-01-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-01-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-01-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-01-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-01-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-01-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-01-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 31, 'day_of_year() on 2038-01-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-01-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 31, 'doy() on 2038-01-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-01-21 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-01-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-01-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-21 Gregorian' );
Monday 30 Afteryule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283328000, 'utc_rd_as_seconds() on 2038-01-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744020,
  0,
  0
]
, 'utc_rd_values() on 2038-01-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-01-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-01-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-01-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-01-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-01-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-01-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 32, 'day_of_year() on 2038-01-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-01-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 32, 'doy() on 2038-01-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-01-22 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-22 Gregorian' );
Trewsday 1 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283414400, 'utc_rd_as_seconds() on 2038-01-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744021,
  0,
  0
]
, 'utc_rd_values() on 2038-01-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-01-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-01-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-01-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-01-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-01-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-01-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 33, 'day_of_year() on 2038-01-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-01-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 33, 'doy() on 2038-01-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-01-23 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-23 Gregorian' );
Hevensday 2 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283500800, 'utc_rd_as_seconds() on 2038-01-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744022,
  0,
  0
]
, 'utc_rd_values() on 2038-01-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-01-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-01-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-01-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-01-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-01-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-01-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 34, 'day_of_year() on 2038-01-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-01-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 34, 'doy() on 2038-01-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-01-24 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-24 Gregorian' );
Mersday 3 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283587200, 'utc_rd_as_seconds() on 2038-01-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744023,
  0,
  0
]
, 'utc_rd_values() on 2038-01-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-01-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-01-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-01-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-01-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-01-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-01-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 35, 'day_of_year() on 2038-01-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-01-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 35, 'doy() on 2038-01-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-01-25 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-25 Gregorian' );
Highday 4 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283673600, 'utc_rd_as_seconds() on 2038-01-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744024,
  0,
  0
]
, 'utc_rd_values() on 2038-01-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-01-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  5
]
, 'week() on 2038-01-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 5, 'week_number() on 2038-01-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-01-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-01-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-01-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-01-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-01-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 36, 'day_of_year() on 2038-01-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-01-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 36, 'doy() on 2038-01-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-01-26 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-26 Gregorian' );
Sterday 5 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283760000, 'utc_rd_as_seconds() on 2038-01-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744025,
  0,
  0
]
, 'utc_rd_values() on 2038-01-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-01-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-01-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-01-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-01-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-01-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-01-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 37, 'day_of_year() on 2038-01-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-01-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 37, 'doy() on 2038-01-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-01-27 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-27 Gregorian' );
Sunday 6 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283846400, 'utc_rd_as_seconds() on 2038-01-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744026,
  0,
  0
]
, 'utc_rd_values() on 2038-01-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-01-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-01-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-01-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-01-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-01-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-01-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 38, 'day_of_year() on 2038-01-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-01-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 38, 'doy() on 2038-01-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-01-28 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-28 Gregorian' );
Monday 7 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64283932800, 'utc_rd_as_seconds() on 2038-01-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744027,
  0,
  0
]
, 'utc_rd_values() on 2038-01-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-01-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-01-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-01-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-01-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-01-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-01-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 39, 'day_of_year() on 2038-01-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-01-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 39, 'doy() on 2038-01-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-01-29 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-29 Gregorian' );
Trewsday 8 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284019200, 'utc_rd_as_seconds() on 2038-01-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744028,
  0,
  0
]
, 'utc_rd_values() on 2038-01-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-01-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-01-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-01-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-01-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-01-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-01-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 40, 'day_of_year() on 2038-01-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-01-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 40, 'doy() on 2038-01-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-01-30 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-30 Gregorian' );
Hevensday 9 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284105600, 'utc_rd_as_seconds() on 2038-01-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744029,
  0,
  0
]
, 'utc_rd_values() on 2038-01-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-01-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 1 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 1,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-01-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-01-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-01-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-01-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-01-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 41, 'day_of_year() on 2038-01-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-01-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 41, 'doy() on 2038-01-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-01-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-01-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-01-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-01-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-01-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-01-31 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-01-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-01-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-01-31 Gregorian' );
Mersday 10 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284192000, 'utc_rd_as_seconds() on 2038-01-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744030,
  0,
  0
]
, 'utc_rd_values() on 2038-01-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-01-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-01-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-01-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-01-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-01-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-02-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-02-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-02-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-02-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-02-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 42, 'day_of_year() on 2038-02-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-02-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 42, 'doy() on 2038-02-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-02-01 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-01 Gregorian' );
Highday 11 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284278400, 'utc_rd_as_seconds() on 2038-02-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744031,
  0,
  0
]
, 'utc_rd_values() on 2038-02-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-02-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  6
]
, 'week() on 2038-02-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 6, 'week_number() on 2038-02-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-02-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-02-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-02-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-02-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-02-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 43, 'day_of_year() on 2038-02-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-02-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 43, 'doy() on 2038-02-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-02-02 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-02 Gregorian' );
Sterday 12 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284364800, 'utc_rd_as_seconds() on 2038-02-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744032,
  0,
  0
]
, 'utc_rd_values() on 2038-02-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-02-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-02-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-02-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-02-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-02-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-02-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 44, 'day_of_year() on 2038-02-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-02-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 44, 'doy() on 2038-02-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-02-03 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-03 Gregorian' );
Sunday 13 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284451200, 'utc_rd_as_seconds() on 2038-02-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744033,
  0,
  0
]
, 'utc_rd_values() on 2038-02-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-02-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-02-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-02-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-02-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-02-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-02-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 45, 'day_of_year() on 2038-02-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-02-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 45, 'doy() on 2038-02-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-02-04 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-04 Gregorian' );
Monday 14 Solmath 7502

Frodo and Sam look in the Mirror of Galadriel, 1419.
Gandalf returns to life, and lies in a trance, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284537600, 'utc_rd_as_seconds() on 2038-02-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744034,
  0,
  0
]
, 'utc_rd_values() on 2038-02-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-02-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-02-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-02-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-02-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-02-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-02-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 46, 'day_of_year() on 2038-02-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-02-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 46, 'doy() on 2038-02-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-02-05 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-05 Gregorian' );
Trewsday 15 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284624000, 'utc_rd_as_seconds() on 2038-02-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744035,
  0,
  0
]
, 'utc_rd_values() on 2038-02-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-02-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-02-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-02-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-02-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-02-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-02-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 47, 'day_of_year() on 2038-02-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-02-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 47, 'doy() on 2038-02-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-02-06 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-06 Gregorian' );
Hevensday 16 Solmath 7502

Company of the Ring says farewell to Lorien --
Gollum observes departure, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284710400, 'utc_rd_as_seconds() on 2038-02-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744036,
  0,
  0
]
, 'utc_rd_values() on 2038-02-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-02-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-02-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-02-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-02-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-02-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-02-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 48, 'day_of_year() on 2038-02-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-02-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 48, 'doy() on 2038-02-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-02-07 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-07 Gregorian' );
Mersday 17 Solmath 7502

Gwaihir the eagle bears Gandalf to Lorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284796800, 'utc_rd_as_seconds() on 2038-02-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744037,
  0,
  0
]
, 'utc_rd_values() on 2038-02-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-02-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-02-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-02-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-02-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-02-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-02-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 49, 'day_of_year() on 2038-02-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-02-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 49, 'doy() on 2038-02-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-02-08 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-08 Gregorian' );
Highday 18 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284883200, 'utc_rd_as_seconds() on 2038-02-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744038,
  0,
  0
]
, 'utc_rd_values() on 2038-02-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-02-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  7
]
, 'week() on 2038-02-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 7, 'week_number() on 2038-02-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-02-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-02-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-02-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-02-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-02-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 50, 'day_of_year() on 2038-02-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-02-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 50, 'doy() on 2038-02-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-02-09 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-09 Gregorian' );
Sterday 19 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64284969600, 'utc_rd_as_seconds() on 2038-02-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744039,
  0,
  0
]
, 'utc_rd_values() on 2038-02-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-02-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-02-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-02-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-02-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-02-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-02-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 51, 'day_of_year() on 2038-02-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-02-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 51, 'doy() on 2038-02-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-02-10 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-10 Gregorian' );
Sunday 20 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285056000, 'utc_rd_as_seconds() on 2038-02-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744040,
  0,
  0
]
, 'utc_rd_values() on 2038-02-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-02-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-02-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-02-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-02-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-02-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-02-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 52, 'day_of_year() on 2038-02-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-02-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 52, 'doy() on 2038-02-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-02-11 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-11 Gregorian' );
Monday 21 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285142400, 'utc_rd_as_seconds() on 2038-02-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744041,
  0,
  0
]
, 'utc_rd_values() on 2038-02-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-02-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-02-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-02-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-02-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-02-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-02-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 53, 'day_of_year() on 2038-02-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-02-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 53, 'doy() on 2038-02-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-02-12 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-12 Gregorian' );
Trewsday 22 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285228800, 'utc_rd_as_seconds() on 2038-02-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744042,
  0,
  0
]
, 'utc_rd_values() on 2038-02-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-02-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-02-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-02-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-02-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-02-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-02-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 54, 'day_of_year() on 2038-02-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-02-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 54, 'doy() on 2038-02-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-02-13 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-13 Gregorian' );
Hevensday 23 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285315200, 'utc_rd_as_seconds() on 2038-02-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744043,
  0,
  0
]
, 'utc_rd_values() on 2038-02-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-02-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-02-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-02-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-02-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-02-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-02-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 55, 'day_of_year() on 2038-02-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-02-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 55, 'doy() on 2038-02-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-02-14 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-14 Gregorian' );
Mersday 24 Solmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285401600, 'utc_rd_as_seconds() on 2038-02-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744044,
  0,
  0
]
, 'utc_rd_values() on 2038-02-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-02-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-02-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-02-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-02-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-02-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-02-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 56, 'day_of_year() on 2038-02-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-02-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 56, 'doy() on 2038-02-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-02-15 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-15 Gregorian' );
Highday 25 Solmath 7502

The Company of the Ring pass the Argonath and camp at Parth Galen, 1419.
First battle of the Fords of Isen -- Theodred son of Theoden slain, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285488000, 'utc_rd_as_seconds() on 2038-02-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744045,
  0,
  0
]
, 'utc_rd_values() on 2038-02-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-02-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  8
]
, 'week() on 2038-02-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 8, 'week_number() on 2038-02-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-02-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-02-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-02-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-02-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-02-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 57, 'day_of_year() on 2038-02-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-02-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 57, 'doy() on 2038-02-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-02-16 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-16 Gregorian' );
Sterday 26 Solmath 7502

Breaking of the Fellowship, 1419.
Death of Boromir; his horn is heard in Minas Tirith, 1419.
Meriadoc and Peregrin captured by Orcs -- Aragorn pursues, 1419.
Eomer hears of the descent of the Orc-band from Emyn Muil, 1419.
Frodo and Samwise enter the eastern Emyn Muil, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285574400, 'utc_rd_as_seconds() on 2038-02-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744046,
  0,
  0
]
, 'utc_rd_values() on 2038-02-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-02-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-02-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-02-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-02-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-02-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-02-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 58, 'day_of_year() on 2038-02-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-02-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 58, 'doy() on 2038-02-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-02-17 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-17 Gregorian' );
Sunday 27 Solmath 7502

Aragorn reaches the west-cliff at sunrise, 1419.
Eomer sets out from Eastfold against Theoden's orders to pursue the Orcs, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285660800, 'utc_rd_as_seconds() on 2038-02-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744047,
  0,
  0
]
, 'utc_rd_values() on 2038-02-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-02-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-02-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-02-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-02-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-02-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-02-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 59, 'day_of_year() on 2038-02-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-02-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 59, 'doy() on 2038-02-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-02-18 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-18 Gregorian' );
Monday 28 Solmath 7502

Eomer overtakes the Orcs just outside of Fangorn Forest, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285747200, 'utc_rd_as_seconds() on 2038-02-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744048,
  0,
  0
]
, 'utc_rd_values() on 2038-02-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-02-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-02-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-02-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-02-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-02-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-02-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 60, 'day_of_year() on 2038-02-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-02-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 60, 'doy() on 2038-02-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-02-19 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-19 Gregorian' );
Trewsday 29 Solmath 7502

Meriodoc and Pippin escape and meet Treebeard, 1419.
The Rohirrim attack at sunrise and destroy the Orcs, 1419.
Frodo descends from the Emyn Muil and meets Gollum, 1419.
Faramir sees the funeral boat of Boromir, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285833600, 'utc_rd_as_seconds() on 2038-02-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744049,
  0,
  0
]
, 'utc_rd_values() on 2038-02-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-02-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-02-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-02-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-02-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-02-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-02-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 61, 'day_of_year() on 2038-02-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-02-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 61, 'doy() on 2038-02-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-02-20 Gregorian' );
cmp_ok( $dts->month(), '==', 2, 'month() on 2038-02-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Solmath', 'month_name() on 2038-02-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-20 Gregorian' );
Hevensday 30 Solmath 7502

Entmoot begins, 1419.
Eomer, returning to Edoras, meets Aragorn, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64285920000, 'utc_rd_as_seconds() on 2038-02-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744050,
  0,
  0
]
, 'utc_rd_values() on 2038-02-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-02-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-02-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-02-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-02-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-02-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-02-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 62, 'day_of_year() on 2038-02-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-02-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 62, 'doy() on 2038-02-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-02-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-21 Gregorian' );
Mersday 1 Rethe 7502

Aragorn meets Gandalf the White, and they set out for Edoras, 1419.
Faramir leaves Minas Tirith on an errand to Ithilien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286006400, 'utc_rd_as_seconds() on 2038-02-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744051,
  0,
  0
]
, 'utc_rd_values() on 2038-02-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-02-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-02-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-02-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-02-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-02-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-02-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 63, 'day_of_year() on 2038-02-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-02-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 63, 'doy() on 2038-02-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-02-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-22 Gregorian' );
Highday 2 Rethe 7502

The Rohirrim ride west against Saruman, 1419.
Second battle at the Fords of Isen; Erkenbrand defeated, 1419.
Entmoot ends.  Ents march on Isengard and reach it at night, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286092800, 'utc_rd_as_seconds() on 2038-02-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744052,
  0,
  0
]
, 'utc_rd_values() on 2038-02-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-02-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  9
]
, 'week() on 2038-02-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 9, 'week_number() on 2038-02-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-02-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-02-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-02-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-02-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-02-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 64, 'day_of_year() on 2038-02-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-02-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 64, 'doy() on 2038-02-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-02-23 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-23 Gregorian' );
Sterday 3 Rethe 7502

Theoden retreats to Helm's Deep; battle of the Hornburg begins, 1419.
Ents complete the destruction of Isengard.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286179200, 'utc_rd_as_seconds() on 2038-02-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744053,
  0,
  0
]
, 'utc_rd_values() on 2038-02-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-02-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-02-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-02-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-02-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-02-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-02-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 65, 'day_of_year() on 2038-02-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-02-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 65, 'doy() on 2038-02-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-02-24 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-24 Gregorian' );
Sunday 4 Rethe 7502

Theoden and Gandalf set out from Helm's Deep for Isengard, 1419.
Frodo reaches the slag mound on the edge of the of the Morannon, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286265600, 'utc_rd_as_seconds() on 2038-02-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744054,
  0,
  0
]
, 'utc_rd_values() on 2038-02-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-02-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-02-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-02-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-02-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-02-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-02-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 66, 'day_of_year() on 2038-02-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-02-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 66, 'doy() on 2038-02-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-02-25 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-25 Gregorian' );
Monday 5 Rethe 7502

Theoden reaches Isengard at noon; parley with Saruman in Orthanc, 1419.
Gandalf sets out with Peregrin for Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286352000, 'utc_rd_as_seconds() on 2038-02-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744055,
  0,
  0
]
, 'utc_rd_values() on 2038-02-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-02-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-02-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-02-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-02-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-02-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-02-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 67, 'day_of_year() on 2038-02-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-02-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 67, 'doy() on 2038-02-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-02-26 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-26 Gregorian' );
Trewsday 6 Rethe 7502

Aragorn overtaken by the Dunedain in the early hours, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286438400, 'utc_rd_as_seconds() on 2038-02-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744056,
  0,
  0
]
, 'utc_rd_values() on 2038-02-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-02-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-02-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-02-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-02-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-02-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-02-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 68, 'day_of_year() on 2038-02-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-02-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 68, 'doy() on 2038-02-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-02-27 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-27 Gregorian' );
Hevensday 7 Rethe 7502

Frodo taken by Faramir to Henneth Annun, 1419.
Aragorn comes to Dunharrow at nightfall, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286524800, 'utc_rd_as_seconds() on 2038-02-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744057,
  0,
  0
]
, 'utc_rd_values() on 2038-02-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-02-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 2 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 2,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-02-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-02-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-02-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-02-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-02-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 69, 'day_of_year() on 2038-02-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-02-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 69, 'doy() on 2038-02-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-02-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-02-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-02-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-02-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-02-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-02-28 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-02-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-02-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-02-28 Gregorian' );
Mersday 8 Rethe 7502

Aragorn takes the "Paths of the Dead", and reaches Erech at midnight, 1419.
Frodo leaves Henneth Annun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286611200, 'utc_rd_as_seconds() on 2038-02-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744058,
  0,
  0
]
, 'utc_rd_values() on 2038-02-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-02-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-02-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-02-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-02-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-02-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-03-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-03-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-03-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-03-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-03-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 70, 'day_of_year() on 2038-03-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-03-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 70, 'doy() on 2038-03-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-03-01 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-01 Gregorian' );
Highday 9 Rethe 7502

Gandalf reaches Minas Tirith, 1419.
Darkness begins to flow out of Mordor, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286697600, 'utc_rd_as_seconds() on 2038-03-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744059,
  0,
  0
]
, 'utc_rd_values() on 2038-03-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-03-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  10
]
, 'week() on 2038-03-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 10, 'week_number() on 2038-03-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-03-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-03-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-03-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-03-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-03-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 71, 'day_of_year() on 2038-03-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-03-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 71, 'doy() on 2038-03-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-03-02 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-02 Gregorian' );
Sterday 10 Rethe 7502

The Dawnless Day, 1419.
The Rohirrim are mustered and ride from Harrowdale, 1419.
Faramir rescued by Gandalf at the gates of Minas Tirith, 1419.
An army from the Morannon takes Cair Andros and passes into Anorien, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286784000, 'utc_rd_as_seconds() on 2038-03-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744060,
  0,
  0
]
, 'utc_rd_values() on 2038-03-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-03-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-03-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-03-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-03-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-03-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-03-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 72, 'day_of_year() on 2038-03-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-03-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 72, 'doy() on 2038-03-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-03-03 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-03 Gregorian' );
Sunday 11 Rethe 7502

Gollum visits Shelob, 1419.
Denethor sends Faramir to Osgiliath, 1419.
Eastern Rohan is invaded and Lorien assaulted, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286870400, 'utc_rd_as_seconds() on 2038-03-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744061,
  0,
  0
]
, 'utc_rd_values() on 2038-03-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-03-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-03-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-03-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-03-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-03-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-03-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 73, 'day_of_year() on 2038-03-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-03-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 73, 'doy() on 2038-03-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-03-04 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-04 Gregorian' );
Monday 12 Rethe 7502

Gollum leads Frodo into Shelob's lair, 1419.
Ents defeat the invaders of Rohan, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64286956800, 'utc_rd_as_seconds() on 2038-03-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744062,
  0,
  0
]
, 'utc_rd_values() on 2038-03-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-03-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-03-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-03-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-03-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-03-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-03-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 74, 'day_of_year() on 2038-03-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-03-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 74, 'doy() on 2038-03-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-03-05 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-05 Gregorian' );
Trewsday 13 Rethe 7502

Frodo captured by the Orcs of Cirith Ungol, 1419.
The Pelennor is overrun and Faramir is wounded, 1419.
Aragorn reaches Pelargir and captures the fleet of Umbar, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287043200, 'utc_rd_as_seconds() on 2038-03-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744063,
  0,
  0
]
, 'utc_rd_values() on 2038-03-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-03-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-03-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-03-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-03-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-03-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-03-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 75, 'day_of_year() on 2038-03-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-03-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 75, 'doy() on 2038-03-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-03-06 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-06 Gregorian' );
Hevensday 14 Rethe 7502

Samwise finds Frodo in the tower of Cirith Ungol, 1419.
Minas Tirith besieged, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287129600, 'utc_rd_as_seconds() on 2038-03-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744064,
  0,
  0
]
, 'utc_rd_values() on 2038-03-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-03-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-03-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-03-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-03-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-03-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-03-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 76, 'day_of_year() on 2038-03-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-03-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 76, 'doy() on 2038-03-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-03-07 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-07 Gregorian' );
Mersday 15 Rethe 7502

Witch King breaks the gates of Minas Tirith, 1419.
Denethor, Steward of Gondor, burns himself on a pyre, 1419.
The battle of the Pelennor occurs as Theoden and Aragorn arrive, 1419.
Thranduil repels the forces of Dol Guldur in Mirkwood, 1419.
Lorien assaulted for second time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287216000, 'utc_rd_as_seconds() on 2038-03-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744065,
  0,
  0
]
, 'utc_rd_values() on 2038-03-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-03-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-03-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-03-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-03-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-03-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-03-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 77, 'day_of_year() on 2038-03-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-03-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 77, 'doy() on 2038-03-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-03-08 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-08 Gregorian' );
Highday 16 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287302400, 'utc_rd_as_seconds() on 2038-03-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744066,
  0,
  0
]
, 'utc_rd_values() on 2038-03-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-03-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  11
]
, 'week() on 2038-03-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 11, 'week_number() on 2038-03-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-03-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-03-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-03-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-03-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-03-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 78, 'day_of_year() on 2038-03-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-03-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 78, 'doy() on 2038-03-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-03-09 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-09 Gregorian' );
Sterday 17 Rethe 7502

Battle of Dale, where King Brand and King Dain Ironfoot fall, 1419.
Shagrat brings Frodo's cloak, mail-shirt, and sword to Barad-dur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287388800, 'utc_rd_as_seconds() on 2038-03-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744067,
  0,
  0
]
, 'utc_rd_values() on 2038-03-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-03-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-03-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-03-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-03-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-03-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-03-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 79, 'day_of_year() on 2038-03-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-03-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 79, 'doy() on 2038-03-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-03-10 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-10 Gregorian' );
Sunday 18 Rethe 7502

Host of the west leaves Minas Tirith, 1419.
Frodo and Sam overtaken by Orcs on the road from Durthang to Udun, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287475200, 'utc_rd_as_seconds() on 2038-03-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744068,
  0,
  0
]
, 'utc_rd_values() on 2038-03-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-03-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-03-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-03-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-03-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-03-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-03-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 80, 'day_of_year() on 2038-03-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-03-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 80, 'doy() on 2038-03-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-03-11 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-11 Gregorian' );
Monday 19 Rethe 7502

Frodo and Sam escape the Orcs and start on the road toward Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287561600, 'utc_rd_as_seconds() on 2038-03-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744069,
  0,
  0
]
, 'utc_rd_values() on 2038-03-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-03-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-03-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-03-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-03-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-03-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-03-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 81, 'day_of_year() on 2038-03-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-03-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 81, 'doy() on 2038-03-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-03-12 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-12 Gregorian' );
Trewsday 20 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287648000, 'utc_rd_as_seconds() on 2038-03-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744070,
  0,
  0
]
, 'utc_rd_values() on 2038-03-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-03-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-03-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-03-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-03-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-03-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-03-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 82, 'day_of_year() on 2038-03-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-03-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 82, 'doy() on 2038-03-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-03-13 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-13 Gregorian' );
Hevensday 21 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287734400, 'utc_rd_as_seconds() on 2038-03-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744071,
  0,
  0
]
, 'utc_rd_values() on 2038-03-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-03-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-03-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-03-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-03-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-03-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-03-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 83, 'day_of_year() on 2038-03-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-03-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 83, 'doy() on 2038-03-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-03-14 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-14 Gregorian' );
Mersday 22 Rethe 7502

Lorien assaulted for the third time, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287820800, 'utc_rd_as_seconds() on 2038-03-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744072,
  0,
  0
]
, 'utc_rd_values() on 2038-03-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-03-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-03-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-03-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-03-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-03-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-03-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 84, 'day_of_year() on 2038-03-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-03-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 84, 'doy() on 2038-03-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-03-15 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-15 Gregorian' );
Highday 23 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287907200, 'utc_rd_as_seconds() on 2038-03-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744073,
  0,
  0
]
, 'utc_rd_values() on 2038-03-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-03-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  12
]
, 'week() on 2038-03-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 12, 'week_number() on 2038-03-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-03-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-03-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-03-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-03-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-03-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 85, 'day_of_year() on 2038-03-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-03-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 85, 'doy() on 2038-03-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-03-16 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-16 Gregorian' );
Sterday 24 Rethe 7502

Frodo and Sam reach the base of Mount Doom, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64287993600, 'utc_rd_as_seconds() on 2038-03-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744074,
  0,
  0
]
, 'utc_rd_values() on 2038-03-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-03-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-03-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-03-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-03-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-03-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-03-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 86, 'day_of_year() on 2038-03-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-03-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 86, 'doy() on 2038-03-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-03-17 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-17 Gregorian' );
Sunday 25 Rethe 7502

Battle of the Host of the West on the slag hill of the Morannon, 1419.
Gollum siezes the Ring of Power and falls into the Cracks of Doom, 1419.
Downfall of Barad-dur and the passing of Sauron!, 1419.
Birth of Elanor the Fair, daughter of Samwise, 1421.
Fourth age begins in the reckoning of Gondor, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288080000, 'utc_rd_as_seconds() on 2038-03-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744075,
  0,
  0
]
, 'utc_rd_values() on 2038-03-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-03-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-03-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-03-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-03-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-03-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-03-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 87, 'day_of_year() on 2038-03-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-03-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 87, 'doy() on 2038-03-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-03-18 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-18 Gregorian' );
Monday 26 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288166400, 'utc_rd_as_seconds() on 2038-03-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744076,
  0,
  0
]
, 'utc_rd_values() on 2038-03-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-03-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-03-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-03-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-03-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-03-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-03-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 88, 'day_of_year() on 2038-03-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-03-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 88, 'doy() on 2038-03-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-03-19 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-19 Gregorian' );
Trewsday 27 Rethe 7502

Bard II and Thorin III Stonehelm drive the enemy from Dale, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288252800, 'utc_rd_as_seconds() on 2038-03-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744077,
  0,
  0
]
, 'utc_rd_values() on 2038-03-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-03-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-03-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-03-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-03-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-03-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-03-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 89, 'day_of_year() on 2038-03-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-03-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 89, 'doy() on 2038-03-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-03-20 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-20 Gregorian' );
Hevensday 28 Rethe 7502

Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288339200, 'utc_rd_as_seconds() on 2038-03-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744078,
  0,
  0
]
, 'utc_rd_values() on 2038-03-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-03-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-03-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-03-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-03-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-03-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-03-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 90, 'day_of_year() on 2038-03-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-03-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 90, 'doy() on 2038-03-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-03-21 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-21 Gregorian' );
Mersday 29 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288425600, 'utc_rd_as_seconds() on 2038-03-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744079,
  0,
  0
]
, 'utc_rd_values() on 2038-03-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-03-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-03-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-03-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-03-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-03-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-03-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 91, 'day_of_year() on 2038-03-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-03-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 91, 'doy() on 2038-03-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-03-22 Gregorian' );
cmp_ok( $dts->month(), '==', 3, 'month() on 2038-03-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Rethe', 'month_name() on 2038-03-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-22 Gregorian' );
Highday 30 Rethe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288512000, 'utc_rd_as_seconds() on 2038-03-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744080,
  0,
  0
]
, 'utc_rd_values() on 2038-03-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-03-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  13
]
, 'week() on 2038-03-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 13, 'week_number() on 2038-03-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-03-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-03-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-03-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-03-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-03-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 92, 'day_of_year() on 2038-03-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-03-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 92, 'doy() on 2038-03-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-03-23 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-23 Gregorian' );
Sterday 1 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288598400, 'utc_rd_as_seconds() on 2038-03-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744081,
  0,
  0
]
, 'utc_rd_values() on 2038-03-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-03-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-03-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-03-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-03-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-03-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-03-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 93, 'day_of_year() on 2038-03-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-03-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 93, 'doy() on 2038-03-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-03-24 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-24 Gregorian' );
Sunday 2 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288684800, 'utc_rd_as_seconds() on 2038-03-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744082,
  0,
  0
]
, 'utc_rd_values() on 2038-03-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-03-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-03-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-03-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-03-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-03-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-03-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 94, 'day_of_year() on 2038-03-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-03-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 94, 'doy() on 2038-03-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-03-25 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-25 Gregorian' );
Monday 3 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288771200, 'utc_rd_as_seconds() on 2038-03-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744083,
  0,
  0
]
, 'utc_rd_values() on 2038-03-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-03-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-03-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-03-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-03-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-03-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-03-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 95, 'day_of_year() on 2038-03-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-03-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 95, 'doy() on 2038-03-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-03-26 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-26 Gregorian' );
Trewsday 4 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288857600, 'utc_rd_as_seconds() on 2038-03-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744084,
  0,
  0
]
, 'utc_rd_values() on 2038-03-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-03-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-03-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-03-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-03-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-03-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-03-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 96, 'day_of_year() on 2038-03-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-03-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 96, 'doy() on 2038-03-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-03-27 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-27 Gregorian' );
Hevensday 5 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64288944000, 'utc_rd_as_seconds() on 2038-03-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744085,
  0,
  0
]
, 'utc_rd_values() on 2038-03-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-03-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-03-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-03-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-03-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-03-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-03-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 97, 'day_of_year() on 2038-03-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-03-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 97, 'doy() on 2038-03-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-03-28 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-28 Gregorian' );
Mersday 6 Astron 7502

The mallorn tree flowers in the party field, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289030400, 'utc_rd_as_seconds() on 2038-03-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744086,
  0,
  0
]
, 'utc_rd_values() on 2038-03-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-03-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-03-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-03-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-03-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-03-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-03-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 98, 'day_of_year() on 2038-03-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-03-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 98, 'doy() on 2038-03-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-03-29 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-29 Gregorian' );
Highday 7 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289116800, 'utc_rd_as_seconds() on 2038-03-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744087,
  0,
  0
]
, 'utc_rd_values() on 2038-03-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-03-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  14
]
, 'week() on 2038-03-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 14, 'week_number() on 2038-03-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-03-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-03-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-03-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-03-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-03-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 99, 'day_of_year() on 2038-03-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-03-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 99, 'doy() on 2038-03-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-03-30 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-30 Gregorian' );
Sterday 8 Astron 7502

Ring bearers are honored on the fields of Cormallen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289203200, 'utc_rd_as_seconds() on 2038-03-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744088,
  0,
  0
]
, 'utc_rd_values() on 2038-03-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-03-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-03-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-03-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 3 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 3,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-03-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-03-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-03-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-03-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-03-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 100, 'day_of_year() on 2038-03-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-03-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 100, 'doy() on 2038-03-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-03-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-03-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-03-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-03-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-03-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-03-31 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-03-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-03-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-03-31 Gregorian' );
Sunday 9 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289289600, 'utc_rd_as_seconds() on 2038-03-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744089,
  0,
  0
]
, 'utc_rd_values() on 2038-03-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-03-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-03-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-03-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-03-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-03-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-04-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-04-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-04-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-04-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-04-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 101, 'day_of_year() on 2038-04-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-04-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 101, 'doy() on 2038-04-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-04-01 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-01 Gregorian' );
Monday 10 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289376000, 'utc_rd_as_seconds() on 2038-04-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744090,
  0,
  0
]
, 'utc_rd_values() on 2038-04-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-04-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-04-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-04-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-04-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-04-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-04-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-04-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-04-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 102, 'day_of_year() on 2038-04-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-04-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 102, 'doy() on 2038-04-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-04-02 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-02 Gregorian' );
Trewsday 11 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289462400, 'utc_rd_as_seconds() on 2038-04-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744091,
  0,
  0
]
, 'utc_rd_values() on 2038-04-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-04-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-04-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-04-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-04-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-04-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-04-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-04-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-04-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 103, 'day_of_year() on 2038-04-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-04-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 103, 'doy() on 2038-04-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-04-03 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-03 Gregorian' );
Hevensday 12 Astron 7502

Gandalf arrives in Hobbiton, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289548800, 'utc_rd_as_seconds() on 2038-04-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744092,
  0,
  0
]
, 'utc_rd_values() on 2038-04-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-04-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-04-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-04-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-04-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-04-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-04-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-04-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-04-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 104, 'day_of_year() on 2038-04-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-04-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 104, 'doy() on 2038-04-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-04-04 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-04 Gregorian' );
Mersday 13 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289635200, 'utc_rd_as_seconds() on 2038-04-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744093,
  0,
  0
]
, 'utc_rd_values() on 2038-04-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-04-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-04-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-04-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-04-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-04-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-04-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-04-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-04-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 105, 'day_of_year() on 2038-04-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-04-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 105, 'doy() on 2038-04-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-04-05 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-05 Gregorian' );
Highday 14 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289721600, 'utc_rd_as_seconds() on 2038-04-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744094,
  0,
  0
]
, 'utc_rd_values() on 2038-04-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-04-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  15
]
, 'week() on 2038-04-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 15, 'week_number() on 2038-04-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-04-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-04-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-04-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-04-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-04-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 106, 'day_of_year() on 2038-04-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-04-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 106, 'doy() on 2038-04-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-04-06 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-06 Gregorian' );
Sterday 15 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289808000, 'utc_rd_as_seconds() on 2038-04-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744095,
  0,
  0
]
, 'utc_rd_values() on 2038-04-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-04-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-04-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-04-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-04-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-04-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-04-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 107, 'day_of_year() on 2038-04-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-04-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 107, 'doy() on 2038-04-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-04-07 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-07 Gregorian' );
Sunday 16 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289894400, 'utc_rd_as_seconds() on 2038-04-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744096,
  0,
  0
]
, 'utc_rd_values() on 2038-04-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-04-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-04-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-04-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-04-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-04-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-04-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 108, 'day_of_year() on 2038-04-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-04-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 108, 'doy() on 2038-04-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-04-08 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-08 Gregorian' );
Monday 17 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64289980800, 'utc_rd_as_seconds() on 2038-04-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744097,
  0,
  0
]
, 'utc_rd_values() on 2038-04-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-04-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-04-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-04-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-04-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-04-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-04-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 109, 'day_of_year() on 2038-04-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-04-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 109, 'doy() on 2038-04-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-04-09 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-09 Gregorian' );
Trewsday 18 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290067200, 'utc_rd_as_seconds() on 2038-04-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744098,
  0,
  0
]
, 'utc_rd_values() on 2038-04-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-04-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-04-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-04-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-04-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-04-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-04-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 110, 'day_of_year() on 2038-04-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-04-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 110, 'doy() on 2038-04-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-04-10 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-10 Gregorian' );
Hevensday 19 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290153600, 'utc_rd_as_seconds() on 2038-04-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744099,
  0,
  0
]
, 'utc_rd_values() on 2038-04-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-04-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-04-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-04-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-04-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-04-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-04-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 111, 'day_of_year() on 2038-04-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-04-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 111, 'doy() on 2038-04-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-04-11 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-11 Gregorian' );
Mersday 20 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290240000, 'utc_rd_as_seconds() on 2038-04-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744100,
  0,
  0
]
, 'utc_rd_values() on 2038-04-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-04-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-04-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-04-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-04-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-04-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-04-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 112, 'day_of_year() on 2038-04-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-04-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 112, 'doy() on 2038-04-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-04-12 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-12 Gregorian' );
Highday 21 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290326400, 'utc_rd_as_seconds() on 2038-04-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744101,
  0,
  0
]
, 'utc_rd_values() on 2038-04-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-04-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  16
]
, 'week() on 2038-04-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 16, 'week_number() on 2038-04-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-04-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-04-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-04-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-04-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-04-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 113, 'day_of_year() on 2038-04-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-04-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 113, 'doy() on 2038-04-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-04-13 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-13 Gregorian' );
Sterday 22 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290412800, 'utc_rd_as_seconds() on 2038-04-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744102,
  0,
  0
]
, 'utc_rd_values() on 2038-04-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-04-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-04-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-04-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-04-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-04-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-04-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 114, 'day_of_year() on 2038-04-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-04-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 114, 'doy() on 2038-04-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-04-14 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-14 Gregorian' );
Sunday 23 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290499200, 'utc_rd_as_seconds() on 2038-04-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744103,
  0,
  0
]
, 'utc_rd_values() on 2038-04-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-04-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-04-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-04-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-04-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-04-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-04-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 115, 'day_of_year() on 2038-04-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-04-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 115, 'doy() on 2038-04-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-04-15 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-15 Gregorian' );
Monday 24 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290585600, 'utc_rd_as_seconds() on 2038-04-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744104,
  0,
  0
]
, 'utc_rd_values() on 2038-04-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-04-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-04-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-04-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-04-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-04-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-04-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 116, 'day_of_year() on 2038-04-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-04-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 116, 'doy() on 2038-04-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-04-16 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-16 Gregorian' );
Trewsday 25 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290672000, 'utc_rd_as_seconds() on 2038-04-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744105,
  0,
  0
]
, 'utc_rd_values() on 2038-04-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-04-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-04-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-04-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-04-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-04-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-04-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 117, 'day_of_year() on 2038-04-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-04-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 117, 'doy() on 2038-04-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-04-17 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-17 Gregorian' );
Hevensday 26 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290758400, 'utc_rd_as_seconds() on 2038-04-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744106,
  0,
  0
]
, 'utc_rd_values() on 2038-04-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-04-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-04-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-04-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-04-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-04-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-04-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 118, 'day_of_year() on 2038-04-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-04-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 118, 'doy() on 2038-04-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-04-18 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-18 Gregorian' );
Mersday 27 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290844800, 'utc_rd_as_seconds() on 2038-04-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744107,
  0,
  0
]
, 'utc_rd_values() on 2038-04-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-04-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-04-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-04-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-04-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-04-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-04-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 119, 'day_of_year() on 2038-04-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-04-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 119, 'doy() on 2038-04-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-04-19 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-19 Gregorian' );
Highday 28 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64290931200, 'utc_rd_as_seconds() on 2038-04-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744108,
  0,
  0
]
, 'utc_rd_values() on 2038-04-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-04-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  17
]
, 'week() on 2038-04-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 17, 'week_number() on 2038-04-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-04-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-04-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-04-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-04-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-04-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 120, 'day_of_year() on 2038-04-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-04-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 120, 'doy() on 2038-04-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-04-20 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-20 Gregorian' );
Sterday 29 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291017600, 'utc_rd_as_seconds() on 2038-04-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744109,
  0,
  0
]
, 'utc_rd_values() on 2038-04-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-04-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-04-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-04-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-04-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-04-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-04-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 121, 'day_of_year() on 2038-04-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-04-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 121, 'doy() on 2038-04-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-04-21 Gregorian' );
cmp_ok( $dts->month(), '==', 4, 'month() on 2038-04-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Astron', 'month_name() on 2038-04-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-21 Gregorian' );
Sunday 30 Astron 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291104000, 'utc_rd_as_seconds() on 2038-04-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744110,
  0,
  0
]
, 'utc_rd_values() on 2038-04-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-04-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-04-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-04-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-04-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-04-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-04-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 122, 'day_of_year() on 2038-04-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-04-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 122, 'doy() on 2038-04-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-04-22 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-22 Gregorian' );
Monday 1 Thrimidge 7502

Crowning of King Elessar, 1419.
Samwise marries Rose, 1420.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291190400, 'utc_rd_as_seconds() on 2038-04-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744111,
  0,
  0
]
, 'utc_rd_values() on 2038-04-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-04-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-04-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-04-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-04-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-04-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-04-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 123, 'day_of_year() on 2038-04-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-04-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 123, 'doy() on 2038-04-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-04-23 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-23 Gregorian' );
Trewsday 2 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291276800, 'utc_rd_as_seconds() on 2038-04-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744112,
  0,
  0
]
, 'utc_rd_values() on 2038-04-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-04-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-04-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-04-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-04-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-04-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-04-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 124, 'day_of_year() on 2038-04-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-04-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 124, 'doy() on 2038-04-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-04-24 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-24 Gregorian' );
Hevensday 3 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291363200, 'utc_rd_as_seconds() on 2038-04-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744113,
  0,
  0
]
, 'utc_rd_values() on 2038-04-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-04-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-04-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-04-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-04-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-04-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-04-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 125, 'day_of_year() on 2038-04-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-04-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 125, 'doy() on 2038-04-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-04-25 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-25 Gregorian' );
Mersday 4 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291449600, 'utc_rd_as_seconds() on 2038-04-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744114,
  0,
  0
]
, 'utc_rd_values() on 2038-04-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-04-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-04-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-04-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-04-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-04-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-04-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 126, 'day_of_year() on 2038-04-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-04-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 126, 'doy() on 2038-04-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-04-26 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-26 Gregorian' );
Highday 5 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291536000, 'utc_rd_as_seconds() on 2038-04-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744115,
  0,
  0
]
, 'utc_rd_values() on 2038-04-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-04-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  18
]
, 'week() on 2038-04-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 18, 'week_number() on 2038-04-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-04-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-04-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-04-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-04-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-04-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 127, 'day_of_year() on 2038-04-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-04-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 127, 'doy() on 2038-04-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-04-27 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-27 Gregorian' );
Sterday 6 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291622400, 'utc_rd_as_seconds() on 2038-04-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744116,
  0,
  0
]
, 'utc_rd_values() on 2038-04-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-04-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-04-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-04-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-04-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-04-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-04-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-04-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-04-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 128, 'day_of_year() on 2038-04-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-04-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 128, 'doy() on 2038-04-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-04-28 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-28 Gregorian' );
Sunday 7 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291708800, 'utc_rd_as_seconds() on 2038-04-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744117,
  0,
  0
]
, 'utc_rd_values() on 2038-04-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-04-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-04-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-04-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-04-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-04-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-04-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-04-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-04-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 129, 'day_of_year() on 2038-04-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-04-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 129, 'doy() on 2038-04-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-04-29 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-29 Gregorian' );
Monday 8 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291795200, 'utc_rd_as_seconds() on 2038-04-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744118,
  0,
  0
]
, 'utc_rd_values() on 2038-04-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-04-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-04-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-04-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 4 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 4,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-04-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-04-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-04-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-04-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-04-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 130, 'day_of_year() on 2038-04-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-04-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 130, 'doy() on 2038-04-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-04-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-04-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-04-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-04-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-04-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-04-30 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-04-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-04-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-04-30 Gregorian' );
Trewsday 9 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291881600, 'utc_rd_as_seconds() on 2038-04-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744119,
  0,
  0
]
, 'utc_rd_values() on 2038-04-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-04-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-04-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-04-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-04-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-04-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-05-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-05-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-05-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-05-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-05-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 131, 'day_of_year() on 2038-05-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-05-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 131, 'doy() on 2038-05-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-05-01 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-01 Gregorian' );
Hevensday 10 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64291968000, 'utc_rd_as_seconds() on 2038-05-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744120,
  0,
  0
]
, 'utc_rd_values() on 2038-05-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-05-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-05-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-05-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-05-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-05-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-05-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-05-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-05-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 132, 'day_of_year() on 2038-05-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-05-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 132, 'doy() on 2038-05-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-05-02 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-02 Gregorian' );
Mersday 11 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292054400, 'utc_rd_as_seconds() on 2038-05-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744121,
  0,
  0
]
, 'utc_rd_values() on 2038-05-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-05-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-05-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-05-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-05-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-05-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-05-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-05-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-05-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 133, 'day_of_year() on 2038-05-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-05-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 133, 'doy() on 2038-05-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-05-03 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-03 Gregorian' );
Highday 12 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292140800, 'utc_rd_as_seconds() on 2038-05-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744122,
  0,
  0
]
, 'utc_rd_values() on 2038-05-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-05-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  19
]
, 'week() on 2038-05-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 19, 'week_number() on 2038-05-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-05-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-05-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-05-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-05-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-05-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 134, 'day_of_year() on 2038-05-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-05-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 134, 'doy() on 2038-05-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-05-04 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-04 Gregorian' );
Sterday 13 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292227200, 'utc_rd_as_seconds() on 2038-05-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744123,
  0,
  0
]
, 'utc_rd_values() on 2038-05-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-05-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-05-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-05-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-05-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-05-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-05-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 135, 'day_of_year() on 2038-05-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-05-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 135, 'doy() on 2038-05-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-05-05 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-05 Gregorian' );
Sunday 14 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292313600, 'utc_rd_as_seconds() on 2038-05-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744124,
  0,
  0
]
, 'utc_rd_values() on 2038-05-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-05-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-05-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-05-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-05-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-05-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-05-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 136, 'day_of_year() on 2038-05-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-05-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 136, 'doy() on 2038-05-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-05-06 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-06 Gregorian' );
Monday 15 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292400000, 'utc_rd_as_seconds() on 2038-05-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744125,
  0,
  0
]
, 'utc_rd_values() on 2038-05-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-05-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-05-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-05-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-05-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-05-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-05-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 137, 'day_of_year() on 2038-05-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-05-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 137, 'doy() on 2038-05-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-05-07 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-07 Gregorian' );
Trewsday 16 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292486400, 'utc_rd_as_seconds() on 2038-05-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744126,
  0,
  0
]
, 'utc_rd_values() on 2038-05-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-05-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-05-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-05-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-05-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-05-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-05-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 138, 'day_of_year() on 2038-05-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-05-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 138, 'doy() on 2038-05-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-05-08 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-08 Gregorian' );
Hevensday 17 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292572800, 'utc_rd_as_seconds() on 2038-05-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744127,
  0,
  0
]
, 'utc_rd_values() on 2038-05-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-05-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-05-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-05-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-05-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-05-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-05-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 139, 'day_of_year() on 2038-05-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-05-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 139, 'doy() on 2038-05-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-05-09 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-09 Gregorian' );
Mersday 18 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292659200, 'utc_rd_as_seconds() on 2038-05-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744128,
  0,
  0
]
, 'utc_rd_values() on 2038-05-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-05-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-05-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-05-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-05-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-05-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-05-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 140, 'day_of_year() on 2038-05-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-05-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 140, 'doy() on 2038-05-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-05-10 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-10 Gregorian' );
Highday 19 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292745600, 'utc_rd_as_seconds() on 2038-05-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744129,
  0,
  0
]
, 'utc_rd_values() on 2038-05-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-05-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  20
]
, 'week() on 2038-05-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 20, 'week_number() on 2038-05-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-05-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-05-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-05-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-05-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-05-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 141, 'day_of_year() on 2038-05-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-05-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 141, 'doy() on 2038-05-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-05-11 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-11 Gregorian' );
Sterday 20 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292832000, 'utc_rd_as_seconds() on 2038-05-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744130,
  0,
  0
]
, 'utc_rd_values() on 2038-05-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-05-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-05-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-05-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-05-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-05-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-05-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 142, 'day_of_year() on 2038-05-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-05-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 142, 'doy() on 2038-05-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-05-12 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-12 Gregorian' );
Sunday 21 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64292918400, 'utc_rd_as_seconds() on 2038-05-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744131,
  0,
  0
]
, 'utc_rd_values() on 2038-05-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-05-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-05-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-05-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-05-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-05-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-05-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 143, 'day_of_year() on 2038-05-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-05-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 143, 'doy() on 2038-05-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-05-13 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-13 Gregorian' );
Monday 22 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293004800, 'utc_rd_as_seconds() on 2038-05-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744132,
  0,
  0
]
, 'utc_rd_values() on 2038-05-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-05-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-05-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-05-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-05-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-05-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-05-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 144, 'day_of_year() on 2038-05-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-05-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 144, 'doy() on 2038-05-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-05-14 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-14 Gregorian' );
Trewsday 23 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293091200, 'utc_rd_as_seconds() on 2038-05-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744133,
  0,
  0
]
, 'utc_rd_values() on 2038-05-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-05-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-05-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-05-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-05-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-05-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-05-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 145, 'day_of_year() on 2038-05-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-05-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 145, 'doy() on 2038-05-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-05-15 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-15 Gregorian' );
Hevensday 24 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293177600, 'utc_rd_as_seconds() on 2038-05-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744134,
  0,
  0
]
, 'utc_rd_values() on 2038-05-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-05-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-05-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-05-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-05-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-05-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-05-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 146, 'day_of_year() on 2038-05-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-05-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 146, 'doy() on 2038-05-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-05-16 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-16 Gregorian' );
Mersday 25 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293264000, 'utc_rd_as_seconds() on 2038-05-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744135,
  0,
  0
]
, 'utc_rd_values() on 2038-05-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-05-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-05-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-05-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-05-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-05-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-05-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 147, 'day_of_year() on 2038-05-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-05-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 147, 'doy() on 2038-05-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-05-17 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-17 Gregorian' );
Highday 26 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293350400, 'utc_rd_as_seconds() on 2038-05-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744136,
  0,
  0
]
, 'utc_rd_values() on 2038-05-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-05-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  21
]
, 'week() on 2038-05-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 21, 'week_number() on 2038-05-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-05-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-05-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-05-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-05-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-05-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 148, 'day_of_year() on 2038-05-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-05-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 148, 'doy() on 2038-05-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-05-18 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-18 Gregorian' );
Sterday 27 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293436800, 'utc_rd_as_seconds() on 2038-05-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744137,
  0,
  0
]
, 'utc_rd_values() on 2038-05-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-05-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-05-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-05-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-05-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-05-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-05-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 149, 'day_of_year() on 2038-05-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-05-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 149, 'doy() on 2038-05-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-05-19 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-19 Gregorian' );
Sunday 28 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293523200, 'utc_rd_as_seconds() on 2038-05-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744138,
  0,
  0
]
, 'utc_rd_values() on 2038-05-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-05-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-05-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-05-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-05-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-05-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-05-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 150, 'day_of_year() on 2038-05-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-05-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 150, 'doy() on 2038-05-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-05-20 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-20 Gregorian' );
Monday 29 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293609600, 'utc_rd_as_seconds() on 2038-05-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744139,
  0,
  0
]
, 'utc_rd_values() on 2038-05-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-05-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-05-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-05-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-05-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-05-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-05-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 151, 'day_of_year() on 2038-05-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-05-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 151, 'doy() on 2038-05-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-05-21 Gregorian' );
cmp_ok( $dts->month(), '==', 5, 'month() on 2038-05-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Thrimidge', 'month_name() on 2038-05-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-21 Gregorian' );
Trewsday 30 Thrimidge 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293696000, 'utc_rd_as_seconds() on 2038-05-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744140,
  0,
  0
]
, 'utc_rd_values() on 2038-05-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-05-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-05-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-05-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-05-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-05-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-05-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 152, 'day_of_year() on 2038-05-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-05-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 152, 'doy() on 2038-05-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-05-22 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-22 Gregorian' );
Hevensday 1 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293782400, 'utc_rd_as_seconds() on 2038-05-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744141,
  0,
  0
]
, 'utc_rd_values() on 2038-05-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-05-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-05-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-05-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-05-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-05-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-05-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 153, 'day_of_year() on 2038-05-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-05-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 153, 'doy() on 2038-05-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-05-23 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-23 Gregorian' );
Mersday 2 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293868800, 'utc_rd_as_seconds() on 2038-05-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744142,
  0,
  0
]
, 'utc_rd_values() on 2038-05-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-05-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-05-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-05-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-05-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-05-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-05-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 154, 'day_of_year() on 2038-05-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-05-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 154, 'doy() on 2038-05-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-05-24 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-24 Gregorian' );
Highday 3 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64293955200, 'utc_rd_as_seconds() on 2038-05-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744143,
  0,
  0
]
, 'utc_rd_values() on 2038-05-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-05-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  22
]
, 'week() on 2038-05-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 22, 'week_number() on 2038-05-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-05-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-05-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-05-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-05-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-05-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 155, 'day_of_year() on 2038-05-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-05-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 155, 'doy() on 2038-05-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-05-25 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-25 Gregorian' );
Sterday 4 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294041600, 'utc_rd_as_seconds() on 2038-05-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744144,
  0,
  0
]
, 'utc_rd_values() on 2038-05-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-05-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-05-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-05-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-05-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-05-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-05-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 156, 'day_of_year() on 2038-05-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-05-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 156, 'doy() on 2038-05-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-05-26 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-26 Gregorian' );
Sunday 5 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294128000, 'utc_rd_as_seconds() on 2038-05-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744145,
  0,
  0
]
, 'utc_rd_values() on 2038-05-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-05-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-05-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-05-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-05-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-05-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-05-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 157, 'day_of_year() on 2038-05-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-05-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 157, 'doy() on 2038-05-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-05-27 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-27 Gregorian' );
Monday 6 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294214400, 'utc_rd_as_seconds() on 2038-05-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744146,
  0,
  0
]
, 'utc_rd_values() on 2038-05-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-05-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-05-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-05-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-05-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-05-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-05-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 158, 'day_of_year() on 2038-05-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-05-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 158, 'doy() on 2038-05-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-05-28 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-28 Gregorian' );
Trewsday 7 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294300800, 'utc_rd_as_seconds() on 2038-05-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744147,
  0,
  0
]
, 'utc_rd_values() on 2038-05-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-05-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-05-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-05-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-05-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-05-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-05-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 159, 'day_of_year() on 2038-05-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-05-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 159, 'doy() on 2038-05-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-05-29 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-29 Gregorian' );
Hevensday 8 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294387200, 'utc_rd_as_seconds() on 2038-05-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744148,
  0,
  0
]
, 'utc_rd_values() on 2038-05-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-05-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-05-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-05-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-05-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-05-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-05-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 160, 'day_of_year() on 2038-05-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-05-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 160, 'doy() on 2038-05-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-05-30 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-30 Gregorian' );
Mersday 9 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294473600, 'utc_rd_as_seconds() on 2038-05-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744149,
  0,
  0
]
, 'utc_rd_values() on 2038-05-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-05-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 5 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 5,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-05-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-05-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-05-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-05-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-05-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 161, 'day_of_year() on 2038-05-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-05-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 161, 'doy() on 2038-05-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-05-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-05-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-05-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-05-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-05-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-05-31 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-05-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-05-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-05-31 Gregorian' );
Highday 10 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294560000, 'utc_rd_as_seconds() on 2038-05-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744150,
  0,
  0
]
, 'utc_rd_values() on 2038-05-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-05-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  23
]
, 'week() on 2038-05-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 23, 'week_number() on 2038-05-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-05-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-05-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-06-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-06-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-06-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-06-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-06-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 162, 'day_of_year() on 2038-06-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-06-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 162, 'doy() on 2038-06-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-06-01 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-01 Gregorian' );
Sterday 11 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294646400, 'utc_rd_as_seconds() on 2038-06-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744151,
  0,
  0
]
, 'utc_rd_values() on 2038-06-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-06-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-06-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-06-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-06-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-06-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-06-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 163, 'day_of_year() on 2038-06-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-06-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 163, 'doy() on 2038-06-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-06-02 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-02 Gregorian' );
Sunday 12 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294732800, 'utc_rd_as_seconds() on 2038-06-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744152,
  0,
  0
]
, 'utc_rd_values() on 2038-06-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-06-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-06-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-06-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-06-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-06-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-06-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 164, 'day_of_year() on 2038-06-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-06-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 164, 'doy() on 2038-06-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-06-03 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-03 Gregorian' );
Monday 13 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294819200, 'utc_rd_as_seconds() on 2038-06-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744153,
  0,
  0
]
, 'utc_rd_values() on 2038-06-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-06-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-06-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-06-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-06-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-06-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-06-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 165, 'day_of_year() on 2038-06-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-06-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 165, 'doy() on 2038-06-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-06-04 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-04 Gregorian' );
Trewsday 14 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294905600, 'utc_rd_as_seconds() on 2038-06-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744154,
  0,
  0
]
, 'utc_rd_values() on 2038-06-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-06-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-06-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-06-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-06-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-06-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-06-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 166, 'day_of_year() on 2038-06-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-06-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 166, 'doy() on 2038-06-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-06-05 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-05 Gregorian' );
Hevensday 15 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64294992000, 'utc_rd_as_seconds() on 2038-06-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744155,
  0,
  0
]
, 'utc_rd_values() on 2038-06-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-06-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-06-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-06-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-06-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-06-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-06-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 167, 'day_of_year() on 2038-06-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-06-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 167, 'doy() on 2038-06-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-06-06 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-06 Gregorian' );
Mersday 16 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295078400, 'utc_rd_as_seconds() on 2038-06-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744156,
  0,
  0
]
, 'utc_rd_values() on 2038-06-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-06-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-06-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-06-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-06-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-06-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-06-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 168, 'day_of_year() on 2038-06-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-06-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 168, 'doy() on 2038-06-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-06-07 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-07 Gregorian' );
Highday 17 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295164800, 'utc_rd_as_seconds() on 2038-06-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744157,
  0,
  0
]
, 'utc_rd_values() on 2038-06-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-06-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  24
]
, 'week() on 2038-06-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 24, 'week_number() on 2038-06-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-06-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-06-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-06-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-06-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-06-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 169, 'day_of_year() on 2038-06-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-06-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 169, 'doy() on 2038-06-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-06-08 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-08 Gregorian' );
Sterday 18 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295251200, 'utc_rd_as_seconds() on 2038-06-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744158,
  0,
  0
]
, 'utc_rd_values() on 2038-06-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-06-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-06-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-06-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-06-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-06-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-06-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 170, 'day_of_year() on 2038-06-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-06-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 170, 'doy() on 2038-06-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-06-09 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-09 Gregorian' );
Sunday 19 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295337600, 'utc_rd_as_seconds() on 2038-06-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744159,
  0,
  0
]
, 'utc_rd_values() on 2038-06-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-06-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-06-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-06-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-06-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-06-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-06-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 171, 'day_of_year() on 2038-06-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-06-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 171, 'doy() on 2038-06-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-06-10 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-10 Gregorian' );
Monday 20 Forelithe 7502

Sauron attacks Osgiliath, 1418.
Thranduil is attacked, and Gollum escapes, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295424000, 'utc_rd_as_seconds() on 2038-06-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744160,
  0,
  0
]
, 'utc_rd_values() on 2038-06-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-06-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-06-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-06-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-06-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-06-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-06-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 172, 'day_of_year() on 2038-06-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-06-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 172, 'doy() on 2038-06-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-06-11 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-11 Gregorian' );
Trewsday 21 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295510400, 'utc_rd_as_seconds() on 2038-06-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744161,
  0,
  0
]
, 'utc_rd_values() on 2038-06-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-06-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-06-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-06-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-06-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-06-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-06-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 173, 'day_of_year() on 2038-06-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-06-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 173, 'doy() on 2038-06-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-06-12 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-12 Gregorian' );
Hevensday 22 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295596800, 'utc_rd_as_seconds() on 2038-06-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744162,
  0,
  0
]
, 'utc_rd_values() on 2038-06-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-06-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-06-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-06-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-06-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-06-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-06-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 174, 'day_of_year() on 2038-06-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-06-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 174, 'doy() on 2038-06-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-06-13 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-13 Gregorian' );
Mersday 23 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295683200, 'utc_rd_as_seconds() on 2038-06-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744163,
  0,
  0
]
, 'utc_rd_values() on 2038-06-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-06-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-06-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-06-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-06-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-06-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-06-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 175, 'day_of_year() on 2038-06-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-06-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 175, 'doy() on 2038-06-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-06-14 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-14 Gregorian' );
Highday 24 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295769600, 'utc_rd_as_seconds() on 2038-06-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744164,
  0,
  0
]
, 'utc_rd_values() on 2038-06-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-06-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  25
]
, 'week() on 2038-06-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 25, 'week_number() on 2038-06-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-06-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-06-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-06-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-06-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-06-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 176, 'day_of_year() on 2038-06-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-06-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 176, 'doy() on 2038-06-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-06-15 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-15 Gregorian' );
Sterday 25 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295856000, 'utc_rd_as_seconds() on 2038-06-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744165,
  0,
  0
]
, 'utc_rd_values() on 2038-06-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-06-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-06-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-06-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-06-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-06-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-06-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 177, 'day_of_year() on 2038-06-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-06-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 177, 'doy() on 2038-06-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-06-16 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-16 Gregorian' );
Sunday 26 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64295942400, 'utc_rd_as_seconds() on 2038-06-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744166,
  0,
  0
]
, 'utc_rd_values() on 2038-06-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-06-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-06-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-06-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-06-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-06-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-06-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 178, 'day_of_year() on 2038-06-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-06-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 178, 'doy() on 2038-06-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-06-17 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-17 Gregorian' );
Monday 27 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296028800, 'utc_rd_as_seconds() on 2038-06-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744167,
  0,
  0
]
, 'utc_rd_values() on 2038-06-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-06-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-06-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-06-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-06-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-06-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-06-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 179, 'day_of_year() on 2038-06-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-06-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 179, 'doy() on 2038-06-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-06-18 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-18 Gregorian' );
Trewsday 28 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296115200, 'utc_rd_as_seconds() on 2038-06-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744168,
  0,
  0
]
, 'utc_rd_values() on 2038-06-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-06-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-06-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-06-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-06-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-06-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-06-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 180, 'day_of_year() on 2038-06-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-06-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 180, 'doy() on 2038-06-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-06-19 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-19 Gregorian' );
Hevensday 29 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296201600, 'utc_rd_as_seconds() on 2038-06-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744169,
  0,
  0
]
, 'utc_rd_values() on 2038-06-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-06-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-06-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-06-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-06-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-06-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-06-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 181, 'day_of_year() on 2038-06-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-06-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 181, 'doy() on 2038-06-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-06-20 Gregorian' );
cmp_ok( $dts->month(), '==', 6, 'month() on 2038-06-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Forelithe', 'month_name() on 2038-06-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-20 Gregorian' );
Mersday 30 Forelithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296288000, 'utc_rd_as_seconds() on 2038-06-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744170,
  0,
  0
]
, 'utc_rd_values() on 2038-06-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-06-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2038-06-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-06-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-06-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2038-06-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-06-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 182, 'day_of_year() on 2038-06-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-06-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 182, 'doy() on 2038-06-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 2, 'holiday() on 2038-06-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Lithe', 'holiday_name() on 2038-06-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2038-06-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2038-06-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2038-06-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-21 Gregorian' );
Highday 1 Lithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296374400, 'utc_rd_as_seconds() on 2038-06-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744171,
  0,
  0
]
, 'utc_rd_values() on 2038-06-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-06-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  26
]
, 'week() on 2038-06-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 26, 'week_number() on 2038-06-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2038-06-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', '', 'day_name() on 2038-06-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', '', 'day_name_trad() on 2038-06-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2038-06-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 0, 'day_of_week() on 2038-06-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 183, 'day_of_year() on 2038-06-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 0, 'dow() on 2038-06-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 183, 'doy() on 2038-06-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 3, 'holiday() on 2038-06-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', 'Midyear\'s day', 'holiday_name() on 2038-06-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2038-06-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2038-06-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2038-06-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-22 Gregorian' );
Midyear's day 7502

Wedding of King Elessar and Arwen, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296460800, 'utc_rd_as_seconds() on 2038-06-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744172,
  0,
  0
]
, 'utc_rd_values() on 2038-06-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 0, 'wday() on 2038-06-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  0
]
, 'week() on 2038-06-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 0, 'week_number() on 2038-06-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2038-06-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-06-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-06-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2038-06-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-06-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 184, 'day_of_year() on 2038-06-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-06-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 184, 'doy() on 2038-06-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 5, 'holiday() on 2038-06-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Lithe', 'holiday_name() on 2038-06-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2038-06-23 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2038-06-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2038-06-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-23 Gregorian' );
Sterday 2 Lithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296547200, 'utc_rd_as_seconds() on 2038-06-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744173,
  0,
  0
]
, 'utc_rd_values() on 2038-06-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-06-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-06-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-06-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-06-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-06-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-06-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 185, 'day_of_year() on 2038-06-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-06-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 185, 'doy() on 2038-06-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-06-24 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-24 Gregorian' );
Sunday 1 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296633600, 'utc_rd_as_seconds() on 2038-06-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744174,
  0,
  0
]
, 'utc_rd_values() on 2038-06-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-06-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-06-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-06-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-06-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-06-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-06-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 186, 'day_of_year() on 2038-06-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-06-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 186, 'doy() on 2038-06-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-06-25 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-25 Gregorian' );
Monday 2 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296720000, 'utc_rd_as_seconds() on 2038-06-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744175,
  0,
  0
]
, 'utc_rd_values() on 2038-06-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-06-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-06-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-06-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-06-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-06-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-06-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 187, 'day_of_year() on 2038-06-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-06-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 187, 'doy() on 2038-06-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-06-26 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-26 Gregorian' );
Trewsday 3 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296806400, 'utc_rd_as_seconds() on 2038-06-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744176,
  0,
  0
]
, 'utc_rd_values() on 2038-06-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-06-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-06-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-06-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-06-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-06-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-06-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 188, 'day_of_year() on 2038-06-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-06-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 188, 'doy() on 2038-06-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-06-27 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-27 Gregorian' );
Hevensday 4 Afterlithe 7502

Boromir sets out from Minas Tirith, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296892800, 'utc_rd_as_seconds() on 2038-06-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744177,
  0,
  0
]
, 'utc_rd_values() on 2038-06-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-06-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-06-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-06-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-06-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-06-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-06-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 189, 'day_of_year() on 2038-06-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-06-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 189, 'doy() on 2038-06-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-06-28 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-28 Gregorian' );
Mersday 5 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64296979200, 'utc_rd_as_seconds() on 2038-06-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744178,
  0,
  0
]
, 'utc_rd_values() on 2038-06-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-06-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-06-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-06-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-06-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-06-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-06-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 190, 'day_of_year() on 2038-06-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-06-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 190, 'doy() on 2038-06-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-06-29 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-29 Gregorian' );
Highday 6 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297065600, 'utc_rd_as_seconds() on 2038-06-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744179,
  0,
  0
]
, 'utc_rd_values() on 2038-06-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-06-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  27
]
, 'week() on 2038-06-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 27, 'week_number() on 2038-06-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 6 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 6,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-06-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-06-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-06-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-06-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-06-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 191, 'day_of_year() on 2038-06-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-06-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 191, 'doy() on 2038-06-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-06-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-06-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-06-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-06-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-06-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-06-30 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-06-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-06-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-06-30 Gregorian' );
Sterday 7 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297152000, 'utc_rd_as_seconds() on 2038-06-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744180,
  0,
  0
]
, 'utc_rd_values() on 2038-06-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-06-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-06-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-06-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-06-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-06-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-07-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-07-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-07-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-07-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-07-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 192, 'day_of_year() on 2038-07-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-07-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 192, 'doy() on 2038-07-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-07-01 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-01 Gregorian' );
Sunday 8 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297238400, 'utc_rd_as_seconds() on 2038-07-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744181,
  0,
  0
]
, 'utc_rd_values() on 2038-07-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-07-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-07-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-07-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-07-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-07-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-07-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 193, 'day_of_year() on 2038-07-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-07-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 193, 'doy() on 2038-07-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-07-02 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-02 Gregorian' );
Monday 9 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297324800, 'utc_rd_as_seconds() on 2038-07-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744182,
  0,
  0
]
, 'utc_rd_values() on 2038-07-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-07-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-07-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-07-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-07-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-07-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-07-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 194, 'day_of_year() on 2038-07-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-07-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 194, 'doy() on 2038-07-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-07-03 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-03 Gregorian' );
Trewsday 10 Afterlithe 7502

Gandalf imprisoned in Orthanc, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297411200, 'utc_rd_as_seconds() on 2038-07-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744183,
  0,
  0
]
, 'utc_rd_values() on 2038-07-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-07-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-07-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-07-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-07-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-07-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-07-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 195, 'day_of_year() on 2038-07-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-07-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 195, 'doy() on 2038-07-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-07-04 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-04 Gregorian' );
Hevensday 11 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297497600, 'utc_rd_as_seconds() on 2038-07-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744184,
  0,
  0
]
, 'utc_rd_values() on 2038-07-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-07-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-07-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-07-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-07-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-07-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-07-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 196, 'day_of_year() on 2038-07-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-07-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 196, 'doy() on 2038-07-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-07-05 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-05 Gregorian' );
Mersday 12 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297584000, 'utc_rd_as_seconds() on 2038-07-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744185,
  0,
  0
]
, 'utc_rd_values() on 2038-07-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-07-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-07-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-07-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-07-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-07-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-07-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 197, 'day_of_year() on 2038-07-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-07-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 197, 'doy() on 2038-07-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-07-06 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-06 Gregorian' );
Highday 13 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297670400, 'utc_rd_as_seconds() on 2038-07-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744186,
  0,
  0
]
, 'utc_rd_values() on 2038-07-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-07-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  28
]
, 'week() on 2038-07-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 28, 'week_number() on 2038-07-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-07-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-07-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-07-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-07-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-07-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 198, 'day_of_year() on 2038-07-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-07-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 198, 'doy() on 2038-07-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-07-07 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-07 Gregorian' );
Sterday 14 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297756800, 'utc_rd_as_seconds() on 2038-07-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744187,
  0,
  0
]
, 'utc_rd_values() on 2038-07-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-07-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-07-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-07-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-07-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-07-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-07-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 199, 'day_of_year() on 2038-07-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-07-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 199, 'doy() on 2038-07-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-07-08 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-08 Gregorian' );
Sunday 15 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297843200, 'utc_rd_as_seconds() on 2038-07-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744188,
  0,
  0
]
, 'utc_rd_values() on 2038-07-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-07-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-07-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-07-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-07-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-07-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-07-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 200, 'day_of_year() on 2038-07-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-07-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 200, 'doy() on 2038-07-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-07-09 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-09 Gregorian' );
Monday 16 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64297929600, 'utc_rd_as_seconds() on 2038-07-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744189,
  0,
  0
]
, 'utc_rd_values() on 2038-07-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-07-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-07-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-07-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-07-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-07-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-07-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 201, 'day_of_year() on 2038-07-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-07-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 201, 'doy() on 2038-07-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-07-10 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-10 Gregorian' );
Trewsday 17 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298016000, 'utc_rd_as_seconds() on 2038-07-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744190,
  0,
  0
]
, 'utc_rd_values() on 2038-07-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-07-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-07-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-07-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-07-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-07-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-07-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 202, 'day_of_year() on 2038-07-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-07-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 202, 'doy() on 2038-07-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-07-11 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-11 Gregorian' );
Hevensday 18 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298102400, 'utc_rd_as_seconds() on 2038-07-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744191,
  0,
  0
]
, 'utc_rd_values() on 2038-07-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-07-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-07-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-07-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-07-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-07-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-07-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 203, 'day_of_year() on 2038-07-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-07-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 203, 'doy() on 2038-07-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-07-12 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-12 Gregorian' );
Mersday 19 Afterlithe 7502

Funeral Escort of King Theoden leaves Minas Tirith, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298188800, 'utc_rd_as_seconds() on 2038-07-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744192,
  0,
  0
]
, 'utc_rd_values() on 2038-07-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-07-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-07-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-07-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-07-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-07-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-07-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 204, 'day_of_year() on 2038-07-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-07-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 204, 'doy() on 2038-07-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-07-13 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-13 Gregorian' );
Highday 20 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298275200, 'utc_rd_as_seconds() on 2038-07-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744193,
  0,
  0
]
, 'utc_rd_values() on 2038-07-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-07-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  29
]
, 'week() on 2038-07-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 29, 'week_number() on 2038-07-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-07-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-07-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-07-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-07-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-07-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 205, 'day_of_year() on 2038-07-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-07-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 205, 'doy() on 2038-07-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-07-14 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-14 Gregorian' );
Sterday 21 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298361600, 'utc_rd_as_seconds() on 2038-07-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744194,
  0,
  0
]
, 'utc_rd_values() on 2038-07-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-07-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-07-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-07-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-07-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-07-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-07-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 206, 'day_of_year() on 2038-07-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-07-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 206, 'doy() on 2038-07-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-07-15 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-15 Gregorian' );
Sunday 22 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298448000, 'utc_rd_as_seconds() on 2038-07-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744195,
  0,
  0
]
, 'utc_rd_values() on 2038-07-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-07-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-07-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-07-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-07-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-07-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-07-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 207, 'day_of_year() on 2038-07-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-07-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 207, 'doy() on 2038-07-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-07-16 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-16 Gregorian' );
Monday 23 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298534400, 'utc_rd_as_seconds() on 2038-07-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744196,
  0,
  0
]
, 'utc_rd_values() on 2038-07-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-07-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-07-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-07-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-07-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-07-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-07-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 208, 'day_of_year() on 2038-07-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-07-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 208, 'doy() on 2038-07-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-07-17 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-17 Gregorian' );
Trewsday 24 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298620800, 'utc_rd_as_seconds() on 2038-07-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744197,
  0,
  0
]
, 'utc_rd_values() on 2038-07-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-07-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-07-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-07-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-07-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-07-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-07-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 209, 'day_of_year() on 2038-07-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-07-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 209, 'doy() on 2038-07-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-07-18 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-18 Gregorian' );
Hevensday 25 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298707200, 'utc_rd_as_seconds() on 2038-07-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744198,
  0,
  0
]
, 'utc_rd_values() on 2038-07-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-07-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-07-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-07-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-07-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-07-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-07-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 210, 'day_of_year() on 2038-07-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-07-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 210, 'doy() on 2038-07-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-07-19 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-19 Gregorian' );
Mersday 26 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298793600, 'utc_rd_as_seconds() on 2038-07-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744199,
  0,
  0
]
, 'utc_rd_values() on 2038-07-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-07-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-07-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-07-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-07-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-07-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-07-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 211, 'day_of_year() on 2038-07-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-07-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 211, 'doy() on 2038-07-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-07-20 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-20 Gregorian' );
Highday 27 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298880000, 'utc_rd_as_seconds() on 2038-07-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744200,
  0,
  0
]
, 'utc_rd_values() on 2038-07-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-07-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  30
]
, 'week() on 2038-07-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 30, 'week_number() on 2038-07-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-07-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-07-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-07-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-07-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-07-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 212, 'day_of_year() on 2038-07-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-07-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 212, 'doy() on 2038-07-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-07-21 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-21 Gregorian' );
Sterday 28 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64298966400, 'utc_rd_as_seconds() on 2038-07-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744201,
  0,
  0
]
, 'utc_rd_values() on 2038-07-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-07-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-07-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-07-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-07-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-07-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-07-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 213, 'day_of_year() on 2038-07-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-07-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 213, 'doy() on 2038-07-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-07-22 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-22 Gregorian' );
Sunday 29 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299052800, 'utc_rd_as_seconds() on 2038-07-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744202,
  0,
  0
]
, 'utc_rd_values() on 2038-07-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-07-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-07-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-07-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-07-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-07-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-07-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 214, 'day_of_year() on 2038-07-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-07-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 214, 'doy() on 2038-07-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-07-23 Gregorian' );
cmp_ok( $dts->month(), '==', 7, 'month() on 2038-07-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afterlithe', 'month_name() on 2038-07-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-23 Gregorian' );
Monday 30 Afterlithe 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299139200, 'utc_rd_as_seconds() on 2038-07-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744203,
  0,
  0
]
, 'utc_rd_values() on 2038-07-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-07-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-07-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-07-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-07-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-07-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-07-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 215, 'day_of_year() on 2038-07-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-07-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 215, 'doy() on 2038-07-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-07-24 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-24 Gregorian' );
Trewsday 1 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299225600, 'utc_rd_as_seconds() on 2038-07-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744204,
  0,
  0
]
, 'utc_rd_values() on 2038-07-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-07-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-07-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-07-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-07-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-07-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-07-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 216, 'day_of_year() on 2038-07-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-07-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 216, 'doy() on 2038-07-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-07-25 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-25 Gregorian' );
Hevensday 2 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299312000, 'utc_rd_as_seconds() on 2038-07-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744205,
  0,
  0
]
, 'utc_rd_values() on 2038-07-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-07-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-07-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-07-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-07-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-07-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-07-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 217, 'day_of_year() on 2038-07-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-07-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 217, 'doy() on 2038-07-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-07-26 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-26 Gregorian' );
Mersday 3 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299398400, 'utc_rd_as_seconds() on 2038-07-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744206,
  0,
  0
]
, 'utc_rd_values() on 2038-07-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-07-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-07-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-07-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-07-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-07-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-07-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 218, 'day_of_year() on 2038-07-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-07-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 218, 'doy() on 2038-07-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-07-27 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-27 Gregorian' );
Highday 4 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299484800, 'utc_rd_as_seconds() on 2038-07-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744207,
  0,
  0
]
, 'utc_rd_values() on 2038-07-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-07-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  31
]
, 'week() on 2038-07-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 31, 'week_number() on 2038-07-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-07-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-07-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-07-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-07-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-07-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 219, 'day_of_year() on 2038-07-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-07-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 219, 'doy() on 2038-07-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-07-28 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-28 Gregorian' );
Sterday 5 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299571200, 'utc_rd_as_seconds() on 2038-07-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744208,
  0,
  0
]
, 'utc_rd_values() on 2038-07-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-07-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-07-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-07-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-07-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-07-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-07-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-07-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-07-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 220, 'day_of_year() on 2038-07-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-07-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 220, 'doy() on 2038-07-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-07-29 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-29 Gregorian' );
Sunday 6 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299657600, 'utc_rd_as_seconds() on 2038-07-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744209,
  0,
  0
]
, 'utc_rd_values() on 2038-07-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-07-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-07-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-07-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-07-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-07-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-07-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-07-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-07-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 221, 'day_of_year() on 2038-07-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-07-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 221, 'doy() on 2038-07-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-07-30 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-30 Gregorian' );
Monday 7 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299744000, 'utc_rd_as_seconds() on 2038-07-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744210,
  0,
  0
]
, 'utc_rd_values() on 2038-07-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-07-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-07-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-07-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 7 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 7,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-07-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-07-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-07-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-07-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-07-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 222, 'day_of_year() on 2038-07-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-07-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 222, 'doy() on 2038-07-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-07-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-07-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-07-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-07-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-07-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-07-31 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-07-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-07-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-07-31 Gregorian' );
Trewsday 8 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299830400, 'utc_rd_as_seconds() on 2038-07-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744211,
  0,
  0
]
, 'utc_rd_values() on 2038-07-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-07-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-07-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-07-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-07-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-07-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-08-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-08-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-08-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-08-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-08-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 223, 'day_of_year() on 2038-08-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-08-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 223, 'doy() on 2038-08-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-08-01 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-01 Gregorian' );
Hevensday 9 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64299916800, 'utc_rd_as_seconds() on 2038-08-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744212,
  0,
  0
]
, 'utc_rd_values() on 2038-08-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-08-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-08-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-08-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-08-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-08-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-08-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-08-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-08-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 224, 'day_of_year() on 2038-08-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-08-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 224, 'doy() on 2038-08-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-08-02 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-02 Gregorian' );
Mersday 10 Wedmath 7502

Funeral of King Theoden, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300003200, 'utc_rd_as_seconds() on 2038-08-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744213,
  0,
  0
]
, 'utc_rd_values() on 2038-08-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-08-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-08-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-08-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-08-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-08-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-08-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-08-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-08-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 225, 'day_of_year() on 2038-08-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-08-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 225, 'doy() on 2038-08-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-08-03 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-03 Gregorian' );
Highday 11 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300089600, 'utc_rd_as_seconds() on 2038-08-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744214,
  0,
  0
]
, 'utc_rd_values() on 2038-08-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-08-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  32
]
, 'week() on 2038-08-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 32, 'week_number() on 2038-08-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-08-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-08-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-08-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-08-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-08-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 226, 'day_of_year() on 2038-08-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-08-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 226, 'doy() on 2038-08-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-08-04 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-04 Gregorian' );
Sterday 12 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300176000, 'utc_rd_as_seconds() on 2038-08-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744215,
  0,
  0
]
, 'utc_rd_values() on 2038-08-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-08-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-08-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-08-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-08-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-08-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-08-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 227, 'day_of_year() on 2038-08-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-08-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 227, 'doy() on 2038-08-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-08-05 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-05 Gregorian' );
Sunday 13 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300262400, 'utc_rd_as_seconds() on 2038-08-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744216,
  0,
  0
]
, 'utc_rd_values() on 2038-08-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-08-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-08-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-08-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-08-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-08-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-08-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 228, 'day_of_year() on 2038-08-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-08-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 228, 'doy() on 2038-08-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-08-06 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-06 Gregorian' );
Monday 14 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300348800, 'utc_rd_as_seconds() on 2038-08-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744217,
  0,
  0
]
, 'utc_rd_values() on 2038-08-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-08-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-08-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-08-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-08-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-08-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-08-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 229, 'day_of_year() on 2038-08-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-08-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 229, 'doy() on 2038-08-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-08-07 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-07 Gregorian' );
Trewsday 15 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300435200, 'utc_rd_as_seconds() on 2038-08-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744218,
  0,
  0
]
, 'utc_rd_values() on 2038-08-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-08-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-08-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-08-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-08-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-08-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-08-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 230, 'day_of_year() on 2038-08-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-08-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 230, 'doy() on 2038-08-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-08-08 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-08 Gregorian' );
Hevensday 16 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300521600, 'utc_rd_as_seconds() on 2038-08-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744219,
  0,
  0
]
, 'utc_rd_values() on 2038-08-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-08-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-08-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-08-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-08-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-08-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-08-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 231, 'day_of_year() on 2038-08-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-08-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 231, 'doy() on 2038-08-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-08-09 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-09 Gregorian' );
Mersday 17 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300608000, 'utc_rd_as_seconds() on 2038-08-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744220,
  0,
  0
]
, 'utc_rd_values() on 2038-08-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-08-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-08-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-08-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-08-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-08-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-08-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 232, 'day_of_year() on 2038-08-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-08-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 232, 'doy() on 2038-08-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-08-10 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-10 Gregorian' );
Highday 18 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300694400, 'utc_rd_as_seconds() on 2038-08-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744221,
  0,
  0
]
, 'utc_rd_values() on 2038-08-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-08-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  33
]
, 'week() on 2038-08-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 33, 'week_number() on 2038-08-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-08-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-08-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-08-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-08-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-08-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 233, 'day_of_year() on 2038-08-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-08-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 233, 'doy() on 2038-08-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-08-11 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-11 Gregorian' );
Sterday 19 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300780800, 'utc_rd_as_seconds() on 2038-08-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744222,
  0,
  0
]
, 'utc_rd_values() on 2038-08-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-08-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-08-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-08-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-08-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-08-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-08-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 234, 'day_of_year() on 2038-08-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-08-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 234, 'doy() on 2038-08-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-08-12 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-12 Gregorian' );
Sunday 20 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300867200, 'utc_rd_as_seconds() on 2038-08-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744223,
  0,
  0
]
, 'utc_rd_values() on 2038-08-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-08-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-08-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-08-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-08-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-08-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-08-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 235, 'day_of_year() on 2038-08-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-08-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 235, 'doy() on 2038-08-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-08-13 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-13 Gregorian' );
Monday 21 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64300953600, 'utc_rd_as_seconds() on 2038-08-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744224,
  0,
  0
]
, 'utc_rd_values() on 2038-08-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-08-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-08-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-08-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-08-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-08-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-08-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 236, 'day_of_year() on 2038-08-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-08-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 236, 'doy() on 2038-08-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-08-14 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-14 Gregorian' );
Trewsday 22 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301040000, 'utc_rd_as_seconds() on 2038-08-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744225,
  0,
  0
]
, 'utc_rd_values() on 2038-08-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-08-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-08-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-08-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-08-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-08-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-08-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 237, 'day_of_year() on 2038-08-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-08-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 237, 'doy() on 2038-08-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-08-15 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-15 Gregorian' );
Hevensday 23 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301126400, 'utc_rd_as_seconds() on 2038-08-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744226,
  0,
  0
]
, 'utc_rd_values() on 2038-08-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-08-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-08-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-08-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-08-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-08-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-08-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 238, 'day_of_year() on 2038-08-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-08-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 238, 'doy() on 2038-08-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-08-16 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-16 Gregorian' );
Mersday 24 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301212800, 'utc_rd_as_seconds() on 2038-08-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744227,
  0,
  0
]
, 'utc_rd_values() on 2038-08-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-08-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-08-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-08-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-08-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-08-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-08-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 239, 'day_of_year() on 2038-08-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-08-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 239, 'doy() on 2038-08-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-08-17 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-17 Gregorian' );
Highday 25 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301299200, 'utc_rd_as_seconds() on 2038-08-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744228,
  0,
  0
]
, 'utc_rd_values() on 2038-08-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-08-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  34
]
, 'week() on 2038-08-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 34, 'week_number() on 2038-08-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-08-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-08-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-08-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-08-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-08-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 240, 'day_of_year() on 2038-08-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-08-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 240, 'doy() on 2038-08-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-08-18 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-18 Gregorian' );
Sterday 26 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301385600, 'utc_rd_as_seconds() on 2038-08-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744229,
  0,
  0
]
, 'utc_rd_values() on 2038-08-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-08-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-08-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-08-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-08-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-08-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-08-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 241, 'day_of_year() on 2038-08-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-08-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 241, 'doy() on 2038-08-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-08-19 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-19 Gregorian' );
Sunday 27 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301472000, 'utc_rd_as_seconds() on 2038-08-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744230,
  0,
  0
]
, 'utc_rd_values() on 2038-08-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-08-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-08-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-08-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-08-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-08-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-08-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 242, 'day_of_year() on 2038-08-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-08-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 242, 'doy() on 2038-08-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-08-20 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-20 Gregorian' );
Monday 28 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301558400, 'utc_rd_as_seconds() on 2038-08-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744231,
  0,
  0
]
, 'utc_rd_values() on 2038-08-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-08-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-08-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-08-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-08-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-08-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-08-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 243, 'day_of_year() on 2038-08-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-08-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 243, 'doy() on 2038-08-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-08-21 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-21 Gregorian' );
Trewsday 29 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301644800, 'utc_rd_as_seconds() on 2038-08-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744232,
  0,
  0
]
, 'utc_rd_values() on 2038-08-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-08-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-08-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-08-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-08-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-08-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-08-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 244, 'day_of_year() on 2038-08-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-08-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 244, 'doy() on 2038-08-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-08-22 Gregorian' );
cmp_ok( $dts->month(), '==', 8, 'month() on 2038-08-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Wedmath', 'month_name() on 2038-08-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-22 Gregorian' );
Hevensday 30 Wedmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301731200, 'utc_rd_as_seconds() on 2038-08-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744233,
  0,
  0
]
, 'utc_rd_values() on 2038-08-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-08-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-08-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-08-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-08-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-08-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-08-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 245, 'day_of_year() on 2038-08-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-08-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 245, 'doy() on 2038-08-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-08-23 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-23 Gregorian' );
Mersday 1 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301817600, 'utc_rd_as_seconds() on 2038-08-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744234,
  0,
  0
]
, 'utc_rd_values() on 2038-08-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-08-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-08-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-08-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-08-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-08-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-08-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 246, 'day_of_year() on 2038-08-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-08-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 246, 'doy() on 2038-08-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-08-24 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-24 Gregorian' );
Highday 2 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301904000, 'utc_rd_as_seconds() on 2038-08-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744235,
  0,
  0
]
, 'utc_rd_values() on 2038-08-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-08-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  35
]
, 'week() on 2038-08-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 35, 'week_number() on 2038-08-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-08-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-08-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-08-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-08-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-08-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 247, 'day_of_year() on 2038-08-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-08-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 247, 'doy() on 2038-08-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-08-25 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-25 Gregorian' );
Sterday 3 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64301990400, 'utc_rd_as_seconds() on 2038-08-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744236,
  0,
  0
]
, 'utc_rd_values() on 2038-08-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-08-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-08-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-08-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-08-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-08-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-08-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 248, 'day_of_year() on 2038-08-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-08-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 248, 'doy() on 2038-08-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-08-26 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-26 Gregorian' );
Sunday 4 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302076800, 'utc_rd_as_seconds() on 2038-08-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744237,
  0,
  0
]
, 'utc_rd_values() on 2038-08-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-08-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-08-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-08-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-08-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-08-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-08-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 249, 'day_of_year() on 2038-08-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-08-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 249, 'doy() on 2038-08-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-08-27 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-27 Gregorian' );
Monday 5 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302163200, 'utc_rd_as_seconds() on 2038-08-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744238,
  0,
  0
]
, 'utc_rd_values() on 2038-08-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-08-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-08-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-08-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-08-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-08-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-08-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 250, 'day_of_year() on 2038-08-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-08-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 250, 'doy() on 2038-08-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-08-28 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-28 Gregorian' );
Trewsday 6 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302249600, 'utc_rd_as_seconds() on 2038-08-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744239,
  0,
  0
]
, 'utc_rd_values() on 2038-08-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-08-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-08-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-08-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-08-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-08-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-08-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 251, 'day_of_year() on 2038-08-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-08-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 251, 'doy() on 2038-08-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-08-29 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-29 Gregorian' );
Hevensday 7 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302336000, 'utc_rd_as_seconds() on 2038-08-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744240,
  0,
  0
]
, 'utc_rd_values() on 2038-08-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-08-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-08-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-08-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-08-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-08-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-08-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 252, 'day_of_year() on 2038-08-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-08-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 252, 'doy() on 2038-08-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-08-30 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-30 Gregorian' );
Mersday 8 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302422400, 'utc_rd_as_seconds() on 2038-08-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744241,
  0,
  0
]
, 'utc_rd_values() on 2038-08-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-08-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 8 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 8,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-08-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-08-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-08-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-08-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-08-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 253, 'day_of_year() on 2038-08-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-08-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 253, 'doy() on 2038-08-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-08-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-08-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-08-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-08-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-08-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-08-31 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-08-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-08-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-08-31 Gregorian' );
Highday 9 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302508800, 'utc_rd_as_seconds() on 2038-08-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744242,
  0,
  0
]
, 'utc_rd_values() on 2038-08-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-08-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  36
]
, 'week() on 2038-08-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 36, 'week_number() on 2038-08-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-08-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-08-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-09-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-09-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-09-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-09-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-09-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 254, 'day_of_year() on 2038-09-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-09-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 254, 'doy() on 2038-09-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-09-01 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-01 Gregorian' );
Sterday 10 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302595200, 'utc_rd_as_seconds() on 2038-09-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744243,
  0,
  0
]
, 'utc_rd_values() on 2038-09-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-09-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-09-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-09-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-09-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-09-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-09-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 255, 'day_of_year() on 2038-09-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-09-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 255, 'doy() on 2038-09-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-09-02 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-02 Gregorian' );
Sunday 11 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302681600, 'utc_rd_as_seconds() on 2038-09-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744244,
  0,
  0
]
, 'utc_rd_values() on 2038-09-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-09-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-09-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-09-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-09-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-09-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-09-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 256, 'day_of_year() on 2038-09-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-09-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 256, 'doy() on 2038-09-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-09-03 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-03 Gregorian' );
Monday 12 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302768000, 'utc_rd_as_seconds() on 2038-09-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744245,
  0,
  0
]
, 'utc_rd_values() on 2038-09-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-09-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-09-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-09-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-09-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-09-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-09-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 257, 'day_of_year() on 2038-09-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-09-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 257, 'doy() on 2038-09-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-09-04 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-04 Gregorian' );
Trewsday 13 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302854400, 'utc_rd_as_seconds() on 2038-09-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744246,
  0,
  0
]
, 'utc_rd_values() on 2038-09-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-09-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-09-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-09-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-09-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-09-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-09-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 258, 'day_of_year() on 2038-09-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-09-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 258, 'doy() on 2038-09-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-09-05 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-05 Gregorian' );
Hevensday 14 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64302940800, 'utc_rd_as_seconds() on 2038-09-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744247,
  0,
  0
]
, 'utc_rd_values() on 2038-09-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-09-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-09-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-09-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-09-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-09-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-09-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 259, 'day_of_year() on 2038-09-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-09-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 259, 'doy() on 2038-09-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-09-06 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-06 Gregorian' );
Mersday 15 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303027200, 'utc_rd_as_seconds() on 2038-09-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744248,
  0,
  0
]
, 'utc_rd_values() on 2038-09-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-09-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-09-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-09-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-09-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-09-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-09-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 260, 'day_of_year() on 2038-09-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-09-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 260, 'doy() on 2038-09-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-09-07 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-07 Gregorian' );
Highday 16 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303113600, 'utc_rd_as_seconds() on 2038-09-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744249,
  0,
  0
]
, 'utc_rd_values() on 2038-09-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-09-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  37
]
, 'week() on 2038-09-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 37, 'week_number() on 2038-09-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-09-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-09-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-09-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-09-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-09-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 261, 'day_of_year() on 2038-09-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-09-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 261, 'doy() on 2038-09-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-09-08 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-08 Gregorian' );
Sterday 17 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303200000, 'utc_rd_as_seconds() on 2038-09-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744250,
  0,
  0
]
, 'utc_rd_values() on 2038-09-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-09-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-09-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-09-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-09-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-09-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-09-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 262, 'day_of_year() on 2038-09-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-09-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 262, 'doy() on 2038-09-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-09-09 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-09 Gregorian' );
Sunday 18 Halimath 7502

Gandalf escapes from Orthanc in the early hours, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303286400, 'utc_rd_as_seconds() on 2038-09-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744251,
  0,
  0
]
, 'utc_rd_values() on 2038-09-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-09-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-09-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-09-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-09-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-09-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-09-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 263, 'day_of_year() on 2038-09-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-09-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 263, 'doy() on 2038-09-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-09-10 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-10 Gregorian' );
Monday 19 Halimath 7502

Gandalf comes to Edoras as a beggar, and is refused admittance, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303372800, 'utc_rd_as_seconds() on 2038-09-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744252,
  0,
  0
]
, 'utc_rd_values() on 2038-09-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-09-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-09-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-09-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-09-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-09-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-09-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 264, 'day_of_year() on 2038-09-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-09-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 264, 'doy() on 2038-09-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-09-11 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-11 Gregorian' );
Trewsday 20 Halimath 7502

Gandalf gains entrance to Edoras.  Theoden commands him to go:
"Take any horse, only be gone ere tomorrow is old", 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303459200, 'utc_rd_as_seconds() on 2038-09-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744253,
  0,
  0
]
, 'utc_rd_values() on 2038-09-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-09-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-09-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-09-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-09-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-09-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-09-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 265, 'day_of_year() on 2038-09-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-09-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 265, 'doy() on 2038-09-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-09-12 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-12 Gregorian' );
Hevensday 21 Halimath 7502

The hobbits return to Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303545600, 'utc_rd_as_seconds() on 2038-09-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744254,
  0,
  0
]
, 'utc_rd_values() on 2038-09-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-09-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-09-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-09-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-09-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-09-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-09-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 266, 'day_of_year() on 2038-09-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-09-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 266, 'doy() on 2038-09-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-09-13 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-13 Gregorian' );
Mersday 22 Halimath 7502

Birthday of Bilbo and Frodo.
The Black Riders reach Sarn Ford at evening;
  they drive off the guard of Rangers, 1418.
Saruman comes to the Shire, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303632000, 'utc_rd_as_seconds() on 2038-09-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744255,
  0,
  0
]
, 'utc_rd_values() on 2038-09-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-09-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-09-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-09-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-09-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-09-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-09-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 267, 'day_of_year() on 2038-09-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-09-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 267, 'doy() on 2038-09-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-09-14 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-14 Gregorian' );
Highday 23 Halimath 7502

Four Black Riders enter the shire before dawn.  The others pursue 
the Rangers eastward and then return to watch the Greenway, 1418.
A Black Rider comes to Hobbiton at nightfall, 1418.
Frodo leaves Bag End, 1418.
Gandalf having tamed Shadowfax rides from Rohan, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303718400, 'utc_rd_as_seconds() on 2038-09-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744256,
  0,
  0
]
, 'utc_rd_values() on 2038-09-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-09-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  38
]
, 'week() on 2038-09-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 38, 'week_number() on 2038-09-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-09-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-09-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-09-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-09-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-09-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 268, 'day_of_year() on 2038-09-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-09-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 268, 'doy() on 2038-09-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-09-15 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-15 Gregorian' );
Sterday 24 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303804800, 'utc_rd_as_seconds() on 2038-09-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744257,
  0,
  0
]
, 'utc_rd_values() on 2038-09-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-09-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-09-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-09-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-09-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-09-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-09-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 269, 'day_of_year() on 2038-09-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-09-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 269, 'doy() on 2038-09-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-09-16 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-16 Gregorian' );
Sunday 25 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303891200, 'utc_rd_as_seconds() on 2038-09-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744258,
  0,
  0
]
, 'utc_rd_values() on 2038-09-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-09-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-09-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-09-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-09-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-09-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-09-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 270, 'day_of_year() on 2038-09-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-09-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 270, 'doy() on 2038-09-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-09-17 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-17 Gregorian' );
Monday 26 Halimath 7502

Frodo comes to Bombadil, 1418
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64303977600, 'utc_rd_as_seconds() on 2038-09-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744259,
  0,
  0
]
, 'utc_rd_values() on 2038-09-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-09-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-09-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-09-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-09-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-09-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-09-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 271, 'day_of_year() on 2038-09-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-09-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 271, 'doy() on 2038-09-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-09-18 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-18 Gregorian' );
Trewsday 27 Halimath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304064000, 'utc_rd_as_seconds() on 2038-09-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744260,
  0,
  0
]
, 'utc_rd_values() on 2038-09-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-09-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-09-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-09-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-09-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-09-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-09-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 272, 'day_of_year() on 2038-09-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-09-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 272, 'doy() on 2038-09-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-09-19 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-19 Gregorian' );
Hevensday 28 Halimath 7502

The Hobbits are captured by a barrow-wight, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304150400, 'utc_rd_as_seconds() on 2038-09-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744261,
  0,
  0
]
, 'utc_rd_values() on 2038-09-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-09-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-09-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-09-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-09-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-09-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-09-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 273, 'day_of_year() on 2038-09-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-09-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 273, 'doy() on 2038-09-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-09-20 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-20 Gregorian' );
Mersday 29 Halimath 7502

Frodo reaches Bree at night, 1418.
Frodo and Bilbo depart over the sea with the three Keepers, 1421.
End of the Third Age, 1421.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304236800, 'utc_rd_as_seconds() on 2038-09-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744262,
  0,
  0
]
, 'utc_rd_values() on 2038-09-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-09-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-09-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-09-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-09-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-09-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-09-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 274, 'day_of_year() on 2038-09-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-09-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 274, 'doy() on 2038-09-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-09-21 Gregorian' );
cmp_ok( $dts->month(), '==', 9, 'month() on 2038-09-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Halimath', 'month_name() on 2038-09-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-21 Gregorian' );
Highday 30 Halimath 7502

Crickhollow and the inn at Bree are raided in the early hours, 1418.
Frodo leaves Bree, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304323200, 'utc_rd_as_seconds() on 2038-09-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744263,
  0,
  0
]
, 'utc_rd_values() on 2038-09-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-09-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  39
]
, 'week() on 2038-09-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 39, 'week_number() on 2038-09-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-09-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-09-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-09-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-09-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-09-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 275, 'day_of_year() on 2038-09-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-09-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 275, 'doy() on 2038-09-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-09-22 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-22 Gregorian' );
Sterday 1 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304409600, 'utc_rd_as_seconds() on 2038-09-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744264,
  0,
  0
]
, 'utc_rd_values() on 2038-09-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-09-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-09-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-09-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-09-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-09-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-09-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 276, 'day_of_year() on 2038-09-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-09-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 276, 'doy() on 2038-09-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-09-23 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-23 Gregorian' );
Sunday 2 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304496000, 'utc_rd_as_seconds() on 2038-09-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744265,
  0,
  0
]
, 'utc_rd_values() on 2038-09-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-09-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-09-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-09-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-09-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-09-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-09-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 277, 'day_of_year() on 2038-09-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-09-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 277, 'doy() on 2038-09-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-09-24 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-24 Gregorian' );
Monday 3 Winterfilth 7502

Gandalf attacked at night on Weathertop, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304582400, 'utc_rd_as_seconds() on 2038-09-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744266,
  0,
  0
]
, 'utc_rd_values() on 2038-09-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-09-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-09-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-09-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-09-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-09-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-09-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 278, 'day_of_year() on 2038-09-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-09-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 278, 'doy() on 2038-09-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-09-25 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-25 Gregorian' );
Trewsday 4 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304668800, 'utc_rd_as_seconds() on 2038-09-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744267,
  0,
  0
]
, 'utc_rd_values() on 2038-09-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-09-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-09-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-09-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-09-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-09-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-09-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 279, 'day_of_year() on 2038-09-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-09-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 279, 'doy() on 2038-09-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-09-26 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-26 Gregorian' );
Hevensday 5 Winterfilth 7502

Gandalf and the Hobbits leave Rivendell, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304755200, 'utc_rd_as_seconds() on 2038-09-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744268,
  0,
  0
]
, 'utc_rd_values() on 2038-09-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-09-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-09-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-09-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-09-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-09-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-09-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 280, 'day_of_year() on 2038-09-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-09-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 280, 'doy() on 2038-09-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-09-27 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-27 Gregorian' );
Mersday 6 Winterfilth 7502

The camp under Weathertop is attacked at night and Frodo is wounded, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304841600, 'utc_rd_as_seconds() on 2038-09-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744269,
  0,
  0
]
, 'utc_rd_values() on 2038-09-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-09-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-09-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-09-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-09-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-09-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-09-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 281, 'day_of_year() on 2038-09-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-09-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 281, 'doy() on 2038-09-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-09-28 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-28 Gregorian' );
Highday 7 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64304928000, 'utc_rd_as_seconds() on 2038-09-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744270,
  0,
  0
]
, 'utc_rd_values() on 2038-09-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-09-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  40
]
, 'week() on 2038-09-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 40, 'week_number() on 2038-09-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-09-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-09-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-09-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-09-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-09-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 282, 'day_of_year() on 2038-09-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-09-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 282, 'doy() on 2038-09-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-09-29 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-29 Gregorian' );
Sterday 8 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305014400, 'utc_rd_as_seconds() on 2038-09-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744271,
  0,
  0
]
, 'utc_rd_values() on 2038-09-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-09-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-09-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-09-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 9 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 9,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-09-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-09-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-09-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-09-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-09-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 283, 'day_of_year() on 2038-09-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-09-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 283, 'doy() on 2038-09-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-09-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-09-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-09-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-09-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-09-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-09-30 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-09-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-09-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-09-30 Gregorian' );
Sunday 9 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305100800, 'utc_rd_as_seconds() on 2038-09-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744272,
  0,
  0
]
, 'utc_rd_values() on 2038-09-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-09-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-09-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-09-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-09-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-09-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-10-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-10-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-10-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-10-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-10-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 284, 'day_of_year() on 2038-10-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-10-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 284, 'doy() on 2038-10-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-10-01 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-01 Gregorian' );
Monday 10 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305187200, 'utc_rd_as_seconds() on 2038-10-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744273,
  0,
  0
]
, 'utc_rd_values() on 2038-10-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-10-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-10-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-10-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-10-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-10-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-10-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-10-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-10-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 285, 'day_of_year() on 2038-10-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-10-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 285, 'doy() on 2038-10-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-10-02 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-02 Gregorian' );
Trewsday 11 Winterfilth 7502

Glorfindel drives the Black Riders off the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305273600, 'utc_rd_as_seconds() on 2038-10-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744274,
  0,
  0
]
, 'utc_rd_values() on 2038-10-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-10-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-10-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-10-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-10-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-10-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-10-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-10-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-10-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 286, 'day_of_year() on 2038-10-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-10-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 286, 'doy() on 2038-10-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-10-03 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-03 Gregorian' );
Hevensday 12 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305360000, 'utc_rd_as_seconds() on 2038-10-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744275,
  0,
  0
]
, 'utc_rd_values() on 2038-10-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-10-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-10-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-10-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-10-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-10-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-10-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-10-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-10-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 287, 'day_of_year() on 2038-10-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-10-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 287, 'doy() on 2038-10-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-10-04 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-04 Gregorian' );
Mersday 13 Winterfilth 7502

Frodo crosses the Bridge of Mitheithel, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305446400, 'utc_rd_as_seconds() on 2038-10-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744276,
  0,
  0
]
, 'utc_rd_values() on 2038-10-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-10-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-10-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-10-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-10-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-10-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-10-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-10-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-10-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 288, 'day_of_year() on 2038-10-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-10-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 288, 'doy() on 2038-10-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-10-05 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-05 Gregorian' );
Highday 14 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305532800, 'utc_rd_as_seconds() on 2038-10-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744277,
  0,
  0
]
, 'utc_rd_values() on 2038-10-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-10-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  41
]
, 'week() on 2038-10-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 41, 'week_number() on 2038-10-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-10-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-10-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-10-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-10-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-10-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 289, 'day_of_year() on 2038-10-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-10-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 289, 'doy() on 2038-10-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-10-06 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-06 Gregorian' );
Sterday 15 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305619200, 'utc_rd_as_seconds() on 2038-10-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744278,
  0,
  0
]
, 'utc_rd_values() on 2038-10-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-10-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-10-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-10-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-10-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-10-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-10-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 290, 'day_of_year() on 2038-10-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-10-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 290, 'doy() on 2038-10-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-10-07 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-07 Gregorian' );
Sunday 16 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305705600, 'utc_rd_as_seconds() on 2038-10-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744279,
  0,
  0
]
, 'utc_rd_values() on 2038-10-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-10-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-10-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-10-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-10-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-10-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-10-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 291, 'day_of_year() on 2038-10-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-10-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 291, 'doy() on 2038-10-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-10-08 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-08 Gregorian' );
Monday 17 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305792000, 'utc_rd_as_seconds() on 2038-10-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744280,
  0,
  0
]
, 'utc_rd_values() on 2038-10-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-10-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-10-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-10-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-10-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-10-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-10-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 292, 'day_of_year() on 2038-10-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-10-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 292, 'doy() on 2038-10-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-10-09 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-09 Gregorian' );
Trewsday 18 Winterfilth 7502

Glorfindel finds Frodo at dusk, 1418.
Gandalf reaches Rivendell, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305878400, 'utc_rd_as_seconds() on 2038-10-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744281,
  0,
  0
]
, 'utc_rd_values() on 2038-10-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-10-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-10-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-10-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-10-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-10-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-10-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 293, 'day_of_year() on 2038-10-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-10-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 293, 'doy() on 2038-10-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-10-10 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-10 Gregorian' );
Hevensday 19 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64305964800, 'utc_rd_as_seconds() on 2038-10-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744282,
  0,
  0
]
, 'utc_rd_values() on 2038-10-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-10-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-10-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-10-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-10-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-10-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-10-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 294, 'day_of_year() on 2038-10-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-10-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 294, 'doy() on 2038-10-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-10-11 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-11 Gregorian' );
Mersday 20 Winterfilth 7502

Escape across the Ford of Bruinen, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306051200, 'utc_rd_as_seconds() on 2038-10-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744283,
  0,
  0
]
, 'utc_rd_values() on 2038-10-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-10-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-10-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-10-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-10-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-10-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-10-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 295, 'day_of_year() on 2038-10-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-10-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 295, 'doy() on 2038-10-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-10-12 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-12 Gregorian' );
Highday 21 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306137600, 'utc_rd_as_seconds() on 2038-10-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744284,
  0,
  0
]
, 'utc_rd_values() on 2038-10-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-10-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  42
]
, 'week() on 2038-10-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 42, 'week_number() on 2038-10-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-10-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-10-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-10-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-10-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-10-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 296, 'day_of_year() on 2038-10-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-10-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 296, 'doy() on 2038-10-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-10-13 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-13 Gregorian' );
Sterday 22 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306224000, 'utc_rd_as_seconds() on 2038-10-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744285,
  0,
  0
]
, 'utc_rd_values() on 2038-10-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-10-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-10-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-10-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-10-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-10-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-10-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 297, 'day_of_year() on 2038-10-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-10-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 297, 'doy() on 2038-10-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-10-14 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-14 Gregorian' );
Sunday 23 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306310400, 'utc_rd_as_seconds() on 2038-10-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744286,
  0,
  0
]
, 'utc_rd_values() on 2038-10-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-10-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-10-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-10-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-10-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-10-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-10-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 298, 'day_of_year() on 2038-10-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-10-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 298, 'doy() on 2038-10-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-10-15 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-15 Gregorian' );
Monday 24 Winterfilth 7502

Frodo recovers and wakes, 1418.
Boromir arrives at Rivendell at night, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306396800, 'utc_rd_as_seconds() on 2038-10-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744287,
  0,
  0
]
, 'utc_rd_values() on 2038-10-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-10-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-10-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-10-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-10-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-10-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-10-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 299, 'day_of_year() on 2038-10-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-10-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 299, 'doy() on 2038-10-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-10-16 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-16 Gregorian' );
Trewsday 25 Winterfilth 7502

Council of Elrond, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306483200, 'utc_rd_as_seconds() on 2038-10-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744288,
  0,
  0
]
, 'utc_rd_values() on 2038-10-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-10-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-10-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-10-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-10-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-10-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-10-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 300, 'day_of_year() on 2038-10-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-10-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 300, 'doy() on 2038-10-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-10-17 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-17 Gregorian' );
Hevensday 26 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306569600, 'utc_rd_as_seconds() on 2038-10-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744289,
  0,
  0
]
, 'utc_rd_values() on 2038-10-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-10-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-10-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-10-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-10-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-10-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-10-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 301, 'day_of_year() on 2038-10-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-10-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 301, 'doy() on 2038-10-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-10-18 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-18 Gregorian' );
Mersday 27 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306656000, 'utc_rd_as_seconds() on 2038-10-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744290,
  0,
  0
]
, 'utc_rd_values() on 2038-10-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-10-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-10-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-10-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-10-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-10-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-10-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 302, 'day_of_year() on 2038-10-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-10-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 302, 'doy() on 2038-10-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-10-19 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-19 Gregorian' );
Highday 28 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306742400, 'utc_rd_as_seconds() on 2038-10-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744291,
  0,
  0
]
, 'utc_rd_values() on 2038-10-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-10-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  43
]
, 'week() on 2038-10-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 43, 'week_number() on 2038-10-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-10-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-10-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-10-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-10-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-10-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 303, 'day_of_year() on 2038-10-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-10-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 303, 'doy() on 2038-10-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-10-20 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-20 Gregorian' );
Sterday 29 Winterfilth 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306828800, 'utc_rd_as_seconds() on 2038-10-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744292,
  0,
  0
]
, 'utc_rd_values() on 2038-10-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-10-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-10-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-10-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-10-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-10-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-10-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 304, 'day_of_year() on 2038-10-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-10-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 304, 'doy() on 2038-10-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-10-21 Gregorian' );
cmp_ok( $dts->month(), '==', 10, 'month() on 2038-10-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Winterfilth', 'month_name() on 2038-10-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-21 Gregorian' );
Sunday 30 Winterfilth 7502

The four Hobbits arrive at the Brandywine Bridge in the dark, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64306915200, 'utc_rd_as_seconds() on 2038-10-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744293,
  0,
  0
]
, 'utc_rd_values() on 2038-10-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-10-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-10-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-10-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-10-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-10-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-10-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 305, 'day_of_year() on 2038-10-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-10-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 305, 'doy() on 2038-10-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-10-22 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-22 Gregorian' );
Monday 1 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307001600, 'utc_rd_as_seconds() on 2038-10-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744294,
  0,
  0
]
, 'utc_rd_values() on 2038-10-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-10-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-10-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-10-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-10-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-10-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-10-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 306, 'day_of_year() on 2038-10-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-10-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 306, 'doy() on 2038-10-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-10-23 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-23 Gregorian' );
Trewsday 2 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307088000, 'utc_rd_as_seconds() on 2038-10-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744295,
  0,
  0
]
, 'utc_rd_values() on 2038-10-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-10-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-10-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-10-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-10-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-10-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-10-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 307, 'day_of_year() on 2038-10-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-10-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 307, 'doy() on 2038-10-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-10-24 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-24 Gregorian' );
Hevensday 3 Blotmath 7502

Battle of Bywater and passing of Saruman, 1419.
End of the War of the Ring, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307174400, 'utc_rd_as_seconds() on 2038-10-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744296,
  0,
  0
]
, 'utc_rd_values() on 2038-10-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-10-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-10-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-10-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-10-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-10-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-10-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 308, 'day_of_year() on 2038-10-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-10-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 308, 'doy() on 2038-10-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-10-25 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-25 Gregorian' );
Mersday 4 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307260800, 'utc_rd_as_seconds() on 2038-10-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744297,
  0,
  0
]
, 'utc_rd_values() on 2038-10-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-10-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-10-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-10-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-10-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-10-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-10-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 309, 'day_of_year() on 2038-10-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-10-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 309, 'doy() on 2038-10-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-10-26 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-26 Gregorian' );
Highday 5 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307347200, 'utc_rd_as_seconds() on 2038-10-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744298,
  0,
  0
]
, 'utc_rd_values() on 2038-10-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-10-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  44
]
, 'week() on 2038-10-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 44, 'week_number() on 2038-10-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-10-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-10-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-10-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-10-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-10-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 310, 'day_of_year() on 2038-10-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-10-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 310, 'doy() on 2038-10-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-10-27 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-27 Gregorian' );
Sterday 6 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307433600, 'utc_rd_as_seconds() on 2038-10-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744299,
  0,
  0
]
, 'utc_rd_values() on 2038-10-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-10-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-10-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-10-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-10-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-10-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-10-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-10-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-10-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 311, 'day_of_year() on 2038-10-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-10-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 311, 'doy() on 2038-10-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-10-28 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-28 Gregorian' );
Sunday 7 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307520000, 'utc_rd_as_seconds() on 2038-10-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744300,
  0,
  0
]
, 'utc_rd_values() on 2038-10-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-10-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-10-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-10-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-10-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-10-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-10-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-10-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-10-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 312, 'day_of_year() on 2038-10-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-10-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 312, 'doy() on 2038-10-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-10-29 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-29 Gregorian' );
Monday 8 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307606400, 'utc_rd_as_seconds() on 2038-10-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744301,
  0,
  0
]
, 'utc_rd_values() on 2038-10-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-10-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-10-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-10-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-10-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-10-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-10-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-10-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-10-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 313, 'day_of_year() on 2038-10-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-10-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 313, 'doy() on 2038-10-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-10-30 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-30 Gregorian' );
Trewsday 9 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307692800, 'utc_rd_as_seconds() on 2038-10-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744302,
  0,
  0
]
, 'utc_rd_values() on 2038-10-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-10-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-10-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-10-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 10 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 10,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-10-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-10-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-10-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-10-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-10-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 314, 'day_of_year() on 2038-10-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-10-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 314, 'doy() on 2038-10-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-10-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-10-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-10-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-10-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-10-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-10-31 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-10-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-10-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-10-31 Gregorian' );
Hevensday 10 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307779200, 'utc_rd_as_seconds() on 2038-10-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744303,
  0,
  0
]
, 'utc_rd_values() on 2038-10-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-10-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-10-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-10-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-10-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-10-31 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-11-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-11-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-11-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-11-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-11-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 315, 'day_of_year() on 2038-11-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-11-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 315, 'doy() on 2038-11-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-11-01 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-01 Gregorian' );
Mersday 11 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307865600, 'utc_rd_as_seconds() on 2038-11-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744304,
  0,
  0
]
, 'utc_rd_values() on 2038-11-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-11-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-11-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-11-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-11-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-11-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-11-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-11-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-11-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 316, 'day_of_year() on 2038-11-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-11-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 316, 'doy() on 2038-11-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-11-02 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-02 Gregorian' );
Highday 12 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64307952000, 'utc_rd_as_seconds() on 2038-11-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744305,
  0,
  0
]
, 'utc_rd_values() on 2038-11-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-11-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  45
]
, 'week() on 2038-11-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 45, 'week_number() on 2038-11-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-11-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-11-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-11-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-11-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-11-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 317, 'day_of_year() on 2038-11-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-11-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 317, 'doy() on 2038-11-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-11-03 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-03 Gregorian' );
Sterday 13 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308038400, 'utc_rd_as_seconds() on 2038-11-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744306,
  0,
  0
]
, 'utc_rd_values() on 2038-11-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-11-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-11-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-11-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-11-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-11-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-11-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 318, 'day_of_year() on 2038-11-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-11-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 318, 'doy() on 2038-11-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-11-04 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-04 Gregorian' );
Sunday 14 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308124800, 'utc_rd_as_seconds() on 2038-11-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744307,
  0,
  0
]
, 'utc_rd_values() on 2038-11-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-11-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-11-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-11-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-11-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-11-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-11-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 319, 'day_of_year() on 2038-11-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-11-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 319, 'doy() on 2038-11-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-11-05 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-05 Gregorian' );
Monday 15 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308211200, 'utc_rd_as_seconds() on 2038-11-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744308,
  0,
  0
]
, 'utc_rd_values() on 2038-11-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-11-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-11-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-11-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-11-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-11-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-11-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 320, 'day_of_year() on 2038-11-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-11-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 320, 'doy() on 2038-11-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-11-06 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-06 Gregorian' );
Trewsday 16 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308297600, 'utc_rd_as_seconds() on 2038-11-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744309,
  0,
  0
]
, 'utc_rd_values() on 2038-11-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-11-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-11-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-11-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-11-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-11-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-11-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 321, 'day_of_year() on 2038-11-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-11-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 321, 'doy() on 2038-11-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-11-07 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-07 Gregorian' );
Hevensday 17 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308384000, 'utc_rd_as_seconds() on 2038-11-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744310,
  0,
  0
]
, 'utc_rd_values() on 2038-11-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-11-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-11-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-11-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-11-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-11-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-11-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 322, 'day_of_year() on 2038-11-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-11-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 322, 'doy() on 2038-11-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-11-08 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-08 Gregorian' );
Mersday 18 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308470400, 'utc_rd_as_seconds() on 2038-11-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744311,
  0,
  0
]
, 'utc_rd_values() on 2038-11-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-11-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-11-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-11-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-11-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-11-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-11-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 323, 'day_of_year() on 2038-11-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-11-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 323, 'doy() on 2038-11-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-11-09 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-09 Gregorian' );
Highday 19 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308556800, 'utc_rd_as_seconds() on 2038-11-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744312,
  0,
  0
]
, 'utc_rd_values() on 2038-11-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-11-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  46
]
, 'week() on 2038-11-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 46, 'week_number() on 2038-11-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-11-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-11-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-11-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-11-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-11-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 324, 'day_of_year() on 2038-11-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-11-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 324, 'doy() on 2038-11-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-11-10 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-10 Gregorian' );
Sterday 20 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308643200, 'utc_rd_as_seconds() on 2038-11-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744313,
  0,
  0
]
, 'utc_rd_values() on 2038-11-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-11-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-11-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-11-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-11-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-11-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-11-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 325, 'day_of_year() on 2038-11-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-11-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 325, 'doy() on 2038-11-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-11-11 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-11 Gregorian' );
Sunday 21 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308729600, 'utc_rd_as_seconds() on 2038-11-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744314,
  0,
  0
]
, 'utc_rd_values() on 2038-11-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-11-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-11-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-11-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-11-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-11-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-11-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 326, 'day_of_year() on 2038-11-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-11-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 326, 'doy() on 2038-11-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-11-12 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-12 Gregorian' );
Monday 22 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308816000, 'utc_rd_as_seconds() on 2038-11-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744315,
  0,
  0
]
, 'utc_rd_values() on 2038-11-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-11-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-11-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-11-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-11-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-11-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-11-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 327, 'day_of_year() on 2038-11-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-11-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 327, 'doy() on 2038-11-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-11-13 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-13 Gregorian' );
Trewsday 23 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308902400, 'utc_rd_as_seconds() on 2038-11-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744316,
  0,
  0
]
, 'utc_rd_values() on 2038-11-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-11-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-11-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-11-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-11-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-11-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-11-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 328, 'day_of_year() on 2038-11-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-11-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 328, 'doy() on 2038-11-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-11-14 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-14 Gregorian' );
Hevensday 24 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64308988800, 'utc_rd_as_seconds() on 2038-11-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744317,
  0,
  0
]
, 'utc_rd_values() on 2038-11-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-11-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-11-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-11-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-11-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-11-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-11-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 329, 'day_of_year() on 2038-11-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-11-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 329, 'doy() on 2038-11-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-11-15 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-15 Gregorian' );
Mersday 25 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309075200, 'utc_rd_as_seconds() on 2038-11-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744318,
  0,
  0
]
, 'utc_rd_values() on 2038-11-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-11-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-11-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-11-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-11-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-11-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-11-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 330, 'day_of_year() on 2038-11-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-11-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 330, 'doy() on 2038-11-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-11-16 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-16 Gregorian' );
Highday 26 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309161600, 'utc_rd_as_seconds() on 2038-11-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744319,
  0,
  0
]
, 'utc_rd_values() on 2038-11-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-11-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  47
]
, 'week() on 2038-11-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 47, 'week_number() on 2038-11-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-11-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-11-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-11-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-11-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-11-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 331, 'day_of_year() on 2038-11-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-11-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 331, 'doy() on 2038-11-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-11-17 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-17 Gregorian' );
Sterday 27 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309248000, 'utc_rd_as_seconds() on 2038-11-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744320,
  0,
  0
]
, 'utc_rd_values() on 2038-11-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-11-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-11-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-11-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-11-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-11-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-11-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 332, 'day_of_year() on 2038-11-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-11-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 332, 'doy() on 2038-11-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-11-18 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-18 Gregorian' );
Sunday 28 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309334400, 'utc_rd_as_seconds() on 2038-11-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744321,
  0,
  0
]
, 'utc_rd_values() on 2038-11-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-11-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-11-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-11-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-11-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-11-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-11-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 333, 'day_of_year() on 2038-11-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-11-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 333, 'doy() on 2038-11-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-11-19 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-19 Gregorian' );
Monday 29 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309420800, 'utc_rd_as_seconds() on 2038-11-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744322,
  0,
  0
]
, 'utc_rd_values() on 2038-11-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-11-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-11-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-11-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-11-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-11-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-11-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 334, 'day_of_year() on 2038-11-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-11-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 334, 'doy() on 2038-11-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-11-20 Gregorian' );
cmp_ok( $dts->month(), '==', 11, 'month() on 2038-11-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Blotmath', 'month_name() on 2038-11-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-20 Gregorian' );
Trewsday 30 Blotmath 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309507200, 'utc_rd_as_seconds() on 2038-11-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744323,
  0,
  0
]
, 'utc_rd_values() on 2038-11-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-11-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-11-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-11-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-11-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-11-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-11-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 335, 'day_of_year() on 2038-11-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-11-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 335, 'doy() on 2038-11-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-11-21 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-21 Gregorian' );
Hevensday 1 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309593600, 'utc_rd_as_seconds() on 2038-11-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744324,
  0,
  0
]
, 'utc_rd_values() on 2038-11-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-11-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-11-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-11-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-11-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-11-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-11-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 336, 'day_of_year() on 2038-11-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-11-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 336, 'doy() on 2038-11-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-11-22 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-22 Gregorian' );
Mersday 2 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309680000, 'utc_rd_as_seconds() on 2038-11-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744325,
  0,
  0
]
, 'utc_rd_values() on 2038-11-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-11-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-11-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-11-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-11-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-11-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-11-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 337, 'day_of_year() on 2038-11-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-11-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 337, 'doy() on 2038-11-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-11-23 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-23 Gregorian' );
Highday 3 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309766400, 'utc_rd_as_seconds() on 2038-11-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744326,
  0,
  0
]
, 'utc_rd_values() on 2038-11-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-11-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  48
]
, 'week() on 2038-11-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 48, 'week_number() on 2038-11-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-11-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-11-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-11-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-11-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-11-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 338, 'day_of_year() on 2038-11-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-11-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 338, 'doy() on 2038-11-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-11-24 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-24 Gregorian' );
Sterday 4 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309852800, 'utc_rd_as_seconds() on 2038-11-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744327,
  0,
  0
]
, 'utc_rd_values() on 2038-11-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-11-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-11-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-11-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-11-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-11-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-11-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 339, 'day_of_year() on 2038-11-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-11-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 339, 'doy() on 2038-11-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-11-25 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-25 Gregorian' );
Sunday 5 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64309939200, 'utc_rd_as_seconds() on 2038-11-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744328,
  0,
  0
]
, 'utc_rd_values() on 2038-11-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-11-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-11-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-11-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-11-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-11-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-11-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 340, 'day_of_year() on 2038-11-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-11-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 340, 'doy() on 2038-11-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-11-26 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-26 Gregorian' );
Monday 6 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310025600, 'utc_rd_as_seconds() on 2038-11-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744329,
  0,
  0
]
, 'utc_rd_values() on 2038-11-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-11-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-11-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-11-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-11-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-11-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-11-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 341, 'day_of_year() on 2038-11-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-11-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 341, 'doy() on 2038-11-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-11-27 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-27 Gregorian' );
Trewsday 7 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310112000, 'utc_rd_as_seconds() on 2038-11-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744330,
  0,
  0
]
, 'utc_rd_values() on 2038-11-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-11-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-11-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-11-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-11-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-11-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-11-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 342, 'day_of_year() on 2038-11-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-11-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 342, 'doy() on 2038-11-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-11-28 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-28 Gregorian' );
Hevensday 8 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310198400, 'utc_rd_as_seconds() on 2038-11-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744331,
  0,
  0
]
, 'utc_rd_values() on 2038-11-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-11-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-11-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-11-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-11-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-11-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-11-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 343, 'day_of_year() on 2038-11-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-11-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 343, 'doy() on 2038-11-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-11-29 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-29 Gregorian' );
Mersday 9 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310284800, 'utc_rd_as_seconds() on 2038-11-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744332,
  0,
  0
]
, 'utc_rd_values() on 2038-11-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-11-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 11 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 11,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 10, 'day() on 2038-11-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-11-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-11-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 10, 'day_of_month() on 2038-11-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-11-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 344, 'day_of_year() on 2038-11-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-11-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 344, 'doy() on 2038-11-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-11-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-11-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-11-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-11-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-11-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 10, 'mday() on 2038-11-30 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-11-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-11-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-11-30 Gregorian' );
Highday 10 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310371200, 'utc_rd_as_seconds() on 2038-11-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744333,
  0,
  0
]
, 'utc_rd_values() on 2038-11-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-11-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  49
]
, 'week() on 2038-11-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 49, 'week_number() on 2038-11-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-11-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-11-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 1, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 1,
    ),
);
cmp_ok( $dts->day(), '==', 11, 'day() on 2038-12-01 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-12-01 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-12-01 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 11, 'day_of_month() on 2038-12-01 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-12-01 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 345, 'day_of_year() on 2038-12-01 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-12-01 Gregorian' );
cmp_ok( $dts->doy(), '==', 345, 'doy() on 2038-12-01 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-01 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-01 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-01 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-01 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-01 Gregorian' );
cmp_ok( $dts->mday(), '==', 11, 'mday() on 2038-12-01 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-01 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-01 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-01 Gregorian' );
Sterday 11 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310457600, 'utc_rd_as_seconds() on 2038-12-01 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744334,
  0,
  0
]
, 'utc_rd_values() on 2038-12-01 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-12-01 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-01 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-01 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-01 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-01 Gregorian' );

$epoch = timegm( 0, 0, 0, 2, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 2,
    ),
);
cmp_ok( $dts->day(), '==', 12, 'day() on 2038-12-02 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-12-02 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-12-02 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 12, 'day_of_month() on 2038-12-02 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-12-02 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 346, 'day_of_year() on 2038-12-02 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-12-02 Gregorian' );
cmp_ok( $dts->doy(), '==', 346, 'doy() on 2038-12-02 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-02 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-02 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-02 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-02 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-02 Gregorian' );
cmp_ok( $dts->mday(), '==', 12, 'mday() on 2038-12-02 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-02 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-02 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-02 Gregorian' );
Sunday 12 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310544000, 'utc_rd_as_seconds() on 2038-12-02 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744335,
  0,
  0
]
, 'utc_rd_values() on 2038-12-02 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-12-02 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-02 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-02 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-02 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-02 Gregorian' );

$epoch = timegm( 0, 0, 0, 3, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 3,
    ),
);
cmp_ok( $dts->day(), '==', 13, 'day() on 2038-12-03 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-12-03 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-12-03 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 13, 'day_of_month() on 2038-12-03 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-12-03 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 347, 'day_of_year() on 2038-12-03 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-12-03 Gregorian' );
cmp_ok( $dts->doy(), '==', 347, 'doy() on 2038-12-03 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-03 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-03 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-03 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-03 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-03 Gregorian' );
cmp_ok( $dts->mday(), '==', 13, 'mday() on 2038-12-03 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-03 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-03 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-03 Gregorian' );
Monday 13 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310630400, 'utc_rd_as_seconds() on 2038-12-03 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744336,
  0,
  0
]
, 'utc_rd_values() on 2038-12-03 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-12-03 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-03 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-03 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-03 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-03 Gregorian' );

$epoch = timegm( 0, 0, 0, 4, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 4,
    ),
);
cmp_ok( $dts->day(), '==', 14, 'day() on 2038-12-04 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-12-04 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-12-04 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 14, 'day_of_month() on 2038-12-04 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-12-04 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 348, 'day_of_year() on 2038-12-04 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-12-04 Gregorian' );
cmp_ok( $dts->doy(), '==', 348, 'doy() on 2038-12-04 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-04 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-04 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-04 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-04 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-04 Gregorian' );
cmp_ok( $dts->mday(), '==', 14, 'mday() on 2038-12-04 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-04 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-04 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-04 Gregorian' );
Trewsday 14 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310716800, 'utc_rd_as_seconds() on 2038-12-04 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744337,
  0,
  0
]
, 'utc_rd_values() on 2038-12-04 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-12-04 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-04 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-04 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-04 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-04 Gregorian' );

$epoch = timegm( 0, 0, 0, 5, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 5,
    ),
);
cmp_ok( $dts->day(), '==', 15, 'day() on 2038-12-05 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-12-05 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-12-05 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 15, 'day_of_month() on 2038-12-05 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-12-05 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 349, 'day_of_year() on 2038-12-05 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-12-05 Gregorian' );
cmp_ok( $dts->doy(), '==', 349, 'doy() on 2038-12-05 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-05 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-05 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-05 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-05 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-05 Gregorian' );
cmp_ok( $dts->mday(), '==', 15, 'mday() on 2038-12-05 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-05 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-05 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-05 Gregorian' );
Hevensday 15 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310803200, 'utc_rd_as_seconds() on 2038-12-05 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744338,
  0,
  0
]
, 'utc_rd_values() on 2038-12-05 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-12-05 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-05 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-05 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-05 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-05 Gregorian' );

$epoch = timegm( 0, 0, 0, 6, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 6,
    ),
);
cmp_ok( $dts->day(), '==', 16, 'day() on 2038-12-06 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-12-06 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-12-06 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 16, 'day_of_month() on 2038-12-06 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-12-06 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 350, 'day_of_year() on 2038-12-06 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-12-06 Gregorian' );
cmp_ok( $dts->doy(), '==', 350, 'doy() on 2038-12-06 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-06 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-06 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-06 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-06 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-06 Gregorian' );
cmp_ok( $dts->mday(), '==', 16, 'mday() on 2038-12-06 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-06 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-06 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-06 Gregorian' );
Mersday 16 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310889600, 'utc_rd_as_seconds() on 2038-12-06 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744339,
  0,
  0
]
, 'utc_rd_values() on 2038-12-06 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-12-06 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-06 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-06 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-06 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-06 Gregorian' );

$epoch = timegm( 0, 0, 0, 7, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 7,
    ),
);
cmp_ok( $dts->day(), '==', 17, 'day() on 2038-12-07 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-12-07 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-12-07 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 17, 'day_of_month() on 2038-12-07 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-12-07 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 351, 'day_of_year() on 2038-12-07 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-12-07 Gregorian' );
cmp_ok( $dts->doy(), '==', 351, 'doy() on 2038-12-07 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-07 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-07 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-07 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-07 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-07 Gregorian' );
cmp_ok( $dts->mday(), '==', 17, 'mday() on 2038-12-07 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-07 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-07 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-07 Gregorian' );
Highday 17 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64310976000, 'utc_rd_as_seconds() on 2038-12-07 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744340,
  0,
  0
]
, 'utc_rd_values() on 2038-12-07 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-12-07 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  50
]
, 'week() on 2038-12-07 Gregorian' );
cmp_ok( $dts->week_number(), '==', 50, 'week_number() on 2038-12-07 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-07 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-07 Gregorian' );

$epoch = timegm( 0, 0, 0, 8, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 8,
    ),
);
cmp_ok( $dts->day(), '==', 18, 'day() on 2038-12-08 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-12-08 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-12-08 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 18, 'day_of_month() on 2038-12-08 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-12-08 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 352, 'day_of_year() on 2038-12-08 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-12-08 Gregorian' );
cmp_ok( $dts->doy(), '==', 352, 'doy() on 2038-12-08 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-08 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-08 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-08 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-08 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-08 Gregorian' );
cmp_ok( $dts->mday(), '==', 18, 'mday() on 2038-12-08 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-08 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-08 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-08 Gregorian' );
Sterday 18 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311062400, 'utc_rd_as_seconds() on 2038-12-08 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744341,
  0,
  0
]
, 'utc_rd_values() on 2038-12-08 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-12-08 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-08 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-08 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-08 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-08 Gregorian' );

$epoch = timegm( 0, 0, 0, 9, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 9,
    ),
);
cmp_ok( $dts->day(), '==', 19, 'day() on 2038-12-09 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-12-09 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-12-09 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 19, 'day_of_month() on 2038-12-09 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-12-09 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 353, 'day_of_year() on 2038-12-09 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-12-09 Gregorian' );
cmp_ok( $dts->doy(), '==', 353, 'doy() on 2038-12-09 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-09 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-09 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-09 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-09 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-09 Gregorian' );
cmp_ok( $dts->mday(), '==', 19, 'mday() on 2038-12-09 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-09 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-09 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-09 Gregorian' );
Sunday 19 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311148800, 'utc_rd_as_seconds() on 2038-12-09 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744342,
  0,
  0
]
, 'utc_rd_values() on 2038-12-09 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-12-09 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-09 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-09 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-09 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-09 Gregorian' );

$epoch = timegm( 0, 0, 0, 10, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 10,
    ),
);
cmp_ok( $dts->day(), '==', 20, 'day() on 2038-12-10 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-12-10 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-12-10 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 20, 'day_of_month() on 2038-12-10 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-12-10 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 354, 'day_of_year() on 2038-12-10 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-12-10 Gregorian' );
cmp_ok( $dts->doy(), '==', 354, 'doy() on 2038-12-10 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-10 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-10 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-10 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-10 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-10 Gregorian' );
cmp_ok( $dts->mday(), '==', 20, 'mday() on 2038-12-10 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-10 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-10 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-10 Gregorian' );
Monday 20 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311235200, 'utc_rd_as_seconds() on 2038-12-10 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744343,
  0,
  0
]
, 'utc_rd_values() on 2038-12-10 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-12-10 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-10 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-10 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-10 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-10 Gregorian' );

$epoch = timegm( 0, 0, 0, 11, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 11,
    ),
);
cmp_ok( $dts->day(), '==', 21, 'day() on 2038-12-11 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-12-11 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-12-11 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 21, 'day_of_month() on 2038-12-11 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-12-11 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 355, 'day_of_year() on 2038-12-11 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-12-11 Gregorian' );
cmp_ok( $dts->doy(), '==', 355, 'doy() on 2038-12-11 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-11 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-11 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-11 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-11 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-11 Gregorian' );
cmp_ok( $dts->mday(), '==', 21, 'mday() on 2038-12-11 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-11 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-11 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-11 Gregorian' );
Trewsday 21 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311321600, 'utc_rd_as_seconds() on 2038-12-11 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744344,
  0,
  0
]
, 'utc_rd_values() on 2038-12-11 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-12-11 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-11 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-11 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-11 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-11 Gregorian' );

$epoch = timegm( 0, 0, 0, 12, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 12,
    ),
);
cmp_ok( $dts->day(), '==', 22, 'day() on 2038-12-12 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-12-12 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-12-12 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 22, 'day_of_month() on 2038-12-12 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-12-12 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 356, 'day_of_year() on 2038-12-12 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-12-12 Gregorian' );
cmp_ok( $dts->doy(), '==', 356, 'doy() on 2038-12-12 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-12 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-12 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-12 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-12 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-12 Gregorian' );
cmp_ok( $dts->mday(), '==', 22, 'mday() on 2038-12-12 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-12 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-12 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-12 Gregorian' );
Hevensday 22 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311408000, 'utc_rd_as_seconds() on 2038-12-12 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744345,
  0,
  0
]
, 'utc_rd_values() on 2038-12-12 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-12-12 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-12 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-12 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-12 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-12 Gregorian' );

$epoch = timegm( 0, 0, 0, 13, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 13,
    ),
);
cmp_ok( $dts->day(), '==', 23, 'day() on 2038-12-13 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-12-13 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-12-13 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 23, 'day_of_month() on 2038-12-13 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-12-13 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 357, 'day_of_year() on 2038-12-13 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-12-13 Gregorian' );
cmp_ok( $dts->doy(), '==', 357, 'doy() on 2038-12-13 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-13 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-13 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-13 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-13 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-13 Gregorian' );
cmp_ok( $dts->mday(), '==', 23, 'mday() on 2038-12-13 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-13 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-13 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-13 Gregorian' );
Mersday 23 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311494400, 'utc_rd_as_seconds() on 2038-12-13 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744346,
  0,
  0
]
, 'utc_rd_values() on 2038-12-13 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-12-13 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-13 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-13 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-13 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-13 Gregorian' );

$epoch = timegm( 0, 0, 0, 14, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 14,
    ),
);
cmp_ok( $dts->day(), '==', 24, 'day() on 2038-12-14 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-12-14 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-12-14 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 24, 'day_of_month() on 2038-12-14 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-12-14 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 358, 'day_of_year() on 2038-12-14 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-12-14 Gregorian' );
cmp_ok( $dts->doy(), '==', 358, 'doy() on 2038-12-14 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-14 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-14 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-14 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-14 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-14 Gregorian' );
cmp_ok( $dts->mday(), '==', 24, 'mday() on 2038-12-14 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-14 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-14 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-14 Gregorian' );
Highday 24 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311580800, 'utc_rd_as_seconds() on 2038-12-14 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744347,
  0,
  0
]
, 'utc_rd_values() on 2038-12-14 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-12-14 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  51
]
, 'week() on 2038-12-14 Gregorian' );
cmp_ok( $dts->week_number(), '==', 51, 'week_number() on 2038-12-14 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-14 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-14 Gregorian' );

$epoch = timegm( 0, 0, 0, 15, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 15,
    ),
);
cmp_ok( $dts->day(), '==', 25, 'day() on 2038-12-15 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-12-15 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-12-15 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 25, 'day_of_month() on 2038-12-15 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-12-15 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 359, 'day_of_year() on 2038-12-15 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-12-15 Gregorian' );
cmp_ok( $dts->doy(), '==', 359, 'doy() on 2038-12-15 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-15 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-15 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-15 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-15 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-15 Gregorian' );
cmp_ok( $dts->mday(), '==', 25, 'mday() on 2038-12-15 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-15 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-15 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-15 Gregorian' );
Sterday 25 Foreyule 7502

The Company of the Ring leaves Rivendell at dusk, 1418.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311667200, 'utc_rd_as_seconds() on 2038-12-15 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744348,
  0,
  0
]
, 'utc_rd_values() on 2038-12-15 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-12-15 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-15 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-15 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-15 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-15 Gregorian' );

$epoch = timegm( 0, 0, 0, 16, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 16,
    ),
);
cmp_ok( $dts->day(), '==', 26, 'day() on 2038-12-16 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-12-16 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-12-16 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 26, 'day_of_month() on 2038-12-16 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-12-16 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 360, 'day_of_year() on 2038-12-16 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-12-16 Gregorian' );
cmp_ok( $dts->doy(), '==', 360, 'doy() on 2038-12-16 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-16 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-16 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-16 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-16 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-16 Gregorian' );
cmp_ok( $dts->mday(), '==', 26, 'mday() on 2038-12-16 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-16 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-16 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-16 Gregorian' );
Sunday 26 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311753600, 'utc_rd_as_seconds() on 2038-12-16 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744349,
  0,
  0
]
, 'utc_rd_values() on 2038-12-16 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-12-16 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-16 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-16 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-16 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-16 Gregorian' );

$epoch = timegm( 0, 0, 0, 17, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 17,
    ),
);
cmp_ok( $dts->day(), '==', 27, 'day() on 2038-12-17 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-12-17 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-12-17 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 27, 'day_of_month() on 2038-12-17 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-12-17 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 361, 'day_of_year() on 2038-12-17 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-12-17 Gregorian' );
cmp_ok( $dts->doy(), '==', 361, 'doy() on 2038-12-17 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-17 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-17 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-17 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-17 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-17 Gregorian' );
cmp_ok( $dts->mday(), '==', 27, 'mday() on 2038-12-17 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-17 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-17 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-17 Gregorian' );
Monday 27 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311840000, 'utc_rd_as_seconds() on 2038-12-17 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744350,
  0,
  0
]
, 'utc_rd_values() on 2038-12-17 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-12-17 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-17 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-17 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-17 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-17 Gregorian' );

$epoch = timegm( 0, 0, 0, 18, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 18,
    ),
);
cmp_ok( $dts->day(), '==', 28, 'day() on 2038-12-18 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-12-18 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-12-18 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 28, 'day_of_month() on 2038-12-18 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-12-18 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 362, 'day_of_year() on 2038-12-18 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-12-18 Gregorian' );
cmp_ok( $dts->doy(), '==', 362, 'doy() on 2038-12-18 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-18 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-18 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-18 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-18 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-18 Gregorian' );
cmp_ok( $dts->mday(), '==', 28, 'mday() on 2038-12-18 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-18 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-18 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-18 Gregorian' );
Trewsday 28 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64311926400, 'utc_rd_as_seconds() on 2038-12-18 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744351,
  0,
  0
]
, 'utc_rd_values() on 2038-12-18 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-12-18 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-18 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-18 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-18 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-18 Gregorian' );

$epoch = timegm( 0, 0, 0, 19, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 19,
    ),
);
cmp_ok( $dts->day(), '==', 29, 'day() on 2038-12-19 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-12-19 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-12-19 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 29, 'day_of_month() on 2038-12-19 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-12-19 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 363, 'day_of_year() on 2038-12-19 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-12-19 Gregorian' );
cmp_ok( $dts->doy(), '==', 363, 'doy() on 2038-12-19 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-19 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-19 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-19 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-19 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-19 Gregorian' );
cmp_ok( $dts->mday(), '==', 29, 'mday() on 2038-12-19 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-19 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-19 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-19 Gregorian' );
Hevensday 29 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312012800, 'utc_rd_as_seconds() on 2038-12-19 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744352,
  0,
  0
]
, 'utc_rd_values() on 2038-12-19 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-12-19 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-19 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-19 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-19 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-19 Gregorian' );

$epoch = timegm( 0, 0, 0, 20, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 20,
    ),
);
cmp_ok( $dts->day(), '==', 30, 'day() on 2038-12-20 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-12-20 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-12-20 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 30, 'day_of_month() on 2038-12-20 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-12-20 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 364, 'day_of_year() on 2038-12-20 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-12-20 Gregorian' );
cmp_ok( $dts->doy(), '==', 364, 'doy() on 2038-12-20 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-20 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-20 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-20 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-20 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-20 Gregorian' );
cmp_ok( $dts->mday(), '==', 30, 'mday() on 2038-12-20 Gregorian' );
cmp_ok( $dts->month(), '==', 12, 'month() on 2038-12-20 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Foreyule', 'month_name() on 2038-12-20 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-20 Gregorian' );
Mersday 30 Foreyule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312099200, 'utc_rd_as_seconds() on 2038-12-20 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744353,
  0,
  0
]
, 'utc_rd_values() on 2038-12-20 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-12-20 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-20 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-20 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-20 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-20 Gregorian' );

$epoch = timegm( 0, 0, 0, 21, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 21,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2038-12-21 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-12-21 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-12-21 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2038-12-21 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-12-21 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 365, 'day_of_year() on 2038-12-21 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-12-21 Gregorian' );
cmp_ok( $dts->doy(), '==', 365, 'doy() on 2038-12-21 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-21 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-21 Gregorian' );
cmp_ok( $dts->holiday(), '==', 6, 'holiday() on 2038-12-21 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '1 Yule', 'holiday_name() on 2038-12-21 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-21 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2038-12-21 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2038-12-21 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2038-12-21 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-21 Gregorian' );
Highday 1 Yule 7502
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312185600, 'utc_rd_as_seconds() on 2038-12-21 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744354,
  0,
  0
]
, 'utc_rd_values() on 2038-12-21 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-12-21 Gregorian' );
is_deeply( [ $dts->week() ], [
  7502,
  52
]
, 'week() on 2038-12-21 Gregorian' );
cmp_ok( $dts->week_number(), '==', 52, 'week_number() on 2038-12-21 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7502, 'week_year() on 2038-12-21 Gregorian' );
cmp_ok( $dts->year(), '==', 7502, 'year() on 2038-12-21 Gregorian' );

$epoch = timegm( 0, 0, 0, 22, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 22,
    ),
);
cmp_ok( $dts->day(), '==', 0, 'day() on 2038-12-22 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-12-22 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-12-22 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 0, 'day_of_month() on 2038-12-22 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-12-22 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 1, 'day_of_year() on 2038-12-22 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-12-22 Gregorian' );
cmp_ok( $dts->doy(), '==', 1, 'doy() on 2038-12-22 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-22 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-22 Gregorian' );
cmp_ok( $dts->holiday(), '==', 1, 'holiday() on 2038-12-22 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '2 Yule', 'holiday_name() on 2038-12-22 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-22 Gregorian' );
cmp_ok( $dts->mday(), '==', 0, 'mday() on 2038-12-22 Gregorian' );
cmp_ok( $dts->month(), '==', 0, 'month() on 2038-12-22 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', '', 'month_name() on 2038-12-22 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-22 Gregorian' );
Sterday 2 Yule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312272000, 'utc_rd_as_seconds() on 2038-12-22 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744355,
  0,
  0
]
, 'utc_rd_values() on 2038-12-22 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-12-22 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-22 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-22 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-22 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-22 Gregorian' );

$epoch = timegm( 0, 0, 0, 23, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 23,
    ),
);
cmp_ok( $dts->day(), '==', 1, 'day() on 2038-12-23 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-12-23 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-12-23 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 1, 'day_of_month() on 2038-12-23 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-12-23 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 2, 'day_of_year() on 2038-12-23 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-12-23 Gregorian' );
cmp_ok( $dts->doy(), '==', 2, 'doy() on 2038-12-23 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-23 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-23 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-23 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-23 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-23 Gregorian' );
cmp_ok( $dts->mday(), '==', 1, 'mday() on 2038-12-23 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-23 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-23 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-23 Gregorian' );
Sunday 1 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312358400, 'utc_rd_as_seconds() on 2038-12-23 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744356,
  0,
  0
]
, 'utc_rd_values() on 2038-12-23 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-12-23 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-23 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-23 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-23 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-23 Gregorian' );

$epoch = timegm( 0, 0, 0, 24, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 24,
    ),
);
cmp_ok( $dts->day(), '==', 2, 'day() on 2038-12-24 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-12-24 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-12-24 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 2, 'day_of_month() on 2038-12-24 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-12-24 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 3, 'day_of_year() on 2038-12-24 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-12-24 Gregorian' );
cmp_ok( $dts->doy(), '==', 3, 'doy() on 2038-12-24 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-24 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-24 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-24 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-24 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-24 Gregorian' );
cmp_ok( $dts->mday(), '==', 2, 'mday() on 2038-12-24 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-24 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-24 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-24 Gregorian' );
Monday 2 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312444800, 'utc_rd_as_seconds() on 2038-12-24 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744357,
  0,
  0
]
, 'utc_rd_values() on 2038-12-24 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-12-24 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-24 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-24 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-24 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-24 Gregorian' );

$epoch = timegm( 0, 0, 0, 25, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 25,
    ),
);
cmp_ok( $dts->day(), '==', 3, 'day() on 2038-12-25 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Trewsday', 'day_name() on 2038-12-25 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Trewesdei', 'day_name_trad() on 2038-12-25 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 3, 'day_of_month() on 2038-12-25 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 4, 'day_of_week() on 2038-12-25 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 4, 'day_of_year() on 2038-12-25 Gregorian' );
cmp_ok( $dts->dow(), '==', 4, 'dow() on 2038-12-25 Gregorian' );
cmp_ok( $dts->doy(), '==', 4, 'doy() on 2038-12-25 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-25 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-25 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-25 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-25 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-25 Gregorian' );
cmp_ok( $dts->mday(), '==', 3, 'mday() on 2038-12-25 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-25 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-25 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-25 Gregorian' );
Trewsday 3 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312531200, 'utc_rd_as_seconds() on 2038-12-25 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744358,
  0,
  0
]
, 'utc_rd_values() on 2038-12-25 Gregorian' );
cmp_ok( $dts->wday(), '==', 4, 'wday() on 2038-12-25 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-25 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-25 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-25 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-25 Gregorian' );

$epoch = timegm( 0, 0, 0, 26, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 26,
    ),
);
cmp_ok( $dts->day(), '==', 4, 'day() on 2038-12-26 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Hevensday', 'day_name() on 2038-12-26 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Hevenesdei', 'day_name_trad() on 2038-12-26 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 4, 'day_of_month() on 2038-12-26 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 5, 'day_of_week() on 2038-12-26 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 5, 'day_of_year() on 2038-12-26 Gregorian' );
cmp_ok( $dts->dow(), '==', 5, 'dow() on 2038-12-26 Gregorian' );
cmp_ok( $dts->doy(), '==', 5, 'doy() on 2038-12-26 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-26 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-26 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-26 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-26 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-26 Gregorian' );
cmp_ok( $dts->mday(), '==', 4, 'mday() on 2038-12-26 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-26 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-26 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-26 Gregorian' );
Hevensday 4 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312617600, 'utc_rd_as_seconds() on 2038-12-26 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744359,
  0,
  0
]
, 'utc_rd_values() on 2038-12-26 Gregorian' );
cmp_ok( $dts->wday(), '==', 5, 'wday() on 2038-12-26 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-26 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-26 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-26 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-26 Gregorian' );

$epoch = timegm( 0, 0, 0, 27, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 27,
    ),
);
cmp_ok( $dts->day(), '==', 5, 'day() on 2038-12-27 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Mersday', 'day_name() on 2038-12-27 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Meresdei', 'day_name_trad() on 2038-12-27 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 5, 'day_of_month() on 2038-12-27 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 6, 'day_of_week() on 2038-12-27 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 6, 'day_of_year() on 2038-12-27 Gregorian' );
cmp_ok( $dts->dow(), '==', 6, 'dow() on 2038-12-27 Gregorian' );
cmp_ok( $dts->doy(), '==', 6, 'doy() on 2038-12-27 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-27 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-27 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-27 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-27 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-27 Gregorian' );
cmp_ok( $dts->mday(), '==', 5, 'mday() on 2038-12-27 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-27 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-27 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-27 Gregorian' );
Mersday 5 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312704000, 'utc_rd_as_seconds() on 2038-12-27 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744360,
  0,
  0
]
, 'utc_rd_values() on 2038-12-27 Gregorian' );
cmp_ok( $dts->wday(), '==', 6, 'wday() on 2038-12-27 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-27 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-27 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-27 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-27 Gregorian' );

$epoch = timegm( 0, 0, 0, 28, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 28,
    ),
);
cmp_ok( $dts->day(), '==', 6, 'day() on 2038-12-28 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Highday', 'day_name() on 2038-12-28 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Highdei', 'day_name_trad() on 2038-12-28 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 6, 'day_of_month() on 2038-12-28 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 7, 'day_of_week() on 2038-12-28 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 7, 'day_of_year() on 2038-12-28 Gregorian' );
cmp_ok( $dts->dow(), '==', 7, 'dow() on 2038-12-28 Gregorian' );
cmp_ok( $dts->doy(), '==', 7, 'doy() on 2038-12-28 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-28 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-28 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-28 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-28 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-28 Gregorian' );
cmp_ok( $dts->mday(), '==', 6, 'mday() on 2038-12-28 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-28 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-28 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-28 Gregorian' );
Highday 6 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312790400, 'utc_rd_as_seconds() on 2038-12-28 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744361,
  0,
  0
]
, 'utc_rd_values() on 2038-12-28 Gregorian' );
cmp_ok( $dts->wday(), '==', 7, 'wday() on 2038-12-28 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  1
]
, 'week() on 2038-12-28 Gregorian' );
cmp_ok( $dts->week_number(), '==', 1, 'week_number() on 2038-12-28 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-28 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-28 Gregorian' );

$epoch = timegm( 0, 0, 0, 29, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 29,
    ),
);
cmp_ok( $dts->day(), '==', 7, 'day() on 2038-12-29 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sterday', 'day_name() on 2038-12-29 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sterrendei', 'day_name_trad() on 2038-12-29 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 7, 'day_of_month() on 2038-12-29 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 1, 'day_of_week() on 2038-12-29 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 8, 'day_of_year() on 2038-12-29 Gregorian' );
cmp_ok( $dts->dow(), '==', 1, 'dow() on 2038-12-29 Gregorian' );
cmp_ok( $dts->doy(), '==', 8, 'doy() on 2038-12-29 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-29 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-29 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-29 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-29 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-29 Gregorian' );
cmp_ok( $dts->mday(), '==', 7, 'mday() on 2038-12-29 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-29 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-29 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-29 Gregorian' );
Sterday 7 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312876800, 'utc_rd_as_seconds() on 2038-12-29 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744362,
  0,
  0
]
, 'utc_rd_values() on 2038-12-29 Gregorian' );
cmp_ok( $dts->wday(), '==', 1, 'wday() on 2038-12-29 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  2
]
, 'week() on 2038-12-29 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-12-29 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-29 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-29 Gregorian' );

$epoch = timegm( 0, 0, 0, 30, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 30,
    ),
);
cmp_ok( $dts->day(), '==', 8, 'day() on 2038-12-30 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Sunday', 'day_name() on 2038-12-30 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Sunnendei', 'day_name_trad() on 2038-12-30 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 8, 'day_of_month() on 2038-12-30 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 2, 'day_of_week() on 2038-12-30 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 9, 'day_of_year() on 2038-12-30 Gregorian' );
cmp_ok( $dts->dow(), '==', 2, 'dow() on 2038-12-30 Gregorian' );
cmp_ok( $dts->doy(), '==', 9, 'doy() on 2038-12-30 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-30 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-30 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-30 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-30 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-30 Gregorian' );
cmp_ok( $dts->mday(), '==', 8, 'mday() on 2038-12-30 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-30 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-30 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-30 Gregorian' );
Sunday 8 Afteryule 7503

The Company of the Ring reaches Hollin, 1419.
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64312963200, 'utc_rd_as_seconds() on 2038-12-30 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744363,
  0,
  0
]
, 'utc_rd_values() on 2038-12-30 Gregorian' );
cmp_ok( $dts->wday(), '==', 2, 'wday() on 2038-12-30 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  2
]
, 'week() on 2038-12-30 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-12-30 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-30 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-30 Gregorian' );

$epoch = timegm( 0, 0, 0, 31, 12 - 1, 2038 );
$dts = DateTime::Fiction::JRRTolkien::Shire->from_object(
    object	=> DateTime->new(
	year	=> 2038,
	month	=> 12,
	day	=> 31,
    ),
);
cmp_ok( $dts->day(), '==', 9, 'day() on 2038-12-31 Gregorian' );
cmp_ok( $dts->day_name(), 'eq', 'Monday', 'day_name() on 2038-12-31 Gregorian' );
cmp_ok( $dts->day_name_trad(), 'eq', 'Monendei', 'day_name_trad() on 2038-12-31 Gregorian' );
cmp_ok( $dts->day_of_month(), '==', 9, 'day_of_month() on 2038-12-31 Gregorian' );
cmp_ok( $dts->day_of_week(), '==', 3, 'day_of_week() on 2038-12-31 Gregorian' );
cmp_ok( $dts->day_of_year(), '==', 10, 'day_of_year() on 2038-12-31 Gregorian' );
cmp_ok( $dts->dow(), '==', 3, 'dow() on 2038-12-31 Gregorian' );
cmp_ok( $dts->doy(), '==', 10, 'doy() on 2038-12-31 Gregorian' );
cmp_ok( $dts->epoch(), '==', $epoch, 'epoch() on 2038-12-31 Gregorian' );
cmp_ok( $dts->hires_epoch(), '==', $epoch, 'hires_epoch() on 2038-12-31 Gregorian' );
cmp_ok( $dts->holiday(), '==', 0, 'holiday() on 2038-12-31 Gregorian' );
cmp_ok( $dts->holiday_name(), 'eq', '', 'holiday_name() on 2038-12-31 Gregorian' );
cmp_ok( $dts->is_leap_year(), '==', 0, 'is_leap_year() on 2038-12-31 Gregorian' );
cmp_ok( $dts->mday(), '==', 9, 'mday() on 2038-12-31 Gregorian' );
cmp_ok( $dts->month(), '==', 1, 'month() on 2038-12-31 Gregorian' );
cmp_ok( $dts->month_name(), 'eq', 'Afteryule', 'month_name() on 2038-12-31 Gregorian' );
cmp_ok( $dts->on_date(), 'eq', <<'EOT', 'on_date() on 2038-12-31 Gregorian' );
Monday 9 Afteryule 7503
EOT
cmp_ok( $dts->utc_rd_as_seconds(), '==', 64313049600, 'utc_rd_as_seconds() on 2038-12-31 Gregorian' );
is_deeply( [ $dts->utc_rd_values() ], [
  744364,
  0,
  0
]
, 'utc_rd_values() on 2038-12-31 Gregorian' );
cmp_ok( $dts->wday(), '==', 3, 'wday() on 2038-12-31 Gregorian' );
is_deeply( [ $dts->week() ], [
  7503,
  2
]
, 'week() on 2038-12-31 Gregorian' );
cmp_ok( $dts->week_number(), '==', 2, 'week_number() on 2038-12-31 Gregorian' );
cmp_ok( $dts->week_year(), '==', 7503, 'week_year() on 2038-12-31 Gregorian' );
cmp_ok( $dts->year(), '==', 7503, 'year() on 2038-12-31 Gregorian' );

1;

# ex: set textwidth=72 :
